@@ -58,8 +58,8 @@ public class SWT_AWT {
 
 	static boolean loaded, swingInitialized;
 
-	static native final long /*int*/ getAWTHandle (Canvas canvas);
-	static native final Object initFrame (long /*int*/ handle, String className);
+	static native final long getAWTHandle (Canvas canvas);
+	static native final Object initFrame (long handle, String className);
 	static native final void validateWithBounds (Frame frame, int x, int y, int w, int h);
 	static native final void synthesizeWindowActivation (Frame frame, boolean doActivate);
 
@@ -137,7 +137,7 @@ public static Frame new_Frame(final Composite parent) {
 	if ((parent.getStyle() & SWT.EMBEDDED) == 0) {
 		SWT.error(SWT.ERROR_INVALID_ARGUMENT);
 	}
-	final long /*int*/ handle = parent.view.id;
+	final long handle = parent.view.id;
 	final String className = embeddedFrameClass != null ? embeddedFrameClass : JDK17_FRAME;
 	try {
 		if (embeddedFrameClass != null) {
@@ -178,7 +178,7 @@ public static Frame new_Frame(final Composite parent) {
 		EventQueue.invokeLater(runnable);
 		Display display = parent.getDisplay();
 		while (result[0] == null && exception[0] == null) {
-			display.setData(RUN_AWT_INVOKE_LATER_KEY, new Boolean (true));
+			display.setData(RUN_AWT_INVOKE_LATER_KEY, true);
 			Boolean invoked = (Boolean)display.getData(RUN_AWT_INVOKE_LATER_KEY);
 			if (invoked != null && !invoked.booleanValue()) {
 				runnable.run();
@@ -311,7 +311,7 @@ public static Frame new_Frame(final Composite parent) {
 public static Shell new_Shell(final Display display, final Canvas parent) {
 	if (display == null) SWT.error (SWT.ERROR_NULL_ARGUMENT);
 	if (parent == null) SWT.error (SWT.ERROR_NULL_ARGUMENT);
-	long /*int*/ handle = 0;
+	long handle = 0;
 
 	try {
 		loadLibrary ();
