@@ -34,7 +34,7 @@ import org.eclipse.swt.widgets.*;
  * The DropTarget can receive data from within the same application or from other applications
  * (such as text dragged from a text editor like Word).</p>
  *
- * <code><pre>
+ * <pre><code>
  *	int operations = DND.DROP_MOVE | DND.DROP_COPY | DND.DROP_LINK;
  *	Transfer[] types = new Transfer[] {TextTransfer.getInstance()};
  *	DropTarget target = new DropTarget(label, operations);
@@ -48,7 +48,7 @@ import org.eclipse.swt.widgets.*;
  * <code>event.currentDataType</code> field.  When the data is dropped, it is the responsibility of
  * the application to copy this data for its own purposes.
  *
- * <code><pre>
+ * <pre><code>
  *	target.addDropListener (new DropTargetListener() {
  *		public void dragEnter(DropTargetEvent event) {};
  *		public void dragOver(DropTargetEvent event) {};
@@ -64,7 +64,7 @@ import org.eclipse.swt.widgets.*;
  *			label.setText ((String) event.data); // data copied to label text
  *		}
  * 	});
- * </pre></code>
+ * </code></pre>
  *
  * <dl>
  *	<dt><b>Styles</b></dt> <dd>DND.DROP_NONE, DND.DROP_COPY, DND.DROP_MOVE, DND.DROP_LINK</dd>
@@ -81,7 +81,7 @@ import org.eclipse.swt.widgets.*;
 public class DropTarget extends Widget {
 
 	static Callback dropTarget2Args, dropTarget3Args, dropTarget6Args;
-	static long /*int*/ proc2Args, proc3Args, proc6Args;
+	static long proc2Args, proc3Args, proc6Args;
 	static final String LOCK_CURSOR = "org.eclipse.swt.internal.lockCursor"; //$NON-NLS-1$
 
 	static {
@@ -124,27 +124,27 @@ void addDragHandlers() {
 	// the types with the Control's NSView and AppKit will call the methods in the protocol
 	// when a drag goes over the view.
 
-	long /*int*/ cls = OS.object_getClass(control.view.id);
+	long cls = OS.object_getClass(control.view.id);
 
 	if (cls == 0) {
 		DND.error(DND.ERROR_CANNOT_INIT_DROP);
 	}
 
 	// If we already added it, no need to do it again.
-	long /*int*/ procPtr = OS.class_getMethodImplementation(cls, OS.sel_draggingEntered_);
+	long procPtr = OS.class_getMethodImplementation(cls, OS.sel_draggingEntered_);
 	if (procPtr == proc3Args) return;
 	addDragHandlers(cls);
 
 	// If the content view can be image view, then add the dragging methods to image view too.
 	// This is used by Label so that dragging can work even when the Label has an image set on it.
-	long /*int*/ imageView = 0;
+	long imageView = 0;
 	if ((imageView = OS.objc_msgSend(control.view.id, OS.sel_getImageView)) != 0) {
 		cls = OS.object_getClass(imageView);
 		addDragHandlers(cls);
 	}
 }
 
-void addDragHandlers (long /*int*/ cls) {
+void addDragHandlers (long cls) {
 	// Add the NSDraggingDestination callbacks
 	OS.class_addMethod(cls, OS.sel_draggingEntered_, proc3Args, "@:@");
 	OS.class_addMethod(cls, OS.sel_draggingUpdated_, proc3Args, "@:@");
@@ -167,7 +167,7 @@ void addDragHandlers (long /*int*/ cls) {
  * it one of the messages defined in the <code>DropTargetListener</code>
  * interface.
  *
- * <p><ul>
+ * <ul>
  * <li><code>dragEnter</code> is called when the cursor has entered the drop target boundaries
  * <li><code>dragLeave</code> is called when the cursor has left the drop target boundaries and just before
  * the drop occurs or is cancelled.
@@ -177,7 +177,7 @@ void addDragHandlers (long /*int*/ cls) {
  * <li><code>dropAccept</code> is called just before the drop is performed.  The drop target is given
  * the chance to change the nature of the drop or veto the drop by setting the <code>event.detail</code> field
  * <li><code>drop</code> is called when the data is being dropped
- * </ul></p>
+ * </ul>
  *
  * @param listener the listener which should be notified
  *
@@ -206,7 +206,7 @@ public void addDropListener(DropTargetListener listener) {
 	addListener (DND.DropAccept, typedListener);
 }
 
-long /*int*/ dndCallSuper (long /*int*/ id, long /*int*/ sel, long /*int*/ arg0) {
+long dndCallSuper (long id, long sel, long arg0) {
 	objc_super super_struct = new objc_super();
 	super_struct.receiver = id;
 	super_struct.super_class = OS.objc_msgSend(id, OS.sel_superclass);
@@ -227,7 +227,7 @@ protected void checkSubclass () {
 	}
 }
 
-int draggingEntered(long /*int*/ id, long /*int*/ sel, NSObject sender) {
+int draggingEntered(long id, long sel, NSObject sender) {
 	if (sender == null) return OS.NSDragOperationNone;
 
 	DNDEvent event = new DNDEvent();
@@ -273,12 +273,12 @@ int draggingEntered(long /*int*/ id, long /*int*/ sel, NSObject sender) {
 	}
 
 	if (new NSObject(id).isKindOfClass(OS.class_NSTableView)) {
-		return (int)/*64*/dndCallSuper(id, sel, sender.id);
+		return (int)dndCallSuper(id, sel, sender.id);
 	}
 	return opToOsOp(selectedOperation);
 }
 
-void draggingExited(long /*int*/ id, long /*int*/ sel, NSObject sender) {
+void draggingExited(long id, long sel, NSObject sender) {
 	clearDropNotAllowed();
 	if (keyOperation == -1) return;
 	keyOperation = -1;
@@ -294,7 +294,7 @@ void draggingExited(long /*int*/ id, long /*int*/ sel, NSObject sender) {
 	}
 }
 
-int draggingUpdated(long /*int*/ id, long /*int*/ sel, NSObject sender) {
+int draggingUpdated(long id, long sel, NSObject sender) {
 	if (sender == null) return OS.NSDragOperationNone;
 	int oldKeyOperation = keyOperation;
 
@@ -349,7 +349,7 @@ int draggingUpdated(long /*int*/ id, long /*int*/ sel, NSObject sender) {
 	}
 
 	if (new NSObject(id).isKindOfClass(OS.class_NSTableView)) {
-		return (int)/*64*/dndCallSuper(id, sel, sender.id);
+		return (int)dndCallSuper(id, sel, sender.id);
 	}
 
 	return opToOsOp(selectedOperation);
@@ -417,7 +417,7 @@ public DropTarget(Control control, int style) {
 	addDragHandlers();
 }
 
-static long /*int*/ dropTargetProc(long /*int*/ id, long /*int*/ sel) {
+static long dropTargetProc(long id, long sel) {
 	Display display = Display.findDisplay(Thread.currentThread());
 	if (display == null || display.isDisposed()) return 0;
 	Widget widget = display.findWidget(id);
@@ -432,7 +432,7 @@ static long /*int*/ dropTargetProc(long /*int*/ id, long /*int*/ sel) {
 	return 0;
 }
 
-static long /*int*/ dropTargetProc(long /*int*/ id, long /*int*/ sel, long /*int*/ arg0) {
+static long dropTargetProc(long id, long sel, long arg0) {
 	Display display = Display.findDisplay(Thread.currentThread());
 	if (display == null || display.isDisposed()) return 0;
 	Widget widget = display.findWidget(id);
@@ -457,7 +457,7 @@ static long /*int*/ dropTargetProc(long /*int*/ id, long /*int*/ sel, long /*int
 	return 0;
 }
 
-static long /*int*/ dropTargetProc(long /*int*/ id, long /*int*/ sel, long /*int*/ arg0, long /*int*/ arg1, long /*int*/ arg2, long /*int*/ arg3) {
+static long dropTargetProc(long id, long sel, long arg0, long arg1, long arg2, long arg3) {
 	Display display = Display.findDisplay(Thread.currentThread());
 	if (display == null || display.isDisposed()) return 0;
 	Widget widget = display.findWidget(id);
@@ -549,7 +549,7 @@ int getOperationFromKeyState() {
 	// correct Cocoa behavior.  Control + Option or Command is NSDragOperationGeneric,
 	// or DND.DROP_DEFAULT in the SWT.
 	NSEvent currEvent = NSApplication.sharedApplication().currentEvent();
-	long /*int*/ modifiers = currEvent.modifierFlags();
+	long modifiers = currEvent.modifierFlags();
 	boolean option = (modifiers & OS.NSAlternateKeyMask) == OS.NSAlternateKeyMask;
 	boolean control = (modifiers & OS.NSControlKeyMask) == OS.NSControlKeyMask;
 	if (control && option) return DND.DROP_DEFAULT;
@@ -598,7 +598,7 @@ int opToOsOp(int operation) {
 	return osOperation;
 }
 
-int osOpToOp(long /*int*/ osOperation){
+int osOpToOp(long osOperation){
 	int operation = 0;
 	if ((osOperation & OS.NSDragOperationCopy) != 0){
 		operation |= DND.DROP_COPY;
@@ -732,7 +732,7 @@ boolean drop(NSObject sender) {
 	return (selectedOperation != DND.DROP_NONE);
 }
 
-boolean performDragOperation(long /*int*/ id, long /*int*/ sel, NSObject sender) {
+boolean performDragOperation(long id, long sel, NSObject sender) {
 	if (new NSObject(id).isKindOfClass(OS.class_NSTableView)) {
 		return dndCallSuper(id, sel, sender.id) != 0;
 	}
@@ -740,11 +740,11 @@ boolean performDragOperation(long /*int*/ id, long /*int*/ sel, NSObject sender)
 	return drop (sender);
 }
 
-boolean outlineView_acceptDrop_item_childIndex(long /*int*/ id, long /*int*/ sel, long /*int*/ outlineView, long /*int*/ info, long /*int*/ item, long /*int*/ index) {
+boolean outlineView_acceptDrop_item_childIndex(long id, long sel, long outlineView, long info, long item, long index) {
 	return drop(new NSObject(info));
 }
 
-long /*int*/ outlineView_validateDrop_proposedItem_proposedChildIndex(long /*int*/ id, long /*int*/ sel, long /*int*/ outlineView, long /*int*/ info, long /*int*/ item, long /*int*/ index) {
+long outlineView_validateDrop_proposedItem_proposedChildIndex(long id, long sel, long outlineView, long info, long item, long index) {
 	//TODO expansion animation and auto collapse not working because of outlineView:shouldExpandItem:
 	NSOutlineView widget = new NSOutlineView(outlineView);
 	NSObject sender = new NSObject(info);
@@ -825,7 +825,7 @@ boolean setEventData(NSObject draggingState, DNDEvent event) {
 
 	// get allowed operations
 	int style = getStyle();
-	long /*int*/ allowedActions = draggingState.draggingSourceOperationMask();
+	long allowedActions = draggingState.draggingSourceOperationMask();
 	int operations = osOpToOp(allowedActions) & style;
 	if (operations == DND.DROP_NONE) return false;
 
@@ -833,9 +833,9 @@ boolean setEventData(NSObject draggingState, DNDEvent event) {
 	int operation = getOperationFromKeyState();
 	keyOperation = operation;
 	if (operation == DND.DROP_DEFAULT) {
-		 if ((style & DND.DROP_DEFAULT) == 0) {
+		if ((style & DND.DROP_DEFAULT) == 0) {
 			operation = (operations & DND.DROP_MOVE) != 0 ? DND.DROP_MOVE : DND.DROP_NONE;
-		 }
+		}
 	} else {
 		if ((operation & operations) == 0) operation = DND.DROP_NONE;
 	}
@@ -846,7 +846,7 @@ boolean setEventData(NSObject draggingState, DNDEvent event) {
 	NSArray draggedTypes = dragPBoard.types();
 	if (draggedTypes == null) return false;
 
-	long /*int*/ draggedTypeCount = draggedTypes.count();
+	long draggedTypeCount = draggedTypes.count();
 
 	TransferData[] dataTypes = new TransferData[(int)draggedTypeCount];
 	int index = -1;
@@ -961,16 +961,16 @@ void clearDropNotAllowed() {
 	}
 }
 
-boolean tableView_acceptDrop_row_dropOperation(long /*int*/ id, long /*int*/ sel, long /*int*/ tableView, long /*int*/ info, long /*int*/ row, long /*int*/ operation) {
+boolean tableView_acceptDrop_row_dropOperation(long id, long sel, long tableView, long info, long row, long operation) {
 	return drop(new NSObject(info));
 }
 
-int tableView_validateDrop_proposedRow_proposedDropOperation(long /*int*/ id, long /*int*/ sel, long /*int*/ tableView, long /*int*/ info, long /*int*/ row, long /*int*/ operation) {
+int tableView_validateDrop_proposedRow_proposedDropOperation(long id, long sel, long tableView, long info, long row, long operation) {
 	NSTableView widget = new NSTableView(tableView);
 	NSObject sender = new NSObject(info);
 	NSPoint pt = sender.draggingLocation();
 	pt = widget.convertPoint_fromView_(pt, null);
-	long /*int*/ hitRow = widget.rowAtPoint(pt);
+	long hitRow = widget.rowAtPoint(pt);
 	if (0 <= hitRow && hitRow < widget.numberOfRows()) {
 		if (feedback == 0) {
 			widget.setDropRow(-1, OS.NSTableViewDropOn);
@@ -991,7 +991,7 @@ int tableView_validateDrop_proposedRow_proposedDropOperation(long /*int*/ id, lo
 }
 
 // By returning true we get draggingUpdated messages even when the mouse isn't moving.
-boolean wantsPeriodicDraggingUpdates(long /*int*/ id, long /*int*/ sel) {
+boolean wantsPeriodicDraggingUpdates(long id, long sel) {
 	return true;
 }
 
