@@ -35,12 +35,11 @@ import org.eclipse.swt.widgets.*;
  * (that is, using the <code>int</code> "|" operator) two or more
  * of those <code>DND</code> effect constants.
  * </p>
- * <p>
  * <dl>
  * <dt><b>Feedback:</b></dt>
  * <dd>FEEDBACK_SELECT, FEEDBACK_INSERT_BEFORE, FEEDBACK_INSERT_AFTER, FEEDBACK_EXPAND, FEEDBACK_SCROLL</dd>
  * </dl>
- * </p><p>
+ * <p>
  * Note: Only one of the styles FEEDBACK_SELECT, FEEDBACK_INSERT_BEFORE or
  * FEEDBACK_INSERT_AFTER may be specified.
  * </p>
@@ -117,7 +116,7 @@ public class TreeDropTargetEffect extends DropTargetEffect {
 	@Override
 	public void dragLeave(DropTargetEvent event) {
 		Tree tree = (Tree) control;
-		long /*int*/ handle = tree.handle;
+		long handle = tree.handle;
 		GTK.gtk_tree_view_set_drag_dest_row(handle, 0, GTK.GTK_TREE_VIEW_DROP_BEFORE);
 
 		scrollBeginTime = 0;
@@ -149,14 +148,14 @@ public class TreeDropTargetEffect extends DropTargetEffect {
 		Tree tree = (Tree) control;
 		int effect = checkEffect(event.feedback);
 
-		long /*int*/ handle = tree.handle;
+		long handle = tree.handle;
 		Point coordinates = new Point(event.x, event.y);
 		coordinates = DPIUtil.autoScaleUp(tree.toControl(coordinates));
-		long /*int*/ [] path = new long /*int*/ [1];
+		long [] path = new long [1];
 		GTK.gtk_tree_view_get_path_at_pos (handle, coordinates.x, coordinates.y, path, null, null, null);
 		int index = -1;
 		if (path[0] != 0) {
-			long /*int*/ indices = GTK.gtk_tree_path_get_indices(path[0]);
+			long indices = GTK.gtk_tree_path_get_indices(path[0]);
 			if (indices != 0) {
 				int depth = GTK.gtk_tree_path_get_depth(path[0]);
 				int[] temp = new int[depth];
