@@ -235,7 +235,7 @@ public void dispose () {
  * <p>The following snippet shows text and RTF text being retrieved from the
  * clipboard:</p>
  *
- *    <code><pre>
+ *    <pre><code>
  *    Clipboard clipboard = new Clipboard(display);
  *    TextTransfer textTransfer = TextTransfer.getInstance();
  *    String textData = (String)clipboard.getContents(textTransfer);
@@ -270,7 +270,7 @@ public Object getContents(Transfer transfer) {
  * <p>The following snippet shows text and RTF text being retrieved from the
  * clipboard:</p>
  *
- *    <code><pre>
+ *    <pre><code>
  *    Clipboard clipboard = new Clipboard(display);
  *    TextTransfer textTransfer = TextTransfer.getInstance();
  *    String textData = (String)clipboard.getContents(textTransfer);
@@ -319,7 +319,7 @@ public Object getContents(Transfer transfer, int clipboards) {
 	* the clipboard, use PeekMessage() to enable cross thread
 	* message sends.
 	*/
-	long /*int*/[] ppv = new long /*int*/[1];
+	long[] ppv = new long[1];
 	int retryCount = 0;
 	/* OleGetClipboard([out] ppDataObject).
 	 * AddRef has already been called on ppDataObject by the callee and must be released by the caller.
@@ -379,7 +379,7 @@ public boolean isDisposed () {
  * clipboard:
  * </p>
  *
- * <code><pre>
+ * <pre><code>
  * 	Clipboard clipboard = new Clipboard(display);
  *	String textData = "Hello World";
  *	String rtfData = "{\\rtf1\\b\\i Hello World}";
@@ -436,7 +436,7 @@ public void setContents(Object[] data, Transfer[] dataTypes) {
  * clipboard:
  * </p>
  *
- * <code><pre>
+ * <pre><code>
  * 	Clipboard clipboard = new Clipboard(display);
  *	String textData = "Hello World";
  *	String rtfData = "{\\rtf1\\b\\i Hello World}";
@@ -522,20 +522,20 @@ private void createCOMInterfaces() {
 	// register each of the interfaces that this object implements
 	iDataObject = new COMObject(new int[]{2, 0, 0, 2, 2, 1, 2, 3, 2, 4, 1, 1}){
 		@Override
-		public long /*int*/ method0(long /*int*/[] args) {return QueryInterface(args[0], args[1]);}
+		public long method0(long[] args) {return QueryInterface(args[0], args[1]);}
 		@Override
-		public long /*int*/ method1(long /*int*/[] args) {return AddRef();}
+		public long method1(long[] args) {return AddRef();}
 		@Override
-		public long /*int*/ method2(long /*int*/[] args) {return Release();}
+		public long method2(long[] args) {return Release();}
 		@Override
-		public long /*int*/ method3(long /*int*/[] args) {return GetData(args[0], args[1]);}
+		public long method3(long[] args) {return GetData(args[0], args[1]);}
 		// method4 GetDataHere - not implemented
 		@Override
-		public long /*int*/ method5(long /*int*/[] args) {return QueryGetData(args[0]);}
+		public long method5(long[] args) {return QueryGetData(args[0]);}
 		// method6 GetCanonicalFormatEtc - not implemented
 		// method7 SetData - not implemented
 		@Override
-		public long /*int*/ method8(long /*int*/[] args) {return EnumFormatEtc((int)/*64*/args[0], args[1]);}
+		public long method8(long[] args) {return EnumFormatEtc((int)args[0], args[1]);}
 		// method9 DAdvise - not implemented
 		// method10 DUnadvise - not implemented
 		// method11 EnumDAdvise - not implemented
@@ -551,7 +551,7 @@ private void disposeCOMInterfaces() {
  * Ownership of ppenumFormatetc transfers from callee to caller so reference count on ppenumFormatetc
  * must be incremented before returning.  Caller is responsible for releasing ppenumFormatetc.
  */
-private int EnumFormatEtc(int dwDirection, long /*int*/ ppenumFormatetc) {
+private int EnumFormatEtc(int dwDirection, long ppenumFormatetc) {
 	// only allow getting of data - SetData is not currently supported
 	if (dwDirection == COM.DATADIR_SET) return COM.E_NOTIMPL;
 	// what types have been registered?
@@ -577,10 +577,10 @@ private int EnumFormatEtc(int dwDirection, long /*int*/ ppenumFormatetc) {
 	dropeffect.tymed = COM.TYMED_HGLOBAL;
 	formats[formats.length -1] = dropeffect;
 	enumFORMATETC.setFormats(formats);
-	OS.MoveMemory(ppenumFormatetc, new long /*int*/[] {enumFORMATETC.getAddress()}, C.PTR_SIZEOF);
+	OS.MoveMemory(ppenumFormatetc, new long[] {enumFORMATETC.getAddress()}, C.PTR_SIZEOF);
 	return COM.S_OK;
 }
-private int GetData(long /*int*/ pFormatetc, long /*int*/ pmedium) {
+private int GetData(long pFormatetc, long pmedium) {
 	/* Called by a data consumer to obtain data from a source data object.
 	   The GetData method renders the data described in the specified FORMATETC
 	   structure and transfers it through the specified STGMEDIUM structure.
@@ -622,7 +622,7 @@ private int GetData(long /*int*/ pFormatetc, long /*int*/ pmedium) {
 	return transferData.result;
 }
 
-private int QueryGetData(long /*int*/ pFormatetc) {
+private int QueryGetData(long pFormatetc) {
 	if (transferAgents == null) return COM.E_FAIL;
 	TransferData transferData = new TransferData();
 	transferData.formatetc = new FORMATETC();
@@ -641,16 +641,16 @@ private int QueryGetData(long /*int*/ pFormatetc) {
  * Ownership of ppvObject transfers from callee to caller so reference count on ppvObject
  * must be incremented before returning.  Caller is responsible for releasing ppvObject.
  */
-private int QueryInterface(long /*int*/ riid, long /*int*/ ppvObject) {
+private int QueryInterface(long riid, long ppvObject) {
 	if (riid == 0 || ppvObject == 0) return COM.E_INVALIDARG;
 	GUID guid = new GUID();
 	COM.MoveMemory(guid, riid, GUID.sizeof);
 	if (COM.IsEqualGUID(guid, COM.IIDIUnknown) || COM.IsEqualGUID(guid, COM.IIDIDataObject) ) {
-		OS.MoveMemory(ppvObject, new long /*int*/[] {iDataObject.getAddress()}, C.PTR_SIZEOF);
+		OS.MoveMemory(ppvObject, new long[] {iDataObject.getAddress()}, C.PTR_SIZEOF);
 		AddRef();
 		return COM.S_OK;
 	}
-	OS.MoveMemory(ppvObject, new long /*int*/[] {0}, C.PTR_SIZEOF);
+	OS.MoveMemory(ppvObject, new long[] {0}, C.PTR_SIZEOF);
 	return COM.E_NOINTERFACE;
 }
 private int Release() {
@@ -743,10 +743,10 @@ public String[] getAvailableTypeNames() {
 	String[] names = new String[types.length];
 	int maxSize = 128;
 	for (int i = 0; i < types.length; i++){
-		TCHAR buffer = new TCHAR(0, maxSize);
+		char [] buffer = new char [maxSize];
 		int size = OS.GetClipboardFormatName(types[i].cfFormat, buffer, maxSize);
 		if (size != 0) {
-			names[i] = buffer.toString(0, size);
+			names[i] = new String (buffer, 0, size);
 		} else {
 			switch (types[i].cfFormat) {
 				case COM.CF_HDROP: names[i] = "CF_HDROP"; break; //$NON-NLS-1$
@@ -775,13 +775,13 @@ public String[] getAvailableTypeNames() {
 
 private FORMATETC[] _getAvailableTypes() {
 	FORMATETC[] types = new FORMATETC[0];
-	long /*int*/[] ppv = new long /*int*/[1];
+	long[] ppv = new long[1];
 	/* OleGetClipboard([out] ppDataObject).
 	 * AddRef has already been called on ppDataObject by the callee and must be released by the caller.
 	 */
 	if (COM.OleGetClipboard(ppv) != COM.S_OK) return types;
 	IDataObject dataObject = new IDataObject(ppv[0]);
-	long /*int*/[] ppFormatetc = new long /*int*/[1];
+	long[] ppFormatetc = new long[1];
 	/* EnumFormatEtc([in] dwDirection, [out] ppenumFormatetc)
 	 * AddRef has already been called on ppenumFormatetc by the callee and must be released by the caller.
 	 */
@@ -790,7 +790,7 @@ private FORMATETC[] _getAvailableTypes() {
 	if (rc != COM.S_OK)return types;
 	IEnumFORMATETC enumFormatetc = new IEnumFORMATETC(ppFormatetc[0]);
 	// Loop over enumerator and save any types that match what we are looking for
-	long /*int*/ rgelt = OS.GlobalAlloc(OS.GMEM_FIXED | OS.GMEM_ZEROINIT, FORMATETC.sizeof);
+	long rgelt = OS.GlobalAlloc(OS.GMEM_FIXED | OS.GMEM_ZEROINIT, FORMATETC.sizeof);
 	int[] pceltFetched = new int[1];
 	enumFormatetc.Reset();
 	while (enumFormatetc.Next(1, rgelt, pceltFetched) == COM.S_OK && pceltFetched[0] == 1) {
