@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -55,7 +55,7 @@ import org.eclipse.swt.widgets.*;
  *
  * <p> The following example shows a Label widget that allows text to be dragged from it.</p>
  *
- * <code><pre>
+ * <pre><code>
  *	// Enable a label as a Drag Source
  *	Label label = new Label(shell, SWT.NONE);
  *	// This example will allow text to be dragged
@@ -90,7 +90,7 @@ import org.eclipse.swt.widgets.*;
  *				label.setText("");
  *		}
  *	});
- * </pre></code>
+ * </code></pre>
  *
  *
  * <dl>
@@ -111,7 +111,7 @@ public class DragSource extends Widget {
 	Transfer[] transferAgents = new Transfer[0];
 	DragSourceEffect dragEffect;
 	Composite topControl;
-	long /*int*/ hwndDrag;
+	long hwndDrag;
 
 	// ole interfaces
 	COMObject iDropSource;
@@ -161,8 +161,6 @@ public DragSource(Control control, int style) {
 		DND.error(DND.ERROR_CANNOT_INIT_DRAG);
 	}
 	control.setData(DND.DRAG_SOURCE_KEY, this);
-	createCOMInterfaces();
-	this.AddRef();
 
 	controlListener = event -> {
 		if (event.type == SWT.Dispose) {
@@ -202,14 +200,14 @@ static int checkStyle(int style) {
  * it one of the messages defined in the <code>DragSourceListener</code>
  * interface.
  *
- * <p><ul>
+ * <ul>
  * <li><code>dragStart</code> is called when the user has begun the actions required to drag the widget.
  * This event gives the application the chance to decide if a drag should be started.
  * <li><code>dragSetData</code> is called when the data is required from the drag source.
  * <li><code>dragFinished</code> is called when the drop has successfully completed (mouse up
  * over a valid target) or has been terminated (such as hitting the ESC key). Perform cleanup
  * such as removing data from the source side on a successful move operation.
- * </ul></p>
+ * </ul>
  *
  * @param listener the listener which should be notified
  *
@@ -241,41 +239,43 @@ private int AddRef() {
 }
 
 private void createCOMInterfaces() {
+	disposeCOMInterfaces();
 	// register each of the interfaces that this object implements
 	iDropSource = new COMObject(new int[]{2, 0, 0, 2, 1}){
 		@Override
-		public long /*int*/ method0(long /*int*/[] args) {return QueryInterface(args[0], args[1]);}
+		public long method0(long[] args) {return QueryInterface(args[0], args[1]);}
 		@Override
-		public long /*int*/ method1(long /*int*/[] args) {return AddRef();}
+		public long method1(long[] args) {return AddRef();}
 		@Override
-		public long /*int*/ method2(long /*int*/[] args) {return Release();}
+		public long method2(long[] args) {return Release();}
 		@Override
-		public long /*int*/ method3(long /*int*/[] args) {return QueryContinueDrag((int)/*64*/args[0], (int)/*64*/args[1]);}
+		public long method3(long[] args) {return QueryContinueDrag((int)args[0], (int)args[1]);}
 		@Override
-		public long /*int*/ method4(long /*int*/[] args) {return GiveFeedback((int)/*64*/args[0]);}
+		public long method4(long[] args) {return GiveFeedback((int)args[0]);}
 	};
 
 	iDataObject = new COMObject(new int[]{2, 0, 0, 2, 2, 1, 2, 3, 2, 4, 1, 1}){
 		@Override
-		public long /*int*/ method0(long /*int*/[] args) {return QueryInterface(args[0], args[1]);}
+		public long method0(long[] args) {return QueryInterface(args[0], args[1]);}
 		@Override
-		public long /*int*/ method1(long /*int*/[] args) {return AddRef();}
+		public long method1(long[] args) {return AddRef();}
 		@Override
-		public long /*int*/ method2(long /*int*/[] args) {return Release();}
+		public long method2(long[] args) {return Release();}
 		@Override
-		public long /*int*/ method3(long /*int*/[] args) {return GetData(args[0], args[1]);}
+		public long method3(long[] args) {return GetData(args[0], args[1]);}
 		// method4 GetDataHere - not implemented
 		@Override
-		public long /*int*/ method5(long /*int*/[] args) {return QueryGetData(args[0]);}
+		public long method5(long[] args) {return QueryGetData(args[0]);}
 		// method6 GetCanonicalFormatEtc - not implemented
 		@Override
-		public long /*int*/ method7(long /*int*/[] args) {return SetData(args[0], args[1], (int)/*64*/args[2]);}
+		public long method7(long[] args) {return SetData(args[0], args[1], (int)args[2]);}
 		@Override
-		public long /*int*/ method8(long /*int*/[] args) {return EnumFormatEtc((int)/*64*/args[0], args[1]);}
+		public long method8(long[] args) {return EnumFormatEtc((int)args[0], args[1]);}
 		// method9 DAdvise - not implemented
 		// method10 DUnadvise - not implemented
 		// method11 EnumDAdvise - not implemented
 	};
+	refCount = 1;
 }
 
 @Override
@@ -307,6 +307,7 @@ private void drag(Event dragEvent) {
 	notifyListeners(DND.DragStart,event);
 	if (!event.doit || transferAgents == null || transferAgents.length == 0 ) return;
 
+	createCOMInterfaces();
 	int[] pdwEffect = new int[1];
 	int operations = opToOs(getStyle());
 	Display display = control.getDisplay();
@@ -347,14 +348,14 @@ private void drag(Event dragEvent) {
 			OS.ShowWindow (hwndDrag, OS.SW_SHOW);
 		}
 		OS.ImageList_BeginDrag(imagelist.getHandle(), 0, offsetX, event.offsetY);
-        /*
-        * Feature in Windows. When ImageList_DragEnter() is called,
-        * it takes a snapshot of the screen  If a drag is started
-        * when another window is in front, then the snapshot will
-        * contain part of the other window, causing pixel corruption.
-        * The fix is to force all paints to be delivered before
-        * calling ImageList_DragEnter().
-        */
+		/*
+		* Feature in Windows. When ImageList_DragEnter() is called,
+		* it takes a snapshot of the screen  If a drag is started
+		* when another window is in front, then the snapshot will
+		* contain part of the other window, causing pixel corruption.
+		* The fix is to force all paints to be delivered before
+		* calling ImageList_DragEnter().
+		*/
 		int flags = OS.RDW_UPDATENOW | OS.RDW_ALLCHILDREN;
 		OS.RedrawWindow (topControl.handle, null, 0, flags);
 		POINT pt = new POINT ();
@@ -379,6 +380,7 @@ private void drag(Event dragEvent) {
 			topControl = null;
 		}
 		display.setData(key, oldValue);
+		Release();
 	}
 	int operation = osToOp(pdwEffect[0]);
 	if (dataEffect == DND.DROP_MOVE) {
@@ -388,6 +390,34 @@ private void drag(Event dragEvent) {
 			operation = dataEffect;
 		}
 	}
+
+	/*
+	 * Bug 549643: a proper drag&drop operation is finished when the DoDragDrop loop/function returns.
+	 * Unfortunately the Windows Explorer is ignoring this fact while showing a Portable Device
+	 * (e.g. Smartphone attached through MTP). I.e. dropping a file on Windows Explorer in this
+	 * situation will query the iDataObject at least once for its data _after_ DoDragDrop finished.
+	 * Revoking this getData request will fail the drop.
+	 *
+	 * This behavior can succeeds because most applications store the actual data to transfer in
+	 * the IDataObject and since its lifetime is managed through ref counting it can return the data
+	 * even after the drag&drop finished. In SWT the data to transfer is not stored in the IDataObject
+	 * but instead obtained on demand through a DND.DragSetData event. Additional some clients release
+	 * the data to drag in the DragEnd event and therefore do not like to get such events after DragEnd.
+	 *
+	 * That's why the next few lines exist. In case the DropTarget has not yet released the IDataObject
+	 * (which is the case for the faulty Windows Explorer described above) we delay the DragEnd event in
+	 * case an additional DragSetData is triggered. Since the DropTarget can be any (faulty or malicious)
+	 * application maybe never releasing the object wait is combined with a tight timeout.
+	 */
+	final long start = System.currentTimeMillis();
+	while (refCount > 0 && System.currentTimeMillis() - start < 1000) {
+		if (!display.readAndDispatch()) {
+			try { Thread.sleep(10); }
+			catch (InterruptedException e) { break; }
+		}
+	}
+	disposeCOMInterfaces();
+
 	event = new DNDEvent();
 	event.widget = this;
 	event.time = OS.GetMessageTime();
@@ -401,7 +431,7 @@ private void drag(Event dragEvent) {
  * Ownership of ppenumFormatetc transfers from callee to caller so reference count on ppenumFormatetc
  * must be incremented before returning.  Caller is responsible for releasing ppenumFormatetc.
  */
-private int EnumFormatEtc(int dwDirection, long /*int*/ ppenumFormatetc) {
+private int EnumFormatEtc(int dwDirection, long ppenumFormatetc) {
 	// only allow getting of data - SetData is not currently supported
 	if (dwDirection == COM.DATADIR_SET) return COM.E_NOTIMPL;
 
@@ -427,7 +457,7 @@ private int EnumFormatEtc(int dwDirection, long /*int*/ ppenumFormatetc) {
 	}
 	enumFORMATETC.setFormats(formats);
 
-	OS.MoveMemory(ppenumFormatetc, new long /*int*/[] {enumFORMATETC.getAddress()}, C.PTR_SIZEOF);
+	OS.MoveMemory(ppenumFormatetc, new long[] {enumFORMATETC.getAddress()}, C.PTR_SIZEOF);
 	return COM.S_OK;
 }
 /**
@@ -440,7 +470,7 @@ public Control getControl() {
 	return control;
 }
 
-private int GetData(long /*int*/ pFormatetc, long /*int*/ pmedium) {
+private int GetData(long pFormatetc, long pmedium) {
 	/* Called by a data consumer to obtain data from a source data object.
 	   The GetData method renders the data described in the specified FORMATETC
 	   structure and transfers it through the specified STGMEDIUM structure.
@@ -615,7 +645,7 @@ private int osToOp(int osOperation){
 	return operation;
 }
 
-private int QueryGetData(long /*int*/ pFormatetc) {
+private int QueryGetData(long pFormatetc) {
 	if (transferAgents == null) return COM.E_FAIL;
 	TransferData transferData = new TransferData();
 	transferData.formatetc = new FORMATETC();
@@ -636,25 +666,25 @@ private int QueryGetData(long /*int*/ pFormatetc) {
  * Ownership of ppvObject transfers from callee to caller so reference count on ppvObject
  * must be incremented before returning.  Caller is responsible for releasing ppvObject.
  */
-private int QueryInterface(long /*int*/ riid, long /*int*/ ppvObject) {
+private int QueryInterface(long riid, long ppvObject) {
 	if (riid == 0 || ppvObject == 0)
 		return COM.E_INVALIDARG;
 	GUID guid = new GUID();
 	COM.MoveMemory(guid, riid, GUID.sizeof);
 
 	if (COM.IsEqualGUID(guid, COM.IIDIUnknown) || COM.IsEqualGUID(guid, COM.IIDIDropSource)) {
-		OS.MoveMemory(ppvObject, new long /*int*/[] {iDropSource.getAddress()}, C.PTR_SIZEOF);
+		OS.MoveMemory(ppvObject, new long[] {iDropSource.getAddress()}, C.PTR_SIZEOF);
 		AddRef();
 		return COM.S_OK;
 	}
 
 	if (COM.IsEqualGUID(guid, COM.IIDIDataObject) ) {
-		OS.MoveMemory(ppvObject, new long /*int*/[] {iDataObject.getAddress()}, C.PTR_SIZEOF);
+		OS.MoveMemory(ppvObject, new long[] {iDataObject.getAddress()}, C.PTR_SIZEOF);
 		AddRef();
 		return COM.S_OK;
 	}
 
-	OS.MoveMemory(ppvObject, new long /*int*/[] {0}, C.PTR_SIZEOF);
+	OS.MoveMemory(ppvObject, new long[] {0}, C.PTR_SIZEOF);
 	return COM.E_NOINTERFACE;
 }
 
@@ -694,7 +724,7 @@ public void removeDragListener(DragSourceListener listener) {
 	removeListener(DND.DragEnd, listener);
 }
 
-private int SetData(long /*int*/ pFormatetc, long /*int*/ pmedium, int fRelease) {
+private int SetData(long pFormatetc, long pmedium, int fRelease) {
 	if (pFormatetc == 0 || pmedium == 0) return COM.E_INVALIDARG;
 	FORMATETC formatetc = new FORMATETC();
 	COM.MoveMemory(formatetc, pFormatetc, FORMATETC.sizeof);
@@ -702,7 +732,7 @@ private int SetData(long /*int*/ pFormatetc, long /*int*/ pmedium, int fRelease)
 		STGMEDIUM stgmedium = new STGMEDIUM();
 		COM.MoveMemory(stgmedium, pmedium,STGMEDIUM.sizeof);
 		//TODO - this should be GlobalLock()
-		long /*int*/[] ptrEffect = new long /*int*/[1];
+		long[] ptrEffect = new long[1];
 		OS.MoveMemory(ptrEffect, stgmedium.unionField, C.PTR_SIZEOF);
 		int[] effect = new int[1];
 		OS.MoveMemory(effect, ptrEffect[0], 4);
