@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2012 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -9,12 +9,14 @@
  * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
- *     IBM Corporation - initial API and implementation
+ *    IBM Corporation - initial API and implementation
  *******************************************************************************/
 package org.eclipse.swt.internal.cocoa;
 
 public class CFRange {
-	public long /*int*/ location;
-	public long /*int*/ length;
-	public static int sizeof = OS.CFRange_sizeof();
+	/** @field cast=(CFIndex) */
+	public long location;
+	/** @field cast=(CFIndex) */
+	public long length;
+	public static final int sizeof = OS.CFRange_sizeof();
 }
