@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2012 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -9,16 +9,16 @@
  * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
- *     IBM Corporation - initial API and implementation
+ *    IBM Corporation - initial API and implementation
  *******************************************************************************/
-
 package org.eclipse.swt.internal.cocoa;
 
 public class CTParagraphStyleSetting {
 	/** @field cast=(CTParagraphStyleSpecifier) */
 	public int spec;
-	public long /*int*/ valueSize;
-	/** @field cast=(void *) */
-	public long /*int*/ value;
+	/** @field cast=(size_t) */
+	public long valueSize;
+	/** @field cast=(void*) */
+	public long value;
 	public static final int sizeof = OS.CTParagraphStyleSetting_sizeof();
-}
\ No newline at end of file
+}
