@@ -19,7 +19,7 @@ public NSData() {
 	super();
 }
 
-public NSData(long /*int*/ id) {
+public NSData(long id) {
 	super(id);
 }
 
@@ -27,12 +27,12 @@ public NSData(id id) {
 	super(id);
 }
 
-public long /*int*/ bytes() {
+public long bytes() {
 	return OS.objc_msgSend(this.id, OS.sel_bytes);
 }
 
-public static NSData dataWithBytes(byte[] bytes, long /*int*/ length) {
-	long /*int*/ result = OS.objc_msgSend(OS.class_NSData, OS.sel_dataWithBytes_length_, bytes, length);
+public static NSData dataWithBytes(byte[] bytes, long length) {
+	long result = OS.objc_msgSend(OS.class_NSData, OS.sel_dataWithBytes_length_, bytes, length);
 	return result != 0 ? new NSData(result) : null;
 }
 
@@ -40,11 +40,11 @@ public void getBytes(byte[] buffer) {
 	OS.objc_msgSend(this.id, OS.sel_getBytes_, buffer);
 }
 
-public void getBytes(long /*int*/ buffer, long /*int*/ length) {
+public void getBytes(long buffer, long length) {
 	OS.objc_msgSend(this.id, OS.sel_getBytes_length_, buffer, length);
 }
 
-public long /*int*/ length() {
+public long length() {
 	return OS.objc_msgSend(this.id, OS.sel_length);
 }
 
