@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2012 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -19,7 +19,7 @@ public NSFontPanel() {
 	super();
 }
 
-public NSFontPanel(long /*int*/ id) {
+public NSFontPanel(long id) {
 	super(id);
 }
 
@@ -28,7 +28,7 @@ public NSFontPanel(id id) {
 }
 
 public NSFont panelConvertFont(NSFont fontObj) {
-	long /*int*/ result = OS.objc_msgSend(this.id, OS.sel_panelConvertFont_, fontObj != null ? fontObj.id : 0);
+	long result = OS.objc_msgSend(this.id, OS.sel_panelConvertFont_, fontObj != null ? fontObj.id : 0);
 	return result != 0 ? new NSFont(result) : null;
 }
 
@@ -37,15 +37,15 @@ public void setPanelFont(NSFont fontObj, boolean flag) {
 }
 
 public static NSFontPanel sharedFontPanel() {
-	long /*int*/ result = OS.objc_msgSend(OS.class_NSFontPanel, OS.sel_sharedFontPanel);
+	long result = OS.objc_msgSend(OS.class_NSFontPanel, OS.sel_sharedFontPanel);
 	return result != 0 ? new NSFontPanel(result) : null;
 }
 
-public static double /*float*/ minFrameWidthWithTitle(NSString aTitle, long /*int*/ aStyle) {
-	return (double /*float*/)OS.objc_msgSend_fpret(OS.class_NSFontPanel, OS.sel_minFrameWidthWithTitle_styleMask_, aTitle != null ? aTitle.id : 0, aStyle);
+public static double minFrameWidthWithTitle(NSString aTitle, long aStyle) {
+	return OS.objc_msgSend_fpret(OS.class_NSFontPanel, OS.sel_minFrameWidthWithTitle_styleMask_, aTitle != null ? aTitle.id : 0, aStyle);
 }
 
-public static long /*int*/ windowNumberAtPoint(NSPoint point, long /*int*/ windowNumber) {
+public static long windowNumberAtPoint(NSPoint point, long windowNumber) {
 	return OS.objc_msgSend(OS.class_NSFontPanel, OS.sel_windowNumberAtPoint_belowWindowWithWindowNumber_, point, windowNumber);
 }
 
