@@ -19,7 +19,7 @@ public NSMutableDictionary() {
 	super();
 }
 
-public NSMutableDictionary(long /*int*/ id) {
+public NSMutableDictionary(long id) {
 	super(id);
 }
 
@@ -27,13 +27,13 @@ public NSMutableDictionary(id id) {
 	super(id);
 }
 
-public static NSMutableDictionary dictionaryWithCapacity(long /*int*/ numItems) {
-	long /*int*/ result = OS.objc_msgSend(OS.class_NSMutableDictionary, OS.sel_dictionaryWithCapacity_, numItems);
+public static NSMutableDictionary dictionaryWithCapacity(long numItems) {
+	long result = OS.objc_msgSend(OS.class_NSMutableDictionary, OS.sel_dictionaryWithCapacity_, numItems);
 	return result != 0 ? new NSMutableDictionary(result) : null;
 }
 
-public NSMutableDictionary initWithCapacity(long /*int*/ numItems) {
-	long /*int*/ result = OS.objc_msgSend(this.id, OS.sel_initWithCapacity_, numItems);
+public NSMutableDictionary initWithCapacity(long numItems) {
+	long result = OS.objc_msgSend(this.id, OS.sel_initWithCapacity_, numItems);
 	return result == this.id ? this : (result != 0 ? new NSMutableDictionary(result) : null);
 }
 
@@ -54,7 +54,7 @@ public void setValue(id value, NSString key) {
 }
 
 public static NSDictionary dictionaryWithObject(id object, id key) {
-	long /*int*/ result = OS.objc_msgSend(OS.class_NSMutableDictionary, OS.sel_dictionaryWithObject_forKey_, object != null ? object.id : 0, key != null ? key.id : 0);
+	long result = OS.objc_msgSend(OS.class_NSMutableDictionary, OS.sel_dictionaryWithObject_forKey_, object != null ? object.id : 0, key != null ? key.id : 0);
 	return result != 0 ? new NSMutableDictionary(result) : null;
 }
 
