@@ -19,7 +19,7 @@ public NSStepper() {
 	super();
 }
 
-public NSStepper(long /*int*/ id) {
+public NSStepper(long id) {
 	super(id);
 }
 
@@ -55,11 +55,11 @@ public void setValueWraps(boolean valueWraps) {
 	OS.objc_msgSend(this.id, OS.sel_setValueWraps_, valueWraps);
 }
 
-public static long /*int*/ cellClass() {
+public static long cellClass() {
 	return OS.objc_msgSend(OS.class_NSStepper, OS.sel_cellClass);
 }
 
-public static void setCellClass(long /*int*/ factoryId) {
+public static void setCellClass(long factoryId) {
 	OS.objc_msgSend(OS.class_NSStepper, OS.sel_setCellClass_, factoryId);
 }
 
