@@ -158,6 +158,7 @@ public enum Selector {
 	, sel_alternateSelectedControlColor("alternateSelectedControlColor")
 	, sel_alternateSelectedControlTextColor("alternateSelectedControlTextColor")
 	, sel_alwaysShowsDecimalSeparator("alwaysShowsDecimalSeparator")
+	, sel_appearanceNamed_("appearanceNamed:")
 	, sel_appendAttributedString_("appendAttributedString:")
 	, sel_appendBezierPath_("appendBezierPath:")
 	, sel_appendBezierPathWithArcWithCenter_radius_startAngle_endAngle_("appendBezierPathWithArcWithCenter:radius:startAngle:endAngle:")
@@ -353,12 +354,12 @@ public enum Selector {
 	, sel_credentialWithUser_password_persistence_("credentialWithUser:password:persistence:")
 	, sel_crosshairCursor("crosshairCursor")
 	, sel_ctrlKey("ctrlKey")
+	, sel_currentAppearance("currentAppearance")
 	, sel_currentApplication("currentApplication")
 	, sel_currentContext("currentContext")
 	, sel_currentCursor("currentCursor")
 	, sel_currentEditor("currentEditor")
 	, sel_currentEvent("currentEvent")
-	, sel_currentHandler("currentHandler")
 	, sel_currentInputManager("currentInputManager")
 	, sel_currentPoint("currentPoint")
 	, sel_currentRunLoop("currentRunLoop")
@@ -426,6 +427,7 @@ public enum Selector {
 	, sel_documentViewShouldHandlePrint("documentViewShouldHandlePrint")
 	, sel_documentVisibleRect("documentVisibleRect")
 	, sel_doubleClickAtIndex_("doubleClickAtIndex:")
+	, sel_doubleClickInterval("doubleClickInterval")
 	, sel_doubleValue("doubleValue")
 	, sel_download("download")
 	, sel_download_decideDestinationWithSuggestedFilename_("download:decideDestinationWithSuggestedFilename:")
@@ -536,8 +538,6 @@ public enum Selector {
 	, sel_graphicsPort("graphicsPort")
 	, sel_greenComponent("greenComponent")
 	, sel_handleEvent_("handleEvent:")
-	, sel_handleFailureInFunction_file_lineNumber_description_("handleFailureInFunction:file:lineNumber:description:")
-	, sel_handleFailureInMethod_object_file_lineNumber_description_("handleFailureInMethod:object:file:lineNumber:description:")
 	, sel_handleMouseEvent_("handleMouseEvent:")
 	, sel_hasAlpha("hasAlpha")
 	, sel_hasMarkedText("hasMarkedText")
@@ -698,6 +698,7 @@ public enum Selector {
 	, sel_locationForGlyphAtIndex_("locationForGlyphAtIndex:")
 	, sel_locationInWindow("locationInWindow")
 	, sel_lockFocus("lockFocus")
+	, sel_lockFocusIfCanDraw("lockFocusIfCanDraw")
 	, sel_lowercaseString("lowercaseString")
 	, sel_magnification("magnification")
 	, sel_magnifyWithEvent_("magnifyWithEvent:")
@@ -752,6 +753,7 @@ public enum Selector {
 	, sel_mutableCopy("mutableCopy")
 	, sel_mutableString("mutableString")
 	, sel_name("name")
+	, sel_nameFieldStringValue("nameFieldStringValue")
 	, sel_needsPanelToBecomeKey("needsPanelToBecomeKey")
 	, sel_nextEventMatchingMask_untilDate_inMode_dequeue_("nextEventMatchingMask:untilDate:inMode:dequeue:")
 	, sel_nextObject("nextObject")
@@ -784,6 +786,7 @@ public enum Selector {
 	, sel_openPanel("openPanel")
 	, sel_openURL_("openURL:")
 	, sel_openURLs_withAppBundleIdentifier_options_additionalEventParamDescriptor_launchIdentifiers_("openURLs:withAppBundleIdentifier:options:additionalEventParamDescriptor:launchIdentifiers:")
+	, sel_operatingSystemVersion("operatingSystemVersion")
 	, sel_operationNotAllowedCursor("operationNotAllowedCursor")
 	, sel_options("options")
 	, sel_orderBack_("orderBack:")
@@ -823,7 +826,8 @@ public enum Selector {
 	, sel_pageDown_("pageDown:")
 	, sel_pageTitle("pageTitle")
 	, sel_pageUp_("pageUp:")
-	, sel_panel_shouldShowFilename_("panel:shouldShowFilename:")
+	, sel_panel_shouldEnableURL_("panel:shouldEnableURL:")
+	, sel_panel_userEnteredFilename_confirmed_("panel:userEnteredFilename:confirmed:")
 	, sel_panelConvertFont_("panelConvertFont:")
 	, sel_paperSize("paperSize")
 	, sel_paragraphs("paragraphs")
@@ -853,6 +857,7 @@ public enum Selector {
 	, sel_postEvent_atStart_("postEvent:atStart:")
 	, sel_preparedCellAtColumn_row_("preparedCellAtColumn:row:")
 	, sel_prependTransform_("prependTransform:")
+	, sel_pressedMouseButtons("pressedMouseButtons")
 	, sel_preventDefault("preventDefault")
 	, sel_previousFailureCount("previousFailureCount")
 	, sel_printDocumentView("printDocumentView")
@@ -863,6 +868,7 @@ public enum Selector {
 	, sel_printer("printer")
 	, sel_printerNames("printerNames")
 	, sel_printerWithName_("printerWithName:")
+	, sel_processInfo("processInfo")
 	, sel_propertyListForType_("propertyListForType:")
 	, sel_proposedCredential("proposedCredential")
 	, sel_protectionSpace("protectionSpace")
@@ -1010,6 +1016,7 @@ public enum Selector {
 	, sel_setAlpha_("setAlpha:")
 	, sel_setAlphaValue_("setAlphaValue:")
 	, sel_setAlternateButtonTitle_("setAlternateButtonTitle:")
+	, sel_setAppearance_("setAppearance:")
 	, sel_setApplicationIconImage_("setApplicationIconImage:")
 	, sel_setApplicationNameForUserAgent_("setApplicationNameForUserAgent:")
 	, sel_setAttachmentCell_("setAttachmentCell:")
@@ -1314,7 +1321,6 @@ public enum Selector {
 	, sel_stringForType_("stringForType:")
 	, sel_stringValue("stringValue")
 	, sel_stringWithCharacters_length_("stringWithCharacters:length:")
-	, sel_stringWithFormat_("stringWithFormat:")
 	, sel_stringWithUTF8String_("stringWithUTF8String:")
 	, sel_stroke("stroke")
 	, sel_strokeRect_("strokeRect:")
