@@ -16,18 +16,18 @@
 #*******************************************************************************
 
 HELP="
-Build Gtk2 or Gtk3 bindings and (optionally) copy them to binary repository.
+Build GTK4 or GTK3 bindings and (optionally) copy them to binary repository.
 Paramaters (specified in this order):
 clean    - delete *.o and *.so files from current folder. If this is the only paramater, do nothing else.
 			But if other paramaters are given and this is the first one, then continue with other actions.
 
 One of the following 3:
--gtk2   : Build bindings with GTK2.
 -gtk3   : Build bindings with GTK3.
--gtk-all : Build bindings with GTK2 as well as GTK3. Note, this flag triggers cleanups before each build
-			because a cleanup is required when buliding different GTK versions for linking to be done correctly.
-			During active development, if you only want to compile updated files, use -gtk2/-gtk3 flags instead,
-			however do not forget to do a cleanup in between gtk2/gtk3.
+-gtk4   : Build bindings with GTK4.
+-gtk-all : Build bindings with GTK3 as well as GTK4. Note, this flag triggers cleanups before each build
+			because a cleanup is required when building different GTK versions for linking to be done correctly.
+			During active development, if you only want to compile updated files, use -gtk3/-gtk4 flags instead,
+			however do not forget to do a cleanup in between gtk3/gtk4.
 
 install  - copy *.so libraries to binary repository.
 
@@ -37,13 +37,12 @@ install  - copy *.so libraries to binary repository.
 -- Examples:
 Most commonly used:
 ./build.sh -gtk-all install
-This will clean everything in your repository, build GTK2 and GTK3, then copy .so files to binary repository.
+This will clean everything in your repository, build GTK3 and GTK4, then copy .so files to binary repository.
 
 Also:
 ./build.sh     	  - only build .so files, do not copy them across. Build according to what GTK_VERSION is set to.
 ./build.sh clean  	  - clean working directory of *.o and *.so files.
-./build.sh install	  - build.so files and copy to binary repository
-./build.sh -gtk3 install  - Build only updated files (or all), copy *.so libs to binary repository.
+./build.sh -gtk4 install	 - build.so files and copy to binary repository
 
 Also note:
 Sometimes you might have to cleanup the binary repository manually as old *.so files are not automatically removed
@@ -132,7 +131,7 @@ case $SWT_OS.$SWT_ARCH in
 			#   java-1.8.0-openjdk-........i386
 			#   java-9-openjdk....i386
 			JAVA_FOLDER=$(ls /usr/lib/jvm | grep java | grep -i openjdk | grep i386 | sort | tail -n 1)
-			if [ "${JAVA_FOLDER}" == "" ]; then
+			if [ "${JAVA_FOLDER}" = "" ]; then
 				func_echo_error "ERROR: Could not find JAVA_HOME/AWT_LIB_PATH on 32bit build system automatically. Expecting it to be in /usr/lib/jvm/ but none was found. See also Bug 533496"
 			fi
 
@@ -157,12 +156,12 @@ case $SWT_OS.$SWT_ARCH in
 				# Cross-platform method of finding JAVA_HOME.
 				# Tested on Fedora 24 and Ubuntu 16
 				DYNAMIC_JAVA_HOME=`readlink -f /usr/bin/java | sed "s:jre/::" | sed "s:bin/java::"`
-				if [ -a "${DYNAMIC_JAVA_HOME}include/jni.h" ]; then
-                	func_echo_plus "JAVA_HOME not set, but jni.h found, dynamically configured to $DYNAMIC_JAVA_HOME"
-            		export JAVA_HOME="$DYNAMIC_JAVA_HOME"
-                else
-                	func_echo_error "JAVA_HOME not set and jni.h could not be located. You might get a compile error about include 'jni.h'. You should install 'java-*-openjdk-devel' package or if you have it installed already, find jni.h and  set JAVA_HOME manually to base of 'include' folder"
-                fi
+				if [ -e "${DYNAMIC_JAVA_HOME}include/jni.h" ]; then
+					func_echo_plus "JAVA_HOME not set, but jni.h found, dynamically configured to $DYNAMIC_JAVA_HOME"
+					export JAVA_HOME="$DYNAMIC_JAVA_HOME"
+				else
+					func_echo_error "JAVA_HOME not set and jni.h could not be located. You might get a compile error about include 'jni.h'. You should install 'java-*-openjdk-devel' package or if you have it installed already, find jni.h and  set JAVA_HOME manually to base of 'include' folder"
+				fi
 			fi
 		fi
 		if [ "${PKG_CONFIG_PATH}" = "" ]; then
@@ -191,7 +190,7 @@ case $SWT_OS.$SWT_ARCH in
 			export PKG_CONFIG_PATH="/usr/lib64/pkgconfig"
 		fi
 		;;
-esac	
+esac
 
 
 # For 64-bit CPUs, we have a switch
@@ -251,7 +250,7 @@ fi
 
 ## Interaction(s) with makefile(s) below:
 
-# Configure OUTPUT_DIR 
+# Configure OUTPUT_DIR
 if [ "x${OUTPUT_DIR}" = "x" ]; then
 	OUTPUT_DIR=../../../../../eclipse.platform.swt.binaries/bundles/org.eclipse.swt.gtk.${SWT_OS}.${SWT_ARCH}
 	if [ -d "$OUTPUT_DIR" ]; then
@@ -303,15 +302,37 @@ fi
 # Announce our target
 func_echo_plus "Building SWT/GTK+ for Architectures: $SWT_OS $SWT_ARCH"
 
+func_build_gtk4 () {
+	export GTK_VERSION=4.0
+
+	# Dictate Webkit2 Extension only if pkg-config flags exist
+	pkg-config --exists webkit2gtk-web-extension-4.0
+	if [ $? = 0 ]; then
+		export BUILD_WEBKIT2EXTENSION="yes";
+	else
+		func_echo_error "Warning: Cannot compile Webkit2 Extension because 'pkg-config --exists webkit2gtk-web-extension-4.0' check failed. Please install webkitgtk4-devel.ARCH on your system."
+	fi
+
+	func_echo_plus "Building GTK4 bindings:"
+	${MAKE_TYPE} -f $MAKEFILE all $MAKE_CAIRO $MAKE_AWT "${@}"
+	RETURN_VALUE=$?   #make can return 1 or 2 if it fails. Thus need to cache it in case it's used programmatically somewhere.
+	if [ "$RETURN_VALUE" -eq 0 ]; then
+		func_echo_plus "GTK4 Build succeeded"
+	else
+		func_echo_error "GTK4 Build failed, aborting further actions.."
+		exit $RETURN_VALUE
+	fi
+}
+
 func_build_gtk3 () {
 	export GTK_VERSION=3.0
 
 	# Dictate Webkit2 Extension only if pkg-config flags exist
 	pkg-config --exists webkit2gtk-web-extension-4.0
-	if [ $? == 0 ]; then
+	if [ $? = 0 ]; then
 		export BUILD_WEBKIT2EXTENSION="yes";
 	else
-		func_echo_error "Warning: Cannot compile Webkit2 Extension because 'pkg-config --exists webkit2gtk-web-extension-4-0' check failed. Please install webkitgtk4-devel.ARCH on your system."
+		func_echo_error "Warning: Cannot compile Webkit2 Extension because 'pkg-config --exists webkit2gtk-web-extension-4.0' check failed. Please install webkitgtk4-devel.ARCH on your system."
 	fi
 
 	func_echo_plus "Building GTK3 bindings:"
@@ -325,41 +346,22 @@ func_build_gtk3 () {
 	fi
 }
 
-func_build_gtk2 () {
-	func_echo_plus "Building GTK2 bindings:"
-	export GTK_VERSION=2.0
-	export BUILD_WEBKIT2EXTENSION="no";
-	if [ ${MODEL} = 'x86_64' ]; then
-		# Bug 515155: Avoid memcpy@GLIBC_2.14 (old Linux compatibility)
-		SWT_PTR_CFLAGS="${SWT_PTR_CFLAGS} -fno-builtin-memmove"
-	fi
-	${MAKE_TYPE} -f $MAKEFILE all $MAKE_CAIRO $MAKE_AWT "$@"
-	RETURN_VALUE=$?
-	if [ "$RETURN_VALUE" -eq 0 ]; then
-		func_echo_plus "GTK2 Build succeeded"
-	else
-		func_echo_error "GTK2 Build failed."
-		exit $RETURN_VALUE
-	fi
-}
-
-
 if [ "$1" = "-gtk-all" ]; then
 	shift
 	func_echo_plus "Note: When building multiple GTK versions, a cleanup is required (and automatically performed) between them."
 	func_clean_up
-	func_build_gtk3 "$@"
+	func_build_gtk4 "$@"
 	func_clean_up
-	func_build_gtk2 "$@"
+	func_build_gtk3 "$@"
+elif [ "$1" = "-gtk4" ]; then
+	shift
+	func_build_gtk4 "$@"
 elif [ "$1" = "-gtk3" ]; then
 	shift
 	func_build_gtk3 "$@"
-elif [ "$1" = "-gtk2" ]; then
-	shift
-	func_build_gtk2 "$@"
-elif [ "${GTK_VERSION}" = "3.0" ]; then
+elif [ "${GTK_VERSION}" = "4.0" ]; then
+	func_build_gtk4 "$@"
+elif [ "${GTK_VERSION}" = "3.0" -o "${GTK_VERSION}" = "" ]; then
+	export GTK_VERSION="3.0"
 	func_build_gtk3 "$@"
-elif [ "${GTK_VERSION}" = "2.0" -o "${GTK_VERSION}" = "" ]; then
-	export GTK_VERSION="2.0"
-	func_build_gtk2 "$@"
 fi
