@@ -1,9 +1,12 @@
 /*******************************************************************************
  * Copyright (c) 2000, 2012 IBM Corporation and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
@@ -17,7 +20,7 @@ public class BitmapData {
 	/** @field cast=(PixelFormat) */
 	public int PixelFormat;
 	/** @field cast=(void*) */
-	public long /*int*/ Scan0;
+	public long Scan0;
 	/** @field cast=(UINT_PTR) */
-	public long /*int*/ Reserved;
+	public long Reserved;
 }
