@@ -17,7 +17,7 @@ public final class SHDRAGIMAGE {
 	public SIZE sizeDragImage = new SIZE ();
 	public POINT ptOffset = new POINT ();
 	/** @field cast=(HBITMAP) */
-	public long /*int*/ hbmpDragImage;
+	public long hbmpDragImage;
 	public int crColorKey;
 	public static final int sizeof = OS.SHDRAGIMAGE_sizeof ();
 }
