@@ -62,7 +62,7 @@ public static PrinterData[] getPrinterList() {
 	if (!NSThread.isMainThread()) pool = (NSAutoreleasePool) new NSAutoreleasePool().alloc().init();
 	try {
 		NSArray printers = NSPrinter.printerNames();
-		int count = (int)/*64*/printers.count();
+		int count = (int)printers.count();
 		PrinterData[] result = new PrinterData[count];
 		for (int i = 0; i < count; i++) {
 			NSString str = new NSString(printers.objectAtIndex(i));
@@ -145,17 +145,17 @@ public Printer(PrinterData data) {
  * printer device is unable to print.  This margin is known as the "trim."
  * This method can be used to calculate the printer's minimum margins
  * by passing in a client area of 0, 0, 0, 0 and then using the resulting
- * x and y coordinates (which will be <= 0) to determine the minimum margins
+ * x and y coordinates (which will be &lt;= 0) to determine the minimum margins
  * for the top and left edges of the paper, and the resulting width and height
  * (offset by the resulting x and y) to determine the minimum margins for the
  * bottom and right edges of the paper, as follows:
+ * </p>
  * <ul>
  * 		<li>The left trim width is -x pixels</li>
  * 		<li>The top trim height is -y pixels</li>
  * 		<li>The right trim width is (x + width) pixels</li>
  * 		<li>The bottom trim height is (y + height) pixels</li>
  * </ul>
- * </p>
  *
  * @param x the x coordinate of the client area
  * @param y the y coordinate of the client area
@@ -216,7 +216,7 @@ protected void create(DeviceData deviceData) {
 			printInfo.setPrinter(printer);
 		}
 		if (data.duplex != SWT.DEFAULT) {
-			long /*int*/ settings = printInfo.PMPrintSettings();
+			long settings = printInfo.PMPrintSettings();
 			int duplex = data.duplex == PrinterData.DUPLEX_SHORT_EDGE ? OS.kPMDuplexTumble
 					: data.duplex == PrinterData.DUPLEX_LONG_EDGE ? OS.kPMDuplexNoTumble
 					: OS.kPMDuplexNone;
@@ -245,7 +245,7 @@ protected void create(DeviceData deviceData) {
 		window.initWithContentRect(rect, OS.NSBorderlessWindowMask, OS.NSBackingStoreBuffered, false);
 		String className = "SWTPrinterView"; //$NON-NLS-1$
 		if (OS.objc_lookUpClass(className) == 0) {
-			long /*int*/ cls = OS.objc_allocateClassPair(OS.class_NSView, className, 0);
+			long cls = OS.objc_allocateClassPair(OS.class_NSView, className, 0);
 			OS.class_addMethod(cls, OS.sel_isFlipped, OS.isFlipped_CALLBACK(), "@:");
 			OS.objc_registerClassPair(cls);
 		}
@@ -302,7 +302,7 @@ protected void destroy() {
  * @noreference This method is not intended to be referenced by clients.
  */
 @Override
-public long /*int*/ internal_new_GC(GCData data) {
+public long internal_new_GC(GCData data) {
 	if (isDisposed()) SWT.error(SWT.ERROR_GRAPHIC_DISPOSED);
 	NSAutoreleasePool pool = null;
 	if (!NSThread.isMainThread()) pool = (NSAutoreleasePool) new NSAutoreleasePool().alloc().init();
@@ -367,7 +367,7 @@ protected void init () {
  * @noreference This method is not intended to be referenced by clients.
  */
 @Override
-public void internal_dispose_GC(long /*int*/ hDC, GCData data) {
+public void internal_dispose_GC(long hDC, GCData data) {
 	if (data != null) isGCCreated = false;
 }
 
@@ -584,12 +584,12 @@ public Point getDPI() {
 	NSAutoreleasePool pool = null;
 	if (!NSThread.isMainThread()) pool = (NSAutoreleasePool) new NSAutoreleasePool().alloc().init();
 	try {
-		long /*int*/ pmPrintSession = printInfo.PMPrintSession();
-		long /*int*/ printer[] = new long /*int*/ [1];
-		long /*int*/ err = OS.PMSessionGetCurrentPrinter(pmPrintSession, printer);
+		long pmPrintSession = printInfo.PMPrintSession();
+		long printer[] = new long [1];
+		long err = OS.PMSessionGetCurrentPrinter(pmPrintSession, printer);
 
 		if (err == OS.noErr) {
-			long /*int*/ printSettings = printInfo.PMPrintSettings();
+			long printSettings = printInfo.PMPrintSettings();
 			short[] destType = new short[1];
 			if (OS.PMSessionGetDestinationType(pmPrintSession, printSettings, destType) == OS.noErr) {
 				if (destType[0] == OS.kPMDestinationPrinter) {
