@@ -1,9 +1,12 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
@@ -41,16 +44,16 @@ import org.eclipse.swt.internal.gtk.*;
  */
 public final class Printer extends Device {
 	static PrinterData [] printerList;
-	static long /*int*/ findPrinter;
+	static long findPrinter;
 	static PrinterData findData;
 
 	PrinterData data;
-	long /*int*/ printer;
-	long /*int*/ printJob;
-	long /*int*/ settings;
-	long /*int*/ pageSetup;
-	long /*int*/ surface;
-	long /*int*/ cairo;
+	long printer;
+	long printJob;
+	long settings;
+	long pageSetup;
+	long surface;
+	long cairo;
 
 	/**
 	 * whether or not a GC was created for this printer
@@ -63,18 +66,10 @@ public final class Printer extends Device {
 	static final String GTK_LPR_BACKEND = "GtkPrintBackendLpr"; //$NON-NLS-1$
 	static final String GTK_FILE_BACKEND = "GtkPrintBackendFile"; //$NON-NLS-1$
 
-	static boolean disablePrinting = System.getProperty("org.eclipse.swt.internal.gtk.disablePrinting") != null; //$NON-NLS-1$
+	static boolean disablePrinting = OS.IsWin32 || System.getProperty("org.eclipse.swt.internal.gtk.disablePrinting") != null; //$NON-NLS-1$
 
 static void gtk_init() {
-	if (OS.GLIB_VERSION < OS.VERSION(2, 32, 0)) {
-		if (!OS.g_thread_supported()) {
-			OS.g_thread_init(0);
-		}
-	}
-	if (OS.GTK_VERSION < OS.VERSION(2, 24, 0)) {
-	    OS.gtk_set_locale();
-	}
-	if (!OS.gtk_init_check (new long /*int*/ [] {0}, null)) {
+	if (!GTK.gtk_init_check (new long [] {0}, null)) {
 		SWT.error (SWT.ERROR_NO_HANDLES, null, " [gtk_init_check() failed]");
 	}
 }
@@ -93,21 +88,21 @@ public static PrinterData[] getPrinterList() {
 	}
 	gtk_init();
 	Callback printerCallback = new Callback(Printer.class, "GtkPrinterFunc_List", 2); //$NON-NLS-1$
-	long /*int*/ GtkPrinterFunc_List = printerCallback.getAddress();
+	long GtkPrinterFunc_List = printerCallback.getAddress();
 	if (GtkPrinterFunc_List == 0) SWT.error (SWT.ERROR_NO_MORE_CALLBACKS);
-	OS.gtk_enumerate_printers(GtkPrinterFunc_List, 0, 0, true);
+	GTK.gtk_enumerate_printers(GtkPrinterFunc_List, 0, 0, true);
 	/*
 	* This call to gdk_threads_leave() is a temporary work around
 	* to avoid deadlocks when gdk_threads_init() is called by native
 	* code outside of SWT (i.e AWT, etc). It ensures that the current
 	* thread leaves the GTK lock acquired by the function above.
 	*/
-	OS.gdk_threads_leave();
+	if (!GTK.GTK4) GDK.gdk_threads_leave();
 	printerCallback.dispose ();
 	return printerList;
 }
 
-static long /*int*/ GtkPrinterFunc_List (long /*int*/ printer, long /*int*/ user_data) {
+static long GtkPrinterFunc_List (long printer, long user_data) {
 	int length = printerList.length;
 	PrinterData [] newList = new PrinterData [length + 1];
 	System.arraycopy (printerList, 0, newList, 0, length);
@@ -117,9 +112,9 @@ static long /*int*/ GtkPrinterFunc_List (long /*int*/ printer, long /*int*/ user
 	* Bug in GTK. While performing a gtk_enumerate_printers(), GTK finds all of the
 	* available printers from each backend and can hang. If a backend requires more
 	* time to gather printer info, GTK will start an event loop waiting for a done
-    * signal before continuing. For the Lpr backend, GTK does not send a done signal
-    * which means the event loop never ends. The fix is to check to see if the driver
-    * is of type Lpr, and stop the enumeration, which exits the event loop.
+	* signal before continuing. For the Lpr backend, GTK does not send a done signal
+	* which means the event loop never ends. The fix is to check to see if the driver
+	* is of type Lpr, and stop the enumeration, which exits the event loop.
 	*/
 	if (printerList[length].driver.equals (GTK_LPR_BACKEND)) return 1;
 	return 0;
@@ -141,48 +136,48 @@ public static PrinterData getDefaultPrinterData() {
 	}
 	gtk_init();
 	Callback printerCallback = new Callback(Printer.class, "GtkPrinterFunc_Default", 2); //$NON-NLS-1$
-	long /*int*/ GtkPrinterFunc_Default = printerCallback.getAddress();
+	long GtkPrinterFunc_Default = printerCallback.getAddress();
 	if (GtkPrinterFunc_Default == 0) SWT.error (SWT.ERROR_NO_MORE_CALLBACKS);
-	OS.gtk_enumerate_printers(GtkPrinterFunc_Default, 0, 0, true);
+	GTK.gtk_enumerate_printers(GtkPrinterFunc_Default, 0, 0, true);
 	/*
 	* This call to gdk_threads_leave() is a temporary work around
 	* to avoid deadlocks when gdk_threads_init() is called by native
 	* code outside of SWT (i.e AWT, etc). It ensures that the current
 	* thread leaves the GTK lock acquired by the function above.
 	*/
-	OS.gdk_threads_leave();
+	if (!GTK.GTK4) GDK.gdk_threads_leave();
 	printerCallback.dispose ();
 	return findData;
 }
 
-static long /*int*/ GtkPrinterFunc_Default (long /*int*/ printer, long /*int*/ user_data) {
-	if (OS.gtk_printer_is_default(printer)) {
+static long GtkPrinterFunc_Default (long printer, long user_data) {
+	if (GTK.gtk_printer_is_default(printer)) {
 		findData = printerDataFromGtkPrinter(printer);
 		return 1;
 	}
 	return 0;
 }
 
-static long /*int*/ gtkPrinterFromPrinterData(PrinterData data) {
+static long gtkPrinterFromPrinterData(PrinterData data) {
 	gtk_init();
 	Callback printerCallback = new Callback(Printer.class, "GtkPrinterFunc_FindNamedPrinter", 2); //$NON-NLS-1$
-	long /*int*/ GtkPrinterFunc_FindNamedPrinter = printerCallback.getAddress();
+	long GtkPrinterFunc_FindNamedPrinter = printerCallback.getAddress();
 	if (GtkPrinterFunc_FindNamedPrinter == 0) SWT.error (SWT.ERROR_NO_MORE_CALLBACKS);
 	findPrinter = 0;
 	findData = data;
-	OS.gtk_enumerate_printers(GtkPrinterFunc_FindNamedPrinter, 0, 0, true);
+	GTK.gtk_enumerate_printers(GtkPrinterFunc_FindNamedPrinter, 0, 0, true);
 	/*
 	* This call to gdk_threads_leave() is a temporary work around
 	* to avoid deadlocks when gdk_threads_init() is called by native
 	* code outside of SWT (i.e AWT, etc). It ensures that the current
 	* thread leaves the GTK lock acquired by the function above.
 	*/
-	OS.gdk_threads_leave();
+	if (!GTK.GTK4) GDK.gdk_threads_leave();
 	printerCallback.dispose ();
 	return findPrinter;
 }
 
-static long /*int*/ GtkPrinterFunc_FindNamedPrinter (long /*int*/ printer, long /*int*/ user_data) {
+static long GtkPrinterFunc_FindNamedPrinter (long printer, long user_data) {
 	PrinterData pd = printerDataFromGtkPrinter(printer);
 	if ((pd.driver.equals(findData.driver) && pd.name.equals(findData.name))
 			|| (pd.driver.equals(GTK_FILE_BACKEND)) && findData.printToFile && findData.driver == null && findData.name == null) {
@@ -194,19 +189,19 @@ static long /*int*/ GtkPrinterFunc_FindNamedPrinter (long /*int*/ printer, long
 	return 0;
 }
 
-static PrinterData printerDataFromGtkPrinter(long /*int*/ printer) {
-	long /*int*/ backend = OS.gtk_printer_get_backend(printer);
-	long /*int*/ address = OS.G_OBJECT_TYPE_NAME(backend);
-	int length = OS.strlen (address);
+static PrinterData printerDataFromGtkPrinter(long printer) {
+	long backend = GTK.gtk_printer_get_backend(printer);
+	long address = OS.G_OBJECT_TYPE_NAME(backend);
+	int length = C.strlen (address);
 	byte [] buffer = new byte [length];
-	OS.memmove (buffer, address, length);
-	String backendType = new String (Converter.mbcsToWcs (null, buffer));
+	C.memmove (buffer, address, length);
+	String backendType = new String (Converter.mbcsToWcs (buffer));
 
-	address = OS.gtk_printer_get_name (printer);
-	length = OS.strlen (address);
+	address = GTK.gtk_printer_get_name (printer);
+	length = C.strlen (address);
 	buffer = new byte [length];
-	OS.memmove (buffer, address, length);
-	String name = new String (Converter.mbcsToWcs (null, buffer));
+	C.memmove (buffer, address, length);
+	String name = new String (Converter.mbcsToWcs (buffer));
 
 	return new PrinterData (backendType, name);
 }
@@ -214,7 +209,7 @@ static PrinterData printerDataFromGtkPrinter(long /*int*/ printer) {
 /*
 * Restore printer settings and page_setup data from data.
 */
-static void restore(byte [] data, long /*int*/ settings, long /*int*/ page_setup) {
+static void restore(byte [] data, long settings, long page_setup) {
 	settingsData = data;
 	start = end = 0;
 	while (end < settingsData.length && settingsData[end] != 0) {
@@ -228,37 +223,37 @@ static void restore(byte [] data, long /*int*/ settings, long /*int*/ page_setup
 		end++;
 		byte [] valueBuffer = new byte [end - start];
 		System.arraycopy (settingsData, start, valueBuffer, 0, valueBuffer.length);
-		OS.gtk_print_settings_set(settings, keyBuffer, valueBuffer);
-		if (DEBUG) System.out.println(new String (Converter.mbcsToWcs (null, keyBuffer))+": "+new String (Converter.mbcsToWcs (null, valueBuffer)));
+		GTK.gtk_print_settings_set(settings, keyBuffer, valueBuffer);
+		if (DEBUG) System.out.println(new String (Converter.mbcsToWcs (keyBuffer))+": "+new String (Converter.mbcsToWcs (valueBuffer)));
 	}
 	end++; // skip extra null terminator
 
 	/* Retrieve stored page_setup data.
 	 * Note that page_setup properties must be stored (in PrintDialog) and restored (here) in the same order.
 	 */
-	OS.gtk_page_setup_set_orientation(page_setup, restoreInt("orientation")); //$NON-NLS-1$
-	OS.gtk_page_setup_set_top_margin(page_setup, restoreDouble("top_margin"), OS.GTK_UNIT_MM); //$NON-NLS-1$
-	OS.gtk_page_setup_set_bottom_margin(page_setup, restoreDouble("bottom_margin"), OS.GTK_UNIT_MM); //$NON-NLS-1$
-	OS.gtk_page_setup_set_left_margin(page_setup, restoreDouble("left_margin"), OS.GTK_UNIT_MM); //$NON-NLS-1$
-	OS.gtk_page_setup_set_right_margin(page_setup, restoreDouble("right_margin"), OS.GTK_UNIT_MM); //$NON-NLS-1$
+	GTK.gtk_page_setup_set_orientation(page_setup, restoreInt("orientation")); //$NON-NLS-1$
+	GTK.gtk_page_setup_set_top_margin(page_setup, restoreDouble("top_margin"), GTK.GTK_UNIT_MM); //$NON-NLS-1$
+	GTK.gtk_page_setup_set_bottom_margin(page_setup, restoreDouble("bottom_margin"), GTK.GTK_UNIT_MM); //$NON-NLS-1$
+	GTK.gtk_page_setup_set_left_margin(page_setup, restoreDouble("left_margin"), GTK.GTK_UNIT_MM); //$NON-NLS-1$
+	GTK.gtk_page_setup_set_right_margin(page_setup, restoreDouble("right_margin"), GTK.GTK_UNIT_MM); //$NON-NLS-1$
 	byte [] name = restoreBytes("paper_size_name", true); //$NON-NLS-1$
 	byte [] display_name = restoreBytes("paper_size_display_name", true); //$NON-NLS-1$
 	byte [] ppd_name = restoreBytes("paper_size_ppd_name", true); //$NON-NLS-1$
 	double width = restoreDouble("paper_size_width"); //$NON-NLS-1$
 	double height = restoreDouble("paper_size_height"); //$NON-NLS-1$
 	boolean custom = restoreBoolean("paper_size_is_custom"); //$NON-NLS-1$
-	long /*int*/ paper_size = 0;
+	long paper_size = 0;
 	if (custom) {
 		if (ppd_name.length > 0) {
-			paper_size = OS.gtk_paper_size_new_from_ppd(ppd_name, display_name, width, height);
+			paper_size = GTK.gtk_paper_size_new_from_ppd(ppd_name, display_name, width, height);
 		} else {
-			paper_size = OS.gtk_paper_size_new_custom(name, display_name, width, height, OS.GTK_UNIT_MM);
+			paper_size = GTK.gtk_paper_size_new_custom(name, display_name, width, height, GTK.GTK_UNIT_MM);
 		}
 	} else {
-		paper_size = OS.gtk_paper_size_new(name);
+		paper_size = GTK.gtk_paper_size_new(name);
 	}
-	OS.gtk_page_setup_set_paper_size(page_setup, paper_size);
-	OS.gtk_paper_size_free(paper_size);
+	GTK.gtk_page_setup_set_paper_size(page_setup, paper_size);
+	GTK.gtk_paper_size_free(paper_size);
 }
 
 static byte [] uriFromFilename(String filename) {
@@ -267,18 +262,18 @@ static byte [] uriFromFilename(String filename) {
 	if (length == 0) return null;
 	char[] chars = new char[length];
 	filename.getChars(0, length, chars, 0);
-	long /*int*/[] error = new long /*int*/[1];
-	long /*int*/ utf8Ptr = OS.g_utf16_to_utf8(chars, chars.length, null, null, error);
+	long [] error = new long [1];
+	long utf8Ptr = OS.g_utf16_to_utf8(chars, chars.length, null, null, error);
 	if (error[0] != 0 || utf8Ptr == 0) return null;
-	long /*int*/ localePtr = OS.g_filename_from_utf8(utf8Ptr, -1, null, null, error);
+	long localePtr = OS.g_filename_from_utf8(utf8Ptr, -1, null, null, error);
 	OS.g_free(utf8Ptr);
 	if (error[0] != 0 || localePtr == 0) return null;
-	long /*int*/ uriPtr = OS.g_filename_to_uri(localePtr, 0, error);
+	long uriPtr = OS.g_filename_to_uri(localePtr, 0, error);
 	OS.g_free(localePtr);
 	if (error[0] != 0 || uriPtr == 0) return null;
-	length = OS.strlen(uriPtr);
+	length = C.strlen(uriPtr);
 	byte[] uri = new byte[length + 1];
-	OS.memmove (uri, uriPtr, length);
+	C.memmove (uri, uriPtr, length);
 	OS.g_free(uriPtr);
 	return uri;
 }
@@ -288,7 +283,7 @@ static DeviceData checkNull (PrinterData data) {
 	if (data.driver == null || data.name == null) {
 		PrinterData defaultData = null;
 		if (data.printToFile) {
-			long /*int*/ filePrinter = gtkPrinterFromPrinterData(data);
+			long filePrinter = gtkPrinterFromPrinterData(data);
 			if (filePrinter != 0) {
 				defaultData = printerDataFromGtkPrinter(filePrinter);
 				OS.g_object_unref(filePrinter);
@@ -355,7 +350,7 @@ static double restoreDouble(String key) {
 
 static boolean restoreBoolean(String key) {
 	byte [] value = restoreBytes(key, false);
-	return Boolean.valueOf(new String(value)).booleanValue();
+	return Boolean.parseBoolean(new String(value));
 }
 
 static byte [] restoreBytes(String key, boolean nullTerminate) {
@@ -375,7 +370,7 @@ static byte [] restoreBytes(String key, boolean nullTerminate) {
 	byte [] valueBuffer = new byte [length];
 	System.arraycopy (settingsData, start, valueBuffer, 0, length);
 
-	if (DEBUG) System.out.println(new String (Converter.mbcsToWcs (null, keyBuffer))+": "+new String (Converter.mbcsToWcs (null, valueBuffer)));
+	if (DEBUG) System.out.println(new String (Converter.mbcsToWcs (keyBuffer))+": "+new String (Converter.mbcsToWcs (valueBuffer)));
 
 	return valueBuffer;
 }
@@ -396,16 +391,9 @@ static byte [] restoreBytes(String key, boolean nullTerminate) {
  * @noreference This method is not intended to be referenced by clients.
  */
 @Override
-public long /*int*/ internal_new_GC(GCData data) {
-	long /*int*/ gc, drawable = 0;
-	if (OS.USE_CAIRO) {
-		gc = cairo;
-	} else {
-		GdkVisual visual = new GdkVisual ();
-		OS.memmove (visual, OS.gdk_visual_get_system());
-		drawable = OS.gdk_pixmap_new(OS.gdk_get_default_root_window(), 1, 1, visual.depth);
-		gc = OS.gdk_gc_new (drawable);
-	}
+public long internal_new_GC(GCData data) {
+	long drawable = 0;
+	long gc = cairo;
 	if (gc == 0) SWT.error (SWT.ERROR_NO_HANDLES);
 	if (data != null) {
 		if (isGCCreated) SWT.error(SWT.ERROR_INVALID_ARGUMENT);
@@ -415,16 +403,16 @@ public long /*int*/ internal_new_GC(GCData data) {
 		}
 		data.device = this;
 		data.drawable = drawable;
-		data.background = getSystemColor (SWT.COLOR_WHITE).handle;
-		data.foreground = getSystemColor (SWT.COLOR_BLACK).handle;
+		data.backgroundRGBA = getSystemColor (SWT.COLOR_WHITE).handle;
+		data.foregroundRGBA = getSystemColor (SWT.COLOR_BLACK).handle;
 		data.font = getSystemFont ();
 		Point dpi = getDPI(), screenDPI = getIndependentDPI();
-		data.width = (int)(OS.gtk_page_setup_get_paper_width (pageSetup, OS.GTK_UNIT_POINTS) * dpi.x / screenDPI.x);
-		data.height = (int)(OS.gtk_page_setup_get_paper_height (pageSetup, OS.GTK_UNIT_POINTS) * dpi.y / screenDPI.y);
+		data.width = (int)(GTK.gtk_page_setup_get_paper_width (pageSetup, GTK.GTK_UNIT_POINTS) * dpi.x / screenDPI.x);
+		data.height = (int)(GTK.gtk_page_setup_get_paper_height (pageSetup, GTK.GTK_UNIT_POINTS) * dpi.y / screenDPI.y);
 		if (cairo == 0) SWT.error(SWT.ERROR_NO_HANDLES);
 		Cairo.cairo_identity_matrix(cairo);
-		double printX = OS.gtk_page_setup_get_left_margin(pageSetup, OS.GTK_UNIT_POINTS);
-		double printY = OS.gtk_page_setup_get_top_margin(pageSetup, OS.GTK_UNIT_POINTS);
+		double printX = GTK.gtk_page_setup_get_left_margin(pageSetup, GTK.GTK_UNIT_POINTS);
+		double printY = GTK.gtk_page_setup_get_top_margin(pageSetup, GTK.GTK_UNIT_POINTS);
 		Cairo.cairo_translate(cairo, printX, printY);
 		Cairo.cairo_scale(cairo, screenDPI.x / (float)dpi.x, screenDPI.y / (float)dpi.y);
 		double[] matrix = new double[6];
@@ -452,15 +440,8 @@ public long /*int*/ internal_new_GC(GCData data) {
  * @noreference This method is not intended to be referenced by clients.
  */
 @Override
-public void internal_dispose_GC(long /*int*/ hDC, GCData data) {
-	long /*int*/ gc = hDC;
+public void internal_dispose_GC(long hDC, GCData data) {
 	if (data != null) isGCCreated = false;
-	if (OS.USE_CAIRO) return;
-	OS.g_object_unref (gc);
-	if (data != null) {
-		if (data.drawable != 0) OS.g_object_unref (data.drawable);
-		data.drawable = data.cairo = 0;
-	}
 }
 
 /**
@@ -494,10 +475,10 @@ public boolean isAutoScalable() {
  */
 public boolean startJob(String jobName) {
 	checkDevice();
-	byte [] buffer = Converter.wcsToMbcs (null, jobName, true);
-	printJob = OS.gtk_print_job_new (buffer, printer, settings, pageSetup);
+	byte [] buffer = Converter.wcsToMbcs (jobName, true);
+	printJob = GTK.gtk_print_job_new (buffer, printer, settings, pageSetup);
 	if (printJob == 0) return false;
-	surface = OS.gtk_print_job_get_surface(printJob, null);
+	surface = GTK.gtk_print_job_get_surface(printJob, null);
 	if (surface == 0) {
 		OS.g_object_unref(printJob);
 		printJob = 0;
@@ -542,7 +523,7 @@ public void endJob() {
 	checkDevice();
 	if (printJob == 0) return;
 	Cairo.cairo_surface_finish(surface);
-	OS.gtk_print_job_send(printJob, 0, 0, 0);
+	GTK.gtk_print_job_send(printJob, 0, 0, 0);
 	OS.g_object_unref(printJob);
 	printJob = 0;
 }
@@ -584,8 +565,8 @@ public void cancelJob() {
 public boolean startPage() {
 	checkDevice();
 	if (printJob == 0) return false;
-	double width = OS.gtk_page_setup_get_paper_width (pageSetup, OS.GTK_UNIT_POINTS);
-	double height = OS.gtk_page_setup_get_paper_height (pageSetup, OS.GTK_UNIT_POINTS);
+	double width = GTK.gtk_page_setup_get_paper_width (pageSetup, GTK.GTK_UNIT_POINTS);
+	double height = GTK.gtk_page_setup_get_paper_height (pageSetup, GTK.GTK_UNIT_POINTS);
 	int type = Cairo.cairo_surface_get_type (surface);
 	switch (type) {
 		case Cairo.CAIRO_SURFACE_TYPE_PS:
@@ -611,7 +592,7 @@ public boolean startPage() {
  */
 public void endPage() {
 	checkDevice();
-	if (cairo != 0) Cairo.cairo_show_page(cairo);
+	Cairo.cairo_show_page(cairo);
 }
 
 /**
@@ -628,7 +609,7 @@ public void endPage() {
 @Override
 public Point getDPI() {
 	checkDevice();
-	int resolution = OS.gtk_print_settings_get_resolution(settings);
+	int resolution = GTK.gtk_print_settings_get_resolution(settings);
 	if (DEBUG) System.out.println("print_settings.resolution=" + resolution);
 	//TODO: use new api for get x resolution and get y resolution
 	if (resolution == 0) return new Point(72, 72);
@@ -654,8 +635,8 @@ public Point getDPI() {
 public Rectangle getBounds() {
 	checkDevice();
 	Point dpi = getDPI(), screenDPI = getIndependentDPI();
-	double width = OS.gtk_page_setup_get_paper_width (pageSetup, OS.GTK_UNIT_POINTS) * dpi.x / screenDPI.x;
-	double height = OS.gtk_page_setup_get_paper_height (pageSetup, OS.GTK_UNIT_POINTS) * dpi.y / screenDPI.y;
+	double width = GTK.gtk_page_setup_get_paper_width (pageSetup, GTK.GTK_UNIT_POINTS) * dpi.x / screenDPI.x;
+	double height = GTK.gtk_page_setup_get_paper_height (pageSetup, GTK.GTK_UNIT_POINTS) * dpi.y / screenDPI.y;
 	return new Rectangle(0, 0, (int) width, (int) height);
 }
 
@@ -680,8 +661,8 @@ public Rectangle getBounds() {
 public Rectangle getClientArea() {
 	checkDevice();
 	Point dpi = getDPI(), screenDPI = getIndependentDPI();
-	double width = OS.gtk_page_setup_get_page_width(pageSetup, OS.GTK_UNIT_POINTS) * dpi.x / screenDPI.x;
-	double height = OS.gtk_page_setup_get_page_height(pageSetup, OS.GTK_UNIT_POINTS) * dpi.y / screenDPI.y;
+	double width = GTK.gtk_page_setup_get_page_width(pageSetup, GTK.GTK_UNIT_POINTS) * dpi.x / screenDPI.x;
+	double height = GTK.gtk_page_setup_get_page_height(pageSetup, GTK.GTK_UNIT_POINTS) * dpi.y / screenDPI.y;
 	return new Rectangle(0, 0, (int) width, (int) height);
 }
 
@@ -698,17 +679,17 @@ Point getIndependentDPI () {
  * printer device is unable to print.  This margin is known as the "trim."
  * This method can be used to calculate the printer's minimum margins
  * by passing in a client area of 0, 0, 0, 0 and then using the resulting
- * x and y coordinates (which will be <= 0) to determine the minimum margins
+ * x and y coordinates (which will be &lt;= 0) to determine the minimum margins
  * for the top and left edges of the paper, and the resulting width and height
  * (offset by the resulting x and y) to determine the minimum margins for the
  * bottom and right edges of the paper, as follows:
+ * </p>
  * <ul>
  * 		<li>The left trim width is -x pixels</li>
  * 		<li>The top trim height is -y pixels</li>
  * 		<li>The right trim width is (x + width) pixels</li>
  * 		<li>The bottom trim height is (y + height) pixels</li>
  * </ul>
- * </p>
  *
  * @param x the x coordinate of the client area
  * @param y the y coordinate of the client area
@@ -727,12 +708,12 @@ Point getIndependentDPI () {
 public Rectangle computeTrim(int x, int y, int width, int height) {
 	checkDevice();
 	Point dpi = getDPI(), screenDPI = getIndependentDPI();
-	double printWidth = OS.gtk_page_setup_get_page_width(pageSetup, OS.GTK_UNIT_POINTS) * dpi.x / screenDPI.x;
-	double printHeight = OS.gtk_page_setup_get_page_height(pageSetup, OS.GTK_UNIT_POINTS) * dpi.y / screenDPI.y;
-	double paperWidth = OS.gtk_page_setup_get_paper_width (pageSetup, OS.GTK_UNIT_POINTS) * dpi.x / screenDPI.x;
-	double paperHeight = OS.gtk_page_setup_get_paper_height (pageSetup, OS.GTK_UNIT_POINTS) * dpi.y / screenDPI.y;
-	double printX = -OS.gtk_page_setup_get_left_margin(pageSetup, OS.GTK_UNIT_POINTS) * dpi.x / screenDPI.x;
-	double printY = -OS.gtk_page_setup_get_top_margin(pageSetup, OS.GTK_UNIT_POINTS) * dpi.y / screenDPI.y;
+	double printWidth = GTK.gtk_page_setup_get_page_width(pageSetup, GTK.GTK_UNIT_POINTS) * dpi.x / screenDPI.x;
+	double printHeight = GTK.gtk_page_setup_get_page_height(pageSetup, GTK.GTK_UNIT_POINTS) * dpi.y / screenDPI.y;
+	double paperWidth = GTK.gtk_page_setup_get_paper_width (pageSetup, GTK.GTK_UNIT_POINTS) * dpi.x / screenDPI.x;
+	double paperHeight = GTK.gtk_page_setup_get_paper_height (pageSetup, GTK.GTK_UNIT_POINTS) * dpi.y / screenDPI.y;
+	double printX = -GTK.gtk_page_setup_get_left_margin(pageSetup, GTK.GTK_UNIT_POINTS) * dpi.x / screenDPI.x;
+	double printY = -GTK.gtk_page_setup_get_top_margin(pageSetup, GTK.GTK_UNIT_POINTS) * dpi.y / screenDPI.y;
 	double hTrim = paperWidth - printWidth;
 	double vTrim = paperHeight - printHeight;
 	return new Rectangle(x + (int)printX, y + (int)printY, width + (int)hTrim, height + (int)vTrim);
@@ -766,8 +747,8 @@ protected void create(DeviceData deviceData) {
  */
 @Override
 protected void init() {
-	settings = OS.gtk_print_settings_new();
-	pageSetup = OS.gtk_page_setup_new();
+	settings = GTK.gtk_print_settings_new();
+	pageSetup = GTK.gtk_page_setup_new();
 	if (data.otherData != null) {
 		restore(data.otherData, settings, pageSetup);
 	}
@@ -776,33 +757,33 @@ protected void init() {
 	if (data.printToFile && data.fileName != null) {
 		byte [] uri = uriFromFilename(data.fileName);
 		if (uri != null) {
-			OS.gtk_print_settings_set(settings, OS.GTK_PRINT_SETTINGS_OUTPUT_URI, uri);
+			GTK.gtk_print_settings_set(settings, GTK.GTK_PRINT_SETTINGS_OUTPUT_URI, uri);
 		}
 	}
-	OS.gtk_print_settings_set_n_copies(settings, data.copyCount);
-	OS.gtk_print_settings_set_collate(settings, data.collate);
+	GTK.gtk_print_settings_set_n_copies(settings, data.copyCount);
+	GTK.gtk_print_settings_set_collate(settings, data.collate);
 	if (data.duplex != SWT.DEFAULT) {
-		int duplex = data.duplex == PrinterData.DUPLEX_LONG_EDGE ? OS.GTK_PRINT_DUPLEX_HORIZONTAL
-			: data.duplex == PrinterData.DUPLEX_SHORT_EDGE ? OS.GTK_PRINT_DUPLEX_VERTICAL
-			: OS.GTK_PRINT_DUPLEX_SIMPLEX;
-		OS.gtk_print_settings_set_duplex (settings, duplex);
+		int duplex = data.duplex == PrinterData.DUPLEX_LONG_EDGE ? GTK.GTK_PRINT_DUPLEX_HORIZONTAL
+			: data.duplex == PrinterData.DUPLEX_SHORT_EDGE ? GTK.GTK_PRINT_DUPLEX_VERTICAL
+			: GTK.GTK_PRINT_DUPLEX_SIMPLEX;
+		GTK.gtk_print_settings_set_duplex (settings, duplex);
 		/*
 		 * Bug in GTK.  The cups backend only looks at the value
 		 * of the non-API field cups-Duplex in the print_settings.
 		 * The fix is to manually set cups-Duplex to Tumble or NoTumble.
 		 */
 		String cupsDuplexType = null;
-		if (duplex == OS.GTK_PRINT_DUPLEX_HORIZONTAL) cupsDuplexType = "DuplexNoTumble";
-		else if (duplex == OS.GTK_PRINT_DUPLEX_VERTICAL) cupsDuplexType = "DuplexTumble";
+		if (duplex == GTK.GTK_PRINT_DUPLEX_HORIZONTAL) cupsDuplexType = "DuplexNoTumble";
+		else if (duplex == GTK.GTK_PRINT_DUPLEX_VERTICAL) cupsDuplexType = "DuplexTumble";
 		if (cupsDuplexType != null) {
-			byte [] keyBuffer = Converter.wcsToMbcs (null, "cups-Duplex", true);
-			byte [] valueBuffer = Converter.wcsToMbcs (null, cupsDuplexType, true);
-			OS.gtk_print_settings_set(settings, keyBuffer, valueBuffer);
+			byte [] keyBuffer = Converter.wcsToMbcs ("cups-Duplex", true);
+			byte [] valueBuffer = Converter.wcsToMbcs (cupsDuplexType, true);
+			GTK.gtk_print_settings_set(settings, keyBuffer, valueBuffer);
 		}
 	}
-	int orientation = data.orientation == PrinterData.LANDSCAPE ? OS.GTK_PAGE_ORIENTATION_LANDSCAPE : OS.GTK_PAGE_ORIENTATION_PORTRAIT;
-	OS.gtk_page_setup_set_orientation(pageSetup, orientation);
-	OS.gtk_print_settings_set_orientation(settings, orientation);
+	int orientation = data.orientation == PrinterData.LANDSCAPE ? GTK.GTK_PAGE_ORIENTATION_LANDSCAPE : GTK.GTK_PAGE_ORIENTATION_PORTRAIT;
+	GTK.gtk_page_setup_set_orientation(pageSetup, orientation);
+	GTK.gtk_print_settings_set_orientation(settings, orientation);
 	super.init ();
 }
 
