@@ -53,7 +53,7 @@ public final class Printer extends Device {
 	 *
 	 * @noreference This field is not intended to be referenced by clients.
 	 */
-	public long /*int*/ handle;
+	public long handle;
 
 	/**
 	 * the printer data describing this printer
@@ -218,15 +218,15 @@ protected void create(DeviceData deviceData) {
 	/* Use the character encoding for the default locale */
 	TCHAR driver = new TCHAR(0, data.driver, true);
 	TCHAR device = new TCHAR(0, data.name, true);
-	long /*int*/ lpInitData = 0;
+	long lpInitData = 0;
 	byte devmodeData [] = data.otherData;
-	long /*int*/ hHeap = OS.GetProcessHeap();
+	long hHeap = OS.GetProcessHeap();
 	if (devmodeData != null && devmodeData.length != 0) {
 		/* If user setup info from a print dialog was specified, restore the DEVMODE struct. */
 		lpInitData = OS.HeapAlloc(hHeap, OS.HEAP_ZERO_MEMORY, devmodeData.length);
 		OS.MoveMemory(lpInitData, devmodeData, devmodeData.length);
 	} else {
-		long /*int*/ [] hPrinter = new long /*int*/ [1];
+		long [] hPrinter = new long [1];
 		OS.OpenPrinter(device, hPrinter, 0);
 		if (hPrinter[0] != 0) {
 			int dwNeeded = OS.DocumentProperties(0, hPrinter[0], device, 0, 0, 0);
@@ -287,7 +287,7 @@ protected void create(DeviceData deviceData) {
  * @noreference This method is not intended to be referenced by clients.
  */
 @Override
-public long /*int*/ internal_new_GC(GCData data) {
+public long internal_new_GC(GCData data) {
 	if (handle == 0) SWT.error(SWT.ERROR_NO_HANDLES);
 	if (data != null) {
 		if (isGCCreated) SWT.error(SWT.ERROR_INVALID_ARGUMENT);
@@ -320,7 +320,7 @@ public long /*int*/ internal_new_GC(GCData data) {
  * @noreference This method is not intended to be referenced by clients.
  */
 @Override
-public void internal_dispose_GC(long /*int*/ hDC, GCData data) {
+public void internal_dispose_GC(long hDC, GCData data) {
 	if (data != null) isGCCreated = false;
 }
 
@@ -357,8 +357,8 @@ public boolean startJob(String jobName) {
 	checkDevice();
 	DOCINFO di = new DOCINFO();
 	di.cbSize = DOCINFO.sizeof;
-	long /*int*/ hHeap = OS.GetProcessHeap();
-	long /*int*/ lpszDocName = 0;
+	long hHeap = OS.GetProcessHeap();
+	long lpszDocName = 0;
 	if (jobName != null && jobName.length() != 0) {
 		/* Use the character encoding for the default locale */
 		TCHAR buffer = new TCHAR(0, jobName, true);
@@ -367,7 +367,7 @@ public boolean startJob(String jobName) {
 		OS.MoveMemory(lpszDocName, buffer, byteCount);
 		di.lpszDocName = lpszDocName;
 	}
-	long /*int*/ lpszOutput = 0;
+	long lpszOutput = 0;
 	if (data.printToFile) {
 		if (data.fileName == null) {
 			/* Prompt the user for a file name. */
@@ -531,17 +531,17 @@ public Rectangle getClientArea () {
  * printer device is unable to print.  This margin is known as the "trim."
  * This method can be used to calculate the printer's minimum margins
  * by passing in a client area of 0, 0, 0, 0 and then using the resulting
- * x and y coordinates (which will be <= 0) to determine the minimum margins
+ * x and y coordinates (which will be &lt;= 0) to determine the minimum margins
  * for the top and left edges of the paper, and the resulting width and height
  * (offset by the resulting x and y) to determine the minimum margins for the
  * bottom and right edges of the paper, as follows:
+ * </p>
  * <ul>
  * 		<li>The left trim width is -x pixels</li>
  * 		<li>The top trim height is -y pixels</li>
  * 		<li>The right trim width is (x + width) pixels</li>
  * 		<li>The bottom trim height is (y + height) pixels</li>
  * </ul>
- * </p>
  *
  * @param x the x coordinate of the client area
  * @param y the y coordinate of the client area
