@@ -15,28 +15,27 @@ package org.eclipse.swt.internal.webkit;
 
 
 import org.eclipse.swt.internal.ole.win32.*;
-import org.eclipse.swt.internal.win32.*;
 
 public class IWebDataSource extends IUnknown {
 
-public IWebDataSource (long /*int*/ address) {
+public IWebDataSource (long address) {
 	super (address);
 }
 
-public int representation (long /*int*/[] rep) {
-	return OS.VtblCall (5, getAddress (), rep);
+public int representation (long[] rep) {
+	return COM.VtblCall (5, getAddress (), rep);
 }
 
-public int webFrame (long /*int*/[] frame) {
-	return OS.VtblCall (6, getAddress (), frame);
+public int webFrame (long[] frame) {
+	return COM.VtblCall (6, getAddress (), frame);
 }
 
-public int request (long /*int*/[] request) {
-	return OS.VtblCall (8, getAddress (), request);
+public int request (long[] request) {
+	return COM.VtblCall (8, getAddress (), request);
 }
 
-public int pageTitle (long /*int*/[] title) {
-	return OS.VtblCall (12, getAddress (), title);
+public int pageTitle (long[] title) {
+	return COM.VtblCall (12, getAddress (), title);
 }
 
 }
