@@ -15,16 +15,15 @@ package org.eclipse.swt.internal.webkit;
 
 
 import org.eclipse.swt.internal.ole.win32.*;
-import org.eclipse.swt.internal.win32.*;
 
 public class IWebDocumentRepresentation extends IUnknown {
 
-public IWebDocumentRepresentation (long /*int*/ address) {
+public IWebDocumentRepresentation (long address) {
 	super (address);
 }
 
-public int documentSource (long /*int*/[] source) {
-	return OS.VtblCall (8, getAddress (), source);
+public int documentSource (long[] source) {
+	return COM.VtblCall (8, getAddress (), source);
 }
 
 }
