@@ -15,28 +15,27 @@ package org.eclipse.swt.internal.webkit;
 
 
 import org.eclipse.swt.internal.ole.win32.*;
-import org.eclipse.swt.internal.win32.*;
 
 public class IWebFrame extends IUnknown {
 
-public IWebFrame (long /*int*/ address) {
+public IWebFrame (long address) {
 	super (address);
 }
 
-public int loadRequest (long /*int*/ request) {
-	return OS.VtblCall (8, getAddress (), request);
+public int loadRequest (long request) {
+	return COM.VtblCall (8, getAddress (), request);
 }
 
-public int loadHTMLString (long /*int*/ string, long /*int*/ baseURL) {
-	return OS.VtblCall (10, getAddress (), string, baseURL);
+public int loadHTMLString (long string, long baseURL) {
+	return COM.VtblCall (10, getAddress (), string, baseURL);
 }
 
-public int dataSource (long /*int*/[] source) {
-	return OS.VtblCall (13, getAddress (), source);
+public int dataSource (long[] source) {
+	return COM.VtblCall (13, getAddress (), source);
 }
 
-public long /*int*/ globalContext () {
-	return OS.VtblCall (23, getAddress ());
+public long globalContext () {
+	return COM.VtblCall (23, getAddress ());
 }
 
 }
