@@ -15,24 +15,23 @@ package org.eclipse.swt.internal.webkit;
 
 
 import org.eclipse.swt.internal.ole.win32.*;
-import org.eclipse.swt.internal.win32.*;
 
 public class IWebFramePrivate extends IUnknown {
 
-public IWebFramePrivate (long /*int*/ address) {
+public IWebFramePrivate (long address) {
 	super (address);
 }
 
-public int setInPrintingMode (int value, long /*int*/ printDC) {
-	return OS.VtblCall (8, getAddress (), value, printDC);
+public int setInPrintingMode (int value, long printDC) {
+	return COM.VtblCall (8, getAddress (), value, printDC);
 }
 
-public int getPrintedPageCount (long /*int*/ printDC, int[] pageCount) {
-	return OS.VtblCall (9, getAddress (), printDC, pageCount);
+public int getPrintedPageCount (long printDC, int[] pageCount) {
+	return COM.VtblCall (9, getAddress (), printDC, pageCount);
 }
 
-public int spoolPages (long /*int*/ printDC, int startPage, int endPage, long /*int*/[] ctx) {
-	return OS.VtblCall (10, getAddress (), printDC, startPage, endPage, ctx);
+public int spoolPages (long printDC, int startPage, int endPage, long[] ctx) {
+	return COM.VtblCall (10, getAddress (), printDC, startPage, endPage, ctx);
 }
 
 }
