@@ -15,28 +15,27 @@ package org.eclipse.swt.internal.webkit;
 
 
 import org.eclipse.swt.internal.ole.win32.*;
-import org.eclipse.swt.internal.win32.*;
 
 public class IWebIBActions extends IUnknown {
 
-public IWebIBActions (long /*int*/ address) {
+public IWebIBActions (long address) {
 	super (address);
 }
 
-public int stopLoading (long /*int*/ sender) {
-	return OS.VtblCall (4, getAddress (), sender);
+public int stopLoading (long sender) {
+	return COM.VtblCall (4, getAddress (), sender);
 }
 
-public int reload (long /*int*/ sender) {
-	return OS.VtblCall (5, getAddress (), sender);
+public int reload (long sender) {
+	return COM.VtblCall (5, getAddress (), sender);
 }
 
-public int canGoBack (long /*int*/ sender, int[] result) {
-	return OS.VtblCall (6, getAddress (), sender, result);
+public int canGoBack (long sender, int[] result) {
+	return COM.VtblCall (6, getAddress (), sender, result);
 }
 
-public int canGoForward (long /*int*/ sender, int[] result) {
-	return OS.VtblCall (8, getAddress (), sender, result);
+public int canGoForward (long sender, int[] result) {
+	return COM.VtblCall (8, getAddress (), sender, result);
 }
 
 }
