@@ -15,28 +15,27 @@ package org.eclipse.swt.internal.webkit;
 
 
 import org.eclipse.swt.internal.ole.win32.*;
-import org.eclipse.swt.internal.win32.*;
 
 public class IWebURLAuthenticationChallenge extends IUnknown {
 
-public IWebURLAuthenticationChallenge (long /*int*/ address) {
+public IWebURLAuthenticationChallenge (long address) {
 	super (address);
 }
 
 public int previousFailureCount (int[] result) {
-	return OS.VtblCall (7, getAddress (), result);
+	return COM.VtblCall (7, getAddress (), result);
 }
 
-public int proposedCredential (long /*int*/[] result) {
-	return OS.VtblCall (8, getAddress (), result);
+public int proposedCredential (long[] result) {
+	return COM.VtblCall (8, getAddress (), result);
 }
 
-public int protectionSpace (long /*int*/[] result) {
-	return OS.VtblCall (9, getAddress (), result);
+public int protectionSpace (long[] result) {
+	return COM.VtblCall (9, getAddress (), result);
 }
 
-public int sender (long /*int*/[] sender) {
-	return OS.VtblCall (10, getAddress (), sender);
+public int sender (long[] sender) {
+	return COM.VtblCall (10, getAddress (), sender);
 }
 
 }
