@@ -15,20 +15,19 @@ package org.eclipse.swt.internal.webkit;
 
 
 import org.eclipse.swt.internal.ole.win32.*;
-import org.eclipse.swt.internal.win32.*;
 
 public class IWebURLAuthenticationChallengeSender extends IUnknown {
 
-public IWebURLAuthenticationChallengeSender (long /*int*/ address) {
+public IWebURLAuthenticationChallengeSender (long address) {
 	super (address);
 }
 
-public int cancelAuthenticationChallenge (long /*int*/ challenge) {
-	return OS.VtblCall (3, getAddress (), challenge);
+public int cancelAuthenticationChallenge (long challenge) {
+	return COM.VtblCall (3, getAddress (), challenge);
 }
 
-public int useCredential (long /*int*/ credential, long /*int*/ challenge) {
-	return OS.VtblCall (5, getAddress (), credential, challenge);
+public int useCredential (long credential, long challenge) {
+	return COM.VtblCall (5, getAddress (), credential, challenge);
 }
 
 }
