@@ -1,9 +1,12 @@
 /*******************************************************************************
- * Copyright (c) 2010, 2012 IBM Corporation and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * Copyright (c) 2010, 2017 IBM Corporation and others.
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
@@ -15,7 +18,7 @@ import org.eclipse.swt.internal.ole.win32.*;
 
 public class IWebURLCredential extends IUnknown {
 
-public IWebURLCredential (long /*int*/ address) {
+public IWebURLCredential (long address) {
 	super (address);
 }
 
@@ -23,15 +26,15 @@ public int hasPassword (int[] result) {
 	return COM.VtblCall (3, getAddress (), result);
 }
 
-public int initWithUser (long /*int*/ user, long /*int*/ password, long /*int*/ persistence) {
+public int initWithUser (long user, long password, long persistence) {
 	return COM.VtblCall (4, getAddress (), user, password, persistence);
 }
 
-public int password (long /*int*/[] password) {
+public int password (long[] password) {
 	return COM.VtblCall (5, getAddress (), password);
 }
 
-public int user (long /*int*/[] result) {
+public int user (long[] result) {
 	return COM.VtblCall (7, getAddress (), result);
 }
 
