@@ -147,7 +147,7 @@ public Device(DeviceData data) {
  * </p><p>
  * In future releases of SWT, there may be more or fewer error
  * checks and exceptions may be thrown for different reasons.
- * <p>
+ * </p>
  *
  * @exception SWTException <ul>
  *    <li>ERROR_WIDGET_DISPOSED - if the receiver has been disposed</li>
@@ -324,7 +324,7 @@ public int getDepth () {
 	checkDevice ();
 	NSScreen primaryScreen = getPrimaryScreen();
 	if (primaryScreen == null) return 0;
-	return (int)/*64*/OS.NSBitsPerPixelFromDepth(primaryScreen.depth());
+	return (int)OS.NSBitsPerPixelFromDepth(primaryScreen.depth());
 }
 
 /**
@@ -370,19 +370,19 @@ public FontData[] getFontList (String faceName, boolean scalable) {
 	NSArray families = NSFontManager.sharedFontManager().availableFontFamilies();
 	FontData[] fds = new FontData[100];
 	if (families != null) {
-		long /*int*/ familyCount = families.count();
+		long familyCount = families.count();
 		for (int i = 0; i < familyCount; i++) {
 			NSString nsFamily = new NSString(families.objectAtIndex(i));
 			String name = nsFamily.getString();
 			NSArray fonts = NSFontManager.sharedFontManager().availableMembersOfFontFamily(nsFamily);
 
 			if (fonts != null) {
-				int fontCount = (int)/*64*/fonts.count();
+				int fontCount = (int)fonts.count();
 				for (int j = 0; j < fontCount; j++) {
 					NSArray fontDetails = new NSArray(fonts.objectAtIndex(j));
 					String nsName = new NSString(fontDetails.objectAtIndex(0)).getString();
-					long /*int*/ weight = new NSNumber(fontDetails.objectAtIndex(2)).integerValue();
-					long /*int*/ traits = new NSNumber(fontDetails.objectAtIndex(3)).integerValue();
+					long weight = new NSNumber(fontDetails.objectAtIndex(2)).integerValue();
+					long traits = new NSNumber(fontDetails.objectAtIndex(3)).integerValue();
 					int style = SWT.NORMAL;
 					if ((traits & OS.NSItalicFontMask) != 0) style |= SWT.ITALIC;
 					if (weight == 9) style |= SWT.BOLD;
@@ -428,10 +428,7 @@ Point getScreenDPI () {
 	NSDictionary dictionary = screen.deviceDescription();
 	NSValue value = new NSValue(dictionary.objectForKey(new id(OS.NSDeviceResolution())).id);
 	NSSize size = value.sizeValue();
-	double /*float*/ scaling = 1;
-	if (OS.VERSION >= 0x1070) {
-		scaling = screen.backingScaleFactor();
-	}
+	double scaling = screen.backingScaleFactor();
 	return new Point((int)(size.width / scaling), (int)(size.height / scaling));
 }
 
@@ -559,7 +556,7 @@ protected void init () {
 
 	/* Initialize the system font slot */
 	boolean smallFonts = System.getProperty("org.eclipse.swt.internal.carbon.smallFonts") != null;
-	double /*float*/ systemFontSize = smallFonts ? NSFont.smallSystemFontSize() : NSFont.systemFontSize();
+	double systemFontSize = smallFonts ? NSFont.smallSystemFontSize() : NSFont.systemFontSize();
 	Point dpi = this.dpi = getDPI(), screenDPI = getScreenDPI();
 	NSFont font = NSFont.systemFontOfSize(systemFontSize * dpi.y / screenDPI.y);
 	font.retain();
@@ -582,7 +579,7 @@ protected void init () {
  * @noreference This method is not intended to be referenced by clients.
  */
 @Override
-public abstract long /*int*/ internal_new_GC (GCData data);
+public abstract long internal_new_GC (GCData data);
 
 /**
  * Invokes platform specific functionality to dispose a GC handle.
@@ -600,7 +597,7 @@ public abstract long /*int*/ internal_new_GC (GCData data);
  * @noreference This method is not intended to be referenced by clients.
  */
 @Override
-public abstract void internal_dispose_GC (long /*int*/ hDC, GCData data);
+public abstract void internal_dispose_GC (long hDC, GCData data);
 
 /**
  * Returns <code>true</code> if the device has been disposed,
@@ -637,19 +634,10 @@ public boolean isDisposed () {
 public boolean loadFont (String path) {
 	checkDevice();
 	if (path == null) SWT.error(SWT.ERROR_NULL_ARGUMENT);
-	boolean result = false;
 	NSString nsPath = NSString.stringWith(path);
-	long /*int*/ fsRepresentation = nsPath.fileSystemRepresentation();
-
-	if (fsRepresentation != 0) {
-		byte [] fsRef = new byte [80];
-		boolean [] isDirectory = new boolean[1];
-		if (OS.FSPathMakeRef (fsRepresentation, fsRef, isDirectory) == OS.noErr) {
-			result = OS.ATSFontActivateFromFileReference (fsRef, OS.kATSFontContextLocal, OS.kATSFontFormatUnspecified, 0, OS.kATSOptionFlagsDefault, null) == OS.noErr;
-		}
-	}
-
-	return result;
+	NSURL nsUrl = NSURL.fileURLWithPath(nsPath);
+	if (nsUrl == null) return false;
+	return OS.CTFontManagerRegisterFontsForURL(nsUrl.id, OS.kCTFontManagerScopeProcess, 0);
 }
 
 void new_Object (Object object) {
@@ -735,7 +723,7 @@ void printErrors () {
  * The handle is needed by <code>destroy</code>.
  * </p>
  * This method is called before <code>destroy</code>.
- * </p><p>
+ * <p>
  * If subclasses reimplement this method, they must
  * call the <code>super</code> implementation.
  * </p>
