@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -19,6 +19,7 @@ import java.io.*;
 import org.eclipse.swt.*;
 import org.eclipse.swt.internal.*;
 import org.eclipse.swt.internal.cocoa.*;
+import org.eclipse.swt.internal.graphics.*;
 
 /**
  * Instances of this class are graphics which have been prepared
@@ -166,8 +167,8 @@ public final class Image extends Resource implements Drawable {
 		}
 
 		void init(NSImageRep nativeRep, NSBitmapImageRep rep) {
-			int width = (int)/*64*/nativeRep.pixelsWide();
-			int height = (int)/*64*/nativeRep.pixelsHigh();
+			int width = (int)nativeRep.pixelsWide();
+			int height = (int)nativeRep.pixelsHigh();
 
 			boolean hasAlpha = rep.hasAlpha();
 			int bpr = width * 4;
@@ -176,8 +177,8 @@ public final class Image extends Resource implements Drawable {
 			rect.height = height;
 
 			/* Compute the pixels */
-			long /*int*/ colorspace = OS.CGColorSpaceCreateDeviceRGB();
-			long /*int*/ ctx = OS.CGBitmapContextCreate(rep.bitmapData(), width, height, 8, bpr, colorspace, OS.kCGImageAlphaNoneSkipFirst);
+			long colorspace = OS.CGColorSpaceCreateDeviceRGB();
+			long ctx = OS.CGBitmapContextCreate(rep.bitmapData(), width, height, 8, bpr, colorspace, OS.kCGImageAlphaNoneSkipFirst);
 			OS.CGColorSpaceRelease(colorspace);
 			NSGraphicsContext.static_saveGraphicsState();
 			NSGraphicsContext.setCurrentContext(NSGraphicsContext.graphicsContextWithGraphicsPort(ctx, false));
@@ -187,15 +188,15 @@ public final class Image extends Resource implements Drawable {
 
 			if (hasAlpha) {
 				/* Compute the alpha values */
-				long /*int*/ bitmapBytesPerRow = width;
-				long /*int*/ bitmapByteCount = bitmapBytesPerRow * height;
-				long /*int*/ alphaBitmapData = C.malloc(bitmapByteCount);
-				long /*int*/ alphaBitmapCtx = OS.CGBitmapContextCreate(alphaBitmapData, width, height, 8, bitmapBytesPerRow, 0, OS.kCGImageAlphaOnly);
+				long bitmapBytesPerRow = width;
+				long bitmapByteCount = bitmapBytesPerRow * height;
+				long alphaBitmapData = C.malloc(bitmapByteCount);
+				long alphaBitmapCtx = OS.CGBitmapContextCreate(alphaBitmapData, width, height, 8, bitmapBytesPerRow, 0, OS.kCGImageAlphaOnly);
 				NSGraphicsContext.static_saveGraphicsState();
 				NSGraphicsContext.setCurrentContext(NSGraphicsContext.graphicsContextWithGraphicsPort(alphaBitmapCtx, false));
 				nativeRep.drawInRect(rect);
 				NSGraphicsContext.static_restoreGraphicsState();
-				byte[] alphaData = new byte[(int)/*64*/bitmapByteCount];
+				byte[] alphaData = new byte[(int)bitmapByteCount];
 				C.memmove(alphaData, alphaBitmapData, bitmapByteCount);
 				C.free(alphaBitmapData);
 				OS.CGContextRelease(alphaBitmapCtx);
@@ -405,17 +406,17 @@ private void copyAlphaInfo(AlphaInfo src_alphaInfo, AlphaInfo dest_alphaInfo) {
  * Applies the flag to the newly created representation. This method is invoked from the Image copy constructor.
  */
 private void createRepFromSourceAndApplyFlag(NSBitmapImageRep srcRep, int srcWidth, int srcHeight, int flag) {
-	long /*int*/ srcData = srcRep.bitmapData();
-	long /*int*/ srcBitmapFormat = srcRep.bitmapFormat();
-	long /*int*/ srcBpp = srcRep.bitsPerPixel();
-	long /*int*/ srcBpr = srcRep.bytesPerRow();
+	long srcData = srcRep.bitmapData();
+	long srcBitmapFormat = srcRep.bitmapFormat();
+	long srcBpp = srcRep.bitsPerPixel();
+	long srcBpr = srcRep.bytesPerRow();
 
 	NSBitmapImageRep rep = (NSBitmapImageRep)new NSBitmapImageRep().alloc();
 	rep = rep.initWithBitmapDataPlanes(0, srcWidth, srcHeight, srcRep.bitsPerSample(), srcRep.samplesPerPixel(), srcRep.hasAlpha(), srcRep.isPlanar(), OS.NSDeviceRGBColorSpace, srcBitmapFormat, srcRep.bytesPerRow(), srcBpp);
 	handle.addRepresentation(rep);
 	rep.release();
 
-	long /*int*/ data = rep.bitmapData();
+	long data = rep.bitmapData();
 	C.memmove(data, srcData, srcWidth * srcHeight * 4);
 	if (flag != SWT.IMAGE_COPY) {
 		final int redOffset, greenOffset, blueOffset;
@@ -441,7 +442,7 @@ private void createRepFromSourceAndApplyFlag(NSBitmapImageRep srcRep, int srcWid
 			byte oneRed = (byte)oneRGB.red;
 			byte oneGreen = (byte)oneRGB.green;
 			byte oneBlue = (byte)oneRGB.blue;
-			byte[] line = new byte[(int)/*64*/srcBpr];
+			byte[] line = new byte[(int)srcBpr];
 			for (int y=0; y<srcHeight; y++) {
 				C.memmove(line, data + (y * srcBpr), srcBpr);
 				int offset = 0;
@@ -466,7 +467,7 @@ private void createRepFromSourceAndApplyFlag(NSBitmapImageRep srcRep, int srcWid
 			break;
 		}
 		case SWT.IMAGE_GRAY: {
-			byte[] line = new byte[(int)/*64*/srcBpr];
+			byte[] line = new byte[(int)srcBpr];
 			for (int y=0; y<srcHeight; y++) {
 				C.memmove(line, data + (y * srcBpr), srcBpr);
 				int offset = 0;
@@ -847,14 +848,14 @@ private AlphaInfo _getAlphaInfoAtCurrentZoom (NSBitmapImageRep rep) {
 }
 
 ImageData _getImageData (NSBitmapImageRep imageRep, AlphaInfo info) {
-	long /*int*/ width = imageRep.pixelsWide();
-	long /*int*/ height = imageRep.pixelsHigh();
-	long /*int*/ bpr = imageRep.bytesPerRow();
-	long /*int*/ bpp = imageRep.bitsPerPixel();
-	long /*int*/ bitmapData = imageRep.bitmapData();
-	long /*int*/ bitmapFormat = imageRep.bitmapFormat();
-	long /*int*/ dataSize = height * bpr;
-	byte[] srcData = new byte[(int)/*64*/dataSize];
+	long width = imageRep.pixelsWide();
+	long height = imageRep.pixelsHigh();
+	long bpr = imageRep.bytesPerRow();
+	long bpp = imageRep.bitsPerPixel();
+	long bitmapData = imageRep.bitmapData();
+	long bitmapFormat = imageRep.bitmapFormat();
+	long dataSize = height * bpr;
+	byte[] srcData = new byte[(int)dataSize];
 	C.memmove(srcData, bitmapData, dataSize);
 
 	PaletteData palette;
@@ -863,8 +864,8 @@ ImageData _getImageData (NSBitmapImageRep imageRep, AlphaInfo info) {
 	} else {
 		palette = new PaletteData(0xFF0000, 0xFF00, 0xFF);
 	}
-	ImageData data = new ImageData((int)/*64*/width, (int)/*64*/height, (int)/*64*/bpp, palette, 1, srcData);
-	data.bytesPerLine = (int)/*64*/bpr;
+	ImageData data = new ImageData((int)width, (int)height, (int)bpp, palette, 1, srcData);
+	data.bytesPerLine = (int)bpr;
 	if (imageRep.hasAlpha() && info.transparentPixel == -1 && info.alpha == -1 && info.alphaData == null) {
 		byte[] alphaD = new byte[(int) (dataSize/4)];
 		int offset = (bitmapFormat & OS.NSAlphaFirstBitmapFormat) != 0 ? 0 : 3, a = 0;
@@ -877,8 +878,8 @@ ImageData _getImageData (NSBitmapImageRep imageRep, AlphaInfo info) {
 		if (info.transparentPixel == -1 && type == SWT.ICON) {
 			/* Get the icon mask data */
 			int maskPad = 2;
-			long /*int*/ maskBpl = (((width + 7) / 8) + (maskPad - 1)) / maskPad * maskPad;
-			byte[] maskData = new byte[(int)/*64*/(height * maskBpl)];
+			long maskBpl = (((width + 7) / 8) + (maskPad - 1)) / maskPad * maskPad;
+			byte[] maskData = new byte[(int)(height * maskBpl)];
 			int offset = 0, maskOffset = 0;
 			for (int y = 0; y<height; y++) {
 				for (int x = 0; x<width; x++) {
@@ -940,12 +941,12 @@ void createAlpha () {
 	if (!NSThread.isMainThread()) pool = (NSAutoreleasePool) new NSAutoreleasePool().alloc().init();
 	try {
 		NSBitmapImageRep imageRep = getRepresentation();
-		long /*int*/ height = imageRep.pixelsHigh();
-		long /*int*/ bpr = imageRep.bytesPerRow();
-		long /*int*/ bitmapData = imageRep.bitmapData();
-		long /*int*/ format = imageRep.bitmapFormat();
-		long /*int*/ dataSize = height * bpr;
-		byte[] srcData = new byte[(int)/*64*/dataSize];
+		long height = imageRep.pixelsHigh();
+		long bpr = imageRep.bytesPerRow();
+		long bitmapData = imageRep.bitmapData();
+		long format = imageRep.bitmapFormat();
+		long dataSize = height * bpr;
+		byte[] srcData = new byte[(int)dataSize];
 		C.memmove(srcData, bitmapData, dataSize);
 		if (info.transparentPixel != -1) {
 			if ((format & OS.NSAlphaFirstBitmapFormat) != 0) {
@@ -965,10 +966,10 @@ void createAlpha () {
 				srcData[i] = a;
 			}
 		} else {
-			long /*int*/ width = imageRep.pixelsWide();
+			long width = imageRep.pixelsWide();
 			int offset = 0, alphaOffset = (format & OS.NSAlphaFirstBitmapFormat) != 0 ? 0 : 3;
 			for (int y = 0; y<height; y++) {
-				for (int x = 0; x<width; x++) {
+				for (int x = 0; x<width && alphaOffset<info.alphaData.length && offset<srcData.length; x++) {
 					srcData[offset] = info.alphaData[alphaOffset];
 					offset += 4;
 					alphaOffset += 1;
@@ -1127,7 +1128,7 @@ public boolean equals (Object object) {
 NSBitmapImageRep getRepresentation_100 () {
 	NSArray reps = handle.representations();
 	NSSize size = handle.size();
-	long /*int*/ count = reps.count();
+	long count = reps.count();
 	for (int i = 0; i < count; i++) {
 		NSBitmapImageRep rep = new NSBitmapImageRep(reps.objectAtIndex(i));
 		if (((int)size.width == rep.pixelsWide() && (int)size.height == rep.pixelsHigh())) {
@@ -1150,16 +1151,36 @@ NSBitmapImageRep getRepresentation_100 () {
 NSBitmapImageRep getRepresentation_200 () {
 	NSArray reps = handle.representations();
 	NSSize size = handle.size();
-	long /*int*/ count = reps.count();
+	long count = reps.count();
+	NSBitmapImageRep bestRep = null;
+	int width = (int)size.width * 2;
+	int height = (int)size.height * 2;
+	NSBitmapImageRep rep;
 	for (int i = 0; i < count; i++) {
-		NSBitmapImageRep rep = new NSBitmapImageRep(reps.objectAtIndex(i));
-		int width = (int)size.width * 2;
-		int height = (int)size.height * 2;
+		rep = new NSBitmapImageRep(reps.objectAtIndex(i));
 		if ((width == rep.pixelsWide() && height == rep.pixelsHigh())) {
 			if (rep.isKindOfClass(OS.class_NSBitmapImageRep)) {
 				return rep;
 			}
+			if (bestRep == null) {
+				bestRep = rep;
+			}
 		}
+
+	}
+	if (bestRep != null) {
+		bestRep.retain();
+		for (int i = 0; i < count; i++) {
+			handle.removeRepresentation(new NSImageRep(handle.representations().objectAtIndex(0)));
+		}
+		handle.addRepresentation(bestRep);
+		NSBitmapImageRep newRep = (NSBitmapImageRep)new NSBitmapImageRep().alloc();
+		newRep = newRep.initWithData(handle.TIFFRepresentation());
+		handle.addRepresentation(newRep);
+		handle.removeRepresentation(bestRep);
+		bestRep.release();
+		newRep.release();
+		return newRep;
 	}
 	return null;
 }
@@ -1190,7 +1211,7 @@ public Color getBackground() {
 	int red = (alphaInfo.transparentPixel >> 16) & 0xFF;
 	int green = (alphaInfo.transparentPixel >> 8) & 0xFF;
 	int blue = (alphaInfo.transparentPixel >> 0) & 0xFF;
-	return Color.cocoa_new(device, new double /*float*/ []{red / 255f, green / 255f, blue / 255f, 1});
+	return Color.cocoa_new(device, new double []{red / 255f, green / 255f, blue / 255f, 1});
 }
 
 /**
@@ -1324,55 +1345,85 @@ public ImageData getImageData(int zoom) {
 		boolean hasImageProvider = imageFileNameProvider != null || imageDataProvider != null;
 		if (zoom == 100) {
 			NSBitmapImageRep imageRep;
-			imageRep = hasImageProvider ? getRepresentation_100() : getRepresentation();
-			return _getImageData(imageRep, alphaInfo_100);
-		}
-		if (zoom == 200) {
 			if (hasImageProvider) {
-				NSBitmapImageRep imageRep200 = getRepresentation_200();
-				if (imageRep200 != null) {
-					if (alphaInfo_100.alphaData != null && alphaInfo_200 != null) {
-						if (alphaInfo_200.alphaData == null) initAlpha_200(imageRep200);
+				imageRep = getRepresentation_100();
+				return _getImageData(imageRep, alphaInfo_100);
+			} else {
+				imageRep = getRepresentation();
+				if (imageRep.pixelsHigh() == this.height) {
+					return _getImageData(imageRep, alphaInfo_100);
+				} else {
+					if (alphaInfo_200 == null) {
+						initAlpha_200(imageRep);
 					}
-					return _getImageData(imageRep200, alphaInfo_200);
+
+					NSArray reps = handle.representations();
+					long count = reps.count();
+					for (int i = 0; i < count; i++) {
+						handle.removeRepresentation(new NSImageRep(handle.representations().objectAtIndex(0)));
+					}
+					handle.addRepresentation(imageRep);
+
+					NSSize targetSize = handle.size();
+					imageRep = createImageRep(targetSize);
+					return _getImageData(imageRep, alphaInfo_100);
 				}
 			}
 		}
+		if (zoom == 200) {
+			NSBitmapImageRep imageRep200 = getRepresentation_200();
+			if (imageRep200 == null) {
+				NSSize imgSize = handle.size();
+				NSSize targetSize = new NSSize();
+				targetSize.height = imgSize.height * 2;
+				targetSize.width = imgSize.width * 2;
+				imageRep200 = createImageRep(targetSize);
+			}
+			if (alphaInfo_100.alphaData != null && alphaInfo_200 != null) {
+				if (alphaInfo_200.alphaData == null) initAlpha_200(imageRep200);
+			}
+			if (alphaInfo_200 == null) {
+				initAlpha_200(imageRep200);
+			}
+			return _getImageData(imageRep200, alphaInfo_200);
+		}
 	} finally {
 		if (pool != null) pool.release();
 	}
-	return DPIUtil.autoScaleImageData (device, getImageData(), zoom, 100);
+	return DPIUtil.autoScaleImageData (device, getImageData(100), zoom, 100);
 }
 
 /** Returns the best available representation. May be 100% or 200% iff there is an image provider. */
 NSBitmapImageRep getRepresentation () {
-	NSBitmapImageRep rep = new NSBitmapImageRep(handle.bestRepresentationForDevice(null));
-	if (rep.isKindOfClass(OS.class_NSBitmapImageRep)) {
-		return rep;
+	NSBitmapImageRep rep = null;
+	int scaleFactor = DPIUtil.getDeviceZoom ();
+	switch (scaleFactor) {
+	case 100:
+		rep = getRepresentation_100 ();
+		break;
+	case 200:
+		rep = getRepresentation_200 ();
+		break;
+	}
+
+	if (rep == null) {
+		NSSize targetSize = new NSSize();
+		NSSize imgSize = handle.size();
+		targetSize.width = (int) imgSize.width * scaleFactor / 100;
+		targetSize.height = (int) imgSize.height * scaleFactor / 100;
+		rep = createImageRep(targetSize);
 	}
 	NSArray reps = handle.representations();
-	NSSize size = handle.size();
-	long /*int*/ count = reps.count();
-	NSBitmapImageRep bestRep = null;
-	for (int i = 0; i < count; i++) {
-		rep = new NSBitmapImageRep(reps.objectAtIndex(i));
-		if (rep.isKindOfClass(OS.class_NSBitmapImageRep)) return rep;
-		if (bestRep == null || ((int)size.width == rep.pixelsWide() && (int)size.height == rep.pixelsHigh())) {
-			bestRep = rep;
-		}
-	}
-	bestRep.retain();
+	long count = reps.count();
 	for (int i = 0; i < count; i++) {
 		handle.removeRepresentation(new NSImageRep(handle.representations().objectAtIndex(0)));
 	}
-	handle.addRepresentation(bestRep);
-	NSBitmapImageRep newRep = (NSBitmapImageRep)new NSBitmapImageRep().alloc();
-	newRep = newRep.initWithData(handle.TIFFRepresentation());
-	handle.addRepresentation(newRep);
-	handle.removeRepresentation(bestRep);
-	bestRep.release();
-	newRep.release();
-	return newRep;
+	handle.addRepresentation(rep);
+	return rep;
+}
+
+ NSBitmapImageRep createImageRep(NSSize targetSize) {
+	return ImageUtil.createImageRep(this, targetSize);
 }
 
 /**
@@ -1392,7 +1443,7 @@ public int hashCode () {
 	} else if (imageFileNameProvider != null) {
 		return imageFileNameProvider.hashCode();
 	} else {
-		return handle != null ? (int)/*64*/handle.id : 0;
+		return handle != null ? (int)handle.id : 0;
 	}
 }
 
@@ -1441,8 +1492,8 @@ void initAlpha_200(NSBitmapImageRep nativeRep) {
 	NSAutoreleasePool pool = null;
 	if (!NSThread.isMainThread()) pool = (NSAutoreleasePool) new NSAutoreleasePool().alloc().init();
 	try {
-		int width = (int)/*64*/nativeRep.pixelsWide();
-		int height = (int)/*64*/nativeRep.pixelsHigh();
+		int width = (int)nativeRep.pixelsWide();
+		int height = (int)nativeRep.pixelsHigh();
 
 		boolean hasAlpha = nativeRep.hasAlpha();
 		int bpr = width * 4;
@@ -1451,6 +1502,7 @@ void initAlpha_200(NSBitmapImageRep nativeRep) {
 
 		if (alphaInfo_200 == null) alphaInfo_200 = new AlphaInfo();
 		alphaInfo_200.init(nativeRep, rep);
+		rep.release();
 	} finally {
 		if (pool != null) pool.release();
 	}
@@ -1480,8 +1532,8 @@ void initNative(String filename) {
 		if (!nativeRep.isKindOfClass(OS.class_NSBitmapImageRep)) {
 			return;
 		}
-		width = (int)/*64*/nativeRep.pixelsWide();
-		height = (int)/*64*/nativeRep.pixelsHigh();
+		width = (int)nativeRep.pixelsWide();
+		height = (int)nativeRep.pixelsHigh();
 
 		boolean hasAlpha = nativeRep.hasAlpha();
 		int bpr = width * 4;
@@ -1528,7 +1580,7 @@ void initNative(String filename) {
  * @noreference This method is not intended to be referenced by clients.
  */
 @Override
-public long /*int*/ internal_new_GC (GCData data) {
+public long internal_new_GC (GCData data) {
 	if (handle == null) SWT.error(SWT.ERROR_GRAPHIC_DISPOSED);
 	if (type != SWT.BITMAP || memGC != null) {
 		SWT.error(SWT.ERROR_INVALID_ARGUMENT);
@@ -1536,6 +1588,7 @@ public long /*int*/ internal_new_GC (GCData data) {
 	NSAutoreleasePool pool = null;
 	if (!NSThread.isMainThread()) pool = (NSAutoreleasePool) new NSAutoreleasePool().alloc().init();
 	try {
+		int scaleFactor = DPIUtil.getDeviceZoom() / 100;
 		NSBitmapImageRep imageRep = getRepresentation();
 
 		// Can't perform transforms on image reps with alpha.
@@ -1550,8 +1603,8 @@ public long /*int*/ internal_new_GC (GCData data) {
 		NSGraphicsContext.setCurrentContext(context);
 		NSAffineTransform transform = NSAffineTransform.transform();
 		NSSize size = handle.size();
-		transform.translateXBy(0, size.height);
-		transform.scaleXBy(1, -1);
+		transform.translateXBy(0, size.height * scaleFactor);
+		transform.scaleXBy(scaleFactor, -scaleFactor);
 		transform.set();
 		NSGraphicsContext.static_restoreGraphicsState();
 		if (data != null) {
@@ -1587,8 +1640,8 @@ public long /*int*/ internal_new_GC (GCData data) {
  * @noreference This method is not intended to be referenced by clients.
  */
 @Override
-public void internal_dispose_GC (long /*int*/ hDC, GCData data) {
-	long /*int*/ context = hDC;
+public void internal_dispose_GC (long hDC, GCData data) {
+	long context = hDC;
 	NSAutoreleasePool pool = null;
 	if (!NSThread.isMainThread()) pool = (NSAutoreleasePool) new NSAutoreleasePool().alloc().init();
 	try {
@@ -1633,13 +1686,13 @@ public boolean isDisposed() {
  * In these cases, it may be desired to simulate transparency by using
  * the background color of the widget to paint the transparent pixels
  * of the image. This method specifies the color that will be used in
- * these cases. For example:
+ * these cases. For example:</p>
  * <pre>
  *    Button b = new Button();
  *    image.setBackground(b.getBackground());
  *    b.setImage(image);
  * </pre>
- * </p><p>
+ * <p>
  * The image may be modified by this operation (in effect, the
  * transparent regions may be filled with the supplied color).  Hence
  * this operation is not reversible and it is not legal to call
@@ -1676,10 +1729,10 @@ public void setBackground(Color color) {
 		byte newGreen = (byte)((int)(color.handle[1] * 255) & 0xFF);
 		byte newBlue = (byte)((int)(color.handle[2] * 255) & 0xFF);
 		long height = imageRep.pixelsHigh();
-		long /*int*/ bpr = imageRep.bytesPerRow();
-		long /*int*/ data = imageRep.bitmapData();
-		long /*int*/ format = imageRep.bitmapFormat();
-		long /*int*/ bpp = imageRep.bitsPerPixel();
+		long bpr = imageRep.bytesPerRow();
+		long data = imageRep.bitmapData();
+		long format = imageRep.bitmapFormat();
+		long bpp = imageRep.bitsPerPixel();
 		final int redOffset, greenOffset, blueOffset;
 		if (bpp == 32 && (format & OS.NSAlphaFirstBitmapFormat) == 0) {
 			redOffset = 0;
