@@ -53,11 +53,11 @@ public class Button extends Control {
 
 	/**
 	 * On MacOS 10.8 and later Radiobuttons with the same parent view and action are automatically in group,
-	 * so the state of the NSButton cannot be used to detect if a selection event should be sent when a button is deselected.
+	 * which is avoided by wrapping them individually in an extra parent view.
 	 */
-	private boolean lastRadioState;
+	private SWTView radioParent;
 
-	private static final double /*float*/ [] DEFAULT_DISABLED_FOREGROUND = new double /*float*/ [] { 0.6745f, 0.6745f, 0.6745f, 1.0f };
+	private static final double [] DEFAULT_DISABLED_FOREGROUND = new double [] { 0.6745f, 0.6745f, 0.6745f, 1.0f };
 
 	static final int EXTRA_HEIGHT = 2;
 	static final int EXTRA_WIDTH = 6;
@@ -147,7 +147,7 @@ public void addSelectionListener(SelectionListener listener) {
 }
 
 @Override
-NSSize cellSizeForBounds (long /*int*/ id, long /*int*/ sel, NSRect cellFrame) {
+NSSize cellSizeForBounds (long id, long sel, NSRect cellFrame) {
 	NSSize size = super.cellSizeForBounds(id, sel, cellFrame);
 	if (image != null && ((style & (SWT.CHECK|SWT.RADIO)) !=0)) {
 		NSSize imageSize = image.handle.size();
@@ -173,7 +173,7 @@ NSSize cellSizeForBounds (long /*int*/ id, long /*int*/ sel, NSRect cellFrame) {
 		NSAttributedString attribStr = createString(text, null, foreground, style, true, true, true);
 		NSRect rect = attribStr.boundingRectWithSize(wrapSize, OS.NSStringDrawingUsesLineFragmentOrigin);
 		attribStr.release();
-		double /*float*/ trimHeight = size.height - titleRect.height;
+		double trimHeight = size.height - titleRect.height;
 		size.height = rect.height;
 		if (image != null && ((style & (SWT.CHECK|SWT.RADIO)) !=0)) {
 			NSSize imageSize = image.handle.size();
@@ -264,6 +264,7 @@ void createHandle () {
 		type = OS.NSSwitchButton;
 	} else if ((style & SWT.RADIO) != 0) {
 		type = OS.NSRadioButton;
+		radioParent = (SWTView) new SWTView().alloc().init();
 	} else if ((style & SWT.TOGGLE) != 0) {
 		type = OS.NSPushOnPushOffButton;
 		if ((style & SWT.FLAT) != 0) {
@@ -304,6 +305,7 @@ NSFont defaultNSFont() {
 void deregister () {
 	super.deregister ();
 	display.removeWidget(((NSControl)view).cell());
+	if (radioParent != null) display.removeWidget(radioParent);
 }
 
 @Override
@@ -313,27 +315,6 @@ boolean dragDetect(int x, int y, boolean filter, boolean[] consume) {
 	return dragging;
 }
 
-@Override
-void drawImageWithFrameInView (long /*int*/ id, long /*int*/ sel, long /*int*/ image, NSRect rect, long /*int*/ view) {
-	/*
-	* Feature in Cocoa.  Images touch the edge of rounded buttons
-	* when set to small size. The fix to subclass the button cell
-    * and offset the image drawing.
-    * This workaround is not required for OSX 10.9 and later as
-    * the problem doesn't happen there.
-	*/
-	if (OS.VERSION_MMB < OS.VERSION_MMB(10, 9, 0)) {
-		NSCell cell = ((NSControl)this.view).cell();
-		if (cell != null && cell.controlSize() == OS.NSRegularControlSize) {
-			if ((style & (SWT.PUSH | SWT.TOGGLE)) != 0 && (style & (SWT.FLAT | SWT.WRAP)) == 0) {
-				rect.y += EXTRA_HEIGHT / 2;
-				rect.height += EXTRA_HEIGHT;
-			}
-		}
-	}
-	super.drawImageWithFrameInView(id, sel, image, rect, view);
-}
-
 private static NSRect smallerRect (NSRect cellFrame, double dx, double dy1, double dy2, float lineWidth) {
 	if (lineWidth == 2) {
 		dx -= 0.5;
@@ -357,7 +338,7 @@ private static NSRect smallerRect (NSRect cellFrame, double dx, double dy1, doub
 }
 
 @Override
-void drawBezelWithFrame_inView (long /*int*/ id, long /*int*/ sel, NSRect cellFrame, long /*int*/ viewid) {
+void drawBezelWithFrame_inView (long id, long sel, NSRect cellFrame, long viewid) {
 	if (this.background != null) {
 		NSButton button = (NSButton) view;
 
@@ -367,7 +348,7 @@ void drawBezelWithFrame_inView (long /*int*/ id, long /*int*/ sel, NSRect cellFr
 		final NSButtonCell defaultButtonCell = window == null ? null : window.defaultButtonCell();
 		final boolean isDefault = defaultButtonCell != null && defaultButtonCell.id == id;
 
-		double /*float*/ [] borderRGB = getLighterOrDarkerColor(this.background, 0.3, luma(background) >= 0.5);
+		double [] borderRGB = getLighterOrDarkerColor(this.background, 0.3, luma(background) >= 0.5);
 		if (isHighlighted && (style & SWT.FLAT) != 0) {
 			borderRGB = getLighterOrDarkerColor(borderRGB, 0.2, true);
 		}
@@ -396,13 +377,13 @@ void drawBezelWithFrame_inView (long /*int*/ id, long /*int*/ sel, NSRect cellFr
 			path = NSBezierPath.bezierPathWithRect(rect2);
 		}
 		if (!isHighlighted) {
-			double /*float*/ [] backgroundRGB = this.background;
+			double [] backgroundRGB = this.background;
 			NSColor backgroundNSColor = NSColor.colorWithDeviceRed(backgroundRGB[0], backgroundRGB[1], backgroundRGB[2], 1f);
 
 			if((style & SWT.FLAT) == 0) {
-				double /*float*/ [] topRGB = getLighterOrDarkerColor(this.background, 0.2, false);
+				double [] topRGB = getLighterOrDarkerColor(this.background, 0.2, false);
 				NSColor topColor = NSColor.colorWithDeviceRed(topRGB[0], topRGB[1], topRGB[2], 1f);
-				double /*float*/ [] bottomRGB = getLighterOrDarkerColor(this.background, 0.1, true);
+				double [] bottomRGB = getLighterOrDarkerColor(this.background, 0.1, true);
 				NSColor bottomColor = NSColor.colorWithDeviceRed(bottomRGB[0], bottomRGB[1], bottomRGB[2], 1f);
 
 				NSMutableArray ma = NSMutableArray.arrayWithCapacity(4);
@@ -418,7 +399,7 @@ void drawBezelWithFrame_inView (long /*int*/ id, long /*int*/ sel, NSRect cellFr
 				path.fill();
 			}
 		} else {
-			double /*float*/ [] colorRGB0 = getLighterOrDarkerColor(this.background, 0.1f, true);
+			double [] colorRGB0 = getLighterOrDarkerColor(this.background, 0.1f, true);
 			NSColor color0 = NSColor.colorWithDeviceRed(colorRGB0[0], colorRGB0[1], colorRGB0[2], 1f);
 			color0.setFill();
 			path.fill();
@@ -437,7 +418,7 @@ void drawBezelWithFrame_inView (long /*int*/ id, long /*int*/ sel, NSRect cellFr
 }
 
 @Override
-void drawInteriorWithFrame_inView (long /*int*/ id, long /*int*/ sel, NSRect cellRect, long /*int*/ viewid) {
+void drawInteriorWithFrame_inView (long id, long sel, NSRect cellRect, long viewid) {
 	if ((style & (SWT.CHECK|SWT.RADIO)) != 0 && backgroundImage != null) {
 		fillBackground (new NSView(viewid), NSGraphicsContext.currentContext(), cellRect, -1);
 	}
@@ -445,8 +426,8 @@ void drawInteriorWithFrame_inView (long /*int*/ id, long /*int*/ sel, NSRect cel
 	if (image != null && ((style & (SWT.CHECK|SWT.RADIO)) !=0)) {
 		NSSize imageSize = image.handle.size();
 		NSCell nsCell = new NSCell(id);
-		double /*float*/ x = 0;
-		double /*float*/ y = (imageSize.height - cellRect.height)/2f;
+		double x = 0;
+		double y = (imageSize.height - cellRect.height)/2f;
 		NSRect imageRect = nsCell.imageRectForBounds(cellRect);
 		NSSize stringSize = ((NSButton)view).attributedTitle().size();
 		switch (style & (SWT.LEFT|SWT.RIGHT|SWT.CENTER)) {
@@ -477,7 +458,7 @@ void drawInteriorWithFrame_inView (long /*int*/ id, long /*int*/ sel, NSRect cel
 }
 
 @Override
-NSRect drawTitleWithFrameInView (long /*int*/ id, long /*int*/ sel, long /*int*/ title, NSRect titleRect, long /*int*/ view) {
+NSRect drawTitleWithFrameInView (long id, long sel, long title, NSRect titleRect, long view) {
 	boolean wrap = (style & SWT.WRAP) != 0 && text.length() != 0;
 	boolean isEnabled = isEnabled();
 	if (wrap) {
@@ -525,7 +506,7 @@ boolean drawsBackground() {
 }
 
 @Override
-void drawWidget (long /*int*/ id, NSGraphicsContext context, NSRect rect) {
+void drawWidget (long id, NSGraphicsContext context, NSRect rect) {
 	if ((style & SWT.ARROW) != 0) {
 		NSRect frame = view.frame();
 		int arrowSize = Math.min((int)frame.height, (int)frame.width) / 2;
@@ -567,7 +548,7 @@ void drawWidget (long /*int*/ id, NSGraphicsContext context, NSRect rect) {
 }
 
 @Override
-NSRect focusRingMaskBoundsForFrame (long /*int*/ id, long /*int*/ sel, NSRect cellFrame, long /*int*/ view) {
+NSRect focusRingMaskBoundsForFrame (long id, long sel, NSRect cellFrame, long view) {
 	return cellFrame;
 }
 
@@ -663,7 +644,7 @@ public boolean getSelection () {
 	checkWidget ();
 	if ((style & (SWT.CHECK | SWT.RADIO | SWT.TOGGLE)) == 0) return false;
 	if ((style & SWT.CHECK) != 0 && grayed) return ((NSButton)view).state() == OS.NSMixedState;
-    return ((NSButton)view).state() == OS.NSOnState;
+	return ((NSButton)view).state() == OS.NSOnState;
 }
 
 /**
@@ -694,7 +675,7 @@ boolean isDescribedByLabel () {
  * to go directly to the desired state if we have a grayed checkbox.
  */
 @Override
-long /*int*/ nextState(long /*int*/ id, long /*int*/ sel) {
+long nextState(long id, long sel) {
 	if ((style & SWT.CHECK) != 0 && grayed) {
 		return ((NSButton)view).state() == OS.NSMixedState ? OS.NSOffState : OS.NSMixedState;
 	}
@@ -706,6 +687,7 @@ long /*int*/ nextState(long /*int*/ id, long /*int*/ sel) {
 void register() {
 	super.register();
 	display.addWidget(((NSControl)view).cell(), this);
+	if (radioParent != null) display.addWidget(radioParent, this);
 }
 
 @Override
@@ -857,6 +839,12 @@ void setBounds (int x, int y, int width, int height, boolean move, boolean resiz
 		}
 	}
 	super.setBounds(x, y, width, height, move, resize);
+	if (radioParent != null && resize) {
+		NSSize size = new NSSize();
+		size.width = width;
+		size.height = height;
+		view.setFrameSize(size);
+	}
 }
 
 @Override
@@ -867,7 +855,7 @@ void setFont (NSFont font) {
 }
 
 @Override
-void setForeground (double /*float*/ [] color) {
+void setForeground (double [] color) {
 	((NSButton)view).setAttributedTitle(createString());
 }
 
@@ -961,7 +949,7 @@ public void setImage (Image image) {
 @Override
 boolean setRadioSelection (boolean value){
 	if ((style & SWT.RADIO) == 0) return false;
-	if (getSelection() != value || lastRadioState != value) {
+	if (getSelection() != value) {
 		setSelection (value);
 		sendSelectionEvent (SWT.Selection);
 	}
@@ -992,7 +980,6 @@ public void setSelection (boolean selected) {
 	} else {
 		((NSButton)view).setState (selected ? OS.NSOnState : OS.NSOffState);
 	}
-	lastRadioState = selected;
 }
 
 /**
@@ -1039,7 +1026,7 @@ public void setText (String string) {
 }
 
 @Override
-NSRect titleRectForBounds (long /*int*/ id, long /*int*/ sel, NSRect cellFrame) {
+NSRect titleRectForBounds (long id, long sel, NSRect cellFrame) {
 	NSRect rect = super.titleRectForBounds(id, sel, cellFrame);
 	if (image != null && ((style & (SWT.CHECK|SWT.RADIO)) !=0)) {
 		NSSize imageSize = image.handle.size();
@@ -1069,4 +1056,15 @@ void updateAlignment () {
 	}
 }
 
+@Override
+NSView topView() {
+	if (radioParent != null) return radioParent;
+	return super.topView();
+}
+
+@Override
+void setZOrder() {
+	super.setZOrder();
+	if (radioParent != null) radioParent.addSubview(view);
+}
 }
