@@ -42,7 +42,7 @@ public class MenuItem extends Item {
 	NSMenuItem nsItem;
 	Menu parent, menu;
 	int accelerator;
-	long /*int*/ nsItemAction;
+	long nsItemAction;
 	id nsItemTarget;
 	String toolTipText;
 
@@ -262,7 +262,6 @@ void destroyWidget () {
  *
  * @return the accelerator or 0
  *
- * </ul>
  * @exception SWTException <ul>
  *    <li>ERROR_WIDGET_DISPOSED - if the receiver has been disposed</li>
  *    <li>ERROR_THREAD_INVALID_ACCESS - if not called from the thread that created the receiver</li>
@@ -367,7 +366,7 @@ public Menu getParent () {
 public boolean getSelection () {
 	checkWidget ();
 	if ((style & (SWT.CHECK | SWT.RADIO)) == 0) return false;
-    return nsItem.state() == OS.NSOnState;
+	return nsItem.state() == OS.NSOnState;
 }
 
 /**
@@ -614,7 +613,6 @@ void sendSelection () {
  *
  * @param accelerator an integer that is the bit-wise OR of masks and a key
  *
- * </ul>
  * @exception SWTException <ul>
  *    <li>ERROR_WIDGET_DISPOSED - if the receiver has been disposed</li>
  *    <li>ERROR_THREAD_INVALID_ACCESS - if not called from the thread that created the receiver</li>
@@ -875,7 +873,7 @@ public void setText (String string) {
  * </p>
  * <p>
  * NOTE: This operation is a hint and behavior is platform specific, on Windows
- * for CJK-style mnemonics of the form " (&C)" at the end of the tooltip text
+ * for CJK-style mnemonics of the form " (&amp;C)" at the end of the tooltip text
  * are not shown in tooltip.
  * </p>
  * @param toolTip the new tool tip text (or null)
@@ -896,12 +894,12 @@ public void setToolTipText (String toolTip) {
 	}
 	if (toolTip == null || toolTip.trim().length() == 0 || toolTip.equals(toolTipText)) return;
 
-    toolTipText = toolTip;
+	toolTipText = toolTip;
 
-    char[] chars = new char [toolTipText.length ()];
-    toolTipText.getChars (0, chars.length, chars, 0);
-    int length = fixMnemonic (chars);
-    nsItem.setToolTip (NSString.stringWithCharacters (chars, length));
+	char[] chars = new char [toolTipText.length ()];
+	toolTipText.getChars (0, chars.length, chars, 0);
+	int length = fixMnemonic (chars);
+	nsItem.setToolTip (NSString.stringWithCharacters (chars, length));
 }
 
 void updateText () {
