@@ -29,7 +29,7 @@ import org.eclipse.swt.internal.cocoa.*;
  * values the scroll bar represents (that is, between its
  * <em>minimum</em> and <em>maximum</em> values).
  * </p><p>
- * Typically, scroll bars will be made up of five areas:
+ * Typically, scroll bars will be made up of five areas:</p>
  * <ol>
  * <li>an arrow button for decrementing the value</li>
  * <li>a page decrement area for decrementing the value by a larger amount</li>
@@ -37,6 +37,7 @@ import org.eclipse.swt.internal.cocoa.*;
  * <li>a page increment area for incrementing the value by a larger amount</li>
  * <li>an arrow button for incrementing the value</li>
  * </ol>
+ * <p>
  * Based on their style, scroll bars are either <code>HORIZONTAL</code>
  * (which have a left facing button for decrementing the value and a
  * right facing button for incrementing it) or <code>VERTICAL</code>
@@ -92,7 +93,7 @@ public class ScrollBar extends Widget {
 	int increment = 1;
 	int pageIncrement = 10;
 	id target;
-	long /*int*/ actionSelector;
+	long actionSelector;
 
 ScrollBar () {
 	/* Do nothing */
@@ -187,7 +188,7 @@ public boolean getEnabled () {
  */
 public int getIncrement () {
 	checkWidget();
-    return increment;
+	return increment;
 }
 
 /**
@@ -234,7 +235,7 @@ public int getMinimum () {
  */
 public int getPageIncrement () {
 	checkWidget();
-    return pageIncrement;
+	return pageIncrement;
 }
 
 /**
@@ -266,7 +267,7 @@ public int getSelection () {
 	checkWidget();
 	NSScroller widget = (NSScroller)view;
 	double value = widget.doubleValue();
-    return (int)(0.5f + ((maximum - thumb - minimum) * value + minimum));
+	return (int)(0.5f + ((maximum - thumb - minimum) * value + minimum));
 }
 
 /**
@@ -481,7 +482,7 @@ void sendSelection () {
 	} else {
 		point = window.mouseLocationOutsideOfEventStream();
 	}
-	int hitPart = (int)/*64*/((NSScroller)view).testPart(point);
+	int hitPart = (int)((NSScroller)view).testPart(point);
 	Event event = new Event();
 	switch (hitPart) {
 	case OS.NSScrollerDecrementLine:
@@ -742,11 +743,11 @@ void updateBar (int selection, int minimum, int maximum, int thumb) {
 	float fraction = range <= 0 ? 1 : (float) (selection - minimum) / range;
 	float knob = range <= 0 ? 1 : (float) thumb / (maximum - minimum);
 	double oldFraction = widget.doubleValue();
-	double /*float*/ oldKnob = widget.knobProportion();
+	double oldKnob = widget.knobProportion();
 	widget.setDoubleValue(fraction);
 	widget.setKnobProportion(knob);
 	widget.setEnabled (range > 0);
-	if (OS.VERSION >= 0x1070 && target == null && (knob != oldKnob || fraction != oldFraction)) {
+	if (target == null && (knob != oldKnob || fraction != oldFraction)) {
 		OS.objc_msgSend(parent.scrollView.id, OS.sel_flashScrollers);
 	}
 }
