@@ -31,7 +31,7 @@ import org.eclipse.swt.internal.cocoa.*;
  * <em>dialog</em> shells.
  * <p>
  * Instances are always displayed in one of the maximized,
- * minimized or normal states:
+ * minimized or normal states:</p>
  * <ul>
  * <li>
  * When an instance is marked as <em>maximized</em>, the
@@ -55,7 +55,7 @@ import org.eclipse.swt.internal.cocoa.*;
  * of these changes are also possible.
  * </li>
  * </ul>
- * </p><p>
+ * <p>
  * The <em>modality</em> of an instance may be specified using
  * style bits. The modality style bits are used to determine
  * whether input is blocked for other shells on the display.
@@ -81,7 +81,7 @@ import org.eclipse.swt.internal.cocoa.*;
  * restrictive style. For example, most operating systems
  * no longer support <code>SYSTEM_MODAL</code> because
  * it can freeze up the desktop, so this is typically
- * downgraded to <code>APPLICATION_MODAL</code>.
+ * downgraded to <code>APPLICATION_MODAL</code>.</p>
  * <dl>
  * <dt><b>Styles:</b></dt>
  * <dd>BORDER, CLOSE, MIN, MAX, NO_MOVE, NO_TRIM, RESIZE, TITLE, ON_TOP, TOOL, SHEET</dd>
@@ -89,8 +89,9 @@ import org.eclipse.swt.internal.cocoa.*;
  * <dt><b>Events:</b></dt>
  * <dd>Activate, Close, Deactivate, Deiconify, Iconify</dd>
  * </dl>
+ * <p>
  * Class <code>SWT</code> provides two "convenience constants"
- * for the most commonly required style combinations:
+ * for the most commonly required style combinations:</p>
  * <dl>
  * <dt><code>SHELL_TRIM</code></dt>
  * <dd>
@@ -105,7 +106,6 @@ import org.eclipse.swt.internal.cocoa.*;
  * is, <code>TITLE | CLOSE | BORDER</code>)
  * </dd>
  * </dl>
- * </p>
  * <p>
  * Note: Only one of the styles APPLICATION_MODAL, MODELESS,
  * PRIMARY_MODAL and SYSTEM_MODAL may be specified.
@@ -124,9 +124,9 @@ import org.eclipse.swt.internal.cocoa.*;
 public class Shell extends Decorations {
 	NSWindow window;
 	SWTWindowDelegate windowDelegate;
-	long /*int*/ hostWindowClass;
+	long hostWindowClass;
 	NSWindow hostWindow;
-	long /*int*/ tooltipOwner, tooltipTag, tooltipUserData;
+	long tooltipOwner, tooltipTag, tooltipUserData;
 	int glContextCount;
 	boolean opened, moved, resized, fullScreen, center, deferFlushing, scrolling, isPopup;
 	Control lastActive;
@@ -271,7 +271,7 @@ public Shell (Display display, int style) {
 	this (display, null, style, 0, false);
 }
 
-Shell (Display display, Shell parent, int style, long /*int*/handle, boolean embedded) {
+Shell (Display display, Shell parent, int style, long handle, boolean embedded) {
 	super ();
 	checkSubclass ();
 	if (display == null) display = Display.getCurrent ();
@@ -398,7 +398,7 @@ public Shell (Shell parent, int style) {
  *
  * @since 3.3
  */
-public static Shell internal_new (Display display, long /*int*/ handle) {
+public static Shell internal_new (Display display, long handle) {
 	return new Shell (display, null, SWT.NO_TRIM, handle, false);
 }
 
@@ -422,7 +422,7 @@ public static Shell internal_new (Display display, long /*int*/ handle) {
  *
  * @since 3.5
  */
-public static Shell cocoa_new (Display display, long /*int*/ handle) {
+public static Shell cocoa_new (Display display, long handle) {
 	return new Shell (display, null, SWT.NO_TRIM, handle, true);
 }
 
@@ -453,7 +453,7 @@ static int checkStyle (Shell parent, int style) {
 }
 
 @Override
-boolean accessibilityIsIgnored(long /*int*/ id, long /*int*/ sel) {
+boolean accessibilityIsIgnored(long id, long sel) {
 	// The content view of a shell is always ignored.
 	if (id == view.id) return true;
 	return super.accessibilityIsIgnored(id, sel);
@@ -491,12 +491,12 @@ public void addShellListener(ShellListener listener) {
 
 void attachObserversToWindow(NSWindow newWindow) {
 	if (newWindow == null || newWindow.id == 0) return;
-	long /*int*/ newHostWindowClass = OS.object_getClass(newWindow.id);
-	long /*int*/ sendEventImpl = OS.class_getMethodImplementation(newHostWindowClass, OS.sel_sendEvent_);
+	long newHostWindowClass = OS.object_getClass(newWindow.id);
+	long sendEventImpl = OS.class_getMethodImplementation(newHostWindowClass, OS.sel_sendEvent_);
 	if (sendEventImpl == Display.windowCallback3.getAddress()) return;
 	hostWindow = newWindow;
 	hostWindow.retain();
-	long /*int*/ embeddedSubclass = display.createWindowSubclass(newHostWindowClass, "SWTAWTWindow", true);
+	long embeddedSubclass = display.createWindowSubclass(newHostWindowClass, "SWTAWTWindow", true);
 	OS.object_setClass(hostWindow.id, embeddedSubclass);
 	display.addWidget (hostWindow, this);
 	hostWindowClass = newHostWindowClass;
@@ -522,7 +522,7 @@ void attachObserversToWindow(NSWindow newWindow) {
 }
 
 @Override
-void becomeKeyWindow (long /*int*/ id, long /*int*/ sel) {
+void becomeKeyWindow (long id, long sel) {
 	Shell modal = getModalShell();
 	if (modal != null && modal.window != null) {
 		modal.window.makeKeyAndOrderFront(null);
@@ -546,7 +546,7 @@ void bringToTop (boolean force) {
 }
 
 @Override
-boolean canBecomeKeyWindow (long /*int*/ id, long /*int*/ sel) {
+boolean canBecomeKeyWindow (long id, long sel) {
 	if (isPopup) return false;
 	// Only answer if SWT created the window.
 	if (window != null) {
@@ -560,7 +560,7 @@ boolean canBecomeKeyWindow (long /*int*/ id, long /*int*/ sel) {
 				}
 			}
 		}
-		long /*int*/ styleMask = window.styleMask();
+		long styleMask = window.styleMask();
 		if (styleMask == OS.NSBorderlessWindowMask || (styleMask & (OS.NSNonactivatingPanelMask | OS.NSDocModalWindowMask | OS.NSResizableWindowMask)) != 0) return true;
 	}
 	return super.canBecomeKeyWindow (id, sel);
@@ -592,7 +592,7 @@ void center () {
 }
 
 @Override
-void clearDeferFlushing (long /*int*/ id, long /*int*/ sel) {
+void clearDeferFlushing (long id, long sel) {
 	deferFlushing = false;
 	scrolling = false;
 	if (window != null) window.flushWindowIfNeeded();
@@ -648,7 +648,7 @@ public Rectangle computeTrim (int x, int y, int width, int height) {
 	rect.height = trim.height;
 	if (window != null) {
 		if (!_getFullScreen() && !fixResize()) {
-			double /*float*/ h = rect.height;
+			double h = rect.height;
 			rect = window.frameRectForContentRect(rect);
 			rect.y += h-rect.height;
 		}
@@ -668,9 +668,9 @@ void createHandle () {
 			} else {
 				styleMask |= OS.NSUtilityWindowMask | OS.NSNonactivatingPanelMask;
 			}
- 		} else {
- 			window = (NSWindow) new SWTWindow().alloc ();
- 		}
+		} else {
+			window = (NSWindow) new SWTWindow().alloc ();
+		}
 		if ((style & SWT.NO_TRIM) == 0) {
 			if ((style & SWT.TITLE) != 0) styleMask |= OS.NSTitledWindowMask;
 			if ((style & SWT.CLOSE) != 0) styleMask |= OS.NSClosableWindowMask;
@@ -686,7 +686,7 @@ void createHandle () {
 		if ((style & (SWT.NO_TRIM | SWT.BORDER | SWT.SHELL_TRIM)) == 0 || (style & (SWT.TOOL | SWT.SHEET)) != 0) {
 			window.setHasShadow (true);
 		}
-		if ((style & SWT.NO_MOVE) != 0 && (OS.VERSION_MMB >= OS.VERSION_MMB(10, 6, 0))) {
+		if ((style & SWT.NO_MOVE) != 0) {
 			window.setMovable(false);
 		}
 		if ((style & SWT.TOOL) != 0) {
@@ -710,7 +710,7 @@ void createHandle () {
 				OS.objc_msgSend(window.id, OS.sel_setMovable_, 0);
 			}
 		}
-		if (OS.VERSION_MMB >= OS.VERSION_MMB(10, 12, 0)) {
+		if (OS.VERSION >= OS.VERSION(10, 12, 0)) {
 			/*
 			 * In macOS 10.12, a new system preference "prefer tabs when opening documents"
 			 * has been added which causes automatic tabbing of windows in Eclipse.
@@ -721,7 +721,7 @@ void createHandle () {
 		}
 		display.cascadeWindow(window, screen);
 		NSRect screenFrame = screen.frame();
-		double /*float*/ width = screenFrame.width * 5 / 8, height = screenFrame.height * 5 / 8;;
+		double width = screenFrame.width * 5 / 8, height = screenFrame.height * 5 / 8;;
 		NSRect frame = window.frame();
 		NSRect primaryFrame = primaryScreen.frame();
 		frame.y = primaryFrame.height - ((primaryFrame.height - (frame.y + frame.height)) + height);
@@ -766,28 +766,19 @@ void createHandle () {
 		NSWindow hostWindow = view.window();
 		attachObserversToWindow(hostWindow);
 	} else {
-		int behavior = 0;
-		if (parent != null) behavior |= OS.NSWindowCollectionBehaviorMoveToActiveSpace;
-		if (OS.VERSION >= 0x1070) {
-			if (parent == null) {
-				if ((style & SWT.TOOL) != 0) {
-					behavior = OS.NSWindowCollectionBehaviorFullScreenAuxiliary;
-				} else {
-					behavior = OS.NSWindowCollectionBehaviorFullScreenPrimary;
-				}
-			}
+		int behavior;
+		if (parent != null) {
+			behavior = OS.NSWindowCollectionBehaviorMoveToActiveSpace;
+		} else if ((style & SWT.TOOL) != 0) {
+			behavior = OS.NSWindowCollectionBehaviorFullScreenAuxiliary;
+		} else {
+			behavior = OS.NSWindowCollectionBehaviorFullScreenPrimary;
 		}
-		if (behavior != 0) window.setCollectionBehavior(behavior);
+		window.setCollectionBehavior(behavior);
 		window.setAcceptsMouseMovedEvents(true);
 		window.setDelegate(windowDelegate);
 	}
 
-	if (OS.VERSION < 0x1060) {
-		// Force a WindowRef to be created for this window so we can use
-		// FindWindow() (see Display.findControl())
-		if (window != null) window.windowRef();
-	}
-
 	NSWindow fieldEditorWindow = window;
 	if (fieldEditorWindow == null) fieldEditorWindow = view.window();
 	id id = fieldEditorWindow.fieldEditor (true, null);
@@ -842,7 +833,7 @@ void destroyWidget () {
 }
 
 @Override
-void drawBackground (long /*int*/ id, NSGraphicsContext context, NSRect rect) {
+void drawBackground (long id, NSGraphicsContext context, NSRect rect) {
 	if (id != view.id) return;
 	if (regionPath != null && background == null) {
 		context.saveGraphicsState();
@@ -945,7 +936,7 @@ public Rectangle getBounds () {
 	checkWidget();
 	if (window != null) {
 		NSRect frame = window.frame();
-		double /*float*/ y = display.getPrimaryFrame().height - (int)(frame.y + frame.height);
+		double y = display.getPrimaryFrame().height - (int)(frame.y + frame.height);
 		return new Rectangle ((int)frame.x, (int)y, (int)frame.width, (int)frame.height);
 	} else {
 		NSRect frame = view.frame();
@@ -1041,7 +1032,7 @@ public Point getLocation () {
 
 	if (window != null) {
 		NSRect frame = window.frame();
-		double /*float*/ y = display.getPrimaryFrame().height - (int)(frame.y + frame.height);
+		double y = display.getPrimaryFrame().height - (int)(frame.y + frame.height);
 		return new Point ((int)frame.x, (int)y);
 	} else {
 		// Start from view's origin, (0, 0)
@@ -1249,7 +1240,7 @@ boolean hasRegion () {
 }
 
 @Override
-void helpRequested(long /*int*/ id, long /*int*/ sel, long /*int*/ theEvent) {
+void helpRequested(long id, long sel, long theEvent) {
 	Control control = display.getFocusControl();
 	while (control != null) {
 		if (control.hooks (SWT.Help)) {
@@ -1300,7 +1291,7 @@ public boolean isVisible () {
 }
 
 @Override
-boolean makeFirstResponder (long /*int*/ id, long /*int*/ sel, long /*int*/ responder) {
+boolean makeFirstResponder (long id, long sel, long responder) {
 	Display display = this.display;
 	boolean result = super.makeFirstResponder(id, sel, responder);
 	if (!display.isDisposed()) display.checkFocus();
@@ -1325,7 +1316,7 @@ void makeKeyAndOrderFront() {
 }
 
 @Override
-void mouseMoved(long /*int*/ id, long /*int*/ sel, long /*int*/ theEvent) {
+void mouseMoved(long id, long sel, long theEvent) {
 	super.mouseMoved(id, sel, theEvent);
 
 	/**
@@ -1341,7 +1332,7 @@ void mouseMoved(long /*int*/ id, long /*int*/ sel, long /*int*/ theEvent) {
 }
 
 @Override
-void noResponderFor(long /*int*/ id, long /*int*/ sel, long /*int*/ selector) {
+void noResponderFor(long id, long sel, long selector) {
 	/**
 	 * Feature in Cocoa.  If the selector is keyDown and nothing has handled the event
 	 * a system beep is generated.  There's no need to beep, as many keystrokes in the SWT
@@ -1543,7 +1534,7 @@ void sendToolTipEvent (boolean enter) {
 			if (userInfo != null) {
 				tooltipUserData = userInfo.id;
 			} else {
-				long /*int*/ [] value = new long /*int*/ [1];
+				long [] value = new long [1];
 				OS.object_getInstanceVariable(tooltipTag, new byte[]{'_','u', 's', 'e', 'r', 'I', 'n', 'f', 'o'}, value);
 				tooltipUserData = value[0];
 			}
@@ -1766,7 +1757,7 @@ public void setFullScreen (boolean fullScreen) {
 		fullScreenFrame = NSScreen.mainScreen().frame();
 		if (getMonitor().equals(display.getPrimaryMonitor ())) {
 			if (menuBar != null) {
-				double /*float*/ menuBarHt = NSStatusBar.systemStatusBar().thickness();
+				double menuBarHt = NSStatusBar.systemStatusBar().thickness();
 				fullScreenFrame.height -= menuBarHt;
 				OS.SetSystemUIMode(OS.kUIModeContentHidden, 0);
 			}
@@ -1898,7 +1889,6 @@ public void setMinimumSize (Point size) {
  *
  * @param modified the new modified state for the receiver
  *
- * </ul>
  * @exception SWTException <ul>
  *    <li>ERROR_WIDGET_DISPOSED - if the receiver has been disposed</li>
  *    <li>ERROR_THREAD_INVALID_ACCESS - if not called from the thread that created the receiver</li>
@@ -2019,9 +2009,6 @@ void setWindowVisible (boolean visible, boolean key) {
 			if ((style & (SWT.SHEET)) != 0) {
 				NSApplication application = NSApplication.sharedApplication();
 				application.beginSheet(window, parentWindow (), null, 0, 0);
-				if (OS.VERSION <= 0x1060 && window.respondsToSelector(OS.sel__setNeedsToUseHeartBeatWindow_)) {
-					OS.objc_msgSend(window.id, OS.sel__setNeedsToUseHeartBeatWindow_, 0);
-				}
 			} else {
 				// If the parent window is miniaturized, the window will be shown
 				// when its parent is shown.
@@ -2152,7 +2139,7 @@ void updateParent (boolean visible) {
 				 */
 				if ((style & SWT.ON_TOP) != 0) {
 					window.setLevel(OS.NSStatusWindowLevel);
-				} else if (OS.VERSION_MMB >= OS.VERSION_MMB(10, 11, 0)) {
+				} else if (OS.VERSION >= OS.VERSION(10, 11, 0)) {
 					/*
 					 * Feature in Cocoa on 10.11: Second-level child windows of
 					 * a full-screen window are sometimes shown behind their
@@ -2205,7 +2192,7 @@ void updateSystemUIMode () {
 }
 
 @Override
-long /*int*/ view_stringForToolTip_point_userData (long /*int*/ id, long /*int*/ sel, long /*int*/ view, long /*int*/ tag, long /*int*/ point, long /*int*/ userData) {
+long view_stringForToolTip_point_userData (long id, long sel, long view, long tag, long point, long userData) {
 	NSPoint pt = new NSPoint();
 	OS.memmove (pt, point, NSPoint.sizeof);
 	Control control = display.findControl (false);
@@ -2220,9 +2207,9 @@ long /*int*/ view_stringForToolTip_point_userData (long /*int*/ id, long /*int*/
 }
 
 @Override
-void viewWillMoveToWindow(long /*int*/ id, long /*int*/ sel, long /*int*/ newWindow) {
+void viewWillMoveToWindow(long id, long sel, long newWindow) {
 	if (window == null) {
-		long /*int*/ currentWindow = hostWindow != null ? hostWindow.id : 0;
+		long currentWindow = hostWindow != null ? hostWindow.id : 0;
 		if (currentWindow != 0) {
 			removeObserversFromWindow();
 		}
@@ -2233,7 +2220,7 @@ void viewWillMoveToWindow(long /*int*/ id, long /*int*/ sel, long /*int*/ newWin
 }
 
 @Override
-void windowDidBecomeKey(long /*int*/ id, long /*int*/ sel, long /*int*/ notification) {
+void windowDidBecomeKey(long id, long sel, long notification) {
 	if (window != null) {
 		Display display = this.display;
 		display.setMenuBar (menuBar);
@@ -2259,25 +2246,25 @@ void windowDidBecomeKey(long /*int*/ id, long /*int*/ sel, long /*int*/ notifica
 }
 
 @Override
-void windowDidDeminiturize(long /*int*/ id, long /*int*/ sel, long /*int*/ notification) {
+void windowDidDeminiturize(long id, long sel, long notification) {
 	minimized = false;
 	sendEvent(SWT.Deiconify);
 }
 
 @Override
-void windowDidMiniturize(long /*int*/ id, long /*int*/ sel, long /*int*/ notification) {
+void windowDidMiniturize(long id, long sel, long notification) {
 	minimized = true;
 	sendEvent(SWT.Iconify);
 }
 
 @Override
-void windowDidMove(long /*int*/ id, long /*int*/ sel, long /*int*/ notification) {
+void windowDidMove(long id, long sel, long notification) {
 	moved = true;
 	sendEvent(SWT.Move);
 }
 
 @Override
-void windowDidResize(long /*int*/ id, long /*int*/ sel, long /*int*/ notification) {
+void windowDidResize(long id, long sel, long notification) {
 	if (((window.collectionBehavior() & OS.NSWindowCollectionBehaviorFullScreenPrimary) == 0) && fullScreen) {
 		window.setFrame(fullScreenFrame, true);
 		NSRect contentViewFrame = new NSRect();
@@ -2300,7 +2287,7 @@ void windowDidResize(long /*int*/ id, long /*int*/ sel, long /*int*/ notificatio
 }
 
 @Override
-void windowDidResignKey(long /*int*/ id, long /*int*/ sel, long /*int*/ notification) {
+void windowDidResignKey(long id, long sel, long notification) {
 	if (display.isDisposed()) return;
 	sendEvent (SWT.Deactivate);
 	if (isDisposed ()) return;
@@ -2310,9 +2297,9 @@ void windowDidResignKey(long /*int*/ id, long /*int*/ sel, long /*int*/ notifica
 }
 
 @Override
-void windowSendEvent (long /*int*/ id, long /*int*/ sel, long /*int*/ event) {
+void windowSendEvent (long id, long sel, long event) {
 	NSEvent nsEvent = new NSEvent (event);
-	int type = (int)/*64*/nsEvent.type ();
+	int type = (int)nsEvent.type ();
 	switch (type) {
 		case OS.NSLeftMouseDown:
 		case OS.NSRightMouseDown:
@@ -2393,7 +2380,7 @@ void windowSendEvent (long /*int*/ id, long /*int*/ sel, long /*int*/ event) {
 				NSString chars = nsEvent.characters();
 
 				if (chars != null && chars.length() == 1) {
-					int firstChar = (int)/*64*/chars.characterAtIndex(0);
+					int firstChar = (int)chars.characterAtIndex(0);
 
 					// Shift-tab appears as control-Y.
 					switch (firstChar) {
@@ -2441,13 +2428,13 @@ private boolean searchForEscMenuItem(Menu menu) {
 }
 
 @Override
-boolean windowShouldClose(long /*int*/ id, long /*int*/ sel, long /*int*/ window) {
+boolean windowShouldClose(long id, long sel, long window) {
 	if (isEnabled()) closeWidget (false);
 	return false;
 }
 
 @Override
-void windowWillClose(long /*int*/ id, long /*int*/ sel, long /*int*/ notification) {
+void windowWillClose(long id, long sel, long notification) {
 	closeWidget(true);
 }
 
