@@ -202,7 +202,7 @@ Point adjustMoveCursor () {
 	int newY = bounds.y;
 	/*
 	 * Convert to screen coordinates if needed
- 	 */
+	 */
 	if (parent != null) {
 		Point pt = parent.toDisplay (newX, newY);
 		newX = pt.x;
@@ -234,7 +234,7 @@ Point adjustResizeCursor (boolean movePointer) {
 
 	/*
 	 * Convert to screen coordinates if needed
- 	 */
+	 */
 	if (parent != null) {
 		Point pt = parent.toDisplay (newX, newY);
 		newX = pt.x;
@@ -368,7 +368,7 @@ void drawRectangles (NSWindow window, Rectangle [] rects, boolean erase) {
 	context.setCompositingOperation(erase ? OS.NSCompositeClear : OS.NSCompositeSourceOver);
 	NSRect rectFrame = new NSRect();
 	NSPoint globalPoint = new NSPoint();
-	double /*float*/ screenHeight = display.getPrimaryFrame().height;
+	double screenHeight = display.getPrimaryFrame().height;
 	for (int i=0; i<rects.length; i++) {
 		Rectangle rect = rects [i];
 		rectFrame.x = rect.x + parentOrigin.x;
@@ -552,7 +552,7 @@ void mouse (NSEvent nsEvent) {
 		}
 		oldX = newX;  oldY = newY;
 	}
-	switch ((int)/*64*/nsEvent.type()) {
+	switch ((int)nsEvent.type()) {
 		case OS.NSLeftMouseUp:
 		case OS.NSRightMouseUp:
 		case OS.NSOtherMouseUp:
@@ -561,8 +561,8 @@ void mouse (NSEvent nsEvent) {
 }
 
 void key (NSEvent nsEvent) {
-	int nsType = (int)/*64*/nsEvent.type();
-	long /*int*/ modifierFlags = nsEvent.modifierFlags();
+	int nsType = (int)nsEvent.type();
+	long modifierFlags = nsEvent.modifierFlags();
 	int nsKeyCode = nsEvent.keyCode();
 	int keyCode = Display.translateKey (nsKeyCode);
 
@@ -780,7 +780,7 @@ public boolean open () {
 	 * NSWindow. Fix is to use one NSWindow per screen.
 	 */
 	NSArray screens = NSScreen.screens();
-	int count = (int)/*64*/screens.count();
+	int count = (int)screens.count();
 	windows = new NSWindow [count];
 	for (int i = 0; i < count; i++) {
 		NSScreen screen = new NSScreen(screens.objectAtIndex(i));
@@ -824,7 +824,7 @@ public boolean open () {
 	NSApplication application = NSApplication.sharedApplication();
 	NSEvent currentEvent = application.currentEvent();
 	if (currentEvent != null) {
-		switch ((int)/*64*/currentEvent.type()) {
+		switch ((int)currentEvent.type()) {
 			case OS.NSLeftMouseDown:
 			case OS.NSLeftMouseDragged:
 			case OS.NSRightMouseDown:
@@ -859,7 +859,7 @@ public boolean open () {
 			display.runDeferredLayouts ();
 			NSEvent event = application.nextEventMatchingMask(OS.NSAnyEventMask, NSDate.distantFuture(), OS.NSDefaultRunLoopMode, true);
 			if (event == null) continue;
-			int type = (int)/*64*/event.type();
+			int type = (int)event.type();
 			switch (type) {
 				case OS.NSLeftMouseUp:
 				case OS.NSRightMouseUp:
