@@ -58,7 +58,7 @@ public final class Cursor extends Resource {
 	 *
 	 * @noreference This field is not intended to be referenced by clients.
 	 */
-	public long /*int*/ handle;
+	public long handle;
 
 	static final byte[] APPSTARTING_SRC = {
 		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00,
@@ -140,34 +140,67 @@ public Cursor(Device device, int style) {
 	super(device);
 	int shape = 0;
 	byte[] name = null;
-	switch (style) {
-		case SWT.CURSOR_APPSTARTING:	name = Converter.wcsToMbcs("progress", true) ; break;
-		case SWT.CURSOR_ARROW:			shape = GDK.GDK_LEFT_PTR; break;
-		case SWT.CURSOR_WAIT:			shape = GDK.GDK_WATCH; break;
-		case SWT.CURSOR_CROSS:			shape = GDK.GDK_CROSS; break;
-		case SWT.CURSOR_HAND:			shape = GDK.GDK_HAND2; break;
-		case SWT.CURSOR_HELP:			shape = GDK.GDK_QUESTION_ARROW; break;
-		case SWT.CURSOR_SIZEALL:		shape = GDK.GDK_FLEUR; break;
-		case SWT.CURSOR_SIZENESW:		shape = GDK.GDK_SIZING; name=Converter.wcsToMbcs("nesw-resize", true); break;
-		case SWT.CURSOR_SIZENS:			shape = GDK.GDK_DOUBLE_ARROW; break;
-		case SWT.CURSOR_SIZENWSE:		shape = GDK.GDK_SIZING; name=Converter.wcsToMbcs("nwse-resize", true); break;
-		case SWT.CURSOR_SIZEWE:			shape = GDK.GDK_SB_H_DOUBLE_ARROW; break;
-		case SWT.CURSOR_SIZEN:			shape = GDK.GDK_TOP_SIDE; break;
-		case SWT.CURSOR_SIZES:			shape = GDK.GDK_BOTTOM_SIDE; break;
-		case SWT.CURSOR_SIZEE:			shape = GDK.GDK_RIGHT_SIDE; break;
-		case SWT.CURSOR_SIZEW:			shape = GDK.GDK_LEFT_SIDE; break;
-		case SWT.CURSOR_SIZENE:			shape = GDK.GDK_TOP_RIGHT_CORNER; break;
-		case SWT.CURSOR_SIZESE:			shape = GDK.GDK_BOTTOM_RIGHT_CORNER; break;
-		case SWT.CURSOR_SIZESW:			shape = GDK.GDK_BOTTOM_LEFT_CORNER; break;
-		case SWT.CURSOR_SIZENW:			shape = GDK.GDK_TOP_LEFT_CORNER; break;
-		case SWT.CURSOR_UPARROW:		shape = GDK.GDK_SB_UP_ARROW; break;
-		case SWT.CURSOR_IBEAM:			shape = GDK.GDK_XTERM; break;
-		case SWT.CURSOR_NO:				shape = GDK.GDK_X_CURSOR; name=Converter.wcsToMbcs("not-allowed", true) ; break;
-		default:
-			SWT.error(SWT.ERROR_INVALID_ARGUMENT);
+	if (GTK.GTK4) {
+		switch (style) {
+			case SWT.CURSOR_APPSTARTING:	name = Converter.wcsToMbcs("progress", true) ; break;
+			case SWT.CURSOR_ARROW:			name = Converter.wcsToMbcs("default", true) ; break;
+			case SWT.CURSOR_WAIT:			name = Converter.wcsToMbcs("wait", true) ; break;
+			case SWT.CURSOR_CROSS:			name = Converter.wcsToMbcs("cell", true) ; break;
+			case SWT.CURSOR_HAND:			name = Converter.wcsToMbcs("pointer", true) ; break;
+			case SWT.CURSOR_HELP:			name = Converter.wcsToMbcs("help", true) ; break;
+			case SWT.CURSOR_SIZEALL:		name = Converter.wcsToMbcs("all-scroll", true) ; break;
+			case SWT.CURSOR_SIZENESW:		name = Converter.wcsToMbcs("nesw-resize", true); break;
+			case SWT.CURSOR_SIZENS:			name = Converter.wcsToMbcs("row-resize", true) ; break;
+			case SWT.CURSOR_SIZENWSE:		name = Converter.wcsToMbcs("nwse-resize", true); break;
+			case SWT.CURSOR_SIZEWE:			name = Converter.wcsToMbcs("col-resize", true); break;
+			case SWT.CURSOR_SIZEN:			name = Converter.wcsToMbcs("n-resize", true); break;
+			case SWT.CURSOR_SIZES:			name = Converter.wcsToMbcs("s-resize", true); break;
+			case SWT.CURSOR_SIZEE:			name = Converter.wcsToMbcs("e-resize", true); break;
+			case SWT.CURSOR_SIZEW:			name = Converter.wcsToMbcs("w-resize", true); break;
+			case SWT.CURSOR_SIZENE:			name = Converter.wcsToMbcs("ne-resize", true); break;
+			case SWT.CURSOR_SIZESE:			name = Converter.wcsToMbcs("se-resize", true); break;
+			case SWT.CURSOR_SIZESW:			name = Converter.wcsToMbcs("sw-resize", true); break;
+			case SWT.CURSOR_SIZENW:			name = Converter.wcsToMbcs("nw-resize", true); break;
+			case SWT.CURSOR_UPARROW:		name = Converter.wcsToMbcs("ns-resize", true); break;
+			case SWT.CURSOR_IBEAM:			name = Converter.wcsToMbcs("text", true); break;
+			case SWT.CURSOR_NO:				name = Converter.wcsToMbcs("not-allowed", true) ; break;
+			default:
+				SWT.error(SWT.ERROR_INVALID_ARGUMENT);
+		}
+	} else {
+		switch (style) {
+			case SWT.CURSOR_APPSTARTING:	name = Converter.wcsToMbcs("progress", true) ; break;
+			case SWT.CURSOR_ARROW:			shape = GDK.GDK_LEFT_PTR; break;
+			case SWT.CURSOR_WAIT:			shape = GDK.GDK_WATCH; break;
+			case SWT.CURSOR_CROSS:			shape = GDK.GDK_CROSS; break;
+			case SWT.CURSOR_HAND:			shape = GDK.GDK_HAND2; break;
+			case SWT.CURSOR_HELP:			shape = GDK.GDK_QUESTION_ARROW; break;
+			case SWT.CURSOR_SIZEALL:		shape = GDK.GDK_FLEUR; break;
+			case SWT.CURSOR_SIZENESW:		shape = GDK.GDK_SIZING; name=Converter.wcsToMbcs("nesw-resize", true); break;
+			case SWT.CURSOR_SIZENS:			shape = GDK.GDK_DOUBLE_ARROW; break;
+			case SWT.CURSOR_SIZENWSE:		shape = GDK.GDK_SIZING; name=Converter.wcsToMbcs("nwse-resize", true); break;
+			case SWT.CURSOR_SIZEWE:			shape = GDK.GDK_SB_H_DOUBLE_ARROW; break;
+			case SWT.CURSOR_SIZEN:			shape = GDK.GDK_TOP_SIDE; break;
+			case SWT.CURSOR_SIZES:			shape = GDK.GDK_BOTTOM_SIDE; break;
+			case SWT.CURSOR_SIZEE:			shape = GDK.GDK_RIGHT_SIDE; break;
+			case SWT.CURSOR_SIZEW:			shape = GDK.GDK_LEFT_SIDE; break;
+			case SWT.CURSOR_SIZENE:			shape = GDK.GDK_TOP_RIGHT_CORNER; break;
+			case SWT.CURSOR_SIZESE:			shape = GDK.GDK_BOTTOM_RIGHT_CORNER; break;
+			case SWT.CURSOR_SIZESW:			shape = GDK.GDK_BOTTOM_LEFT_CORNER; break;
+			case SWT.CURSOR_SIZENW:			shape = GDK.GDK_TOP_LEFT_CORNER; break;
+			case SWT.CURSOR_UPARROW:		shape = GDK.GDK_SB_UP_ARROW; break;
+			case SWT.CURSOR_IBEAM:			shape = GDK.GDK_XTERM; break;
+			case SWT.CURSOR_NO:				shape = GDK.GDK_X_CURSOR; name=Converter.wcsToMbcs("not-allowed", true) ; break;
+			default:
+				SWT.error(SWT.ERROR_INVALID_ARGUMENT);
+		}
 	}
 	if (name != null) {
-		handle = GDK.gdk_cursor_new_from_name (GDK.gdk_display_get_default(), name);
+		if (GTK.GTK4) {
+			handle = GDK.gdk_cursor_new_from_name(name, 0);
+		} else {
+			handle = GDK.gdk_cursor_new_from_name (GDK.gdk_display_get_default(), name);
+		}
 	}
 	if (handle == 0) {
 		if (shape == 0 && style == SWT.CURSOR_APPSTARTING) {
@@ -177,8 +210,9 @@ public Cursor(Device device, int style) {
 			System.arraycopy(APPSTARTING_MASK, 0, mask, 0, mask.length);
 			handle = createCursor(src, mask, 32, 32, 2, 2, true);
 		} else {
-			handle = GDK.gdk_cursor_new_for_display(GDK.gdk_display_get_default(), shape);
+			if (!GTK.GTK4) handle = GDK.gdk_cursor_new_for_display(GDK.gdk_display_get_default(), shape);
 		}
+
 	}
 	if (handle == 0) SWT.error(SWT.ERROR_NO_HANDLES);
 	init();
@@ -309,15 +343,15 @@ public Cursor(Device device, ImageData source, int hotspotX, int hotspotY) {
 		hotspotY >= source.height || hotspotY < 0) {
 		SWT.error(SWT.ERROR_INVALID_ARGUMENT);
 	}
-	long /*int*/ display = 0;
+	long display = 0;
 	if (GDK.gdk_display_supports_cursor_color(display = GDK.gdk_display_get_default ())) {
 		int width = source.width;
 		int height = source.height;
 		PaletteData palette = source.palette;
-		long /*int*/ pixbuf = GDK.gdk_pixbuf_new(GDK.GDK_COLORSPACE_RGB, true, 8, width, height);
+		long pixbuf = GDK.gdk_pixbuf_new(GDK.GDK_COLORSPACE_RGB, true, 8, width, height);
 		if (pixbuf == 0) SWT.error(SWT.ERROR_NO_HANDLES);
 		int stride = GDK.gdk_pixbuf_get_rowstride(pixbuf);
-		long /*int*/ data = GDK.gdk_pixbuf_get_pixels(pixbuf);
+		long data = GDK.gdk_pixbuf_get_pixels(pixbuf);
 		byte[] buffer = source.data;
 		if (!palette.isDirect || source.depth != 24 || stride != source.bytesPerLine || palette.redMask != 0xFF000000 || palette.greenMask != 0xFF0000 || palette.blueMask != 0xFF00) {
 			buffer = new byte[source.width * source.height * 4];
@@ -368,6 +402,10 @@ public Cursor(Device device, ImageData source, int hotspotX, int hotspotY) {
 				for (int i=3; i<buffer.length; i+=4) {
 					buffer[i] = alphaData[i/4];
 				}
+			} else {
+				for (int i=3; i<buffer.length; i+=4) {
+					buffer[i] = -1;
+				}
 			}
 		}
 		C.memmove(data, buffer, stride * height);
@@ -451,83 +489,74 @@ public Cursor(Device device, ImageData source, int hotspotX, int hotspotY) {
 	init();
 }
 
-long /*int*/ createCursor(byte[] sourceData, byte[] maskData, int width, int height, int hotspotX, int hotspotY, boolean reverse) {
-	if (GTK.GTK3) {
-		for (int i = 0; i < sourceData.length; i++) {
-			byte s = sourceData[i];
-			sourceData[i] = (byte)(((s & 0x80) >> 7) |
-				((s & 0x40) >> 5) |
-				((s & 0x20) >> 3) |
-				((s & 0x10) >> 1) |
-				((s & 0x08) << 1) |
-				((s & 0x04) << 3) |
-				((s & 0x02) << 5) |
-				((s & 0x01) << 7));
-			sourceData[i] = (byte) ~sourceData[i];
-		}
-		for (int i = 0; i < maskData.length; i++) {
-			byte s = maskData[i];
-			maskData[i] = (byte)(((s & 0x80) >> 7) |
-				((s & 0x40) >> 5) |
-				((s & 0x20) >> 3) |
-				((s & 0x10) >> 1) |
-				((s & 0x08) << 1) |
-				((s & 0x04) << 3) |
-				((s & 0x02) << 5) |
-				((s & 0x01) << 7));
-			maskData[i] = (byte) ~maskData[i];
-		}
-		PaletteData palette = new PaletteData(new RGB(0, 0, 0), new RGB(255, 255, 255));
-		ImageData source = new ImageData(width, height, 1, palette, 1, sourceData);
-		ImageData mask = new ImageData(width, height, 1, palette, 1, maskData);
-		byte[] data = new byte[source.width * source.height * 4];
-		for (int y = 0; y < source.height; y++) {
-			int offset = y * source.width * 4;
-			for (int x = 0; x < source.width; x++) {
-				int pixel = source.getPixel(x, y);
-				int maskPixel = mask.getPixel(x, y);
-				if (pixel == 0 && maskPixel == 0) {
-					// BLACK
-					data[offset+3] = (byte)0xFF;
-				} else if (pixel == 0 && maskPixel == 1) {
-					// WHITE - cursor color
-					data[offset] = data[offset + 1] = data[offset + 2] = data[offset + 3] = (byte)0xFF;
-				} else if (pixel == 1 && maskPixel == 0) {
-					// SCREEN
-				} else {
-					/* no support */
-					// REVERSE SCREEN -> SCREEN
-				}
-				offset += 4;
+long createCursor(byte[] sourceData, byte[] maskData, int width, int height, int hotspotX, int hotspotY, boolean reverse) {
+	for (int i = 0; i < sourceData.length; i++) {
+		byte s = sourceData[i];
+		sourceData[i] = (byte)(((s & 0x80) >> 7) |
+			((s & 0x40) >> 5) |
+			((s & 0x20) >> 3) |
+			((s & 0x10) >> 1) |
+			((s & 0x08) << 1) |
+			((s & 0x04) << 3) |
+			((s & 0x02) << 5) |
+			((s & 0x01) << 7));
+		sourceData[i] = (byte) ~sourceData[i];
+	}
+	for (int i = 0; i < maskData.length; i++) {
+		byte s = maskData[i];
+		maskData[i] = (byte)(((s & 0x80) >> 7) |
+			((s & 0x40) >> 5) |
+			((s & 0x20) >> 3) |
+			((s & 0x10) >> 1) |
+			((s & 0x08) << 1) |
+			((s & 0x04) << 3) |
+			((s & 0x02) << 5) |
+			((s & 0x01) << 7));
+		maskData[i] = (byte) ~maskData[i];
+	}
+	PaletteData palette = new PaletteData(new RGB(0, 0, 0), new RGB(255, 255, 255));
+	ImageData source = new ImageData(width, height, 1, palette, 1, sourceData);
+	ImageData mask = new ImageData(width, height, 1, palette, 1, maskData);
+	byte[] data = new byte[source.width * source.height * 4];
+	for (int y = 0; y < source.height; y++) {
+		int offset = y * source.width * 4;
+		for (int x = 0; x < source.width; x++) {
+			int pixel = source.getPixel(x, y);
+			int maskPixel = mask.getPixel(x, y);
+			if (pixel == 0 && maskPixel == 0) {
+				// BLACK
+				data[offset+3] = (byte)0xFF;
+			} else if (pixel == 0 && maskPixel == 1) {
+				// WHITE - cursor color
+				data[offset] = data[offset + 1] = data[offset + 2] = data[offset + 3] = (byte)0xFF;
+			} else if (pixel == 1 && maskPixel == 0) {
+				// SCREEN
+			} else {
+				/* no support */
+				// REVERSE SCREEN -> SCREEN
 			}
+			offset += 4;
 		}
-		long /*int*/ pixbuf = GDK.gdk_pixbuf_new(GDK.GDK_COLORSPACE_RGB, true, 8, width, height);
-		if (pixbuf == 0) SWT.error(SWT.ERROR_NO_HANDLES);
-		int stride = GDK.gdk_pixbuf_get_rowstride(pixbuf);
-		long /*int*/ pixels = GDK.gdk_pixbuf_get_pixels(pixbuf);
-		C.memmove(pixels, data, stride * height);
-		long /*int*/ cursor = GDK.gdk_cursor_new_from_pixbuf(GDK.gdk_display_get_default(), pixbuf, hotspotX, hotspotY);
-		OS.g_object_unref(pixbuf);
-		return cursor;
 	}
-	long /*int*/ sourcePixmap = GDK.gdk_bitmap_create_from_data(0, sourceData, width, height);
-	long /*int*/ maskPixmap = GDK.gdk_bitmap_create_from_data(0, maskData, width, height);
-	long /*int*/ cursor = 0;
-	if (sourcePixmap != 0 && maskPixmap != 0) {
-		GdkColor foreground = new GdkColor();
-		if (!reverse) foreground.red = foreground.green = foreground.blue = (short)0xFFFF;
-		GdkColor background = new GdkColor();
-		if (reverse) background.red = background.green = background.blue = (short)0xFFFF;
-		cursor = GDK.gdk_cursor_new_from_pixmap (sourcePixmap, maskPixmap, foreground, background, hotspotX, hotspotY);
+	long pixbuf = GDK.gdk_pixbuf_new(GDK.GDK_COLORSPACE_RGB, true, 8, width, height);
+	if (pixbuf == 0) SWT.error(SWT.ERROR_NO_HANDLES);
+	int stride = GDK.gdk_pixbuf_get_rowstride(pixbuf);
+	long pixels = GDK.gdk_pixbuf_get_pixels(pixbuf);
+	C.memmove(pixels, data, stride * height);
+	long cursor;
+	if (GTK.GTK4) {
+		long texture = GDK.gdk_texture_new_for_pixbuf (pixbuf);
+		cursor = GDK.gdk_cursor_new_from_texture (texture, hotspotX, hotspotY, 0);
+	} else {
+		cursor = GDK.gdk_cursor_new_from_pixbuf(GDK.gdk_display_get_default(), pixbuf, hotspotX, hotspotY);
 	}
-	if (sourcePixmap != 0) OS.g_object_unref (sourcePixmap);
-	if (maskPixmap != 0) OS.g_object_unref (maskPixmap);
+	OS.g_object_unref(pixbuf);
 	return cursor;
 }
 
 @Override
 void destroy() {
-	gdk_cursor_unref(handle);
+	OS.g_object_unref(handle);
 	handle = 0;
 }
 
@@ -564,7 +593,7 @@ public boolean equals(Object object) {
  *
  * @noreference This method is not intended to be referenced by clients.
  */
-public static Cursor gtk_new(Device device, long /*int*/ handle) {
+public static Cursor gtk_new(Device device, long handle) {
 	Cursor cursor = new Cursor(device);
 	cursor.handle = handle;
 	return cursor;
@@ -582,7 +611,7 @@ public static Cursor gtk_new(Device device, long /*int*/ handle) {
  */
 @Override
 public int hashCode() {
-	return (int)/*64*/handle;
+	return (int)handle;
 }
 
 /**
@@ -612,12 +641,4 @@ public String toString () {
 	return "Cursor {" + handle + "}";
 }
 
-void gdk_cursor_unref (long /*int*/ cursor) {
-	if (GTK.GTK3) {
-		OS.g_object_unref (cursor);
-	} else {
-		GDK.gdk_cursor_unref(cursor);
-	}
-}
-
 }
