@@ -38,10 +38,10 @@ public abstract class Device implements Drawable {
 	 */
 	protected static final int CHANGE_SCALEFACTOR = 1;
 	/* Settings callbacks */
-	long /*int*/ gsettingsProc;
+	long gsettingsProc;
 	Callback gsettingsCallback;
 	boolean isConnected = false;
-	long /*int*/ displaySettings; //gsettings Dictionary
+	long displaySettings; //gsettings Dictionary
 
 	/**
 	 * the handle to the X Display
@@ -55,8 +55,8 @@ public abstract class Device implements Drawable {
 	 *
 	 * @noreference This field is not intended to be referenced by clients.
 	 */
-	protected long /*int*/ xDisplay;
-	long /*int*/ shellHandle;
+	protected long xDisplay;
+	long shellHandle;
 
 	/* Debugging */
 	public static boolean DEBUG;
@@ -70,7 +70,7 @@ public abstract class Device implements Drawable {
 	boolean disposed;
 
 	/* Warning and Error Handlers */
-	long /*int*/ logProc;
+	long logProc;
 	Callback logCallback;
 	//NOT DONE - get list of valid names
 	String [] log_domains = {"", "GLib-GObject", "GLib", "GObject", "Pango", "ATK", "GdkPixbuf", "Gdk", "Gtk", "GnomeVFS", "GIO"};
@@ -79,7 +79,7 @@ public abstract class Device implements Drawable {
 
 	/* X Warning and Error Handlers */
 	static Callback XErrorCallback, XIOErrorCallback;
-	static long /*int*/ XErrorProc, XIOErrorProc, XNullErrorProc, XNullIOErrorProc;
+	static long XErrorProc, XIOErrorProc, XNullErrorProc, XNullIOErrorProc;
 	static Device[] Devices = new Device[4];
 
 	/*
@@ -104,7 +104,7 @@ public abstract class Device implements Drawable {
 	 */
 	protected int scaleFactor;
 
-	long /*int*/ emptyTab;
+	long emptyTab;
 
 	/*
 	* TEMPORARY CODE. When a graphics object is
@@ -191,7 +191,7 @@ public Device(DeviceData data) {
  * </p><p>
  * In future releases of SWT, there may be more or fewer error
  * checks and exceptions may be thrown for different reasons.
- * <p>
+ * </p>
  *
  * @exception SWTException <ul>
  *    <li>ERROR_WIDGET_DISPOSED - if the receiver has been disposed</li>
@@ -260,7 +260,7 @@ void dispose_Object (Object object) {
 	}
 }
 
-static synchronized Device findDevice (long /*int*/ xDisplay) {
+static synchronized Device findDevice (long xDisplay) {
 	for (int i=0; i<Devices.length; i++) {
 		Device device = Devices [i];
 		if (device != null && device.xDisplay == xDisplay) {
@@ -418,13 +418,19 @@ public Point getDPI () {
 public FontData[] getFontList (String faceName, boolean scalable) {
 	checkDevice ();
 	if (!scalable) return new FontData[0];
-	long /*int*/[] family = new long /*int*/[1];
-	long /*int*/[] face = new long /*int*/[1];
-	long /*int*/[] families = new long /*int*/[1];
+	long [] family = new long [1];
+	long [] face = new long [1];
+	long [] families = new long [1];
 	int[] n_families = new int[1];
-	long /*int*/[] faces = new long /*int*/[1];
+	long [] faces = new long [1];
 	int[] n_faces = new int[1];
-	long /*int*/ context = GDK.gdk_pango_context_get();
+	long context;
+	if (GTK.GTK4) {
+		long fontMap = OS.pango_cairo_font_map_get_default ();
+		context = OS.pango_font_map_create_context (fontMap);
+	} else {
+		context = GDK.gdk_pango_context_get();
+	}
 	OS.pango_context_list_families(context, families, n_families);
 	int nFds = 0;
 	FontData[] fds = new FontData[faceName != null ? 4 : n_families[0]];
@@ -432,7 +438,7 @@ public FontData[] getFontList (String faceName, boolean scalable) {
 		C.memmove(family, families[0] + i * C.PTR_SIZEOF, C.PTR_SIZEOF);
 		boolean match = true;
 		if (faceName != null) {
-			long /*int*/ familyName = OS.pango_font_family_get_name(family[0]);
+			long familyName = OS.pango_font_family_get_name(family[0]);
 			int length = C.strlen(familyName);
 			byte[] buffer = new byte[length];
 			C.memmove(buffer, familyName, length);
@@ -440,12 +446,12 @@ public FontData[] getFontList (String faceName, boolean scalable) {
 			match = faceName.equalsIgnoreCase(name);
 		}
 		if (match) {
-		    OS.pango_font_family_list_faces(family[0], faces, n_faces);
-		    for (int j=0; j<n_faces[0]; j++) {
-		        C.memmove(face, faces[0] + j * C.PTR_SIZEOF, C.PTR_SIZEOF);
-		        long /*int*/ fontDesc = OS.pango_font_face_describe(face[0]);
-		        Font font = Font.gtk_new(this, fontDesc);
-		        FontData data = font.getFontData()[0];
+			OS.pango_font_family_list_faces(family[0], faces, n_faces);
+			for (int j=0; j<n_faces[0]; j++) {
+				C.memmove(face, faces[0] + j * C.PTR_SIZEOF, C.PTR_SIZEOF);
+				long fontDesc = OS.pango_font_face_describe(face[0]);
+				Font font = Font.gtk_new(this, fontDesc);
+				FontData data = font.getFontData()[0];
 				if (nFds == fds.length) {
 					FontData[] newFds = new FontData[fds.length + n_families[0]];
 					System.arraycopy(fds, 0, newFds, 0, nFds);
@@ -453,9 +459,9 @@ public FontData[] getFontList (String faceName, boolean scalable) {
 				}
 				fds[nFds++] = data;
 				OS.pango_font_description_free(fontDesc);
-		    }
-		    OS.g_free(faces[0]);
-		    if (faceName != null) break;
+			}
+			OS.g_free(faces[0]);
+			if (faceName != null) break;
 		}
 	}
 	OS.g_free(families[0]);
@@ -469,12 +475,13 @@ public FontData[] getFontList (String faceName, boolean scalable) {
 Point getScreenDPI () {
 	int dpi = 96; //default value
 	if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0)) {
-		long /*int*/ display = GDK.gdk_display_get_default();
-		long /*int*/ pMonitor = GDK.gdk_display_get_primary_monitor(display);
+		long display = GDK.gdk_display_get_default();
+		long pMonitor = GDK.gdk_display_get_primary_monitor(display);
 		if (pMonitor == 0) {
 			pMonitor = GDK.gdk_display_get_monitor(display, 0);
 		}
 		int widthMM = GDK.gdk_monitor_get_width_mm(pMonitor);
+		if (widthMM == 0) return new Point (dpi, dpi);
 		int scaleFactor = GDK.gdk_monitor_get_scale_factor(pMonitor);
 		GdkRectangle monitorGeometry = new GdkRectangle ();
 		GDK.gdk_monitor_get_geometry(pMonitor, monitorGeometry);
@@ -654,25 +661,23 @@ protected void init () {
 	if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0)) {
 		double sx[] = new double[1];
 		double sy[] = new double[1];
-		long /*int*/ gdkResource;
-		long /*int*/ surface;
+		long gdkResource;
+		long surface;
 		if (GTK.GTK4) {
-			GTK.gtk_widget_realize(shellHandle);
-			gdkResource = GTK.gtk_widget_get_surface(shellHandle);
-			surface = GDK.gdk_surface_create_similar_surface(gdkResource, Cairo.CAIRO_CONTENT_COLOR, 10, 10);
+			surface = Cairo.cairo_image_surface_create(Cairo.CAIRO_FORMAT_RGB24, 10, 10);
 		} else {
 			gdkResource = GDK.gdk_get_default_root_window();
 			surface = GDK.gdk_window_create_similar_surface(gdkResource, Cairo.CAIRO_CONTENT_COLOR, 10, 10);
 		}
 		Cairo.cairo_surface_get_device_scale(surface, sx, sy);
-		DPIUtil.setUseCairoAutoScale((sx[0]*100) == scaleFactor);
+		DPIUtil.setUseCairoAutoScale((sx[0]*100) == scaleFactor || OS.isGNOME);
 	}
 
 	/* Initialize the system font slot */
-	long /*int*/ [] defaultFontArray = new long /*int*/ [1];
-	long /*int*/ defaultFont;
-	long /*int*/ context = GTK.gtk_widget_get_style_context (shellHandle);
-	if ((GTK.GTK_VERSION < OS.VERSION(3, 8, 0))|| ("ppc64le".equals(System.getProperty("os.arch")))) {
+	long [] defaultFontArray = new long [1];
+	long defaultFont;
+	long context = GTK.gtk_widget_get_style_context (shellHandle);
+	if ("ppc64le".equals(System.getProperty("os.arch"))) {
 		defaultFont = GTK.gtk_style_context_get_font (context, GTK.GTK_STATE_FLAG_NORMAL);
 	} else if (GTK.GTK_VERSION >= OS.VERSION(3, 18, 0)) {
 		GTK.gtk_style_context_save(context);
@@ -716,7 +721,7 @@ protected void init () {
  * Note that much of eclipse 'dark theme' is done by platform.ui's CSS engine, not by SWT.
  */
 private void overrideThemeValues () {
-	long /*int*/ provider = GTK.gtk_css_provider_new();
+	long provider = GTK.gtk_css_provider_new();
 
 	BiFunction <String, Boolean, String> load = (path, isResource) -> {
 		try  {
@@ -738,8 +743,8 @@ private void overrideThemeValues () {
 	// Load functional CSS fixes. Such as keyboard functionality for some widgets.
 	combinedCSS.append(load.apply(
 		GTK.GTK_VERSION < OS.VERSION(3, 20, 0) ?
-				"/org/eclipse/swt/internal/gtk/swt_functional_gtk_pre320.css" :
-				"/org/eclipse/swt/internal/gtk/swt_functional_gtk_320.css"
+				"/org/eclipse/swt/internal/gtk/swt_functional_gtk_pre_3_20.css" :
+				"/org/eclipse/swt/internal/gtk/swt_functional_gtk_3_20.css"
 			, true));
 
 	// By default, load CSS theme fixes to overcome things such as excessive padding that breaks SWT otherwise.
@@ -751,11 +756,14 @@ private void overrideThemeValues () {
 	// - These fixes should not contain any color information, otherwise it might break a light/dark variant of the theme.
 	//   Color fixes should be put either into the theme itself or via swt user api.
 	if (System.getProperty("org.eclipse.swt.internal.gtk.noThemingFixes") == null) {
-		combinedCSS.append(load.apply(
-				GTK.GTK_VERSION < OS.VERSION(3, 20, 0) ?
-						"/org/eclipse/swt/internal/gtk/swt_theming_fixes_gtk_pre320.css" :
-						"/org/eclipse/swt/internal/gtk/swt_theming_fixes_gtk_320.css"
-					, true));
+		if (GTK.GTK_VERSION >= OS.VERSION(3, 20, 0)) {
+			combinedCSS.append(load.apply("/org/eclipse/swt/internal/gtk/swt_theming_fixes_gtk_3_20.css", true));
+			if (GTK.GTK_VERSION >= OS.VERSION(3, 24, 5)) {
+				combinedCSS.append(load.apply("/org/eclipse/swt/internal/gtk/swt_theming_fixes_gtk_3_24_5.css", true));
+			}
+		} else {
+			combinedCSS.append(load.apply("/org/eclipse/swt/internal/gtk/swt_theming_fixes_gtk_pre_3_20.css", true));
+		}
 	}
 
 	// Load CSS from user-defined CSS file.
@@ -768,21 +776,25 @@ private void overrideThemeValues () {
 	}
 
 	if (GTK.GTK4) {
-		long /*int*/ display = GDK.gdk_display_get_default();
+		long display = GDK.gdk_display_get_default();
 		if (display == 0 || provider == 0) {
 			System.err.println("SWT Warning: Override of theme values failed. Reason: could not acquire display or provider.");
 			return;
 		}
 		GTK.gtk_style_context_add_provider_for_display (display, provider, GTK.GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 	} else {
-		long /*int*/ screen = GDK.gdk_screen_get_default();
+		long screen = GDK.gdk_screen_get_default();
 		if (screen == 0 || provider == 0) {
 			System.err.println("SWT Warning: Override of theme values failed. Reason: could not acquire screen or provider.");
 			return;
 		}
 		GTK.gtk_style_context_add_provider_for_screen (screen, provider, GTK.GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 	}
-	GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (combinedCSS.toString(), true), -1, null);
+	if (GTK.GTK4) {
+		GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (combinedCSS.toString(), true), -1);
+	} else {
+		GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (combinedCSS.toString(), true), -1, null);
+	}
 }
 
 /**
@@ -801,7 +813,7 @@ private void overrideThemeValues () {
  * @noreference This method is not intended to be referenced by clients.
  */
 @Override
-public abstract long /*int*/ internal_new_GC (GCData data);
+public abstract long internal_new_GC (GCData data);
 
 /**
  * Invokes platform specific functionality to dispose a GC handle.
@@ -819,7 +831,7 @@ public abstract long /*int*/ internal_new_GC (GCData data);
  * @noreference This method is not intended to be referenced by clients.
  */
 @Override
-public abstract void internal_dispose_GC (long /*int*/ hDC, GCData data);
+public abstract void internal_dispose_GC (long hDC, GCData data);
 
 /**
  * Returns <code>true</code> if the device has been disposed,
@@ -860,7 +872,7 @@ public boolean loadFont (String path) {
 	return OS.FcConfigAppFontAddFile (0, buffer);
 }
 
-long /*int*/ logProc (long /*int*/ log_domain, long /*int*/ log_level, long /*int*/ message, long /*int*/ user_data) {
+long logProc (long log_domain, long log_level, long message, long user_data) {
 	if (DEBUG) {
 		new Error ().printStackTrace ();
 	}
@@ -868,7 +880,7 @@ long /*int*/ logProc (long /*int*/ log_domain, long /*int*/ log_level, long /*in
 		if (DEBUG || debug) {
 			new Error ().printStackTrace ();
 		}
-		OS.g_log_default_handler (log_domain, (int)/*64*/log_level, message, 0);
+		OS.g_log_default_handler (log_domain, (int)log_level, message, 0);
 	}
 	return 0;
 }
@@ -921,7 +933,7 @@ static synchronized void register (Device device) {
  * The handle is needed by <code>destroy</code>.
  * </p>
  * This method is called before <code>destroy</code>.
- * </p><p>
+ * <p>
  * If subclasses reimplement this method, they must
  * call the <code>super</code> implementation.
  * </p>
@@ -1024,7 +1036,7 @@ public void setWarnings (boolean warnings) {
 	}
 }
 
-static long /*int*/ XErrorProc (long /*int*/ xDisplay, long /*int*/ xErrorEvent) {
+static long XErrorProc (long xDisplay, long xErrorEvent) {
 	Device device = findDevice (xDisplay);
 	if (device != null) {
 		if (device.warningLevel == 0) {
@@ -1040,7 +1052,7 @@ static long /*int*/ XErrorProc (long /*int*/ xDisplay, long /*int*/ xErrorEvent)
 	return 0;
 }
 
-static long /*int*/ XIOErrorProc (long /*int*/ xDisplay) {
+static long XIOErrorProc (long xDisplay) {
 	Device device = findDevice (xDisplay);
 	if (device != null) {
 		if (DEBUG || device.debug) {
@@ -1077,12 +1089,12 @@ protected int getDeviceZoom() {
 	 */
 	int dpi = 96;
 	if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0)) {
-		long /*int*/ display = GDK.gdk_display_get_default();
-		long /*int*/ monitor = GDK.gdk_display_get_monitor_at_point(display, 0, 0);
+		long display = GDK.gdk_display_get_default();
+		long monitor = GDK.gdk_display_get_monitor_at_point(display, 0, 0);
 		int scale = GDK.gdk_monitor_get_scale_factor(monitor);
 		dpi = dpi * scale;
-	} else if (GTK.GTK_VERSION > OS.VERSION(3, 9, 0)) {
-		long /*int*/ screen = GDK.gdk_screen_get_default();
+	} else {
+		long screen = GDK.gdk_screen_get_default();
 		dpi = (int) GDK.gdk_screen_get_resolution (screen);
 		if (dpi <= 0) dpi = 96; // gdk_screen_get_resolution returns -1 in case of error
 		int monitor_num = GDK.gdk_screen_get_monitor_at_point (screen, 0, 0);
@@ -1096,8 +1108,8 @@ protected int getDeviceZoom() {
  * @nooverride This method is not intended to be re-implemented or extended by clients.
  * @since 3.105
  */
-protected long /*int*/ gsettingsProc (long /*int*/ gobject, long /*int*/ arg1, long /*int*/ user_data) {
-	switch((int)/*64*/user_data) {
+protected long gsettingsProc (long gobject, long arg1, long user_data) {
+	switch((int)user_data) {
 		case CHANGE_SCALEFACTOR:
 			this.scaleFactor = getDeviceZoom ();
 			DPIUtil.setDeviceZoom (scaleFactor);
