@@ -48,7 +48,7 @@ import org.eclipse.swt.internal.gtk.*;
  * @noextend This class is not intended to be subclassed by clients.
  */
 public class Button extends Control {
-	long /*int*/ boxHandle, labelHandle, imageHandle, arrowHandle, groupHandle;
+	long boxHandle, labelHandle, imageHandle, arrowHandle, groupHandle;
 	boolean selected, grayed;
 	ImageList imageList;
 	Image image;
@@ -115,20 +115,27 @@ static int checkStyle (int style) {
 	return style;
 }
 
-static GtkBorder getBorder (byte[] border, long /*int*/ handle, int defaultBorder) {
-    GtkBorder gtkBorder = new GtkBorder();
-    long /*int*/ []  borderPtr = new long /*int*/ [1];
-    GTK.gtk_widget_style_get (handle, border, borderPtr,0);
-    if (borderPtr[0] != 0) {
-        OS.memmove (gtkBorder, borderPtr[0], GtkBorder.sizeof);
-        GTK.gtk_border_free(borderPtr[0]);
-        return gtkBorder;
-    }
-    gtkBorder.left = defaultBorder;
-    gtkBorder.top = defaultBorder;
-    gtkBorder.right = defaultBorder;
-    gtkBorder.bottom = defaultBorder;
-    return gtkBorder;
+GtkBorder getBorder (byte[] border, long handle, int defaultBorder) {
+	GtkBorder gtkBorder = new GtkBorder();
+	long []  borderPtr = new long [1];
+	if (GTK.GTK4) {
+		long context = GTK.gtk_widget_get_style_context (handle);
+		int stateFlag = GTK.gtk_widget_get_state_flags(handle);
+		gtk_style_context_get_border(context, stateFlag, gtkBorder);
+		return gtkBorder;
+	} else {
+		GTK.gtk_widget_style_get (handle, border, borderPtr,0);
+		if (borderPtr[0] != 0) {
+			OS.memmove (gtkBorder, borderPtr[0], GtkBorder.sizeof);
+			GTK.gtk_border_free(borderPtr[0]);
+			return gtkBorder;
+		}
+	}
+	gtkBorder.left = defaultBorder;
+	gtkBorder.top = defaultBorder;
+	gtkBorder.right = defaultBorder;
+	gtkBorder.bottom = defaultBorder;
+	return gtkBorder;
 }
 
 @Override
@@ -199,20 +206,36 @@ Point computeSizeInPixels (int wHint, int hHint, boolean changed) {
 	Point size;
 	boolean wrap = labelHandle != 0 && (style & SWT.WRAP) != 0 && GTK.gtk_widget_get_visible (labelHandle);
 	if (wrap) {
-		int borderWidth = GTK.gtk_container_get_border_width (handle);
-		int[] focusWidth = new int[1];
-		GTK.gtk_widget_style_get (handle, OS.focus_line_width, focusWidth, 0);
-		int[] focusPadding = new int[1];
-		GTK.gtk_widget_style_get (handle, OS.focus_padding, focusPadding, 0);
-		int trimWidth = 2 * (borderWidth + focusWidth [0] + focusPadding [0]), trimHeight = trimWidth;
+		int borderWidth = gtk_container_get_border_width_or_margin (handle);
+		int trimWidth, trimHeight;
+		if (!GTK.GTK4) {
+			int[] focusWidth = new int[1];
+			GTK.gtk_widget_style_get (handle, OS.focus_line_width, focusWidth, 0);
+			int[] focusPadding = new int[1];
+			GTK.gtk_widget_style_get (handle, OS.focus_padding, focusPadding, 0);
+			trimWidth = 2 * (borderWidth + focusWidth [0] + focusPadding [0]);
+		} else {
+			trimWidth = 2 * borderWidth;
+		}
+		trimHeight = trimWidth;
 		int indicatorHeight = 0;
 		if ((style & (SWT.CHECK | SWT.RADIO)) != 0) {
-			int[] indicatorSize = new int[1];
-			GTK.gtk_widget_style_get (handle, OS.indicator_size, indicatorSize, 0);
-			int[] indicatorSpacing = new int[1];
-			GTK.gtk_widget_style_get (handle, OS.indicator_spacing, indicatorSpacing, 0);
-			indicatorHeight = indicatorSize [0] + 2 * indicatorSpacing [0];
-			trimWidth += indicatorHeight + indicatorSpacing [0];
+			if (GTK.GTK4) {
+				long icon = GTK.gtk_widget_get_first_child(handle);
+				GtkRequisition minimum = new GtkRequisition ();
+				GTK.gtk_widget_get_preferred_size(icon, minimum, null);
+				long context = GTK.gtk_widget_get_style_context(icon);
+				GtkBorder margin = new GtkBorder ();
+				GTK.gtk_style_context_get_margin(context, margin);
+				trimWidth += minimum.width + margin.right;
+			} else {
+				int[] indicatorSize = new int[1];
+				int[] indicatorSpacing = new int[1];
+				GTK.gtk_widget_style_get (handle, OS.indicator_size, indicatorSize, 0);
+				GTK.gtk_widget_style_get (handle, OS.indicator_spacing, indicatorSpacing, 0);
+				indicatorHeight = indicatorSize [0] + 2 * indicatorSpacing [0];
+				trimWidth += indicatorHeight + indicatorSpacing [0];
+			}
 		} else {
 			Point thickness = getThickness (handle);
 			trimWidth += thickness.x * 2;
@@ -236,7 +259,7 @@ Point computeSizeInPixels (int wHint, int hHint, boolean changed) {
 			OS.g_object_get (boxHandle, OS.spacing, spacing, 0);
 			imageWidth += spacing [0];
 		}
-		long /*int*/ labelLayout = GTK.gtk_label_get_layout (labelHandle);
+		long labelLayout = GTK.gtk_label_get_layout (labelHandle);
 		int pangoWidth = OS.pango_layout_get_width (labelLayout);
 		if (wHint != SWT.DEFAULT) {
 			OS.pango_layout_set_width (labelLayout, Math.max (1, (wHint - imageWidth - trimWidth)) * OS.PANGO_SCALE);
@@ -308,7 +331,6 @@ void createHandle (int index) {
 			*/
 			groupHandle = GTK.gtk_radio_button_new (0);
 			if (groupHandle == 0) error (SWT.ERROR_NO_HANDLES);
-			OS.g_object_ref (groupHandle);
 			OS.g_object_ref_sink (groupHandle);
 			handle = GTK.gtk_radio_button_new (GTK.gtk_radio_button_get_group (groupHandle));
 			if (handle == 0) error (SWT.ERROR_NO_HANDLES);
@@ -364,7 +386,7 @@ void deregister () {
 }
 
 @Override
-long /*int*/ fontHandle () {
+long fontHandle () {
 	if (labelHandle != 0) return labelHandle;
 	return super.fontHandle ();
 }
@@ -482,15 +504,15 @@ public String getText () {
 }
 
 @Override
-long /*int*/ gtk_button_press_event (long /*int*/ widget, long /*int*/ event) {
-	long /*int*/ result = super.gtk_button_press_event (widget, event);
+long gtk_button_press_event (long widget, long event) {
+	long result = super.gtk_button_press_event (widget, event);
 	if (result != 0) return result;
 	if ((style & SWT.RADIO) != 0) selected  = getSelection ();
 	return result;
 }
 
 @Override
-long /*int*/ gtk_clicked (long /*int*/ widget) {
+long gtk_clicked (long widget) {
 	if (containedInRegion(lastInput.x, lastInput.y)) return 0;
 	if ((style & SWT.RADIO) != 0) {
 		if ((parent.getStyle () & SWT.NO_RADIO_GROUP) != 0) {
@@ -514,7 +536,7 @@ long /*int*/ gtk_clicked (long /*int*/ widget) {
 }
 
 @Override
-long /*int*/ gtk_draw (long /*int*/ widget, long /*int*/ cairo) {
+long gtk_draw (long widget, long cairo) {
 	/*
 	 * On GTK3.19+, widget are are shown with the default minimum size regardless of the
 	 * size of the fixed container. This causes 0x0 widgets to be visible but cannot be used.
@@ -536,8 +558,8 @@ boolean mustBeVisibleOnInitBounds() {
 }
 
 @Override
-long /*int*/ gtk_focus_in_event (long /*int*/ widget, long /*int*/ event) {
-	long /*int*/ result = super.gtk_focus_in_event (widget, event);
+long gtk_focus_in_event (long widget, long event) {
+	long result = super.gtk_focus_in_event (widget, event);
 	// widget could be disposed at this point
 	if (handle == 0) return 0;
 	if ((style & SWT.PUSH) != 0 && GTK.gtk_widget_has_default (handle)) {
@@ -548,8 +570,8 @@ long /*int*/ gtk_focus_in_event (long /*int*/ widget, long /*int*/ event) {
 }
 
 @Override
-long /*int*/ gtk_focus_out_event (long /*int*/ widget, long /*int*/ event) {
-	long /*int*/ result = super.gtk_focus_out_event (widget, event);
+long gtk_focus_out_event (long widget, long event) {
+	long result = super.gtk_focus_out_event (widget, event);
 	// widget could be disposed at this point
 	if (handle == 0) return 0;
 	if ((style & SWT.PUSH) != 0) {
@@ -562,8 +584,8 @@ long /*int*/ gtk_focus_out_event (long /*int*/ widget, long /*int*/ event) {
 }
 
 @Override
-long /*int*/ gtk_key_press_event (long /*int*/ widget, long /*int*/ event) {
-	long /*int*/ result = super.gtk_key_press_event (widget, event);
+long gtk_key_press_event (long widget, long event) {
+	long result = super.gtk_key_press_event (widget, event);
 	if (result != 0) return result;
 	if ((style & SWT.RADIO) != 0) selected  = getSelection ();
 	return result;
@@ -730,11 +752,11 @@ void _setAlignment (int alignment) {
 	}
 	if ((alignment & SWT.LEFT) != 0) {
 		if (bothVisible) {
-			GTK.gtk_box_set_child_packing (boxHandle, labelHandle, false, false, 0, GTK.GTK_PACK_START);
-			GTK.gtk_box_set_child_packing (boxHandle, imageHandle, false, false, 0, GTK.GTK_PACK_START);
+			gtk_box_set_child_packing (boxHandle, labelHandle, false, false, 0, GTK.GTK_PACK_START);
+			gtk_box_set_child_packing (boxHandle, imageHandle, false, false, 0, GTK.GTK_PACK_START);
 		} else {
-			GTK.gtk_box_set_child_packing (boxHandle, labelHandle, true, true, 0, GTK.GTK_PACK_END);
-			GTK.gtk_box_set_child_packing (boxHandle, imageHandle, true, true, 0, GTK.GTK_PACK_START);
+			gtk_box_set_child_packing (boxHandle, labelHandle, true, true, 0, GTK.GTK_PACK_END);
+			gtk_box_set_child_packing (boxHandle, imageHandle, true, true, 0, GTK.GTK_PACK_START);
 		}
 
 		if (GTK.GTK_VERSION >= OS.VERSION(3, 16, 0)) {
@@ -750,8 +772,8 @@ void _setAlignment (int alignment) {
 	}
 	if ((alignment & SWT.CENTER) != 0) {
 		if (bothVisible) {
-			GTK.gtk_box_set_child_packing (boxHandle, labelHandle, true, true, 0, GTK.GTK_PACK_END);
-			GTK.gtk_box_set_child_packing (boxHandle, imageHandle, true, true, 0, GTK.GTK_PACK_START);
+			gtk_box_set_child_packing (boxHandle, labelHandle, true, true, 0, GTK.GTK_PACK_END);
+			gtk_box_set_child_packing (boxHandle, imageHandle, true, true, 0, GTK.GTK_PACK_START);
 
 			if (GTK.GTK_VERSION >= OS.VERSION(3, 16, 0))  {
 				gtk_label_set_align(labelHandle,0.0f,0.5f);
@@ -762,8 +784,8 @@ void _setAlignment (int alignment) {
 			}
 
 		} else {
-			GTK.gtk_box_set_child_packing (boxHandle, labelHandle, true, true, 0, GTK.GTK_PACK_END);
-			GTK.gtk_box_set_child_packing (boxHandle, imageHandle, true, true, 0, GTK.GTK_PACK_START);
+			gtk_box_set_child_packing (boxHandle, labelHandle, true, true, 0, GTK.GTK_PACK_END);
+			gtk_box_set_child_packing (boxHandle, imageHandle, true, true, 0, GTK.GTK_PACK_START);
 
 			if (GTK.GTK_VERSION >= OS.VERSION(3, 16, 0))  {
 				gtk_label_set_align(labelHandle,0.5f,0.5f);
@@ -778,11 +800,11 @@ void _setAlignment (int alignment) {
 	}
 	if ((alignment & SWT.RIGHT) != 0) {
 		if (bothVisible) {
-			GTK.gtk_box_set_child_packing (boxHandle, labelHandle, false, false, 0, GTK.GTK_PACK_END);
-			GTK.gtk_box_set_child_packing (boxHandle, imageHandle, false, false, 0, GTK.GTK_PACK_END);
+			gtk_box_set_child_packing (boxHandle, labelHandle, false, false, 0, GTK.GTK_PACK_END);
+			gtk_box_set_child_packing (boxHandle, imageHandle, false, false, 0, GTK.GTK_PACK_END);
 		} else {
-			GTK.gtk_box_set_child_packing (boxHandle, labelHandle, true, true, 0, GTK.GTK_PACK_END);
-			GTK.gtk_box_set_child_packing (boxHandle, imageHandle, true, true, 0, GTK.GTK_PACK_START);
+			gtk_box_set_child_packing (boxHandle, labelHandle, true, true, 0, GTK.GTK_PACK_END);
+			gtk_box_set_child_packing (boxHandle, imageHandle, true, true, 0, GTK.GTK_PACK_START);
 		}
 
 		if (GTK.GTK_VERSION >= OS.VERSION(3, 16, 0))  {
@@ -798,14 +820,8 @@ void _setAlignment (int alignment) {
 }
 
 @Override
-void setBackgroundGdkRGBA (long /*int*/ context, long /*int*/ handle, GdkRGBA rgba) {
+void setBackgroundGdkRGBA (long context, long handle, GdkRGBA rgba) {
 	background = rgba;
-	//Pre GTK 3.10 doesn't handle CSS background color very well for GTK Check/Radio button.
-	// 3.10.3 as it was the latest to affect theming in button.
-	if (GTK.GTK_VERSION < OS.VERSION(3, 10, 3) && (style & (SWT.CHECK | SWT.RADIO)) != 0) {
-		super.setBackgroundGdkRGBA (context, handle, rgba);
-		return;
-	}
 	// Form background CSS string
 	String css ="* {background : ";
 	String color = display.gtk_rgba_to_css_string (rgba);
@@ -852,7 +868,7 @@ int setBounds (int x, int y, int width, int height, boolean move, boolean resize
 		GTK.gtk_widget_get_allocation (boxHandle, allocation);
 		int boxWidth = allocation.width;
 		int boxHeight = allocation.height;
-		long /*int*/ labelLayout = GTK.gtk_label_get_layout (labelHandle);
+		long labelLayout = GTK.gtk_label_get_layout (labelHandle);
 		int pangoWidth = OS.pango_layout_get_width (labelLayout);
 		OS.pango_layout_set_width (labelLayout, -1);
 		int [] w = new int [1], h = new int [1];
@@ -885,7 +901,7 @@ int setBounds (int x, int y, int width, int height, boolean move, boolean resize
 }
 
 @Override
-void setFontDescription (long /*int*/ fontDesc) {
+void setFontDescription (long fontDesc) {
 	// Don't set the font if we have no text set
 	if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0) && ((text != null && text.isEmpty()) || text == null)) {
 		return;
@@ -919,20 +935,19 @@ void setForegroundGdkRGBA (GdkRGBA rgba) {
 	 * Giving them a border color that matches the text color ensures consistent visibility
 	 * across most themes. See bug 463733.
 	 */
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 10, 0) && GTK.GTK_VERSION < OS.VERSION (3, 16, 0) &&
-			(style & (SWT.CHECK | SWT.RADIO)) != 0) {
+	if (GTK.GTK_VERSION < OS.VERSION (3, 16, 0) && (style & (SWT.CHECK | SWT.RADIO)) != 0) {
 		gtk_swt_set_border_color (rgba);
 	}
 }
 
 @Override
-void setForegroundGdkRGBA (long /*int*/ handle, GdkRGBA rgba) {
+void setForegroundGdkRGBA (long handle, GdkRGBA rgba) {
 	if (GTK.GTK_VERSION < OS.VERSION(3, 14, 0)) {
 		super.setForegroundGdkRGBA(handle, rgba);
 		return;
 	}
 	GdkRGBA toSet = rgba == null ? display.COLOR_WIDGET_FOREGROUND_RGBA : rgba;
-	long /*int*/ context = GTK.gtk_widget_get_style_context (handle);
+	long context = GTK.gtk_widget_get_style_context (handle);
 
 	// Form foreground string
 	String color = display.gtk_rgba_to_css_string(toSet);
@@ -965,7 +980,7 @@ private void gtk_swt_set_border_color (GdkRGBA rgba) {
 	}
 
 	// Apply the CSS
-	long /*int*/context = GTK.gtk_widget_get_style_context (handle);
+	long context = GTK.gtk_widget_get_style_context (handle);
 	gtk_css_provider_load_from_css (context, finalCss);
 }
 
@@ -1022,7 +1037,7 @@ public void setImage (Image image) {
 		if (image.isDisposed()) error (SWT.ERROR_INVALID_ARGUMENT);
 		imageList = new ImageList ();
 		int imageIndex = imageList.add (image);
-		long /*int*/ pixbuf = imageList.getPixbuf (imageIndex);
+		long pixbuf = imageList.getPixbuf (imageIndex);
 		gtk_image_set_from_gicon(imageHandle, pixbuf);
 	} else {
 		gtk_image_set_from_gicon (imageHandle, 0);
@@ -1160,7 +1175,7 @@ void showWidget () {
 }
 
 @Override
-int traversalCode (int key, GdkEventKey event) {
+int traversalCode(int key, long event) {
 	int code = super.traversalCode (key, event);
 	if ((style & SWT.ARROW) != 0) code &= ~(SWT.TRAVERSE_TAB_NEXT | SWT.TRAVERSE_TAB_PREVIOUS);
 	if ((style & SWT.RADIO) != 0) code |= SWT.TRAVERSE_ARROW_NEXT | SWT.TRAVERSE_ARROW_PREVIOUS;
@@ -1168,16 +1183,16 @@ int traversalCode (int key, GdkEventKey event) {
 }
 
 @Override
-long /*int*/ windowProc (long /*int*/ handle, long /*int*/ arg0, long /*int*/ user_data) {
+long windowProc (long handle, long arg0, long user_data) {
 	/*
 	 * For Labels/Buttons, the first widget in the tree with a GdkWindow is SwtFixed.
 	 * Unfortunately this fails the check in !GTK_IS_CONTAINER check Widget.windowProc().
 	 * Instead lets override windowProc() here and check for paintHandle() compatibility.
 	 * Fixes bug 481485 without re-introducing bug 483791.
 	 */
-	switch ((int)/*64*/user_data) {
+	switch ((int)user_data) {
 		case DRAW: {
-			if (GTK.GTK_VERSION >= OS.VERSION(3, 9, 0) && paintHandle() == handle) {
+			if (paintHandle() == handle) {
 				return gtk_draw(handle, arg0);
 			}
 		}
