@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -151,31 +151,31 @@ public IME getIME () {
 }
 
 @Override
-long /*int*/ gtk_button_press_event (long /*int*/ widget, long /*int*/ event) {
+long gtk_button_press_event (long widget, long event) {
 	if (ime != null) {
-		long /*int*/ result = ime.gtk_button_press_event (widget, event);
+		long result = ime.gtk_button_press_event (widget, event);
 		if (result != 0) return result;
 	}
 	return  super.gtk_button_press_event (widget, event);
 }
 
 @Override
-long /*int*/ gtk_commit (long /*int*/ imcontext, long /*int*/ text) {
+long gtk_commit (long imcontext, long text) {
 	if (ime != null) {
-		long /*int*/ result = ime.gtk_commit (imcontext, text);
+		long result = ime.gtk_commit (imcontext, text);
 		if (result != 0) return result;
 	}
 	return super.gtk_commit (imcontext, text);
 }
 
 @Override
-long /*int*/ gtk_draw (long /*int*/ widget, long /*int*/ cairo) {
+long gtk_draw (long widget, long cairo) {
 	if ((state & OBSCURED) != 0) return 0;
-	long /*int*/ result;
+	long result;
 	if ( GTK.GTK_VERSION < OS.VERSION(3, 22, 0)) {
 		boolean isFocus = caret != null && caret.isFocusCaret ();
 		if (isFocus) caret.killFocus ();
-		 result = super.gtk_draw (widget, cairo);
+		result = super.gtk_draw (widget, cairo);
 		if (isFocus) caret.setFocus ();
 	} else {
 		result = super.gtk_draw (widget, cairo);
@@ -194,7 +194,7 @@ long /*int*/ gtk_draw (long /*int*/ widget, long /*int*/ cairo) {
 	return result;
 }
 
-private void drawCaret (long /*int*/ widget, long /*int*/ cairo) {
+private void drawCaret (long widget, long cairo) {
 	if(this.isDisposed()) return;
 	if (cairo == 0) error(SWT.ERROR_NO_HANDLES);
 	if (drawFlag) {
@@ -202,7 +202,7 @@ private void drawCaret (long /*int*/ widget, long /*int*/ cairo) {
 		if (caret.image != null && !caret.image.isDisposed() && caret.image.mask == 0) {
 			Cairo.cairo_set_source_rgb(cairo, 1, 1, 1);
 			Cairo.cairo_set_operator(cairo, Cairo.CAIRO_OPERATOR_DIFFERENCE);
-			long /*int*/ surface = Cairo.cairo_get_target(cairo);
+			long surface = Cairo.cairo_get_target(cairo);
 			int nWidth = 0;
 			switch (Cairo.cairo_surface_get_type(surface)) {
 				case Cairo.CAIRO_SURFACE_TYPE_IMAGE:
@@ -236,33 +236,23 @@ private void drawCaret (long /*int*/ widget, long /*int*/ cairo) {
 }
 
 @Override
-long /*int*/ gtk_expose_event (long /*int*/ widget, long /*int*/ event) {
-	if ((state & OBSCURED) != 0) return 0;
-	boolean isFocus = caret != null && caret.isFocusCaret ();
-	if (isFocus) caret.killFocus ();
-	long /*int*/ result = super.gtk_expose_event (widget, event);
-	if (isFocus) caret.setFocus ();
-	return result;
-}
-
-@Override
-long /*int*/ gtk_focus_in_event (long /*int*/ widget, long /*int*/ event) {
-	long /*int*/ result = super.gtk_focus_in_event (widget, event);
+long gtk_focus_in_event (long widget, long event) {
+	long result = super.gtk_focus_in_event (widget, event);
 	if (caret != null) caret.setFocus ();
 	return result;
 }
 
 @Override
-long /*int*/ gtk_focus_out_event (long /*int*/ widget, long /*int*/ event) {
-	long /*int*/ result = super.gtk_focus_out_event (widget, event);
+long gtk_focus_out_event (long widget, long event) {
+	long result = super.gtk_focus_out_event (widget, event);
 	if (caret != null) caret.killFocus ();
 	return result;
 }
 
 @Override
-long /*int*/ gtk_preedit_changed (long /*int*/ imcontext) {
+long gtk_preedit_changed (long imcontext) {
 	if (ime != null) {
-		long /*int*/ result = ime.gtk_preedit_changed (imcontext);
+		long result = ime.gtk_preedit_changed (imcontext);
 		if (result != 0) return result;
 	}
 	return super.gtk_preedit_changed (imcontext);
@@ -321,6 +311,13 @@ void reskinChildren (int flags) {
 public void scroll (int destX, int destY, int x, int y, int width, int height, boolean all) {
 	checkWidget();
 	if (width <= 0 || height <= 0) return;
+	/*
+	 * scrollInPixels() doesn't seem to be needed on GTK4, so we can return early.
+	 * In fact it doesn't seem to be needed on GTK3 either, but it's been left
+	 * here for stability on older GTK3 versions. The investigation
+	 * as to why it's unneeded is left as a TODO. See bug 546274.
+	 */
+	if (GTK.GTK4) return;
 	Point destination = DPIUtil.autoScaleUp (new Point (destX, destY));
 	Rectangle srcRect = DPIUtil.autoScaleUp (new Rectangle (x, y, width, height));
 	scrollInPixels(destination.x, destination.y, srcRect.x, srcRect.y, srcRect.width, srcRect.height, all);
@@ -337,14 +334,9 @@ void scrollInPixels (int destX, int destY, int x, int y, int width, int height,
 	if (!isVisible ()) return;
 	boolean isFocus = caret != null && caret.isFocusCaret ();
 	if (isFocus) caret.killFocus ();
-	long /*int*/ window = paintWindow ();
-	long /*int*/ visibleRegion;
-	if (GTK.GTK3) {
-		visibleRegion = GDK.gdk_window_get_visible_region (window);
-	} else {
-		visibleRegion = GDK.gdk_drawable_get_visible_region (window);
-	}
-	GdkRectangle srcRect = new GdkRectangle ();
+	long window = paintWindow ();
+	long visibleRegion = GDK.gdk_window_get_visible_region (window);
+	cairo_rectangle_int_t srcRect = new cairo_rectangle_int_t ();
 	srcRect.x = x;
 	srcRect.y = y;
 	/*
@@ -354,8 +346,8 @@ void scrollInPixels (int destX, int destY, int x, int y, int width, int height,
 	 * hopping effect. See bug 480458.
 	 */
 	if (GTK.GTK_VERSION >= OS.VERSION(3, 16, 0)) {
-		long /*int*/ hBarHandle = 0;
-		long /*int*/ vBarHandle = 0;
+		long hBarHandle = 0;
+		long vBarHandle = 0;
 		if (GTK.GTK_IS_SCROLLED_WINDOW(scrolledHandle)) {
 			hBarHandle = GTK.gtk_scrolled_window_get_hscrollbar (scrolledHandle);
 			vBarHandle = GTK.gtk_scrolled_window_get_vscrollbar (scrolledHandle);
@@ -376,13 +368,13 @@ void scrollInPixels (int destX, int destY, int x, int y, int width, int height,
 	}
 	srcRect.width = width;
 	srcRect.height = height;
-	long /*int*/ copyRegion = GDK.gdk_region_rectangle (srcRect);
-	GDK.gdk_region_intersect(copyRegion, visibleRegion);
-	long /*int*/ invalidateRegion = GDK.gdk_region_rectangle (srcRect);
-	GDK.gdk_region_subtract (invalidateRegion, visibleRegion);
-	GDK.gdk_region_offset (invalidateRegion, deltaX, deltaY);
-	GdkRectangle copyRect = new GdkRectangle();
-	GDK.gdk_region_get_clipbox (copyRegion, copyRect);
+	long copyRegion = Cairo.cairo_region_create_rectangle (srcRect);
+	Cairo.cairo_region_intersect(copyRegion, visibleRegion);
+	long invalidateRegion = Cairo.cairo_region_create_rectangle (srcRect);
+	Cairo.cairo_region_subtract (invalidateRegion, visibleRegion);
+	Cairo.cairo_region_translate (invalidateRegion, deltaX, deltaY);
+	cairo_rectangle_int_t copyRect = new cairo_rectangle_int_t();
+	Cairo.cairo_region_get_extents (copyRegion, copyRect);
 	if (copyRect.width != 0 && copyRect.height != 0) {
 		update ();
 	}
@@ -392,7 +384,15 @@ void scrollInPixels (int destX, int destY, int x, int y, int width, int height,
 		redrawWidget (x, y, width, height, false, false, false);
 		redrawWidget (destX, destY, width, height, false, false, false);
 	} else {
-		long /*int*/ cairo = GDK.gdk_cairo_create(window);
+		long cairo = 0;
+		long context = 0;
+		if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0)) {
+			long cairo_region = GDK.gdk_window_get_visible_region(window);
+			context = GDK.gdk_window_begin_draw_frame(window, cairo_region);
+			cairo = GDK.gdk_drawing_context_get_cairo_context(context);
+		} else {
+			cairo = GDK.gdk_cairo_create(window);
+		}
 		if (Cairo.cairo_version() < Cairo.CAIRO_VERSION_ENCODE(1, 12, 0)) {
 			GDK.gdk_cairo_set_source_window(cairo, window, 0, 0);
 		} else {
@@ -406,17 +406,21 @@ void scrollInPixels (int destX, int destY, int x, int y, int width, int height,
 		Cairo.cairo_rectangle(cairo, copyRect.x + deltaX, copyRect.y + deltaY, copyRect.width, copyRect.height);
 		Cairo.cairo_clip(cairo);
 		Cairo.cairo_paint(cairo);
-		Cairo.cairo_destroy(cairo);
+		if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0)) {
+			if (context != 0) GDK.gdk_window_end_draw_frame(window, context);
+		} else {
+			Cairo.cairo_destroy(cairo);
+		}
 		boolean disjoint = (destX + width < x) || (x + width < destX) || (destY + height < y) || (y + height < destY);
 		if (disjoint) {
-			GdkRectangle rect = new GdkRectangle ();
+			cairo_rectangle_int_t rect = new cairo_rectangle_int_t();
 			rect.x = x;
 			rect.y = y;
 			rect.width = width;
 			rect.height = height;
-			GDK.gdk_region_union_with_rect (invalidateRegion, rect);
+			Cairo.cairo_region_union_rectangle (invalidateRegion, rect);
 		} else {
-			GdkRectangle rect = new GdkRectangle ();
+			cairo_rectangle_int_t rect = new cairo_rectangle_int_t();
 			if (deltaX != 0) {
 				int newX = destX - deltaX;
 				if (deltaX < 0) newX = destX + width;
@@ -424,7 +428,7 @@ void scrollInPixels (int destX, int destY, int x, int y, int width, int height,
 				rect.y = y;
 				rect.width = Math.abs(deltaX);
 				rect.height = height;
-				GDK.gdk_region_union_with_rect (invalidateRegion, rect);
+				Cairo.cairo_region_union_rectangle (invalidateRegion, rect);
 			}
 			if (deltaY != 0) {
 				int newY = destY - deltaY;
@@ -433,14 +437,14 @@ void scrollInPixels (int destX, int destY, int x, int y, int width, int height,
 				rect.y = newY;
 				rect.width = width;
 				rect.height = Math.abs(deltaY);
-				GDK.gdk_region_union_with_rect (invalidateRegion, rect);
+				Cairo.cairo_region_union_rectangle (invalidateRegion, rect);
 			}
 		}
 		GDK.gdk_window_invalidate_region(window, invalidateRegion, all);
 	}
-	GDK.gdk_region_destroy (visibleRegion);
-	GDK.gdk_region_destroy (copyRegion);
-	GDK.gdk_region_destroy (invalidateRegion);
+	Cairo.cairo_region_destroy (visibleRegion);
+	Cairo.cairo_region_destroy (copyRegion);
+	Cairo.cairo_region_destroy (invalidateRegion);
 	if (all) {
 		Control [] children = _getChildren ();
 		for (int i=0; i<children.length; i++) {
@@ -534,7 +538,7 @@ public void setIME (IME ime) {
 }
 
 void updateCaret () {
-	long /*int*/ imHandle = imHandle ();
+	long imHandle = imHandle ();
 	if (imHandle == 0) return;
 	GdkRectangle rect = new GdkRectangle ();
 	rect.x = caret.x;
