@@ -65,8 +65,8 @@ public class Composite extends Scrollable {
 	 *
 	 * @noreference This field is not intended to be referenced by clients.
 	 */
-	public long /*int*/  embeddedHandle;
-	long /*int*/ imHandle, socketHandle;
+	public long  embeddedHandle;
+	long imHandle, socketHandle;
 	Layout layout;
 	Control[] tabList;
 	int layoutCount, backgroundMode;
@@ -75,7 +75,7 @@ public class Composite extends Scrollable {
 	 * needs to have its clip set to its allocation. This is because on GTK3.20+
 	 * some widgets (like Combo) have their clips merged with that of their parent.
 	 */
-	long /*int*/ fixClipHandle;
+	long fixClipHandle;
 	/**
 	 * If fixClipHandle is set, then the fixClipMap HashMap contains children
 	 * of fixClipHandle that also need to have their clips adjusted.
@@ -85,9 +85,26 @@ public class Composite extends Scrollable {
 	 * This array will be traversed in-order to adjust the clipping of each element.
 	 * See bug 500703 and 535323.</p>
 	 */
-	Map<Control, long /*int*/ []> fixClipMap = new HashMap<> ();
+	Map<Control, long []> fixClipMap = new HashMap<> ();
 
 	static final String NO_INPUT_METHOD = "org.eclipse.swt.internal.gtk.noInputMethod"; //$NON-NLS-1$
+	Shell popupChild;
+	/**
+	 * If set to {@code true}, child widgets with negative y coordinate GTK allocation
+	 * will not be drawn. Only relevant if such child widgets are being
+	 * drawn via propagateDraw(), such as Tree/Table editing widgets.
+	 *
+	 * See bug 535978 and bug 547986.
+	 */
+	boolean noChildDrawing = false;
+	/**
+	 * A HashMap of child widgets that keeps track of which child has had their
+	 * GdkWindow lowered/raised. Only relevant if such child widgets are being
+	 * drawn via propagateDraw(), such as Tree/Table editing widgets.
+	 *
+	 * See bug 535978.
+	 */
+	HashMap<Widget, Boolean> childrenLowered = new HashMap<>();
 
 Composite () {
 	/* Do nothing */
@@ -131,7 +148,7 @@ public Composite (Composite parent, int style) {
 	 * Cache the NO_BACKGROUND flag for use in the Cairo setRegion()
 	 * implementation. Only relevant to GTK3.10+, see bug 475784.
 	 */
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 10, 0) && (style & SWT.NO_BACKGROUND) != 0) {
+	if ((style & SWT.NO_BACKGROUND) != 0) {
 		cachedNoBackground = true;
 	}
 }
@@ -143,15 +160,15 @@ static int checkStyle (int style) {
 }
 
 Control [] _getChildren () {
-	long /*int*/ parentHandle = parentingHandle ();
-	long /*int*/ list = GTK.gtk_container_get_children (parentHandle);
+	long parentHandle = parentingHandle ();
+	long list = GTK.gtk_container_get_children (parentHandle);
 	if (list == 0) return new Control [0];
 	int count = OS.g_list_length (list);
 	Control [] children = new Control [count];
 	int i = 0;
-	long /*int*/ temp = list;
+	long temp = list;
 	while (temp != 0) {
-		long /*int*/ handle = OS.g_list_data (temp);
+		long handle = OS.g_list_data (temp);
 		if (handle != 0) {
 			Widget widget = display.getWidget (handle);
 			if (widget != null && widget != this) {
@@ -224,12 +241,6 @@ protected void checkSubclass () {
 	/* Do nothing - Subclassing is allowed */
 }
 
-@Override
-long /*int*/ childStyle () {
-	if (scrolledHandle != 0) return 0;
-	return super.childStyle ();
-}
-
 @Override
 Point computeSizeInPixels (int wHint, int hHint, boolean changed) {
 	checkWidget ();
@@ -292,18 +303,18 @@ void createHandle (int index, boolean fixed, boolean scrolled) {
 		if (fixed) {
 			fixedHandle = OS.g_object_new (display.gtk_fixed_get_type (), 0);
 			if (fixedHandle == 0) error (SWT.ERROR_NO_HANDLES);
-			GTK.gtk_widget_set_has_window (fixedHandle, true);
+			gtk_widget_set_has_surface_or_window (fixedHandle, true);
 		}
-		long /*int*/ vadj = GTK.gtk_adjustment_new (0, 0, 100, 1, 10, 10);
+		long vadj = GTK.gtk_adjustment_new (0, 0, 100, 1, 10, 10);
 		if (vadj == 0) error (SWT.ERROR_NO_HANDLES);
-		long /*int*/ hadj = GTK.gtk_adjustment_new (0, 0, 100, 1, 10, 10);
+		long hadj = GTK.gtk_adjustment_new (0, 0, 100, 1, 10, 10);
 		if (hadj == 0) error (SWT.ERROR_NO_HANDLES);
 		scrolledHandle = GTK.gtk_scrolled_window_new (hadj, vadj);
 		if (scrolledHandle == 0) error (SWT.ERROR_NO_HANDLES);
 	}
 	handle = OS.g_object_new (display.gtk_fixed_get_type (), 0);
 	if (handle == 0) error (SWT.ERROR_NO_HANDLES);
-	GTK.gtk_widget_set_has_window (handle, true);
+	gtk_widget_set_has_surface_or_window (handle, true);
 	GTK.gtk_widget_set_can_focus (handle, true);
 	if ((style & SWT.EMBEDDED) == 0) {
 		if ((state & CANVAS) != 0) {
@@ -364,51 +375,23 @@ void createHandle (int index, boolean fixed, boolean scrolled) {
 
 /**
  * Iterates though the array of child widgets that need to have their clips
- * adjusted: if a child has a negative clip, adjust it. Also check if the child's
- * allocation is negative and adjust it as necessary.
+ * adjusted, and calls Control.adjustChildClipping() on it.
  *
- * <p>If the array is empty this method just returns. See bug 500703.</p>
+ * The default implementation in Composite is: if a child has a negative clip, adjust it.
+ * Also check if the child's allocation is negative, and adjust it as necessary.
+ *
+ * <p>If the array is empty this method just returns. See bug 500703, and 539367.</p>
  */
-void fixChildClippings () {
+void fixClippings () {
 	if (fixClipHandle == 0 || fixClipMap.isEmpty()) {
 		return;
 	} else {
-		GtkRequisition minimumSize = new GtkRequisition ();
-		GtkRequisition naturalSize = new GtkRequisition ();
-		GtkAllocation clip = new GtkAllocation ();
-		GtkAllocation allocation = new GtkAllocation ();
 		Control [] children = _getChildren();
 		for (Control child : children) {
 			if (fixClipMap.containsKey(child)) {
-				long /*int*/ [] childHandles = fixClipMap.get(child);
-				for (long /*int*/ widget : childHandles) {
-					GTK.gtk_widget_get_allocation(widget, allocation);
-					GTK.gtk_widget_get_clip(widget, clip);
-					/*
-					 * If the clip is negative, add the x coordinate to the width
-					 * and set the x coordinate to 0.
-					 */
-					if (clip.x < 0) {
-						clip.width = clip.width + clip.x;
-						clip.x = 0;
-						/*
-						 * Some "transient" widgets like menus get allocations of
-						 * {-1, -1, 1, 1}. Check to make sure this isn't the case
-						 * before proceeding.
-						 */
-						if (allocation.x < -1 && (allocation.width > 1 || allocation.height > 1)) {
-							// Adjust the allocation just like the clip, if it's negative
-							allocation.width = allocation.width + allocation.x;
-							allocation.x = 0;
-							// Call gtk_widget_get_preferred_size() to prevent warnings
-							GTK.gtk_widget_get_preferred_size(widget, minimumSize, naturalSize);
-							// Allocate and queue a resize event
-							GTK.gtk_widget_size_allocate(widget, allocation);
-							GTK.gtk_widget_queue_resize(widget);
-						}
-					}
-					// Adjust the clip
-					GTK.gtk_widget_set_clip(widget, allocation);
+				long [] childHandles = fixClipMap.get(child);
+				for (long widget : childHandles) {
+					child.adjustChildClipping(widget);
 				}
 			}
 		}
@@ -416,9 +399,46 @@ void fixChildClippings () {
 }
 
 @Override
-long /*int*/ gtk_draw (long /*int*/ widget, long /*int*/ cairo) {
+void adjustChildClipping (long widget) {
+	GtkRequisition minimumSize = new GtkRequisition ();
+	GtkRequisition naturalSize = new GtkRequisition ();
+	GtkAllocation clip = new GtkAllocation ();
+	GtkAllocation allocation = new GtkAllocation ();
+	GTK.gtk_widget_get_allocation(widget, allocation);
+	GTK.gtk_widget_get_clip(widget, clip);
+	/*
+	 * If the clip is negative, add the x coordinate to the width
+	 * and set the x coordinate to 0.
+	 */
+	if (clip.x < 0) {
+		/*
+		 * Some "transient" widgets like menus get allocations of
+		 * {-1, -1, 1, 1}. Check to make sure this isn't the case
+		 * before proceeding.
+		 */
+		if (allocation.x < -1 && (allocation.width > 1 || allocation.height > 1)) {
+			// Adjust the allocation just like the clip, if it's negative
+			allocation.width = allocation.width + allocation.x;
+			allocation.x = 0;
+			// Call gtk_widget_get_preferred_size() to prevent warnings
+			GTK.gtk_widget_get_preferred_size(widget, minimumSize, naturalSize);
+			// Allocate and queue a resize event
+			if (GTK.GTK4) {
+				GTK.gtk_widget_size_allocate(widget, allocation, -1);
+			} else {
+				GTK.gtk_widget_size_allocate(widget, allocation);
+			}
+			GTK.gtk_widget_queue_resize(widget);
+		}
+	}
+	// Adjust the clip
+	GTK.gtk_widget_set_clip(widget, allocation);
+}
+
+@Override
+long gtk_draw (long widget, long cairo) {
 	if (GTK.GTK_VERSION >= OS.VERSION(3, 14, 0)) {
-		long /*int*/ context = GTK.gtk_widget_get_style_context(widget);
+		long context = GTK.gtk_widget_get_style_context(widget);
 		GtkAllocation allocation = new GtkAllocation();
 		GTK.gtk_widget_get_allocation (widget, allocation);
 		int width = (state & ZERO_WIDTH) != 0 ? 0 : allocation.width;
@@ -429,12 +449,21 @@ long /*int*/ gtk_draw (long /*int*/ widget, long /*int*/ cairo) {
 		if (GTK.GTK_VERSION >= OS.VERSION(3, 20, 0)) {
 			// If fixClipHandle is set: iterate through the children of widget
 			// and set their clips to be that of their allocation
-			if (widget == fixClipHandle) fixChildClippings();
+			if (widget == fixClipHandle) fixClippings();
 		}
 	}
 	return super.gtk_draw(widget, cairo);
 }
 
+
+@Override
+boolean mustBeVisibleOnInitBounds() {
+	// Bug 540298: if we return false, we will be invisible if the size is
+	// not set, but our layout will not properly work, so that not all children
+	// will be shown properly
+	return true;
+}
+
 @Override
 void deregister () {
 	super.deregister ();
@@ -483,31 +512,17 @@ void drawBackgroundInPixels (GC gc, int x, int y, int width, int height, int off
 	Control control = findBackgroundControl ();
 	if (control != null) {
 		GCData data = gc.getGCData ();
-		long /*int*/ cairo = data.cairo;
+		long cairo = data.cairo;
 		Cairo.cairo_save (cairo);
 		if (control.backgroundImage != null) {
 			Point pt = display.mapInPixels (this, control, 0, 0);
 			Cairo.cairo_translate (cairo, -pt.x - offsetX, -pt.y - offsetY);
 			x += pt.x + offsetX;
 			y += pt.y + offsetY;
-			long /*int*/ surface = control.backgroundImage.surface;
-			if (surface == 0) {
-				long /*int*/ drawable = control.backgroundImage.pixmap;
-				int [] w = new int [1], h = new int [1];
-				GDK.gdk_pixmap_get_size (drawable, w, h);
-				if (OS.isX11()) {
-					long /*int*/ xDisplay = GDK.gdk_x11_display_get_xdisplay(GDK.gdk_display_get_default());
-					long /*int*/ xVisual = GDK.gdk_x11_visual_get_xvisual (GDK.gdk_visual_get_system());
-					long /*int*/ xDrawable = GDK.GDK_PIXMAP_XID (drawable);
-					surface = Cairo.cairo_xlib_surface_create (xDisplay, xDrawable, xVisual, w [0], h [0]);
-				} else {
-					surface = Cairo.cairo_image_surface_create(Cairo.CAIRO_FORMAT_ARGB32, w [0], h [0]);
-				}
-				if (surface == 0) error (SWT.ERROR_NO_HANDLES);
-			} else {
-				Cairo.cairo_surface_reference(surface);
-			}
-			long /*int*/ pattern = Cairo.cairo_pattern_create_for_surface (surface);
+			long surface = control.backgroundImage.surface;
+			if (surface == 0) error (SWT.ERROR_NO_HANDLES);
+			Cairo.cairo_surface_reference(surface);
+			long pattern = Cairo.cairo_pattern_create_for_surface (surface);
 			if (pattern == 0) error (SWT.ERROR_NO_HANDLES);
 			Cairo.cairo_pattern_set_extend (pattern, Cairo.CAIRO_EXTEND_REPEAT);
 			if ((data.style & SWT.MIRRORED) != 0) {
@@ -518,13 +533,8 @@ void drawBackgroundInPixels (GC gc, int x, int y, int width, int height, int off
 			Cairo.cairo_surface_destroy (surface);
 			Cairo.cairo_pattern_destroy (pattern);
 		} else {
-			if (GTK.GTK3) {
-				GdkRGBA rgba = control.getBackgroundGdkRGBA ();
-				Cairo.cairo_set_source_rgba (cairo, rgba.red, rgba.green, rgba.blue, rgba.alpha);
-			} else {
-				GdkColor color = control.getBackgroundGdkColor ();
-				Cairo.cairo_set_source_rgba_compatibility (cairo, color);
-			}
+			GdkRGBA rgba = control.getBackgroundGdkRGBA ();
+			Cairo.cairo_set_source_rgba (cairo, rgba.red, rgba.green, rgba.blue, rgba.alpha);
 		}
 		Cairo.cairo_rectangle (cairo, x, y, width, height);
 		Cairo.cairo_fill (cairo);
@@ -573,17 +583,16 @@ void fixChildren (Shell newShell, Shell oldShell, Decorations newDecorations, De
 }
 
 @Override
-void fixParentGdkWindow() {
-	assert GTK.GTK3;
+void fixParentGdkResource() {
 	// Changes to this method should be verified via
 	// org.eclipse.swt.tests.gtk/*/Bug510803_TabFolder_TreeEditor_Regression.java (part two)
 	for (Control child : _getChildren()) {
-		child.fixParentGdkWindow();
+		child.fixParentGdkResource();
 	}
 }
 
 @Override
-void fixModal(long /*int*/ group, long /*int*/ modalGroup)  {
+void fixModal(long group, long modalGroup)  {
 	Control[] controls = _getChildren ();
 	for (int i = 0; i < controls.length; i++) {
 		controls[i].fixModal (group, modalGroup);
@@ -623,35 +632,56 @@ void fixTabList (Control control) {
 
 void fixZOrder () {
 	if ((state & CANVAS) != 0) return;
-	long /*int*/ parentHandle = parentingHandle ();
-	long /*int*/ parentWindow = gtk_widget_get_window (parentHandle);
-	if (parentWindow == 0) return;
-	long /*int*/ [] userData = new long /*int*/ [1];
-	long /*int*/ windowList = GDK.gdk_window_get_children (parentWindow);
-	if (windowList != 0) {
-		long /*int*/ windows = windowList;
-		while (windows != 0) {
-			long /*int*/ window = OS.g_list_data (windows);
-			if (window != redrawWindow) {
-				GDK.gdk_window_get_user_data (window, userData);
-				if (userData [0] == 0 || OS.G_OBJECT_TYPE (userData [0]) != display.gtk_fixed_get_type ()) {
-					GDK.gdk_window_lower (window);
+	long parentHandle = parentingHandle ();
+	if (GTK.GTK4) {
+		long parentSurface = gtk_widget_get_surface (parentHandle);
+		if (parentSurface == 0) return;
+		long [] userData = new long [1];
+		long surfaceList = GDK.gdk_surface_get_children (parentSurface);
+		if (surfaceList != 0) {
+			long surfaces = surfaceList;
+			while (surfaces != 0) {
+				long surface = OS.g_list_data (surfaces);
+				if (surface != redrawSurface) {
+					GDK.gdk_surface_get_user_data (surface, userData);
+					if (userData [0] == 0 || OS.G_OBJECT_TYPE (userData [0]) != display.gtk_fixed_get_type ()) {
+						GDK.gdk_surface_lower (surface);
+					}
 				}
+				surfaces = OS.g_list_next (surfaces);
 			}
-			windows = OS.g_list_next (windows);
+			OS.g_list_free (surfaceList);
+		}
+	} else {
+		long parentWindow = gtk_widget_get_window (parentHandle);
+		if (parentWindow == 0) return;
+		long [] userData = new long [1];
+		long windowList = GDK.gdk_window_get_children (parentWindow);
+		if (windowList != 0) {
+			long windows = windowList;
+			while (windows != 0) {
+				long window = OS.g_list_data (windows);
+				if (window != redrawWindow) {
+					GDK.gdk_window_get_user_data (window, userData);
+					if (userData [0] == 0 || OS.G_OBJECT_TYPE (userData [0]) != display.gtk_fixed_get_type ()) {
+						GDK.gdk_window_lower (window);
+					}
+				}
+				windows = OS.g_list_next (windows);
+			}
+			OS.g_list_free (windowList);
 		}
-		OS.g_list_free (windowList);
 	}
 }
 
 @Override
-long /*int*/ focusHandle () {
+long focusHandle () {
 	if (socketHandle != 0) return socketHandle;
 	return super.focusHandle ();
 }
 
 @Override
-boolean forceFocus (long /*int*/ focusHandle) {
+boolean forceFocus (long focusHandle) {
 	if (socketHandle != 0) GTK.gtk_widget_set_can_focus (focusHandle, true);
 	boolean result = super.forceFocus (focusHandle);
 	if (socketHandle != 0) GTK.gtk_widget_set_can_focus (focusHandle, false);
@@ -712,7 +742,7 @@ int getChildrenCount () {
 	* NOTE: The current implementation will count
 	* non-registered children.
 	*/
-	long /*int*/ list = GTK.gtk_container_get_children (handle);
+	long list = GTK.gtk_container_get_children (handle);
 	if (list == 0) return 0;
 	int count = OS.g_list_length (list);
 	OS.g_list_free (list);
@@ -727,7 +757,7 @@ Rectangle getClientAreaInPixels () {
 			return new Rectangle (0, 0, 0, 0);
 		}
 		forceResize ();
-		long /*int*/ clientHandle = clientHandle ();
+		long clientHandle = clientHandle ();
 		GtkAllocation allocation = new GtkAllocation();
 		GTK.gtk_widget_get_allocation (clientHandle, allocation);
 		int width = (state & ZERO_WIDTH) != 0 ? 0 : allocation.width;
@@ -807,14 +837,14 @@ public Control [] getTabList () {
 }
 
 @Override
-long /*int*/ gtk_button_press_event (long /*int*/ widget, long /*int*/ event) {
-	long /*int*/ result = super.gtk_button_press_event (widget, event);
+long gtk_button_press_event (long widget, long event) {
+	long result = super.gtk_button_press_event (widget, event);
 	if (result != 0) return result;
 	if ((state & CANVAS) != 0) {
 		if ((style & SWT.NO_FOCUS) == 0 && hooksKeys ()) {
-			GdkEventButton gdkEvent = new GdkEventButton ();
-			OS.memmove (gdkEvent, event, GdkEventButton.sizeof);
-			if (gdkEvent.button == 1) {
+			int [] eventButton = new int [1];
+			GDK.gdk_event_get_button(event, eventButton);
+			if (eventButton[0] == 1) {
 				if (getChildrenCount () == 0) setFocus ();
 			}
 		}
@@ -823,43 +853,8 @@ long /*int*/ gtk_button_press_event (long /*int*/ widget, long /*int*/ event) {
 }
 
 @Override
-long /*int*/ gtk_expose_event (long /*int*/ widget, long /*int*/ eventPtr) {
-	if ((state & OBSCURED) != 0) return 0;
-	if ((state & CANVAS) == 0) {
-		return super.gtk_expose_event (widget, eventPtr);
-	}
-	if ((style & SWT.NO_MERGE_PAINTS) == 0) {
-		return super.gtk_expose_event (widget, eventPtr);
-	}
-	if (!hooksPaint ()) return 0;
-	GdkEventExpose gdkEvent = new GdkEventExpose ();
-	OS.memmove(gdkEvent, eventPtr, GdkEventExpose.sizeof);
-	long /*int*/ [] rectangles = new long /*int*/ [1];
-	int [] n_rectangles = new int [1];
-	GDK.gdk_region_get_rectangles (gdkEvent.region, rectangles, n_rectangles);
-	GdkRectangle rect = new GdkRectangle ();
-	for (int i=0; i<n_rectangles[0]; i++) {
-		Event event = new Event ();
-		OS.memmove (rect, rectangles [0] + i * GdkRectangle.sizeof, GdkRectangle.sizeof);
-		event.setBounds (DPIUtil.autoScaleDown (new Rectangle(rect.x, rect.y, rect.width, rect.height)));
-		if ((style & SWT.MIRRORED) != 0) event.x = DPIUtil.autoScaleDown (getClientWidth ()) - event.width - event.x;
-		long /*int*/ damageRgn = GDK.gdk_region_new ();
-		GDK.gdk_region_union_with_rect (damageRgn, rect);
-		GCData data = new GCData ();
-		data.damageRgn = damageRgn;
-		GC gc = event.gc = GC.gtk_new (this, data);
-		sendEvent (SWT.Paint, event);
-		gc.dispose ();
-		GDK.gdk_region_destroy (damageRgn);
-		event.gc = null;
-	}
-	OS.g_free (rectangles [0]);
-	return 0;
-}
-
-@Override
-long /*int*/ gtk_key_press_event (long /*int*/ widget, long /*int*/ event) {
-	long /*int*/ result = super.gtk_key_press_event (widget, event);
+long gtk_key_press_event (long widget, long event) {
+	long result = super.gtk_key_press_event (widget, event);
 	if (result != 0) return result;
 	/*
 	* Feature in GTK.  The default behavior when the return key
@@ -868,10 +863,9 @@ long /*int*/ gtk_key_press_event (long /*int*/ widget, long /*int*/ event) {
 	* fix is to avoid calling the default handler.
 	*/
 	if ((state & CANVAS) != 0 && socketHandle == 0) {
-		GdkEventKey keyEvent = new GdkEventKey ();
-		OS.memmove (keyEvent, event, GdkEventKey.sizeof);
-		int key = keyEvent.keyval;
-		switch (key) {
+		int [] eventKeyval = new int [1];
+		GDK.gdk_event_get_keyval(event, eventKeyval);
+		switch (eventKeyval[0]) {
 			case GDK.GDK_Return:
 			case GDK.GDK_KP_Enter: return 1;
 		}
@@ -880,39 +874,38 @@ long /*int*/ gtk_key_press_event (long /*int*/ widget, long /*int*/ event) {
 }
 
 @Override
-long /*int*/ gtk_focus (long /*int*/ widget, long /*int*/ directionType) {
+long gtk_focus (long widget, long directionType) {
 	if (widget == socketHandle) return 0;
 	return super.gtk_focus (widget, directionType);
 }
 
 @Override
-long /*int*/ gtk_focus_in_event (long /*int*/ widget, long /*int*/ event) {
-	long /*int*/ result = super.gtk_focus_in_event (widget, event);
+long gtk_focus_in_event (long widget, long event) {
+	long result = super.gtk_focus_in_event (widget, event);
 	return (state & CANVAS) != 0 ? 1 : result;
 }
 
 @Override
-long /*int*/ gtk_focus_out_event (long /*int*/ widget, long /*int*/ event) {
-	long /*int*/ result = super.gtk_focus_out_event (widget, event);
+long gtk_focus_out_event (long widget, long event) {
+	long result = super.gtk_focus_out_event (widget, event);
 	return (state & CANVAS) != 0 ? 1 : result;
 }
 
 @Override
-long /*int*/ gtk_map (long /*int*/ widget) {
+long gtk_map (long widget) {
 	fixZOrder ();
 	return 0;
 }
 
 @Override
-long /*int*/ gtk_realize (long /*int*/ widget) {
-	long /*int*/ result = super.gtk_realize (widget);
+long gtk_realize (long widget) {
+	long result = super.gtk_realize (widget);
 	if ((style & SWT.NO_BACKGROUND) != 0) {
-		long /*int*/ window = gtk_widget_get_window (paintHandle ());
-		if (window != 0) {
-			if (GTK.GTK3) {
+		// No gdk_surface_set_background_pattern() on GTK4.
+		if (GTK.GTK_VERSION < OS.VERSION(3, 22, 0)) {
+			long window = gtk_widget_get_window (paintHandle ());
+			if (window != 0) {
 				GDK.gdk_window_set_background_pattern(window, 0);
-			} else {
-				GDK.gdk_window_set_back_pixmap (window, 0, false);
 			}
 		}
 	}
@@ -923,18 +916,22 @@ long /*int*/ gtk_realize (long /*int*/ widget) {
 }
 
 @Override
-long /*int*/ gtk_scroll_child (long /*int*/ widget, long /*int*/ scrollType, long /*int*/ horizontal) {
+long gtk_scroll_child (long widget, long scrollType, long horizontal) {
 	/* Stop GTK scroll child signal for canvas */
 	OS.g_signal_stop_emission_by_name (widget, OS.scroll_child);
+	if (GTK.GTK4) {
+		// GtkScrollBar moved out of GtkRange, get GtkScrollType from this signal instead
+		if (horizontalBar != null ) horizontalBar.detail = (int) scrollType;
+		if (verticalBar != null) verticalBar.detail = (int) scrollType;
+	}
 	return 1;
 }
 
 @Override
-long /*int*/ gtk_style_set (long /*int*/ widget, long /*int*/ previousStyle) {
-	long /*int*/ result = super.gtk_style_set (widget, previousStyle);
+long gtk_style_updated (long widget) {
+	long result = super.gtk_style_updated (widget);
 	if ((style & SWT.NO_BACKGROUND) != 0) {
-		long /*int*/ window = gtk_widget_get_window (paintHandle ());
-		if (window != 0) GDK.gdk_window_set_back_pixmap (window, 0, false);
+		//TODO: implement this on GTK3 as pixmaps are gone.
 	}
 	return result;
 }
@@ -947,7 +944,7 @@ boolean hasBorder () {
 void hookEvents () {
 	super.hookEvents ();
 	if ((state & CANVAS) != 0) {
-		GTK.gtk_widget_add_events (handle, GDK.GDK_POINTER_MOTION_HINT_MASK);
+		if (!GTK.GTK4) GTK.gtk_widget_add_events (handle, GDK.GDK_POINTER_MOTION_HINT_MASK);
 		if (scrolledHandle != 0) {
 			OS.g_signal_connect_closure (scrolledHandle, OS.scroll_child, display.getClosure (SCROLL_CHILD), false);
 		}
@@ -959,7 +956,7 @@ boolean hooksKeys () {
 }
 
 @Override
-long /*int*/ imHandle () {
+long imHandle () {
 	return imHandle;
 }
 
@@ -1085,7 +1082,6 @@ public void layout (boolean changed) {
  * resize event will invoke the layout of the child.  Note that
  * a layout due to a resize will not flush any cached information
  * (same as <code>layout(false)</code>).
- * </p>
  * <p>
  * It is normally more efficient to invoke {@link Control#requestLayout()}
  * on every control which has changed in the layout than it is to invoke
@@ -1164,6 +1160,7 @@ public void layout (Control [] changed) {
  * receiver.
  * <p>
  * The parameter <code>flags</code> may be a combination of:
+ * </p>
  * <dl>
  * <dt><b>SWT.ALL</b></dt>
  * <dd>all children in the receiver's widget tree should be laid out</dd>
@@ -1172,7 +1169,6 @@ public void layout (Control [] changed) {
  * <dt><b>SWT.DEFER</b></dt>
  * <dd>layout will be deferred</dd>
  * </dl>
- * </p>
  * <p>
  * When the <code>changed</code> array is specified, the flags <code>SWT.ALL</code>
  * and <code>SWT.CHANGED</code> have no effect. In this case, the layouts in the
@@ -1288,90 +1284,22 @@ void markLayout (boolean changed, boolean all) {
 	}
 }
 
-void moveAbove (long /*int*/ child, long /*int*/ sibling) {
+void moveAbove (long child, long sibling) {
 	if (child == sibling) return;
-	long /*int*/ parentHandle = parentingHandle ();
-	if (GTK.GTK3) {
-		OS.swt_fixed_restack (parentHandle, child, sibling, true);
-		return;
-	}
-	GtkFixed fixed = new GtkFixed ();
-	OS.memmove (fixed, parentHandle);
-	long /*int*/ children = fixed.children;
-	if (children == 0) return;
-	long /*int*/ [] data = new long /*int*/ [1];
-	long /*int*/ [] widget = new long /*int*/ [1];
-	long /*int*/ childData = 0, childLink = 0, siblingLink = 0, temp = children;
-	while (temp != 0) {
-		C.memmove (data, temp, C.PTR_SIZEOF);
-		C.memmove (widget, data [0], C.PTR_SIZEOF);
-		if (child == widget [0]) {
-			childLink = temp;
-			childData = data [0];
-		} else if (sibling == widget [0]) {
-			siblingLink = temp;
-		}
-		if (childData != 0 && (sibling == 0 || siblingLink != 0)) break;
-		temp = OS.g_list_next (temp);
-	}
-	children = OS.g_list_remove_link (children, childLink);
-	if (siblingLink == 0 || OS.g_list_previous (siblingLink) == 0) {
-		OS.g_list_free_1 (childLink);
-		children = OS.g_list_prepend (children, childData);
-	} else {
-		temp = OS.g_list_previous (siblingLink);
-		OS.g_list_set_previous (childLink, temp);
-		OS.g_list_set_next (temp, childLink);
-		OS.g_list_set_next (childLink, siblingLink);
-		OS.g_list_set_previous (siblingLink, childLink);
-	}
-	fixed.children = children;
-	OS.memmove (parentHandle, fixed);
+	long parentHandle = parentingHandle ();
+	OS.swt_fixed_restack (parentHandle, child, sibling, true);
+	return;
 }
 
-void moveBelow (long /*int*/ child, long /*int*/ sibling) {
+void moveBelow (long child, long sibling) {
 	if (child == sibling) return;
-	long /*int*/ parentHandle = parentingHandle ();
+	long parentHandle = parentingHandle ();
 	if (sibling == 0 && parentHandle == fixedHandle) {
 		moveAbove (child, scrolledHandle != 0  ? scrolledHandle : handle);
 		return;
 	}
-	if (GTK.GTK3) {
-		OS.swt_fixed_restack (parentHandle, child, sibling, false);
-		return;
-	}
-	GtkFixed fixed = new GtkFixed ();
-	OS.memmove (fixed, parentHandle);
-	long /*int*/ children = fixed.children;
-	if (children == 0) return;
-	long /*int*/ [] data = new long /*int*/ [1];
-	long /*int*/ [] widget = new long /*int*/ [1];
-	long /*int*/ childData = 0, childLink = 0, siblingLink = 0, temp = children;
-	while (temp != 0) {
-		C.memmove (data, temp, C.PTR_SIZEOF);
-		C.memmove (widget, data [0], C.PTR_SIZEOF);
-		if (child == widget [0]) {
-			childLink = temp;
-			childData = data [0];
-		} else if (sibling == widget [0]) {
-			siblingLink = temp;
-		}
-		if (childData != 0 && (sibling == 0 || siblingLink != 0)) break;
-		temp = OS.g_list_next (temp);
-	}
-	children = OS.g_list_remove_link (children, childLink);
-	if (siblingLink == 0 || OS.g_list_next (siblingLink) == 0) {
-		OS.g_list_free_1 (childLink);
-		children = OS.g_list_append (children, childData);
-	} else {
-		temp = OS.g_list_next (siblingLink);
-		OS.g_list_set_next (childLink, temp);
-		OS.g_list_set_previous (temp, childLink);
-		OS.g_list_set_previous (childLink, siblingLink);
-		OS.g_list_set_next (siblingLink, childLink);
-	}
-	fixed.children = children;
-	OS.memmove (parentHandle, fixed);
+	OS.swt_fixed_restack (parentHandle, child, sibling, false);
+	return;
 }
 
 @Override
@@ -1379,7 +1307,7 @@ void moveChildren(int oldWidth) {
 	Control[] children = _getChildren ();
 	for (int i = 0; i < children.length; i++) {
 		Control child = children[i];
-		long /*int*/ topHandle = child.topHandle ();
+		long topHandle = child.topHandle ();
 		GtkAllocation allocation = new GtkAllocation();
 		GTK.gtk_widget_get_allocation (topHandle, allocation);
 		int x = allocation.x;
@@ -1388,8 +1316,14 @@ void moveChildren(int oldWidth) {
 		if (oldWidth > 0) x = oldWidth - controlWidth - x;
 		int clientWidth = getClientWidth ();
 		x = clientWidth - controlWidth - x;
-		if (child.enableWindow != 0) {
-			GDK.gdk_window_move (child.enableWindow, x, y);
+		if (GTK.GTK4) {
+			if (child.enableSurface != 0) {
+				GDK.gdk_surface_move (child.enableSurface, x, y);
+			}
+		} else {
+			if (child.enableWindow != 0) {
+				GDK.gdk_window_move (child.enableWindow, x, y);
+			}
 		}
 		child.moveHandle (x, y);
 		/*
@@ -1398,10 +1332,14 @@ void moveChildren(int oldWidth) {
 		* a call to gtk_widget_size_request().
 		*/
 		GtkRequisition requisition = new GtkRequisition ();
-		gtk_widget_size_request (topHandle, requisition);
+		gtk_widget_get_preferred_size (topHandle, requisition);
 		allocation.x = x;
 		allocation.y = y;
-		GTK.gtk_widget_size_allocate (topHandle, allocation);
+		if (GTK.GTK4) {
+			GTK.gtk_widget_size_allocate (topHandle, allocation, -1);
+		} else {
+			GTK.gtk_widget_size_allocate (topHandle, allocation);
+		}
 		Control control = child.findBackgroundControl ();
 		if (control != null && control.backgroundImage != null) {
 			if (child.isVisible ()) child.redrawWidget (0, 0, 0, 0, true, true, true);
@@ -1425,13 +1363,13 @@ Point minimumSize (int wHint, int hHint, boolean changed) {
 	return new Point (width, height);
 }
 
-long /*int*/ parentingHandle () {
+long parentingHandle () {
 	if ((state & CANVAS) != 0) return handle;
 	return fixedHandle != 0 ? fixedHandle : handle;
 }
 
 @Override
-void printWidget (GC gc, long /*int*/ drawable, int depth, int x, int y) {
+void printWidget (GC gc, long drawable, int depth, int x, int y) {
 	Region oldClip = new Region (gc.getDevice ());
 	Region newClip = new Region (gc.getDevice ());
 	Point loc = DPIUtil.autoScaleDown(new Point (x, y));
@@ -1465,7 +1403,7 @@ void printWidget (GC gc, long /*int*/ drawable, int depth, int x, int y) {
  * NOTE: only the "draw" (EXPOSE) signal is connected, not EXPOSE_EVENT_INVERSE.
  */
 void connectFixedHandleDraw () {
-	long /*int*/ paintHandle = fixedHandle;
+	long paintHandle = fixedHandle;
 	int paintMask = GDK.GDK_EXPOSURE_MASK;
 	GTK.gtk_widget_add_events (paintHandle, paintMask);
 
@@ -1486,16 +1424,50 @@ void connectFixedHandleDraw () {
  * @param container the parent container, i.e. fixedHandle
  * @param cairo the cairo context provided by GTK
  */
-void propagateDraw (long /*int*/ container, long /*int*/ cairo) {
-	if (container == fixedHandle && GTK.GTK3) {
-		long /*int*/ list = GTK.gtk_container_get_children (container);
-		long /*int*/ temp = list;
+void propagateDraw (long container, long cairo) {
+	if (container == fixedHandle) {
+		long list = GTK.gtk_container_get_children (container);
+		long temp = list;
 		while (temp != 0) {
-			long /*int*/ child = OS.g_list_data (temp);
+			long child = OS.g_list_data (temp);
 			if (child != 0) {
 				Widget widget = display.getWidget (child);
 				if (widget != this) {
-					GTK.gtk_container_propagate_draw(container, child, cairo);
+					if (noChildDrawing) {
+						Boolean childLowered = childrenLowered.get(widget);
+						if (childLowered == null) {
+							childrenLowered.put(widget, false);
+							childLowered = false;
+						}
+						GtkAllocation allocation = new GtkAllocation ();
+						GTK.gtk_widget_get_allocation(child, allocation);
+						if (allocation.y < 0) {
+							if (!childLowered) {
+								if (GTK.GTK4) {
+									long surface = gtk_widget_get_surface(child);
+									GDK.gdk_surface_lower(surface);
+								} else {
+									long window = gtk_widget_get_window(child);
+									GDK.gdk_window_lower(window);
+								}
+								childrenLowered.put(widget, true);
+							}
+						} else {
+							if (childLowered) {
+								if (GTK.GTK4) {
+									long surface = gtk_widget_get_surface(child);
+									GDK.gdk_surface_raise(surface);
+								} else {
+									long window = gtk_widget_get_window(child);
+									GDK.gdk_window_raise(window);
+								}
+								childrenLowered.put(widget, false);
+							}
+							GTK.gtk_container_propagate_draw(container, child, cairo);
+						}
+					} else {
+						GTK.gtk_container_propagate_draw(container, child, cairo);
+					}
 				}
 			}
 			temp = OS.g_list_next (temp);
@@ -1568,11 +1540,7 @@ void reskinChildren (int flags) {
 void resizeHandle (int width, int height) {
 	super.resizeHandle (width, height);
 	if (socketHandle != 0) {
-		if (GTK.GTK3) {
-			OS.swt_fixed_resize (handle, socketHandle, width, height);
-		} else {
-			GTK.gtk_widget_set_size_request (socketHandle, width, height);
-		}
+		OS.swt_fixed_resize (handle, socketHandle, width, height);
 	}
 }
 
@@ -1621,9 +1589,8 @@ int setBounds (int x, int y, int width, int height, boolean move, boolean resize
 	 * but fix themselfes upon first resize by mouse, then
 	 * consider moving this fix higher into Control's setBound(...) method instead.
 	 */
-	long /*int*/ topHandle = topHandle ();
-	if (GTK.GTK_VERSION >= OS.VERSION (3, 8, 0)
-			&& fixedHandle != 0 && handle != 0
+	long topHandle = topHandle ();
+	if (fixedHandle != 0 && handle != 0
 			&& getVisible() && !GTK.gtk_widget_get_visible(topHandle) //if SWT State is not HIDDEN, but widget is hidden on GTK side.
 			&& topHandle == fixedHandle && width > 0 && height > 0 && resize) {
 		GTK.gtk_widget_show(topHandle);
@@ -1810,7 +1777,7 @@ boolean translateMnemonic (Event event, Control control) {
 }
 
 @Override
-int traversalCode(int key, GdkEventKey event) {
+int traversalCode(int key, long event) {
 	if ((state & CANVAS) != 0) {
 		if ((style & SWT.NO_FOCUS) != 0) return 0;
 		if (hooksKeys ()) return 0;
@@ -1819,9 +1786,9 @@ int traversalCode(int key, GdkEventKey event) {
 }
 
 @Override
-boolean translateTraversal (GdkEventKey keyEvent) {
+boolean translateTraversal (long event) {
 	if (socketHandle != 0) return false;
-	return super.translateTraversal (keyEvent);
+	return super.translateTraversal (event);
 }
 
 @Override
