@@ -68,7 +68,7 @@ public class DateTime extends Composite {
 	 * Major handles of this class.
 	 * Note, these can vary or all equal each other depending on Date/Time/Calendar/Drop_down
 	 * configuration used. See createHandle () */
-	long /*int*/ textEntryHandle,
+	long textEntryHandle, spinButtonHandle,
 	containerHandle,
 	calendarHandle;
 
@@ -295,7 +295,7 @@ Point computeMaxTextSize (int wHint, int hHint, boolean changed) {
 			// Fixed length for DEFAULT_SHORT_DATE_FORMAT, no need to adjust text length.
 	}
 
-	Point textSize = computeNativeSize (textEntryHandle, wHint, hHint, changed);
+	Point textSize = computeNativeSize (GTK.GTK4? spinButtonHandle : textEntryHandle, wHint, hHint, changed);
 	// Change the text back to match the current calendar
 	updateControl();
 	return textSize;
@@ -361,22 +361,16 @@ Rectangle computeTrimInPixels (int x, int y, int width, int height) {
 	Rectangle trim = super.computeTrimInPixels (x, y, width, height);
 	int xborder = 0, yborder = 0;
 		GtkBorder tmp = new GtkBorder ();
-		long /*int*/ context = GTK.gtk_widget_get_style_context (textEntryHandle);
-		if (GTK.GTK_VERSION < OS.VERSION(3, 18, 0)) {
-			GTK.gtk_style_context_get_padding (context, GTK.GTK_STATE_FLAG_NORMAL, tmp);
-		} else {
-			GTK.gtk_style_context_get_padding (context, GTK.gtk_widget_get_state_flags(textEntryHandle), tmp);
-		}
+		long context = GTK.gtk_widget_get_style_context (GTK.GTK4 ? spinButtonHandle :textEntryHandle);
+		int state_flag = GTK.GTK_VERSION < OS.VERSION(3, 18, 0) ? GTK.GTK_STATE_FLAG_NORMAL : GTK.gtk_widget_get_state_flags(textEntryHandle);
+		gtk_style_context_get_padding(context, state_flag, tmp);
 		trim.x -= tmp.left;
 		trim.y -= tmp.top;
 		trim.width += tmp.left + tmp.right;
 		trim.height += tmp.top + tmp.bottom;
 		if ((style & SWT.BORDER) != 0) {
-			if (GTK.GTK_VERSION < OS.VERSION(3, 18, 0)) {
-				GTK.gtk_style_context_get_border (context, GTK.GTK_STATE_FLAG_NORMAL, tmp);
-			} else {
-				GTK.gtk_style_context_get_border (context, GTK.gtk_widget_get_state_flags(textEntryHandle), tmp);
-			}
+			int state = GTK.GTK_VERSION < OS.VERSION(3, 18, 0) ? GTK.GTK_STATE_FLAG_NORMAL : GTK.gtk_widget_get_state_flags(textEntryHandle);
+			gtk_style_context_get_border(context, state, tmp);
 			trim.x -= tmp.left;
 			trim.y -= tmp.top;
 			trim.width += tmp.left + tmp.right;
@@ -469,17 +463,24 @@ private void createHandleForDateWithDropDown () {
 }
 
 private void createHandleForDateTime () {
-	long /*int*/ adjusment = GTK.gtk_adjustment_new (0, -9999, 9999, 1, 0, 0);
-	textEntryHandle = GTK.gtk_spin_button_new (adjusment, 1, 0);
+	long adjusment = GTK.gtk_adjustment_new (0, -9999, 9999, 1, 0, 0);
+	if (GTK.GTK4) {
+		spinButtonHandle =  GTK.gtk_spin_button_new (adjusment, 1, 0);
+		long boxHandle = GTK.gtk_widget_get_first_child(spinButtonHandle);
+		long textHandle = GTK.gtk_widget_get_first_child(boxHandle);
+		textEntryHandle = textHandle;
+		handle = spinButtonHandle;
+		containerHandle = spinButtonHandle;
+	} else {
+		textEntryHandle = GTK.gtk_spin_button_new (adjusment, 1, 0);
+		handle = textEntryHandle;
+		containerHandle = textEntryHandle;
+	}
 	if (textEntryHandle == 0) error (SWT.ERROR_NO_HANDLES);
 
-	//in this case,the Entry becomes the container.
-	handle = textEntryHandle;
-	containerHandle = textEntryHandle;
-
-	GTK.gtk_spin_button_set_numeric (textEntryHandle, false);
-	GTK.gtk_container_add (fixedHandle, textEntryHandle);
-	GTK.gtk_spin_button_set_wrap (textEntryHandle, (style & SWT.WRAP) != 0);
+	GTK.gtk_spin_button_set_numeric (GTK.GTK4? spinButtonHandle : textEntryHandle, false);
+	GTK.gtk_container_add (fixedHandle, GTK.GTK4? spinButtonHandle : textEntryHandle);
+	GTK.gtk_spin_button_set_wrap (GTK.GTK4? spinButtonHandle : textEntryHandle, (style & SWT.WRAP) != 0);
 }
 
 void createDropDownButton () {
@@ -550,7 +551,7 @@ void createPopupShell (int year, int month, int day) {
 }
 
 @Override
-void setFontDescription (long /*int*/ font) {
+void setFontDescription (long font) {
 	if (isDateWithDropDownButton ()) {
 		prefferedSize = null; //flush cache for computeSize as font can cause size to change.
 		setFontDescription (textEntryHandle, font);
@@ -884,43 +885,48 @@ public int getYear () {
 }
 
 @Override
-long /*int*/ gtk_day_selected (long /*int*/ widget) {
+long gtk_day_selected (long widget) {
 	sendSelectionEvent ();
 	return 0;
 }
 
 @Override
-long /*int*/ gtk_day_selected_double_click (long /*int*/ widget) {
+long gtk_day_selected_double_click (long widget) {
 	sendSelectionEvent (SWT.DefaultSelection);
 	return 0;
 }
 
 @Override
-long /*int*/ gtk_month_changed (long /*int*/ widget) {
+long gtk_month_changed (long widget) {
 	sendSelectionEvent ();
 	return 0;
 }
 
 @Override
-long /*int*/ eventHandle () {
+long eventHandle () {
 	return dateTimeHandle ();
 }
 
 @Override
-long /*int*/ focusHandle () {
+long focusHandle () {
 	return dateTimeHandle ();
 }
 
 @Override
-long /*int*/ fontHandle () {
+long fontHandle () {
 	return dateTimeHandle ();
 }
 
-private long /*int*/ dateTimeHandle () {
+private long dateTimeHandle () {
 	if (isCalendar () && calendarHandle != 0) {
-		 return calendarHandle;
-	} else if ((isDate () || isTime ()) && textEntryHandle != 0) {
-		 return textEntryHandle;
+		return calendarHandle;
+	} else if ((isDate () || isTime ())) {
+		if (GTK.GTK4) {
+			if (spinButtonHandle != 0) return spinButtonHandle;
+		} else {
+			if (textEntryHandle != 0) return textEntryHandle;
+		}
+		return super.focusHandle ();
 	} else {
 		return super.focusHandle ();
 	}
@@ -954,7 +960,16 @@ final private void hookEventsForCalendar () {
 
 final private void hookEventsForDateTimeSpinner () {
 	OS.g_signal_connect_closure (textEntryHandle, OS.output, display.getClosure (OUTPUT), true);
-	OS.g_signal_connect_closure (textEntryHandle, OS.focus_in_event, display.getClosure (FOCUS_IN_EVENT), true);
+	if (GTK.GTK4) {
+		long keyController = GTK.gtk_event_controller_key_new();
+		GTK.gtk_widget_add_controller(textEntryHandle, keyController);
+		GTK.gtk_event_controller_set_propagation_phase(keyController, GTK.GTK_PHASE_TARGET);
+
+		long focusAddress = display.focusCallback.getAddress();
+		OS.g_signal_connect (keyController, OS.focus_in, focusAddress, FOCUS_IN);
+	} else {
+		OS.g_signal_connect_closure (textEntryHandle, OS.focus_in_event, display.getClosure (FOCUS_IN_EVENT), true);
+	}
 }
 
 final private void hookEventsForMenu () {
@@ -1223,7 +1238,6 @@ void handleFocus (int type) {
 			shell.addListener (SWT.Deactivate, popupListener);
 			Display display = getDisplay ();
 			display.removeFilter (SWT.FocusIn, popupFilter);
-			display.addFilter (SWT.FocusIn, popupFilter);
 			Event e = new Event ();
 			notifyListeners (SWT.FocusIn, e);
 			break;
@@ -1236,7 +1250,6 @@ void handleFocus (int type) {
 			Shell shell = getShell ();
 			shell.removeListener (SWT.Deactivate, popupListener);
 			Display display = getDisplay ();
-			display.removeFilter (SWT.FocusIn, popupFilter);
 			display.removeFilter (SWT.MouseDown, mouseEventListener);
 			Event e = new Event ();
 			notifyListeners (SWT.FocusOut, e);
@@ -1333,6 +1346,7 @@ void selectField(FieldPosition fieldPosition) {
 			setSelection(s, end);
 		}
 	});
+	sendSelectionEvent(SWT.Selection);
 }
 
 void sendSelectionEvent () {
@@ -1375,25 +1389,25 @@ void setBackgroundGdkRGBA (GdkRGBA rgba) {
 }
 
 @Override
-void setBackgroundGdkRGBA (long /*int*/ context, long /*int*/ handle, GdkRGBA rgba) {
+void setBackgroundGdkRGBA (long context, long handle, GdkRGBA rgba) {
 	// We need to override here because DateTime widgets use "background" instead of
 	// "background-color" as their CSS property.
 	if (GTK.GTK_VERSION >= OS.VERSION(3, 14, 0)) {
-    	// Form background string
-        String name = GTK.GTK_VERSION >= OS.VERSION(3, 20, 0) ? display.gtk_widget_class_get_css_name(handle)
-        		: display.gtk_widget_get_name(handle);
-        String css = name + " {background: " + display.gtk_rgba_to_css_string (rgba) + ";}\n" +
-        		name + ":selected" + " {background: " + display.gtk_rgba_to_css_string(display.COLOR_LIST_SELECTION_RGBA) + ";}";
+		// Form background string
+		String name = GTK.GTK_VERSION >= OS.VERSION(3, 20, 0) ? display.gtk_widget_class_get_css_name(handle)
+				: display.gtk_widget_get_name(handle);
+		String css = name + " {background: " + display.gtk_rgba_to_css_string (rgba) + ";}\n" +
+				name + ":selected" + " {background: " + display.gtk_rgba_to_css_string(display.COLOR_LIST_SELECTION_RGBA) + ";}";
 
-        // Cache background
-        cssBackground = css;
+		// Cache background
+		cssBackground = css;
 
-        // Apply background color and any cached foreground color
-        String finalCss = display.gtk_css_create_css_color_string (cssBackground, cssForeground, SWT.BACKGROUND);
-        gtk_css_provider_load_from_css (context, finalCss);
-    } else {
-    	super.setBackgroundGdkRGBA(context, handle, rgba);
-    }
+		// Apply background color and any cached foreground color
+		String finalCss = display.gtk_css_create_css_color_string (cssBackground, cssForeground, SWT.BACKGROUND);
+		gtk_css_provider_load_from_css (context, finalCss);
+	} else {
+		super.setBackgroundGdkRGBA(context, handle, rgba);
+	}
 }
 
 @Override
@@ -1674,12 +1688,13 @@ void setBoundsInPixels (int x, int y, int width, int height) {
 
 	//Date with Drop down is in container. Needs extra handling.
 	if (isDateWithDropDownButton ()) {
+		long sizingHandle = GTK.GTK4 ? spinButtonHandle : textEntryHandle;
 		GtkRequisition requisition = new GtkRequisition ();
-		GTK.gtk_widget_get_preferred_size (textEntryHandle, null, requisition);
+		GTK.gtk_widget_get_preferred_size (sizingHandle, null, requisition);
 		int oldHeight = requisition.height; //Entry should not expand vertically. It is single liner.
 
 		int newWidth = width - (down.getSizeInPixels ().x + getGtkBorderPadding ().right);
-		GTK.gtk_widget_set_size_request (textEntryHandle, (newWidth >= 0) ? newWidth : 0, oldHeight);
+		GTK.gtk_widget_set_size_request (sizingHandle, (newWidth >= 0) ? newWidth : 0, oldHeight);
 	}
 
 	/*
@@ -1716,7 +1731,7 @@ private void setDropDownButtonSize () {
 	Point buttonSize = down.computeSizeInPixels (SWT.DEFAULT, parentHeight);
 
 	//TAG_GTK3__NO_VERTICAL_FILL_ADJUSTMENT
-	int dateEntryHeight = computeNativeSize (textEntryHandle, SWT.DEFAULT, SWT.DEFAULT, false).y;
+	int dateEntryHeight = computeNativeSize (GTK.GTK4 ? spinButtonHandle : textEntryHandle, SWT.DEFAULT, SWT.DEFAULT, false).y;
 	int newHeight = dateEntryHeight;
 
 	//Move button a little closer to entry field, by amount of padding.
@@ -1735,12 +1750,10 @@ private void setDropDownButtonSize () {
 GtkBorder getGtkBorderPadding () {
 	//In Gtk3, acquire border.
 	GtkBorder gtkBorderPadding = new GtkBorder ();
-	long /*int*/ context = GTK.gtk_widget_get_style_context (textEntryHandle);
-	if (GTK.GTK_VERSION < OS.VERSION(3, 18 , 0)) {
-		GTK.gtk_style_context_get_padding (context, GTK.GTK_STATE_FLAG_NORMAL, gtkBorderPadding);
-	} else {
-		GTK.gtk_style_context_get_padding (context, GTK.gtk_widget_get_state_flags(textEntryHandle), gtkBorderPadding);
-	}
+	long contextHandle = GTK.GTK4 ? spinButtonHandle : textEntryHandle;
+	long context = GTK.gtk_widget_get_style_context (contextHandle);
+	int state_flag = GTK.GTK_VERSION < OS.VERSION(3, 18, 0) ? GTK.GTK_STATE_FLAG_NORMAL : GTK.gtk_widget_get_state_flags(contextHandle);
+	gtk_style_context_get_padding(context, state_flag, gtkBorderPadding);
 	return gtkBorderPadding;
 }
 
@@ -1749,9 +1762,9 @@ boolean onNumberKeyInput(int key) {
 		return false;
 	}
 	int fieldName = getCalendarField(currentField);
-	StringBuffer prefix = new StringBuffer();
-	StringBuffer current = new StringBuffer();
-	StringBuffer suffix = new StringBuffer();
+	StringBuilder prefix = new StringBuilder();
+	StringBuilder current = new StringBuilder();
+	StringBuilder suffix = new StringBuilder();
 
 	AttributedCharacterIterator iterator = dateFormat.formatToCharacterIterator(calendar.getTime());
 	char c = iterator.first();
@@ -1803,7 +1816,7 @@ boolean onNumberKeyInput(int key) {
 		}
 		typeBufferPos++;
 	}
-	StringBuffer newText = new StringBuffer(prefix);
+	StringBuilder newText = new StringBuilder(prefix);
 	newText.append(typeBuffer);
 	newText.append(suffix);
 	setText(newText.toString());
@@ -1850,19 +1863,29 @@ void deregister () {
 	if (textEntryHandle != 0 && textEntryHandle != containerHandle) display.removeWidget (textEntryHandle);
 }
 
-int getArrow(long /*int*/ widget) {
+int getArrow(long widget) {
+	updateControl();
 	int adj_value = (int) GTK.gtk_adjustment_get_value(GTK.gtk_spin_button_get_adjustment(widget));
 	int new_value = 0;
 	if (isDate()) {
-		if ((style & SWT.LONG) != 0) {
-			if (adj_value == 0) {
-				return 0;
-			} else {
-				return adj_value > 0 ? SWT.ARROW_UP : SWT.ARROW_DOWN;
+		FieldPosition firstField = getNextField(null);
+		int firstFieldConstant = getCalendarField(firstField);
+		new_value = calendar.get(getCalendarField(firstField));
+		if (firstFieldConstant == Calendar.MONTH) {
+			if ((style & SWT.SHORT) != 0) {
+				// adj_value returns the month as a number between 1-12
+				// new_value gets the month as a number between 0-11
+				// shift the adj_value by offset so that we get the correct arrow direction
+				adj_value--;
+			} else if ((style & SWT.MEDIUM) != 0 || (style & SWT.LONG) != 0 ) {
+				// adj_value is either +1, 0, -1 when month is displayed as string
+				if (adj_value == 0) {
+					return 0;
+				} else {
+					return adj_value > 0 ? SWT.ARROW_UP : SWT.ARROW_DOWN;
+				}
 			}
 		}
-		FieldPosition firstField = getNextField(null);
-		new_value = calendar.get(getCalendarField(firstField));
 	} else if (isTime()) {
 		new_value = getHours();
 		if (hasAmPm()) {
@@ -1917,12 +1940,11 @@ void setText (String dateTimeText) {
 }
 
 @Override
-long /*int*/ gtk_key_press_event (long /*int*/ widget, long /*int*/ event) {
+long gtk_key_press_event (long widget, long event) {
 	if (!isReadOnly () && (isTime () || isDate ())) {
-		GdkEventKey keyEvent = new GdkEventKey ();
-		OS.memmove (keyEvent, event, GdkEventKey.sizeof);
-		int key = keyEvent.keyval;
-		switch (key) {
+		int [] key = new int[1];
+		GDK.gdk_event_get_keyval(event, key);
+		switch (key[0]) {
 		case GDK.GDK_Up:
 		case GDK.GDK_KP_Up:
 			incrementField(+1);
@@ -1959,7 +1981,7 @@ long /*int*/ gtk_key_press_event (long /*int*/ widget, long /*int*/ event) {
 			}
 			break;
 		default:
-			onNumberKeyInput(key);
+			onNumberKeyInput(key[0]);
 		}
 	}
 	return 1;
@@ -1982,9 +2004,9 @@ Point getSelection () {
 	int [] start = new int [1];
 	int [] end = new int [1];
 	GTK.gtk_editable_get_selection_bounds (textEntryHandle, start, end);
-	long /*int*/ ptr = GTK.gtk_entry_get_text (textEntryHandle);
-	start[0] = (int)/*64*/OS.g_utf8_offset_to_utf16_offset (ptr, start[0]);
-	end[0] = (int)/*64*/OS.g_utf8_offset_to_utf16_offset (ptr, end[0]);
+	long ptr = GTK.gtk_entry_get_text (textEntryHandle);
+	start[0] = (int)OS.g_utf8_offset_to_utf16_offset (ptr, start[0]);
+	end[0] = (int)OS.g_utf8_offset_to_utf16_offset (ptr, end[0]);
 	selection = new Point (start [0], end [0]);
 	return selection;
 
@@ -2005,7 +2027,7 @@ Point getSelection () {
 String getText () {
 	checkWidget ();
 	if (textEntryHandle != 0) {
-		long /*int*/ str = GTK.gtk_entry_get_text (textEntryHandle);
+		long str = GTK.gtk_entry_get_text (textEntryHandle);
 		if (str == 0) return "";
 		int length = C.strlen (str);
 		byte [] buffer = new byte [length];
@@ -2036,9 +2058,9 @@ String getText (String str,int start, int end) {
 
 void setSelection (int start, int end) {
 	checkWidget ();
-	long /*int*/ ptr = GTK.gtk_entry_get_text (textEntryHandle);
-	start = (int)/*64*/OS.g_utf16_offset_to_utf8_offset (ptr, start);
-	end = (int)/*64*/OS.g_utf16_offset_to_utf8_offset (ptr, end);
+	long ptr = GTK.gtk_entry_get_text (textEntryHandle);
+	start = (int)OS.g_utf16_offset_to_utf8_offset (ptr, start);
+	end = (int)OS.g_utf16_offset_to_utf8_offset (ptr, end);
 	GTK.gtk_editable_set_position (textEntryHandle, start);
 	GTK.gtk_editable_select_region (textEntryHandle, start, end);
 }
@@ -2072,24 +2094,16 @@ private int validateValueBounds(FieldPosition field, int value) {
 }
 
 @Override
-long /*int*/ gtk_button_release_event (long /*int*/ widget, long /*int*/ event) {
+long gtk_button_release_event (long widget, long event) {
 	if (isDate () || isTime ()) {
-		GdkEventButton gdkEvent = getEventInfoFromOS (event);
-		if (gdkEvent.button == 1) { // left mouse button.
-			onTextMouseClick (gdkEvent);
+		int [] eventButton = new int [1];
+		GDK.gdk_event_get_button(event, eventButton);
+		if (eventButton[0] == 1) { // left mouse button.
+			onTextMouseClick ();
 		}
 	}
 	return super.gtk_button_release_event (widget, event);
 }
-
-private GdkEventButton getEventInfoFromOS (long /*int*/ nativeEventPointer) {
-	// create place holder.
-	GdkEventButton localEventCopy = new GdkEventButton ();
-
-	// copy data in memory from OS to local JAVA space.
-	OS.memmove (localEventCopy, nativeEventPointer, GdkEventButton.sizeof);
-	return localEventCopy;
-}
 /**
  * Output signal is called when Spinner's arrow buttons are triggered,
  * usually by clicking the mouse on the [gtk2: up/down] [gtk3: +/-] buttons.
@@ -2097,7 +2111,7 @@ private GdkEventButton getEventInfoFromOS (long /*int*/ nativeEventPointer) {
  * This method compares two values and determines if Up or down arrow was called.
  */
 @Override
-long /*int*/ gtk_output (long /*int*/ widget) {
+long gtk_output (long widget) {
 	if (calendar == null) {
 		return 0; //Guard: Object not fully initialized yet.
 	}
@@ -2126,7 +2140,7 @@ void replaceCurrentlySelectedTextRegion (String string) {
 	GTK.gtk_editable_set_position (textEntryHandle, start [0]);
 }
 
-void onTextMouseClick(GdkEventButton event) {
+void onTextMouseClick() {
 	if (calendar == null) {
 		return; // Guard: Object not fully initialized yet.
 	}
