@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -32,6 +32,7 @@ import org.eclipse.swt.internal.gtk.*;
  * <p>
  * Instances are always displayed in one of the maximized,
  * minimized or normal states:
+ * </p>
  * <ul>
  * <li>
  * When an instance is marked as <em>maximized</em>, the
@@ -55,7 +56,6 @@ import org.eclipse.swt.internal.gtk.*;
  * of these changes are also possible.
  * </li>
  * </ul>
- * </p>
  * Note: The styles supported by this class must be treated
  * as <em>HINT</em>s, since the window manager for the
  * desktop on which the instance is visible has ultimate
@@ -106,7 +106,7 @@ public class Decorations extends Canvas {
 	Menu [] menus;
 	Control savedFocus;
 	Button defaultButton, saveDefault;
-	long /*int*/ accelGroup, vboxHandle;
+	long accelGroup, vboxHandle;
 
 Decorations () {
 	/* Do nothing */
@@ -179,17 +179,17 @@ void _setImages (Image [] images) {
 		sort (bestImages);
 		images = bestImages;
 	}
-	long /*int*/ pixbufs = 0;
+	long pixbufs = 0;
 	if (images != null) {
 		for (int i = 0; i < images.length; i++) {
 			Image image = images [i];
-			long /*int*/ pixbuf = ImageList.createPixbuf (image);
+			long pixbuf = ImageList.createPixbuf (image);
 			pixbufs = OS.g_list_append (pixbufs, pixbuf);
 		}
 	}
 	GTK.gtk_window_set_icon_list (topHandle (), pixbufs);
-	long /*int*/ [] data = new long /*int*/ [1];
-	long /*int*/ temp = pixbufs;
+	long [] data = new long [1];
+	long temp = pixbufs;
 	while (temp != 0) {
 		C.memmove (data, temp, C.PTR_SIZEOF);
 		OS.g_object_unref (data [0]);
@@ -242,7 +242,7 @@ void createAccelGroup () {
 	accelGroup = GTK.gtk_accel_group_new ();
 	if (accelGroup == 0) error (SWT.ERROR_NO_HANDLES);
 	//FIXME - what should we do for Decorations
-	long /*int*/ shellHandle = topHandle ();
+	long shellHandle = topHandle ();
 	GTK.gtk_window_add_accel_group (shellHandle, accelGroup);
 }
 
@@ -254,7 +254,7 @@ void createWidget (int index) {
 
 void destroyAccelGroup () {
 	if (accelGroup == 0) return;
-	long /*int*/ shellHandle = topHandle ();
+	long shellHandle = topHandle ();
 	GTK.gtk_window_remove_accel_group (shellHandle, accelGroup);
 	//TEMPORARY CODE
 //	OS.g_object_unref (accelGroup);
@@ -556,13 +556,24 @@ boolean restoreFocus () {
  */
 public void setDefaultButton (Button button) {
 	checkWidget();
-	long /*int*/ buttonHandle = 0;
+	long buttonHandle = 0;
+	if (saveDefault != null && !saveDefault.isDisposed ()  ) {
+		long saveButtonHandle = saveDefault.handle;
+		if (saveButtonHandle != 0) {
+			long context = GTK.gtk_widget_get_style_context (saveButtonHandle);
+			GTK.gtk_style_context_remove_class(context, GTK.GTK_STYLE_CLASS_SUGGESTED_ACTION);
+		}
+	}
 	if (button != null) {
 		if (button.isDisposed ()) error (SWT.ERROR_INVALID_ARGUMENT);
 		if (button.menuShell () != this) error (SWT.ERROR_INVALID_PARENT);
 		buttonHandle = button.handle;
 	}
 	saveDefault = defaultButton = button;
+	if (buttonHandle != 0) {
+		long context = GTK.gtk_widget_get_style_context (buttonHandle);
+		GTK.gtk_style_context_add_class(context, GTK.GTK_STYLE_CLASS_SUGGESTED_ACTION);
+	}
 	GTK.gtk_window_set_default (topHandle (), buttonHandle);
 }
 
@@ -709,10 +720,10 @@ public void setMinimized (boolean minimized) {
 
 @Override
 void setOrientation (boolean create) {
-    super.setOrientation (create);
-    if (!create) {
-        if (menuBar != null) menuBar._setOrientation (style & (SWT.RIGHT_TO_LEFT | SWT.LEFT_TO_RIGHT));
-    }
+	super.setOrientation (create);
+	if (!create) {
+		if (menuBar != null) menuBar._setOrientation (style & (SWT.RIGHT_TO_LEFT | SWT.LEFT_TO_RIGHT));
+	}
 }
 
 void setSavedFocus (Control control) {
@@ -756,16 +767,16 @@ void sort (Image [] images) {
 	for (int gap=length/2; gap>0; gap/=2) {
 		for (int i=gap; i<length; i++) {
 			for (int j=i-gap; j>=0; j-=gap) {
-		   		if (compare (datas [j], datas [j + gap]) >= 0) {
+				if (compare (datas [j], datas [j + gap]) >= 0) {
 					Image swap = images [j];
 					images [j] = images [j + gap];
 					images [j + gap] = swap;
 					ImageData swapData = datas [j];
 					datas [j] = datas [j + gap];
 					datas [j + gap] = swapData;
-		   		}
-	    	}
-	    }
+				}
+			}
+		}
 	}
 }
 
@@ -785,7 +796,7 @@ boolean traverseReturn () {
 	* key.
 	*/
 	if (!button.isVisible () || !button.isEnabled ()) return true;
-	long /*int*/ shellHandle = _getShell ().topHandle ();
+	long shellHandle = _getShell ().topHandle ();
 	return GTK.gtk_window_activate_default (shellHandle);
 }
 
