@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -25,14 +25,14 @@ import org.eclipse.swt.internal.gtk.*;
  * <p>
  * The item children that may be added to instances of this class
  * must be of type <code>ExpandItem</code>.
- * </p><p>
+ * </p>
  * <dl>
  * <dt><b>Styles:</b></dt>
  * <dd>V_SCROLL</dd>
  * <dt><b>Events:</b></dt>
  * <dd>Expand, Collapse</dd>
  * </dl>
- * </p><p>
+ * <p>
  * IMPORTANT: This class is <em>not</em> intended to be subclassed.
  * </p>
  *
@@ -125,7 +125,7 @@ Point computeSizeInPixels (int wHint, int hHint, boolean changed) {
 	Point size = computeNativeSize (handle, wHint, hHint, changed);
 	if (size.x == 0 && wHint == SWT.DEFAULT) size.x = DEFAULT_WIDTH;
 	if (size.y == 0 && hHint == SWT.DEFAULT) size.y = DEFAULT_HEIGHT;
-	int border = GTK.gtk_container_get_border_width (handle);
+	int border = gtk_container_get_border_width_or_margin (handle);
 	size.x += 2 * border;
 	size.y += 2 * border;
 	return size;
@@ -136,7 +136,7 @@ void createHandle (int index) {
 	state |= HANDLE;
 	fixedHandle = OS.g_object_new (display.gtk_fixed_get_type (), 0);
 	if (fixedHandle == 0) error (SWT.ERROR_NO_HANDLES);
-	GTK.gtk_widget_set_has_window (fixedHandle, true);
+	gtk_widget_set_has_surface_or_window (fixedHandle, true);
 	handle = gtk_box_new (GTK.GTK_ORIENTATION_VERTICAL, false, 0);
 	if (handle == 0) error (SWT.ERROR_NO_HANDLES);
 	if ((style & SWT.V_SCROLL) != 0) {
@@ -144,22 +144,16 @@ void createHandle (int index) {
 		if (scrolledHandle == 0) error (SWT.ERROR_NO_HANDLES);
 		GTK.gtk_scrolled_window_set_policy (scrolledHandle, GTK.GTK_POLICY_NEVER, GTK.GTK_POLICY_AUTOMATIC);
 		GTK.gtk_container_add (fixedHandle, scrolledHandle);
-		if (GTK.GTK_VERSION < OS.VERSION(3, 8, 0)) {
-			GTK.gtk_scrolled_window_add_with_viewport (scrolledHandle, handle);
-		} else {
-			GTK.gtk_container_add(scrolledHandle, handle);
-		}
-		long /*int*/ viewport = GTK.gtk_bin_get_child (scrolledHandle);
+		GTK.gtk_container_add(scrolledHandle, handle);
+		long viewport = GTK.gtk_bin_get_child (scrolledHandle);
 		GTK.gtk_viewport_set_shadow_type (viewport, GTK.GTK_SHADOW_NONE);
 	} else {
 		GTK.gtk_container_add (fixedHandle, handle);
 	}
-	GTK.gtk_container_set_border_width (handle, 0);
+	gtk_container_set_border_width (handle, 0);
 	// In GTK 3 font description is inherited from parent widget which is not how SWT has always worked,
 	// reset to default font to get the usual behavior
-	if (GTK.GTK3) {
-		setFontDescription(defaultFont().handle);
-	}
+	setFontDescription(defaultFont().handle);
 }
 
 void createItem (ExpandItem item, int style, int index) {
@@ -196,12 +190,12 @@ void destroyItem (ExpandItem item) {
 }
 
 @Override
-long /*int*/ eventHandle () {
+long eventHandle () {
 	return fixedHandle;
 }
 
 @Override
-boolean forceFocus (long /*int*/ focusHandle) {
+boolean forceFocus (long focusHandle) {
 	if (lastFocus != null && lastFocus.setFocus ()) return true;
 	for (int i = 0; i < itemCount; i++) {
 		ExpandItem item = items [i];
@@ -315,19 +309,19 @@ int getSpacingInPixels () {
 }
 
 @Override
-long /*int*/ gtk_key_press_event (long /*int*/ widget, long /*int*/ event) {
+long gtk_key_press_event (long widget, long event) {
 	if (!hasFocus ()) return 0;
-	long /*int*/ result = super.gtk_key_press_event (widget, event);
+	long result = super.gtk_key_press_event (widget, event);
 	if (result != 0) return result;
 	int index = 0;
 	while (index < itemCount) {
 		if (items [index].hasFocus ()) break;
 		index++;
 	}
-	GdkEventKey gdkEvent = new GdkEventKey ();
-	OS.memmove (gdkEvent, event, GdkEventKey.sizeof);
+	int [] key = new int[1];
+	GDK.gdk_event_get_keyval(event, key);
 	boolean next = false;
-	switch (gdkEvent.keyval) {
+	switch (key[0]) {
 		case GDK.GDK_Up:
 		case GDK.GDK_Left: next = false; break;
 		case GDK.GDK_Down:
@@ -377,14 +371,14 @@ void layoutItems (int index, boolean setScrollbar) {
 }
 
 @Override
-long /*int*/ gtk_size_allocate (long /*int*/ widget, long /*int*/ allocation) {
-	long /*int*/ result = super.gtk_size_allocate (widget, allocation);
+long gtk_size_allocate (long widget, long allocation) {
+	long result = super.gtk_size_allocate (widget, allocation);
 	layoutItems (0, false);
 	return result;
 }
 
 @Override
-long /*int*/ parentingHandle () {
+long parentingHandle () {
 	return fixedHandle;
 }
 
@@ -446,7 +440,7 @@ void setWidgetBackground  () {
 }
 
 @Override
-void setFontDescription (long /*int*/ font) {
+void setFontDescription (long font) {
 	super.setFontDescription (font);
 	for (int i = 0; i < itemCount; i++) {
 		items[i].setFontDescription (font);
@@ -454,18 +448,8 @@ void setFontDescription (long /*int*/ font) {
 	layoutItems (0, true);
 }
 
-@Override
-void setForegroundGdkColor (GdkColor color) {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	super.setForegroundGdkColor (color);
-	for (int i = 0; i < itemCount; i++) {
-		items[i].setForegroundColor (color);
-	}
-}
-
 @Override
 void setForegroundGdkRGBA (GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
 	super.setForegroundGdkRGBA(rgba);
 	for (int i = 0; i < itemCount; i++) {
 		items[i].setForegroundRGBA (rgba);
@@ -489,7 +473,7 @@ void setScrollbar () {
 	ExpandItem item = items [itemCount - 1];
 	int maxHeight = item.y + getBandHeight () + spacing;
 	if (item.expanded) maxHeight += item.height;
-	long /*int*/ adjustmentHandle = GTK.gtk_scrolled_window_get_vadjustment (scrolledHandle);
+	long adjustmentHandle = GTK.gtk_scrolled_window_get_vadjustment (scrolledHandle);
 	GtkAdjustment adjustment = new GtkAdjustment ();
 	gtk_adjustment_get (adjustmentHandle, adjustment);
 	yCurrentScroll = (int)adjustment.value;
@@ -511,7 +495,7 @@ void setScrollbar () {
 	GTK.gtk_widget_get_allocation (fixedHandle, allocation);
 	int width = allocation.width - spacing * 2;
 	if (policy == GTK.GTK_POLICY_ALWAYS) {
-		long /*int*/ vHandle = 0;
+		long vHandle = 0;
 		vHandle = GTK.gtk_scrolled_window_get_vscrollbar (scrolledHandle);
 		GtkRequisition requisition = new GtkRequisition ();
 		gtk_widget_get_preferred_size (vHandle, requisition);
@@ -525,7 +509,7 @@ void setScrollbar () {
 }
 
 /**
- * Sets the receiver's spacing. Spacing specifies the number of pixels allocated around
+ * Sets the receiver's spacing. Spacing specifies the number of points allocated around
  * each item.
  *
  * @param spacing the spacing around each item
@@ -546,7 +530,7 @@ void setSpacingInPixels (int spacing) {
 	if (spacing == this.spacing) return;
 	this.spacing = spacing;
 	GTK.gtk_box_set_spacing (handle, spacing);
-	GTK.gtk_container_set_border_width (handle, spacing);
+	gtk_container_set_border_width (handle, spacing);
 }
 
 void showItem (ExpandItem item) {
