@@ -25,7 +25,6 @@ import org.eclipse.swt.internal.gtk.*;
  * Instances of this class represent a selectable
  * user interface object that displays a text with
  * links.
- * <p>
  * <dl>
  * <dt><b>Styles:</b></dt>
  * <dd>(none)</dd>
@@ -151,7 +150,7 @@ void createHandle(int index) {
 	state |= HANDLE | THEME_BACKGROUND;
 	handle = OS.g_object_new (display.gtk_fixed_get_type (), 0);
 	if (handle == 0) error (SWT.ERROR_NO_HANDLES);
-	GTK.gtk_widget_set_has_window (handle, true);
+	gtk_widget_set_has_surface_or_window (handle, true);
 	GTK.gtk_widget_set_can_focus (handle, true);
 	layout = new TextLayout (display);
 	disabledColor = new Color (display, LINK_DISABLED_FOREGROUND);
@@ -328,15 +327,20 @@ public String getText () {
 }
 
 @Override
-long /*int*/ gtk_button_press_event (long /*int*/ widget, long /*int*/ event) {
-	long /*int*/ result = super.gtk_button_press_event (widget, event);
+long gtk_button_press_event (long widget, long event) {
+	long result = super.gtk_button_press_event (widget, event);
 	if (result != 0) return result;
-	GdkEventButton gdkEvent = new GdkEventButton ();
-	OS.memmove (gdkEvent, event, GdkEventButton.sizeof);
-	if (gdkEvent.button == 1 && gdkEvent.type == GDK.GDK_BUTTON_PRESS) {
+	int eventType = GDK.gdk_event_get_event_type(event);
+	eventType = fixGdkEventTypeValues(eventType);
+	int [] eventButton = new int [1];
+	GDK.gdk_event_get_button(event, eventButton);
+	double [] eventX = new double [1];
+	double [] eventY = new double [1];
+	GDK.gdk_event_get_coords(event, eventX, eventY);
+	if (eventButton[0] == 1 && eventType == GDK.GDK_BUTTON_PRESS) {
 		if (focusIndex != -1) setFocus ();
-		int x = (int) gdkEvent.x;
-		int y = (int) gdkEvent.y;
+		int x = (int) eventX[0];
+		int y = (int) eventY[0];
 		if ((style & SWT.MIRRORED) != 0) x = getClientWidth () - x;
 		int offset = DPIUtil.autoScaleUp(layout.getOffset (x, y, null));
 		int oldSelectionX = selection.x;
@@ -368,15 +372,18 @@ long /*int*/ gtk_button_press_event (long /*int*/ widget, long /*int*/ event) {
 }
 
 @Override
-long /*int*/ gtk_button_release_event (long /*int*/ widget, long /*int*/ event) {
-	long /*int*/ result = super.gtk_button_release_event (widget, event);
+long gtk_button_release_event (long widget, long event) {
+	long result = super.gtk_button_release_event (widget, event);
 	if (result != 0) return result;
 	if (focusIndex == -1) return result;
-	GdkEventButton gdkEvent = new GdkEventButton ();
-	OS.memmove (gdkEvent, event, GdkEventButton.sizeof);
-	if (gdkEvent.button == 1) {
-		int x = (int) gdkEvent.x;
-		int y = (int) gdkEvent.y;
+	int [] eventButton = new int [1];
+	GDK.gdk_event_get_button(event, eventButton);
+	double [] eventX = new double [1];
+	double [] eventY = new double [1];
+	GDK.gdk_event_get_coords(event, eventX, eventY);
+	if (eventButton[0] == 1) {
+		int x = (int) eventX[0];
+		int y = (int) eventY[0];
 		if ((style & SWT.MIRRORED) != 0) x = getClientWidth () - x;
 		Rectangle [] rects = getRectanglesInPixels (focusIndex);
 		for (int i = 0; i < rects.length; i++) {
@@ -393,9 +400,9 @@ long /*int*/ gtk_button_release_event (long /*int*/ widget, long /*int*/ event)
 }
 
 @Override
-long /*int*/ gtk_draw (long /*int*/ widget, long /*int*/ cairo) {
+long gtk_draw (long widget, long cairo) {
 	if (GTK.GTK_VERSION >= OS.VERSION(3, 14, 0)) {
-		long /*int*/ context = GTK.gtk_widget_get_style_context(widget);
+		long context = GTK.gtk_widget_get_style_context(widget);
 		GtkAllocation allocation = new GtkAllocation();
 		GTK.gtk_widget_get_allocation (widget, allocation);
 		int width = (state & ZERO_WIDTH) != 0 ? 0 : allocation.width;
@@ -408,11 +415,10 @@ long /*int*/ gtk_draw (long /*int*/ widget, long /*int*/ cairo) {
 }
 
 @Override
-long /*int*/ gtk_event_after (long /*int*/ widget, long /*int*/ gdkEvent) {
-	long /*int*/ result = super.gtk_event_after (widget, gdkEvent);
-	GdkEvent event = new GdkEvent ();
-	OS.memmove (event, gdkEvent, GdkEvent.sizeof);
-	switch (event.type) {
+long gtk_event_after (long widget, long gdkEvent) {
+	long result = super.gtk_event_after (widget, gdkEvent);
+	int eventType = GDK.gdk_event_get_event_type(gdkEvent);
+	switch (eventType) {
 		case GDK.GDK_FOCUS_CHANGE:
 			redraw ();
 			break;
@@ -421,13 +427,13 @@ long /*int*/ gtk_event_after (long /*int*/ widget, long /*int*/ gdkEvent) {
 }
 
 @Override
-long /*int*/ gtk_key_press_event (long /*int*/ widget, long /*int*/ eventPtr) {
-	long /*int*/ result = super.gtk_key_press_event (widget, eventPtr);
+long gtk_key_press_event (long widget, long eventPtr) {
+	long result = super.gtk_key_press_event (widget, eventPtr);
 	if (result != 0) return result;
 	if (focusIndex == -1) return result;
-	GdkEventKey gdkEvent = new GdkEventKey ();
-	OS.memmove (gdkEvent, eventPtr, GdkEventKey.sizeof);
-	switch (gdkEvent.keyval) {
+	int [] key = new int[1];
+	GDK.gdk_event_get_keyval(eventPtr, key);
+	switch (key[0]) {
 		case GDK.GDK_Return:
 		case GDK.GDK_KP_Enter:
 		case GDK.GDK_space:
@@ -452,15 +458,18 @@ long /*int*/ gtk_key_press_event (long /*int*/ widget, long /*int*/ eventPtr) {
 }
 
 @Override
-long /*int*/ gtk_motion_notify_event (long /*int*/ widget, long /*int*/ event) {
-	long /*int*/ result = super.gtk_motion_notify_event (widget, event);
+long gtk_motion_notify_event (long widget, long event) {
+	long result = super.gtk_motion_notify_event (widget, event);
 	if (result != 0) return result;
-	GdkEventMotion gdkEvent = new GdkEventMotion ();
-	OS.memmove (gdkEvent, event, GdkEventMotion.sizeof);
-	int x = (int) gdkEvent.x;
-	int y = (int) gdkEvent.y;
+	double [] eventX = new double [1];
+	double [] eventY = new double [1];
+	GDK.gdk_event_get_coords(event, eventX, eventY);
+	int x = (int) eventX[0];
+	int y = (int) eventY[0];
+	int [] state = new int [1];
+	GDK.gdk_event_get_state(event, state);
 	if ((style & SWT.MIRRORED) != 0) x = getClientWidth () - x;
-	if ((gdkEvent.state & GDK.GDK_BUTTON1_MASK) != 0) {
+	if ((state[0] & GDK.GDK_BUTTON1_MASK) != 0) {
 		int oldSelection = selection.y;
 		selection.y = DPIUtil.autoScaleUp(layout.getOffset (x, y, null));
 		if (selection.y != oldSelection) {
@@ -736,7 +745,7 @@ int setBounds(int x, int y, int width, int height, boolean move, boolean resize)
 }
 
 @Override
-void setFontDescription (long /*int*/ font) {
+void setFontDescription (long font) {
 	super.setFontDescription (font);
 	layout.setFont (Font.gtk_new (display, font));
 }
@@ -774,9 +783,9 @@ public void setLinkForeground (Color color) {
 
 @Override
 void setOrientation (boolean create) {
-    super.setOrientation (create);
-    layout.setOrientation (style & (SWT.LEFT_TO_RIGHT | SWT.RIGHT_TO_LEFT));
-    if (!create) redraw (true);
+	super.setOrientation (create);
+	layout.setOrientation (style & (SWT.LEFT_TO_RIGHT | SWT.RIGHT_TO_LEFT));
+	if (!create) redraw (true);
 }
 
 /**
@@ -791,7 +800,7 @@ void setOrientation (boolean create) {
  * HREF attribute can be used to distinguish between them.  The string may
  * include the mnemonic character and line delimiters. The only delimiter
  * the HREF attribute supports is the quotation mark ("). Text containing
- * angle-bracket characters &lt or &gt may be escaped using \\, however
+ * angle-bracket characters &lt; or &gt; may be escaped using \\, however
  * this operation is a hint and varies from platform to platform.
  * </p>
  * <p>
@@ -861,7 +870,7 @@ void styleLinkParts() {
 }
 
 @Override
-int traversalCode (int key, GdkEventKey event) {
+int traversalCode(int key, long event) {
 	if (offsets.length == 0) return 0;
 	int bits = super.traversalCode (key, event);
 	if (key == GDK.GDK_Tab && focusIndex < offsets.length - 1) {
