@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -44,7 +44,7 @@ import org.eclipse.swt.internal.gtk.*;
 public class Sash extends Control {
 	boolean dragging;
 	int startX, startY, lastX, lastY;
-	long /*int*/ defaultCursor;
+	long defaultCursor;
 
 	private final static int INCREMENT = 1;
 	private final static int PAGE_INCREMENT = 9;
@@ -143,47 +143,51 @@ void createHandle (int index) {
 	state |= HANDLE | THEME_BACKGROUND;
 	handle = OS.g_object_new (display.gtk_fixed_get_type (), 0);
 	if (handle == 0) error (SWT.ERROR_NO_HANDLES);
-	GTK.gtk_widget_set_has_window (handle, true);
+	gtk_widget_set_has_surface_or_window (handle, true);
 	GTK.gtk_widget_set_can_focus (handle, true);
-	int type = (style & SWT.VERTICAL) != 0 ? GDK.GDK_SB_H_DOUBLE_ARROW : GDK.GDK_SB_V_DOUBLE_ARROW;
-	defaultCursor = GDK.gdk_cursor_new_for_display (GDK.gdk_display_get_default(), type);
+	if ((style & SWT.VERTICAL) != 0) {
+		if (GTK.GTK4) {
+			byte [] name = Converter.wcsToMbcs("w-resize", true);
+			defaultCursor = GDK.gdk_cursor_new_from_name(name, 0);
+		} else {
+			defaultCursor = GDK.gdk_cursor_new_for_display (GDK.gdk_display_get_default(), GDK.GDK_SB_H_DOUBLE_ARROW);
+		}
+	} else {
+		if (GTK.GTK4) {
+			byte [] name = Converter.wcsToMbcs("ns-resize", true);
+			defaultCursor = GDK.gdk_cursor_new_from_name(name, 0);
+		} else {
+			defaultCursor = GDK.gdk_cursor_new_for_display (GDK.gdk_display_get_default(), GDK.GDK_SB_V_DOUBLE_ARROW);
+		}
+	}
 }
 
 void drawBand (int x, int y, int width, int height) {
 	if ((style & SWT.SMOOTH) != 0) return;
-	long /*int*/ window = gtk_widget_get_window (parent.paintHandle());
-	if (window == 0) return;
-	byte [] bits = {-86, 85, -86, 85, -86, 85, -86, 85};
-	long /*int*/ stipplePixmap = GDK.gdk_bitmap_create_from_data (window, bits, 8, 8);
-	long /*int*/ gc = GDK.gdk_gc_new (window);
-	long /*int*/ colormap = GDK.gdk_colormap_get_system();
-	GdkColor color = new GdkColor ();
-	GDK.gdk_color_white (colormap, color);
-	GDK.gdk_gc_set_foreground (gc, color);
-	GDK.gdk_gc_set_stipple (gc, stipplePixmap);
-	GDK.gdk_gc_set_subwindow (gc, GDK.GDK_INCLUDE_INFERIORS);
-	GDK.gdk_gc_set_fill (gc, GDK.GDK_STIPPLED);
-	GDK.gdk_gc_set_function (gc, GDK.GDK_XOR);
-	GDK.gdk_draw_rectangle (window, gc, 1, x, y, width, height);
-	OS.g_object_unref (stipplePixmap);
-	OS.g_object_unref (gc);
 }
 
 @Override
-long /*int*/ gtk_button_press_event (long /*int*/ widget, long /*int*/ eventPtr) {
-	long /*int*/ result = super.gtk_button_press_event (widget, eventPtr);
+long gtk_button_press_event (long widget, long event) {
+	long result = super.gtk_button_press_event (widget, event);
 	if (result != 0) return result;
-	GdkEventButton gdkEvent = new GdkEventButton ();
-	OS.memmove (gdkEvent, eventPtr, GdkEventButton.sizeof);
-	int button = gdkEvent.button;
+	// Event fields
+	int [] eventButton = new int [1];
+	GDK.gdk_event_get_button(event, eventButton);
+	int eventType = GDK.gdk_event_get_event_type(event);
+	double [] eventRX = new double [1];
+	double [] eventRY = new double [1];
+	GDK.gdk_event_get_root_coords(event, eventRX, eventRY);
+	int eventTime = GDK.gdk_event_get_time(event);
+
+	int button = eventButton[0];
 	if (button != 1) return 0;
-	if (gdkEvent.type == GDK.GDK_2BUTTON_PRESS) return 0;
-	if (gdkEvent.type == GDK.GDK_3BUTTON_PRESS) return 0;
-	long /*int*/ window = gtk_widget_get_window (widget);
+	if (eventType == GDK.GDK_2BUTTON_PRESS) return 0;
+	if (eventType == GDK.GDK_3BUTTON_PRESS) return 0;
+	long window = gtk_widget_get_window (widget);
 	int [] origin_x = new int [1], origin_y = new int [1];
 	GDK.gdk_window_get_origin (window, origin_x, origin_y);
-	startX = (int) (gdkEvent.x_root - origin_x [0]);
-	startY = (int) (gdkEvent.y_root - origin_y [0]);
+	startX = (int) (eventRX[0] - origin_x [0]);
+	startY = (int) (eventRY[0] - origin_y [0]);
 	GtkAllocation allocation = new GtkAllocation ();
 	GTK.gtk_widget_get_allocation(handle, allocation);
 	int x = allocation.x;
@@ -192,19 +196,19 @@ long /*int*/ gtk_button_press_event (long /*int*/ widget, long /*int*/ eventPtr)
 	int height = allocation.height;
 	lastX = x;
 	lastY = y;
-	Event event = new Event ();
-	event.time = gdkEvent.time;
+	Event jEvent = new Event ();
+	jEvent.time = eventTime;
 	Rectangle eventRect = new Rectangle (lastX, lastY, width, height);
-	event.setBounds (DPIUtil.autoScaleDown (eventRect));
+	jEvent.setBounds (DPIUtil.autoScaleDown (eventRect));
 	if ((style & SWT.SMOOTH) == 0) {
-		event.detail = SWT.DRAG;
+		jEvent.detail = SWT.DRAG;
 	}
-	if ((parent.style & SWT.MIRRORED) != 0) event.x = DPIUtil.autoScaleDown (parent.getClientWidth () - width) - event.x;
-	sendSelectionEvent (SWT.Selection, event, true);
+	if ((parent.style & SWT.MIRRORED) != 0) jEvent.x = DPIUtil.autoScaleDown (parent.getClientWidth () - width) - jEvent.x;
+	sendSelectionEvent (SWT.Selection, jEvent, true);
 	if (isDisposed ()) return 0;
-	if (event.doit) {
+	if (jEvent.doit) {
 		dragging = true;
-		Rectangle rect = DPIUtil.autoScaleUp (event.getBounds ());
+		Rectangle rect = DPIUtil.autoScaleUp (jEvent.getBounds ());
 		lastX = rect.x;
 		lastY = rect.y;
 		if ((parent.style & SWT.MIRRORED) != 0) lastX = parent.getClientWidth () - width - lastX;
@@ -219,12 +223,13 @@ long /*int*/ gtk_button_press_event (long /*int*/ widget, long /*int*/ eventPtr)
 }
 
 @Override
-long /*int*/ gtk_button_release_event (long /*int*/ widget, long /*int*/ eventPtr) {
-	long /*int*/ result = super.gtk_button_release_event (widget, eventPtr);
+long gtk_button_release_event (long widget, long event) {
+	long result = super.gtk_button_release_event (widget, event);
 	if (result != 0) return result;
-	GdkEventButton gdkEvent = new GdkEventButton ();
-	OS.memmove (gdkEvent, eventPtr, GdkEventButton.sizeof);
-	int button = gdkEvent.button;
+	int [] eventButton = new int [1];
+	GDK.gdk_event_get_button(event, eventButton);
+	int eventTime = GDK.gdk_event_get_time(event);
+	int button = eventButton[0];
 	if (button != 1) return 0;
 	if (!dragging) return 0;
 	dragging = false;
@@ -232,17 +237,17 @@ long /*int*/ gtk_button_release_event (long /*int*/ widget, long /*int*/ eventPt
 	GTK.gtk_widget_get_allocation (handle, allocation);
 	int width = allocation.width;
 	int height = allocation.height;
-	Event event = new Event ();
-	event.time = gdkEvent.time;
+	Event jEvent = new Event ();
+	jEvent.time = eventTime;
 	Rectangle eventRect = new Rectangle (lastX, lastY, width, height);
-	event.setBounds (DPIUtil.autoScaleDown (eventRect));
+	jEvent.setBounds (DPIUtil.autoScaleDown (eventRect));
 	drawBand (lastX, lastY, width, height);
-	if ((parent.style & SWT.MIRRORED) != 0) event.x = DPIUtil.autoScaleDown (parent.getClientWidth () - width) - event.x;
-	sendSelectionEvent (SWT.Selection, event, true);
+	if ((parent.style & SWT.MIRRORED) != 0) jEvent.x = DPIUtil.autoScaleDown (parent.getClientWidth () - width) - jEvent.x;
+	sendSelectionEvent (SWT.Selection, jEvent, true);
 	if (isDisposed ()) return result;
-	if (event.doit) {
+	if (jEvent.doit) {
 		if ((style & SWT.SMOOTH) != 0) {
-			Rectangle rect = DPIUtil.autoScaleUp (event.getBounds ());
+			Rectangle rect = DPIUtil.autoScaleUp (jEvent.getBounds ());
 			setBoundsInPixels (rect.x, rect.y, width, height);
 			// widget could be disposed at this point
 		}
@@ -251,9 +256,9 @@ long /*int*/ gtk_button_release_event (long /*int*/ widget, long /*int*/ eventPt
 }
 
 @Override
-long /*int*/ gtk_draw (long /*int*/ widget, long /*int*/ cairo) {
+long gtk_draw (long widget, long cairo) {
 	if (GTK.GTK_VERSION >= OS.VERSION(3, 14, 0)) {
-		long /*int*/ context = GTK.gtk_widget_get_style_context(widget);
+		long context = GTK.gtk_widget_get_style_context(widget);
 		GtkAllocation allocation = new GtkAllocation();
 		GTK.gtk_widget_get_allocation (widget, allocation);
 		int width = (state & ZERO_WIDTH) != 0 ? 0 : allocation.width;
@@ -266,8 +271,8 @@ long /*int*/ gtk_draw (long /*int*/ widget, long /*int*/ cairo) {
 }
 
 @Override
-long /*int*/ gtk_focus_in_event (long /*int*/ widget, long /*int*/ event) {
-	long /*int*/ result = super.gtk_focus_in_event (widget, event);
+long gtk_focus_in_event (long widget, long event) {
+	long result = super.gtk_focus_in_event (widget, event);
 	if (result != 0) return result;
 	// widget could be disposed at this point
 	if (handle != 0) {
@@ -280,26 +285,27 @@ long /*int*/ gtk_focus_in_event (long /*int*/ widget, long /*int*/ event) {
 }
 
 @Override
-long /*int*/ gtk_key_press_event (long /*int*/ widget, long /*int*/ eventPtr) {
-	long /*int*/ result = super.gtk_key_press_event (widget, eventPtr);
+long gtk_key_press_event (long widget, long eventPtr) {
+	long result = super.gtk_key_press_event (widget, eventPtr);
 	if (result != 0) return result;
-	GdkEventKey gdkEvent = new GdkEventKey ();
-	OS.memmove (gdkEvent, eventPtr, GdkEventKey.sizeof);
-	int keyval = gdkEvent.keyval;
-	switch (keyval) {
+	int [] key = new int[1];
+	GDK.gdk_event_get_keyval(eventPtr, key);
+	int [] state = new int[1];
+	GDK.gdk_event_get_state(eventPtr, state);
+	switch (key[0]) {
 		case GDK.GDK_Left:
 		case GDK.GDK_Right:
 		case GDK.GDK_Up:
 		case GDK.GDK_Down:
 			int xChange = 0, yChange = 0;
 			int stepSize = PAGE_INCREMENT;
-			if ((gdkEvent.state & GDK.GDK_CONTROL_MASK) != 0) stepSize = INCREMENT;
+			if ((state[0] & GDK.GDK_CONTROL_MASK) != 0) stepSize = INCREMENT;
 			if ((style & SWT.VERTICAL) != 0) {
-				if (keyval == GDK.GDK_Up || keyval == GDK.GDK_Down) break;
-				xChange = keyval == GDK.GDK_Left ? -stepSize : stepSize;
+				if (key[0] == GDK.GDK_Up || key[0] == GDK.GDK_Down) break;
+				xChange = key[0] == GDK.GDK_Left ? -stepSize : stepSize;
 			} else {
-				if (keyval == GDK.GDK_Left ||keyval == GDK.GDK_Right) break;
-				yChange = keyval == GDK.GDK_Up ? -stepSize : stepSize;
+				if (key[0] == GDK.GDK_Left ||key[0] == GDK.GDK_Right) break;
+				yChange = key[0] == GDK.GDK_Up ? -stepSize : stepSize;
 			}
 			int parentBorder = 0;
 			GtkAllocation allocation = new GtkAllocation ();
@@ -318,19 +324,19 @@ long /*int*/ gtk_key_press_event (long /*int*/ widget, long /*int*/ eventPtr) {
 			if (newX == lastX && newY == lastY) return result;
 
 			/* Ensure that the pointer image does not change */
-			long /*int*/ window = gtk_widget_get_window (handle);
+			long gdkResource = GTK.GTK4? gtk_widget_get_surface (handle) : gtk_widget_get_window (handle);
 			int grabMask = GDK.GDK_POINTER_MOTION_MASK | GDK.GDK_BUTTON_RELEASE_MASK;
-			long /*int*/ gdkCursor = cursor != null ? cursor.handle : defaultCursor;
-			int ptrGrabResult = gdk_pointer_grab (window, GDK.GDK_OWNERSHIP_NONE, false, grabMask, window, gdkCursor, GDK.GDK_CURRENT_TIME);
+			long gdkCursor = cursor != null ? cursor.handle : defaultCursor;
+			int ptrGrabResult = gdk_pointer_grab (gdkResource, GDK.GDK_OWNERSHIP_NONE, false, grabMask, gdkResource, gdkCursor, GDK.GDK_CURRENT_TIME);
 
 			/* The event must be sent because its doit flag is used. */
 			Event event = new Event ();
-			event.time = gdkEvent.time;
+			event.time = GDK.gdk_event_get_time(eventPtr);
 			Rectangle eventRect = new Rectangle (newX, newY, width, height);
 			event.setBounds (DPIUtil.autoScaleDown (eventRect));
 			if ((parent.style & SWT.MIRRORED) != 0) event.x = DPIUtil.autoScaleDown (parent.getClientWidth () - width) - event.x;
 			sendSelectionEvent (SWT.Selection, event, true);
-			if (ptrGrabResult == GDK.GDK_GRAB_SUCCESS) gdk_pointer_ungrab (window, GDK.GDK_CURRENT_TIME);
+			if (ptrGrabResult == GDK.GDK_GRAB_SUCCESS) gdk_pointer_ungrab (gdkResource, GDK.GDK_CURRENT_TIME);
 			if (isDisposed ()) break;
 
 			if (event.doit) {
@@ -357,25 +363,41 @@ long /*int*/ gtk_key_press_event (long /*int*/ widget, long /*int*/ eventPtr) {
 }
 
 @Override
-long /*int*/ gtk_motion_notify_event (long /*int*/ widget, long /*int*/ eventPtr) {
-	long /*int*/ result = super.gtk_motion_notify_event (widget, eventPtr);
+long gtk_motion_notify_event (long widget, long eventPtr) {
+	long result = super.gtk_motion_notify_event (widget, eventPtr);
 	if (result != 0) return result;
 	if (!dragging) return 0;
-	GdkEventMotion gdkEvent = new GdkEventMotion ();
-	OS.memmove (gdkEvent, eventPtr, GdkEventButton.sizeof);
 	int eventX, eventY, eventState;
-	if (gdkEvent.is_hint != 0) {
+	double [] fetchedX = new double [1];
+	double [] fetchedY = new double [1];
+	GDK.gdk_event_get_root_coords(eventPtr, fetchedX, fetchedY);
+	int [] state = new int [1];
+	GDK.gdk_event_get_state(eventPtr, state);
+	long gdkResource = gdk_event_get_surface_or_window(eventPtr);
+	boolean isHint;
+	if (GTK.GTK4) {
+		isHint = false;
+	} else {
+		GdkEventMotion gdkEvent = new GdkEventMotion ();
+		OS.memmove(gdkEvent, eventPtr, GdkEventMotion.sizeof);
+		isHint = gdkEvent.is_hint != 0;
+	}
+	if (isHint) {
 		int [] pointer_x = new int [1], pointer_y = new int [1], mask = new int [1];
-		gdk_window_get_device_position (gdkEvent.window, pointer_x, pointer_y, mask);
+		display.gdk_window_get_device_position (gdkResource, pointer_x, pointer_y, mask);
 		eventX = pointer_x [0];
 		eventY = pointer_y [0];
 		eventState = mask [0];
 	} else {
 		int [] origin_x = new int [1], origin_y = new int [1];
-		GDK.gdk_window_get_origin (gdkEvent.window, origin_x, origin_y);
-		eventX = (int) (gdkEvent.x_root - origin_x [0]);
-		eventY = (int) (gdkEvent.y_root - origin_y [0]);
-		eventState = gdkEvent.state;
+		if (GTK.GTK4) {
+			GDK.gdk_surface_get_origin(gdkResource, origin_x, origin_y);
+		} else {
+			GDK.gdk_window_get_origin (gdkResource, origin_x, origin_y);
+		}
+		eventX = (int) (fetchedX[0] - origin_x [0]);
+		eventY = (int) (fetchedY[0] - origin_y [0]);
+		eventState = state[0];
 	}
 	if ((eventState & GDK.GDK_BUTTON1_MASK) == 0) return 0;
 	GtkAllocation allocation = new GtkAllocation ();
@@ -398,7 +420,7 @@ long /*int*/ gtk_motion_notify_event (long /*int*/ widget, long /*int*/ eventPtr
 	drawBand (lastX, lastY, width, height);
 
 	Event event = new Event ();
-	event.time = gdkEvent.time;
+	event.time = GDK.gdk_event_get_time(eventPtr);
 	Rectangle eventRect = new Rectangle (newX, newY, width, height);
 	event.setBounds (DPIUtil.autoScaleDown (eventRect));
 	if ((style & SWT.SMOOTH) == 0) {
@@ -427,7 +449,7 @@ long /*int*/ gtk_motion_notify_event (long /*int*/ widget, long /*int*/ eventPtr
 }
 
 @Override
-long /*int*/ gtk_realize (long /*int*/ widget) {
+long gtk_realize (long widget) {
 	setCursor (cursor != null ? cursor.handle : 0);
 	return super.gtk_realize (widget);
 }
@@ -441,7 +463,7 @@ void hookEvents () {
 @Override
 void releaseWidget () {
 	super.releaseWidget ();
-	if (defaultCursor != 0) gdk_cursor_unref (defaultCursor);
+	if (defaultCursor != 0) OS.g_object_unref (defaultCursor);
 	defaultCursor = 0;
 }
 
@@ -471,12 +493,12 @@ public void removeSelectionListener(SelectionListener listener) {
 }
 
 @Override
-void setCursor (long /*int*/ cursor) {
+void setCursor (long cursor) {
 	super.setCursor (cursor != 0 ? cursor : defaultCursor);
 }
 
 @Override
-int traversalCode (int key, GdkEventKey event) {
+int traversalCode (int key, long event) {
 	return 0;
 }
 
