@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -31,7 +31,7 @@ import org.eclipse.swt.internal.gtk.*;
  * </dl>
  * <p>
  * Note: Only one of the styles HORIZONTAL and VERTICAL may be specified.
- * </p><p>
+ * </p>
  * <p>
  * IMPORTANT: This class is <em>not</em> intended to be subclassed.
  * </p>
@@ -130,13 +130,13 @@ void createHandle (int index) {
 	state |= HANDLE | THEME_BACKGROUND;
 	fixedHandle = OS.g_object_new (display.gtk_fixed_get_type (), 0);
 	if (fixedHandle == 0) error (SWT.ERROR_NO_HANDLES);
-	GTK.gtk_widget_set_has_window (fixedHandle, true);
-	long /*int*/ hAdjustment = GTK.gtk_adjustment_new (0, 0, 100, 1, 10, 0);
+	gtk_widget_set_has_surface_or_window (fixedHandle, true);
+	long hAdjustment = GTK.gtk_adjustment_new (0, 0, 100, 1, 10, 0);
 	if (hAdjustment == 0) error (SWT.ERROR_NO_HANDLES);
 	if ((style & SWT.HORIZONTAL) != 0) {
-		handle = gtk_scale_new (GTK.GTK_ORIENTATION_HORIZONTAL, hAdjustment);
+		handle = GTK.gtk_scale_new (GTK.GTK_ORIENTATION_HORIZONTAL, hAdjustment);
 	} else {
-		handle = gtk_scale_new (GTK.GTK_ORIENTATION_VERTICAL, hAdjustment);
+		handle = GTK.gtk_scale_new (GTK.GTK_ORIENTATION_VERTICAL, hAdjustment);
 	}
 	if (handle == 0) error (SWT.ERROR_NO_HANDLES);
 	GTK.gtk_container_add (fixedHandle, handle);
@@ -164,7 +164,7 @@ void hookEvents () {
  */
 public int getIncrement () {
 	checkWidget ();
-	long /*int*/ hAdjustment = GTK.gtk_range_get_adjustment (handle);
+	long hAdjustment = GTK.gtk_range_get_adjustment (handle);
 	return (int) GTK.gtk_adjustment_get_step_increment (hAdjustment);
 }
 
@@ -180,7 +180,7 @@ public int getIncrement () {
  */
 public int getMaximum () {
 	checkWidget ();
-	long /*int*/ hAdjustment = GTK.gtk_range_get_adjustment (handle);
+	long hAdjustment = GTK.gtk_range_get_adjustment (handle);
 	return (int) GTK.gtk_adjustment_get_upper (hAdjustment);
 }
 
@@ -196,7 +196,7 @@ public int getMaximum () {
  */
 public int getMinimum () {
 	checkWidget ();
-	long /*int*/ hAdjustment = GTK.gtk_range_get_adjustment (handle);
+	long hAdjustment = GTK.gtk_range_get_adjustment (handle);
 	return (int) GTK.gtk_adjustment_get_lower (hAdjustment);
 }
 
@@ -214,7 +214,7 @@ public int getMinimum () {
  */
 public int getPageIncrement () {
 	checkWidget ();
-	long /*int*/ hAdjustment = GTK.gtk_range_get_adjustment (handle);
+	long hAdjustment = GTK.gtk_range_get_adjustment (handle);
 	return (int) GTK.gtk_adjustment_get_page_increment (hAdjustment);
 }
 
@@ -230,12 +230,12 @@ public int getPageIncrement () {
  */
 public int getSelection () {
 	checkWidget ();
-	long /*int*/ hAdjustment = GTK.gtk_range_get_adjustment (handle);
+	long hAdjustment = GTK.gtk_range_get_adjustment (handle);
 	return (int) GTK.gtk_adjustment_get_value (hAdjustment);
 }
 
 @Override
-long /*int*/ gtk_value_changed (long /*int*/ adjustment) {
+long gtk_value_changed (long adjustment) {
 	sendSelectionEvent  (SWT.Selection);
 	return 0;
 }
@@ -370,22 +370,8 @@ public void setSelection (int value) {
 	OS.g_signal_handlers_unblock_matched (handle, OS.G_SIGNAL_MATCH_DATA, 0, 0, 0, 0, VALUE_CHANGED);
 }
 
-long /*int*/ gtk_scale_new (int orientation, long /*int*/ adjustment) {
-	long /*int*/ scale = 0;
-	if (GTK.GTK3)	{
-		scale = GTK.gtk_scale_new (orientation, adjustment);
-	} else {
-		if (orientation == GTK.GTK_ORIENTATION_HORIZONTAL) {
-			scale = GTK.gtk_hscale_new (adjustment);
-		} else {
-			scale = GTK.gtk_vscale_new (adjustment);
-		}
-	}
-	return scale;
-}
-
 @Override
-Point resizeCalculationsGTK3(long /*int*/ widget, int width, int height) {
+Point resizeCalculationsGTK3(long widget, int width, int height) {
 	Point size = super.resizeCalculationsGTK3(widget, width, height);
 	/*
 	 * Bug 534204: (GTK 3.22) Scale with GridLayout height hint has no line
