@@ -30,7 +30,7 @@ import org.eclipse.swt.internal.gtk.*;
  * values the scroll bar represents (that is, between its
  * <em>minimum</em> and <em>maximum</em> values).
  * </p><p>
- * Typically, scroll bars will be made up of five areas:
+ * Typically, scroll bars will be made up of five areas:</p>
  * <ol>
  * <li>an arrow button for decrementing the value</li>
  * <li>a page decrement area for decrementing the value by a larger amount</li>
@@ -38,6 +38,7 @@ import org.eclipse.swt.internal.gtk.*;
  * <li>a page increment area for incrementing the value by a larger amount</li>
  * <li>an arrow button for incrementing the value</li>
  * </ol>
+ * <p>
  * Based on their style, scroll bars are either <code>HORIZONTAL</code>
  * (which have a left facing button for decrementing the value and a
  * right facing button for incrementing it) or <code>VERTICAL</code>
@@ -88,7 +89,7 @@ import org.eclipse.swt.internal.gtk.*;
  */
 public class ScrollBar extends Widget {
 	Scrollable parent;
-	long /*int*/ adjustmentHandle;
+	long adjustmentHandle;
 	int detail;
 	boolean dragSent;
 
@@ -362,14 +363,25 @@ Rectangle getThumbBoundsInPixels () {
 	}
 	Rectangle rect = new Rectangle(x, y, width, height);
 	int [] origin_x = new int [1], origin_y = new int [1];
-	long /*int*/ window = gtk_widget_get_window (parent.scrolledHandle);
-	if (window != 0) GDK.gdk_window_get_origin (window, origin_x, origin_y);
-	rect.x += origin_x [0];
-	rect.y += origin_y [0];
-	window = gtk_widget_get_window (parent.handle);
-	if (window != 0) GDK.gdk_window_get_origin (window, origin_x, origin_y);
-	rect.x -= origin_x [0];
-	rect.y -= origin_y [0];
+	if (GTK.GTK4) {
+		long surface = gtk_widget_get_surface (parent.scrolledHandle);
+		if (surface != 0) GDK.gdk_surface_get_origin (surface, origin_x, origin_y);
+		rect.x += origin_x [0];
+		rect.y += origin_y [0];
+		surface = gtk_widget_get_surface (parent.handle);
+		if (surface != 0) GDK.gdk_surface_get_origin (surface, origin_x, origin_y);
+		rect.x -= origin_x [0];
+		rect.y -= origin_y [0];
+	} else {
+		long window = gtk_widget_get_window (parent.scrolledHandle);
+		if (window != 0) GDK.gdk_window_get_origin (window, origin_x, origin_y);
+		rect.x += origin_x [0];
+		rect.y += origin_y [0];
+		window = gtk_widget_get_window (parent.handle);
+		if (window != 0) GDK.gdk_window_get_origin (window, origin_x, origin_y);
+		rect.x -= origin_x [0];
+		rect.y -= origin_y [0];
+	}
 	return rect;
 }
 
@@ -396,14 +408,21 @@ Rectangle getThumbTrackBoundsInPixels () {
 	checkWidget();
 	int x = 0, y = 0, width, height;
 	int[] has_stepper = new int[1];
-	GTK.gtk_widget_style_get (handle, OS.has_backward_stepper, has_stepper, 0);
-	boolean hasB = has_stepper[0] != 0;
-	GTK.gtk_widget_style_get (handle, OS.has_secondary_backward_stepper, has_stepper, 0);
-	boolean hasB2 = has_stepper[0] != 0;
-	GTK.gtk_widget_style_get (handle, OS.has_forward_stepper, has_stepper, 0);
-	boolean hasF = has_stepper[0] != 0;
-	GTK.gtk_widget_style_get (handle, OS.has_secondary_forward_stepper, has_stepper, 0);
-	boolean hasF2 = has_stepper[0] != 0;
+	boolean hasB = false, hasB2 = false, hasF = false, hasF2 = false;
+	/*
+	 * Only GTK3 scrollbars have steppers, even non-overlay scrollbars in
+	 * GTK4 do not have steppers.
+	 */
+	if (!GTK.GTK4) {
+		GTK.gtk_widget_style_get (handle, OS.has_backward_stepper, has_stepper, 0);
+		hasB = has_stepper[0] != 0;
+		GTK.gtk_widget_style_get (handle, OS.has_secondary_backward_stepper, has_stepper, 0);
+		hasB2 = has_stepper[0] != 0;
+		GTK.gtk_widget_style_get (handle, OS.has_forward_stepper, has_stepper, 0);
+		hasF = has_stepper[0] != 0;
+		GTK.gtk_widget_style_get (handle, OS.has_secondary_forward_stepper, has_stepper, 0);
+		hasF2 = has_stepper[0] != 0;
+	}
 	GtkAllocation allocation = new GtkAllocation ();
 	GTK.gtk_widget_get_allocation (handle, allocation);
 	if ((style & SWT.VERTICAL) != 0) {
@@ -439,14 +458,25 @@ Rectangle getThumbTrackBoundsInPixels () {
 	}
 	Rectangle rect = new Rectangle(x, y, width, height);
 	int [] origin_x = new int [1], origin_y = new int [1];
-	long /*int*/ window = gtk_widget_get_window (parent.scrolledHandle);
-	if (window != 0) GDK.gdk_window_get_origin (window, origin_x, origin_y);
-	rect.x += origin_x [0];
-	rect.y += origin_y [0];
-	window = gtk_widget_get_window (parent.handle);
-	if (window != 0) GDK.gdk_window_get_origin (window, origin_x, origin_y);
-	rect.x -= origin_x [0];
-	rect.y -= origin_y [0];
+	if (GTK.GTK4) {
+		long surface = gtk_widget_get_surface (parent.scrolledHandle);
+		if (surface != 0) GDK.gdk_surface_get_origin (surface, origin_x, origin_y);
+		rect.x += origin_x [0];
+		rect.y += origin_y [0];
+		surface = gtk_widget_get_surface (parent.handle);
+		if (surface != 0) GDK.gdk_surface_get_origin (surface, origin_x, origin_y);
+		rect.x -= origin_x [0];
+		rect.y -= origin_y [0];
+	} else {
+		long window = gtk_widget_get_window (parent.scrolledHandle);
+		if (window != 0) GDK.gdk_window_get_origin (window, origin_x, origin_y);
+		rect.x += origin_x [0];
+		rect.y += origin_y [0];
+		window = gtk_widget_get_window (parent.handle);
+		if (window != 0) GDK.gdk_window_get_origin (window, origin_x, origin_y);
+		rect.x -= origin_x [0];
+		rect.y -= origin_y [0];
+	}
 	return rect;
 }
 
@@ -469,7 +499,7 @@ Rectangle getThumbTrackBoundsInPixels () {
  */
 public boolean getVisible () {
 	checkWidget ();
-	long /*int*/ scrolledHandle = parent.scrolledHandle;
+	long scrolledHandle = parent.scrolledHandle;
 	int [] hsp = new int [1], vsp = new int [1];
 	GTK.gtk_scrolled_window_get_policy (scrolledHandle, hsp, vsp);
 	if ((style & SWT.HORIZONTAL) != 0) {
@@ -480,8 +510,23 @@ public boolean getVisible () {
 }
 
 @Override
-long /*int*/ gtk_button_press_event (long /*int*/ widget, long /*int*/ eventPtr) {
-	long /*int*/ result = super.gtk_button_press_event (widget, eventPtr);
+long gtk_event (long widget, long event) {
+	if (!GTK.GTK4) return 0;
+	int eventType = GDK.gdk_event_get_event_type(event);
+	switch (eventType) {
+		case GDK.GDK4_BUTTON_PRESS: {
+			return gtk_button_press_event(widget, event);
+		}
+		case GDK.GDK4_BUTTON_RELEASE: {
+			return gtk_button_release_event(widget, event);
+		}
+	}
+	return 0;
+}
+
+@Override
+long gtk_button_press_event (long widget, long eventPtr) {
+	long result = super.gtk_button_press_event (widget, eventPtr);
 	if (result != 0) return result;
 	detail = GTK.GTK_SCROLL_NONE;
 	dragSent = false;
@@ -489,17 +534,17 @@ long /*int*/ gtk_button_press_event (long /*int*/ widget, long /*int*/ eventPtr)
 }
 
 @Override
-long /*int*/ gtk_change_value (long /*int*/ widget, long /*int*/ scroll, long /*int*/ value1, long /*int*/ value2) {
-	detail = (int)/*64*/scroll;
+long gtk_change_value (long widget, long scroll, long value1, long value2) {
+	detail = (int)scroll;
 	return 0;
 }
 
-void gtk_range_get_slider_range (long /*int*/ widget, int [] slider_start, int [] slider_end) {
+void gtk_range_get_slider_range (long widget, int [] slider_start, int [] slider_end) {
 	GTK.gtk_range_get_slider_range (widget, slider_start, slider_end);
 }
 
 @Override
-long /*int*/ gtk_value_changed (long /*int*/ adjustment) {
+long gtk_value_changed (long adjustment) {
 	Event event = new Event ();
 	dragSent = detail == GTK.GTK_SCROLL_JUMP;
 	switch (detail) {
@@ -523,21 +568,19 @@ long /*int*/ gtk_value_changed (long /*int*/ adjustment) {
 	if (!dragSent) detail = GTK.GTK_SCROLL_NONE;
 	sendSelectionEvent (SWT.Selection, event, false);
 	parent.updateScrollBarValue (this);
-	if (GTK.GTK3) {
-		GTK.gtk_widget_queue_draw(parent.handle);
-	}
+	GTK.gtk_widget_queue_draw(parent.handle);
 	return 0;
 }
 
 @Override
-long /*int*/ gtk_event_after (long /*int*/ widget, long /*int*/ gdkEvent) {
-	GdkEvent gtkEvent = new GdkEvent ();
-	OS.memmove (gtkEvent, gdkEvent, GdkEvent.sizeof);
-	switch (gtkEvent.type) {
+long gtk_event_after (long widget, long gdkEvent) {
+	int eventType = GDK.gdk_event_get_event_type(gdkEvent);
+	eventType = Control.fixGdkEventTypeValues(eventType);
+	switch (eventType) {
 		case GDK.GDK_BUTTON_RELEASE: {
-			GdkEventButton gdkEventButton = new GdkEventButton ();
-			OS.memmove (gdkEventButton, gdkEvent, GdkEventButton.sizeof);
-			if (gdkEventButton.button == 1 && detail == GTK.GTK_SCROLL_JUMP) {
+			int [] eventButton = new int [1];
+			GDK.gdk_event_get_button(gdkEvent, eventButton);
+			if (eventButton[0] == 1 && detail == GTK.GTK_SCROLL_JUMP) {
 				if (!dragSent) {
 					Event event = new Event ();
 					event.detail = SWT.DRAG;
@@ -556,10 +599,16 @@ long /*int*/ gtk_event_after (long /*int*/ widget, long /*int*/ gdkEvent) {
 @Override
 void hookEvents () {
 	super.hookEvents ();
-	OS.g_signal_connect_closure (handle, OS.change_value, display.getClosure (CHANGE_VALUE), false);
 	OS.g_signal_connect_closure (adjustmentHandle, OS.value_changed, display.getClosure (VALUE_CHANGED), false);
-	OS.g_signal_connect_closure_by_id (handle, display.signalIds [EVENT_AFTER], 0, display.getClosure (EVENT_AFTER), false);
-	OS.g_signal_connect_closure_by_id (handle, display.signalIds [BUTTON_PRESS_EVENT], 0, display.getClosure (BUTTON_PRESS_EVENT), false);
+	if (GTK.GTK4) {
+		// GTK4: event-after replaced with generic event
+		OS.g_signal_connect_closure_by_id (handle, display.signalIds [EVENT], 0, display.getClosure (EVENT), false);
+		// GTK4: change-value moved to gtk_scroll_child in Composite
+	} else {
+		OS.g_signal_connect_closure (handle, OS.change_value, display.getClosure (CHANGE_VALUE), false);
+		OS.g_signal_connect_closure_by_id (handle, display.signalIds [BUTTON_PRESS_EVENT], 0, display.getClosure (BUTTON_PRESS_EVENT), false);
+		OS.g_signal_connect_closure_by_id (handle, display.signalIds [EVENT_AFTER], 0, display.getClosure (EVENT_AFTER), false);
+	}
 }
 
 /**
