@@ -27,14 +27,14 @@ import org.eclipse.swt.internal.gtk.*;
  * <p>
  * Note that although this class is a subclass of <code>Composite</code>,
  * it does not make sense to add children to it, or set a layout on it.
- * </p><p>
+ * </p>
  * <dl>
  * <dt><b>Styles:</b></dt>
  * <dd>READ_ONLY, WRAP</dd>
  * <dt><b>Events:</b></dt>
  * <dd>Selection, Modify, Verify</dd>
  * </dl>
- * </p><p>
+ * <p>
  * IMPORTANT: This class is <em>not</em> intended to be subclassed.
  * </p>
  *
@@ -48,8 +48,9 @@ import org.eclipse.swt.internal.gtk.*;
 public class Spinner extends Composite {
 	static final int MIN_ARROW_WIDTH = 6;
 	int lastEventTime = 0;
-	long /*int*/ imContext;
-	long /*int*/ gdkEventKey = 0;
+	long imContext;
+	long gdkEventKey = 0;
+	long entryHandle;
 	int fixStart = -1, fixEnd = -1;
 	double climbRate = 1;
 
@@ -211,10 +212,9 @@ Point computeSizeInPixels (int wHint, int hHint, boolean changed) {
 	checkWidget ();
 	if (wHint != SWT.DEFAULT && wHint < 0) wHint = 0;
 	if (hHint != SWT.DEFAULT && hHint < 0) hHint = 0;
-	int[] w = new int [1], h = new int [1];
 	GTK.gtk_widget_realize (handle);
-	long /*int*/ layout = GTK.gtk_entry_get_layout (handle);
-	long /*int*/ hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
+	long layout = GTK.gtk_entry_get_layout (GTK.GTK4 ? entryHandle : handle);
+	long hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
 	double upper = GTK.gtk_adjustment_get_upper (hAdjustment);
 	int digits = GTK.gtk_spin_button_get_digits (handle);
 	for (int i = 0; i < digits; i++) upper *= 10;
@@ -231,24 +231,18 @@ Point computeSizeInPixels (int wHint, int hHint, boolean changed) {
 		string = buffer.toString ();
 	}
 	byte [] buffer1 = Converter.wcsToMbcs (string, false);
-	long /*int*/ ptr = OS.pango_layout_get_text (layout);
+	long ptr = OS.pango_layout_get_text (layout);
 	int length = C.strlen (ptr);
 	byte [] buffer2 = new byte [length];
 	C.memmove (buffer2, ptr, length);
 	OS.pango_layout_set_text (layout, buffer1, buffer1.length);
 	int width, height = 0 ;
 	GTK.gtk_widget_realize (handle);
-	if (GTK.GTK3) {
-		GTK.gtk_widget_set_size_request (handle, wHint, hHint);
-		GtkRequisition requisition = new GtkRequisition ();
-		GTK.gtk_widget_get_preferred_size (handle, requisition, null);
-		width = wHint == SWT.DEFAULT ? requisition.width : Math.max(wHint, requisition.width);
-		height = hHint == SWT.DEFAULT ? requisition.height : hHint;
-	} else {
-		OS.pango_layout_get_pixel_size (layout, w, h);
-		width = wHint == SWT.DEFAULT ? w [0] : wHint;
-		height = hHint == SWT.DEFAULT ? h [0] : hHint;
-	}
+	GTK.gtk_widget_set_size_request (handle, wHint, hHint);
+	GtkRequisition requisition = new GtkRequisition ();
+	GTK.gtk_widget_get_preferred_size (handle, requisition, null);
+	width = wHint == SWT.DEFAULT ? requisition.width : Math.max(wHint, requisition.width);
+	height = hHint == SWT.DEFAULT ? requisition.height : hHint;
 	OS.pango_layout_set_text (layout, buffer2, buffer2.length);
 	Rectangle trim = computeTrimInPixels (0, 0, width, height);
 	return new Point (trim.width, trim.height);
@@ -259,53 +253,35 @@ Rectangle computeTrimInPixels (int x, int y, int width, int height) {
 	checkWidget ();
 	int xborder = 0, yborder = 0;
 	Rectangle trim = super.computeTrimInPixels (x, y, width, height);
-	if (GTK.GTK3) {
-		GtkBorder tmp = new GtkBorder();
-		long /*int*/ context = GTK.gtk_widget_get_style_context (handle);
-		if (GTK.GTK_VERSION < OS.VERSION(3, 18, 0)) {
-			GTK.gtk_style_context_get_padding (context, GTK.GTK_STATE_FLAG_NORMAL, tmp);
-		} else {
-			GTK.gtk_style_context_get_padding (context, GTK.gtk_widget_get_state_flags(handle), tmp);
-		}
-		if ((style & SWT.BORDER) != 0) {
-			if (GTK.GTK_VERSION < OS.VERSION(3, 18, 0)) {
-				GTK.gtk_style_context_get_border (context, GTK.GTK_STATE_FLAG_NORMAL, tmp);
-			} else {
-				GTK.gtk_style_context_get_border (context, GTK.gtk_widget_get_state_flags(handle), tmp);
-			}
-			trim.x -= tmp.left;
-			trim.y -= tmp.top;
-			trim.width += tmp.left + tmp.right;
-			trim.height += tmp.top + tmp.bottom;
-		}
-	}else {
-		Point thickness = getThickness (handle);
-		if ((this.style & SWT.BORDER) != 0) {
-			xborder += thickness.x;
-			yborder += thickness.y;
-		}
-		long /*int*/ fontDesc = getFontDescription ();
-		int fontSize = OS.pango_font_description_get_size (fontDesc);
-		int arrowSize = Math.max (OS.PANGO_PIXELS (fontSize), MIN_ARROW_WIDTH);
-		arrowSize = arrowSize - arrowSize % 2;
-		trim.width += arrowSize + (2 * thickness.x);
+	GtkBorder tmp = new GtkBorder();
+	long context = GTK.gtk_widget_get_style_context (handle);
+	int state_flag = GTK.GTK_VERSION < OS.VERSION(3, 18, 0) ? GTK.GTK_STATE_FLAG_NORMAL : GTK.gtk_widget_get_state_flags(handle);
+	gtk_style_context_get_padding(context, state_flag, tmp);
+	if ((style & SWT.BORDER) != 0) {
+		int state = GTK.GTK_VERSION < OS.VERSION(3, 18, 0) ? GTK.GTK_STATE_FLAG_NORMAL : GTK.gtk_widget_get_state_flags(handle);
+		gtk_style_context_get_border(context, state, tmp);
+		trim.x -= tmp.left;
+		trim.y -= tmp.top;
+		trim.width += tmp.left + tmp.right;
+		trim.height += tmp.top + tmp.bottom;
 	}
-	int [] property = new int [1];
-	GTK.gtk_widget_style_get (handle, OS.interior_focus, property, 0);
-	if (property [0] == 0) {
-		GTK.gtk_widget_style_get (handle, OS.focus_line_width, property, 0);
-		xborder += property [0];
-		yborder += property [0];
+	/*
+	 * Focus line width is done via CSS in GTK4, and does not contribute
+	 * to the size of the widget.
+	 */
+	if (!GTK.GTK4) {
+		int [] property = new int [1];
+		GTK.gtk_widget_style_get (handle, OS.interior_focus, property, 0);
+		if (property [0] == 0) {
+			GTK.gtk_widget_style_get (handle, OS.focus_line_width, property, 0);
+			xborder += property [0];
+			yborder += property [0];
+		}
 	}
 	trim.x -= xborder;
 	trim.y -= yborder;
 	trim.width += 2 * xborder;
 	trim.height += 2 * yborder;
-	GtkBorder innerBorder = Display.getEntryInnerBorder (handle);
-	trim.x -= innerBorder.left;
-	trim.y -= innerBorder.top;
-	trim.width += innerBorder.left + innerBorder.right;
-	trim.height += innerBorder.top + innerBorder.bottom;
 	return new Rectangle (trim.x, trim.y, trim.width, trim.height);
 }
 
@@ -322,7 +298,7 @@ Rectangle computeTrimInPixels (int x, int y, int width, int height) {
  */
 public void copy () {
 	checkWidget ();
-	GTK.gtk_editable_copy_clipboard (handle);
+	GTK.gtk_editable_copy_clipboard (GTK.GTK4? entryHandle : handle);
 }
 
 @Override
@@ -330,25 +306,26 @@ void createHandle (int index) {
 	state |= HANDLE | MENU;
 	fixedHandle = OS.g_object_new (display.gtk_fixed_get_type (), 0);
 	if (fixedHandle == 0) error (SWT.ERROR_NO_HANDLES);
-	GTK.gtk_widget_set_has_window (fixedHandle, true);
-	long /*int*/ adjustment = GTK.gtk_adjustment_new (0, 0, 100, 1, 10, 0);
+	gtk_widget_set_has_surface_or_window (fixedHandle, true);
+	long adjustment = GTK.gtk_adjustment_new (0, 0, 100, 1, 10, 0);
 	if (adjustment == 0) error (SWT.ERROR_NO_HANDLES);
 	handle = GTK.gtk_spin_button_new (adjustment, climbRate, 0);
 	if (handle == 0) error (SWT.ERROR_NO_HANDLES);
 	GTK.gtk_container_add (fixedHandle, handle);
-	GTK.gtk_editable_set_editable (handle, (style & SWT.READ_ONLY) == 0);
+	if (GTK.GTK4) {
+		long boxHandle = GTK.gtk_widget_get_first_child(handle);
+		long textHandle = GTK.gtk_widget_get_first_child(boxHandle);
+		entryHandle = textHandle;
+	}
+	GTK.gtk_editable_set_editable (GTK.GTK4 ? entryHandle : handle, (style & SWT.READ_ONLY) == 0);
 	if (GTK.GTK_VERSION <= OS.VERSION(3, 20, 0)) {
-		GTK.gtk_entry_set_has_frame (handle, (style & SWT.BORDER) != 0);
+		GTK.gtk_entry_set_has_frame (GTK.GTK4 ? entryHandle : handle, (style & SWT.BORDER) != 0);
 	}
 	GTK.gtk_spin_button_set_wrap (handle, (style & SWT.WRAP) != 0);
-	if (GTK.GTK3) {
-		imContext = OS.imContextLast();
-	}
+	imContext = OS.imContextLast();
 	// In GTK 3 font description is inherited from parent widget which is not how SWT has always worked,
 	// reset to default font to get the usual behavior
-	if (GTK.GTK3) {
-		setFontDescription(defaultFont().handle);
-	}
+	setFontDescription(defaultFont().handle);
 }
 
 /**
@@ -365,37 +342,42 @@ void createHandle (int index) {
  */
 public void cut () {
 	checkWidget ();
-	GTK.gtk_editable_cut_clipboard (handle);
+	GTK.gtk_editable_cut_clipboard (GTK.GTK4? entryHandle : handle);
 }
 
 @Override
 GdkRGBA defaultBackground () {
-	return display.getSystemColor(SWT.COLOR_LIST_BACKGROUND).handleRGBA;
+	return display.getSystemColor(SWT.COLOR_LIST_BACKGROUND).handle;
 }
 
 @Override
 void deregister () {
 	super.deregister ();
-	long /*int*/ imContext = imContext ();
+	long imContext = imContext ();
 	if (imContext != 0) display.removeWidget (imContext);
 }
 
 @Override
-long /*int*/ eventWindow () {
+long eventWindow () {
 	return paintWindow ();
 }
 
 @Override
-long /*int*/ enterExitHandle () {
+long eventSurface () {
+	return paintSurface ();
+}
+
+@Override
+long enterExitHandle () {
 	return fixedHandle;
 }
 
 @Override
-boolean filterKey (int keyval, long /*int*/ event) {
+boolean filterKey (int keyval, long event) {
 	int time = GDK.gdk_event_get_time (event);
 	if (time != lastEventTime) {
 		lastEventTime = time;
-		long /*int*/ imContext = imContext ();
+		long imContext = imContext ();
 		if (imContext != 0) {
 			return GTK.gtk_im_context_filter_keypress (imContext, event);
 		}
@@ -414,7 +396,7 @@ void fixIM () {
 	*  filter has to be called by SWT.
 	*/
 	if (gdkEventKey != 0 && gdkEventKey != -1) {
-		long /*int*/ imContext = imContext ();
+		long imContext = imContext ();
 		if (imContext != 0) {
 			GTK.gtk_im_context_filter_keypress (imContext, gdkEventKey);
 			gdkEventKey = -1;
@@ -424,12 +406,6 @@ void fixIM () {
 	gdkEventKey = 0;
 }
 
-@Override
-GdkColor getBackgroundGdkColor () {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	return getBaseGdkColor ();
-}
-
 @Override
 int getBorderWidthInPixels () {
 	checkWidget();
@@ -439,12 +415,6 @@ int getBorderWidthInPixels () {
 	return 0;
 }
 
-@Override
-GdkColor getForegroundGdkColor () {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	return getTextColor ();
-}
-
 /**
  * Returns the amount that the receiver's value will be
  * modified by when the up/down arrows are pressed.
@@ -458,7 +428,7 @@ GdkColor getForegroundGdkColor () {
  */
 public int getIncrement () {
 	checkWidget ();
-	long /*int*/ hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
+	long hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
 	int digits = GTK.gtk_spin_button_get_digits (handle);
 	double value = GTK.gtk_adjustment_get_step_increment (hAdjustment);
 	for (int i = 0; i < digits; i++) value *= 10;
@@ -477,7 +447,7 @@ public int getIncrement () {
  */
 public int getMaximum () {
 	checkWidget ();
-	long /*int*/ hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
+	long hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
 	int digits = GTK.gtk_spin_button_get_digits (handle);
 	double value = GTK.gtk_adjustment_get_upper (hAdjustment);
 	for (int i = 0; i < digits; i++) value *= 10;
@@ -496,7 +466,7 @@ public int getMaximum () {
  */
 public int getMinimum () {
 	checkWidget ();
-	long /*int*/ hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
+	long hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
 	int digits = GTK.gtk_spin_button_get_digits (handle);
 	double value = GTK.gtk_adjustment_get_lower (hAdjustment);
 	for (int i = 0; i < digits; i++) value *= 10;
@@ -516,7 +486,7 @@ public int getMinimum () {
  */
 public int getPageIncrement () {
 	checkWidget ();
-	long /*int*/ hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
+	long hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
 	int digits = GTK.gtk_spin_button_get_digits (handle);
 	double value = GTK.gtk_adjustment_get_page_increment (hAdjustment);
 	for (int i = 0; i < digits; i++) value *= 10;
@@ -535,7 +505,7 @@ public int getPageIncrement () {
  */
 public int getSelection () {
 	checkWidget ();
-	long /*int*/ hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
+	long hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
 	int digits = GTK.gtk_spin_button_get_digits (handle);
 	double value = GTK.gtk_adjustment_get_value (hAdjustment);
 	for (int i = 0; i < digits; i++) value *= 10;
@@ -558,7 +528,7 @@ public int getSelection () {
  */
 public String getText () {
 	checkWidget ();
-	long /*int*/ str = GTK.gtk_entry_get_text (handle);
+	long str = GTK.gtk_entry_get_text (GTK.GTK4 ? entryHandle : handle);
 	if (str == 0) return "";
 	int length = C.strlen (str);
 	byte [] buffer = new byte [length];
@@ -585,7 +555,7 @@ public String getText () {
  */
 public int getTextLimit () {
 	checkWidget ();
-	int limit = GTK.gtk_entry_get_max_length (handle);
+	int limit = GTK.gtk_entry_get_max_length (GTK.GTK4 ? entryHandle : handle);
 	return limit == 0 ? LIMIT : limit;
 }
 
@@ -605,7 +575,7 @@ public int getDigits () {
 }
 
 String getDecimalSeparator () {
-	long /*int*/ ptr = OS.localeconv_decimal_point ();
+	long ptr = OS.localeconv_decimal_point ();
 	int length = C.strlen (ptr);
 	byte [] buffer = new byte [length];
 	C.memmove (buffer, ptr, length);
@@ -613,21 +583,21 @@ String getDecimalSeparator () {
 }
 
 @Override
-long /*int*/ gtk_activate (long /*int*/ widget) {
+long gtk_activate (long widget) {
 	sendSelectionEvent (SWT.DefaultSelection);
 	return 0;
 }
 
 @Override
-long /*int*/ gtk_changed (long /*int*/ widget) {
-	long /*int*/ str = GTK.gtk_entry_get_text (handle);
+long gtk_changed (long widget) {
+	long str = GTK.gtk_entry_get_text (GTK.GTK4 ? entryHandle : handle);
 	int length = C.strlen (str);
 	if (length > 0) {
-		long /*int*/ [] endptr = new long /*int*/ [1];
+		long [] endptr = new long [1];
 		double value = OS.g_strtod (str, endptr);
 		int valueLength = (getDigits() == 0) ? String.valueOf((int)value).length() : String.valueOf(value).length();
 		if ((endptr [0] == str + length) && valueLength == length) {
-			long /*int*/ hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
+			long hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
 			GtkAdjustment adjustment = new GtkAdjustment ();
 			gtk_adjustment_get (hAdjustment, adjustment);
 			if (value != adjustment.value && adjustment.lower <= value && value <= adjustment.upper) {
@@ -644,16 +614,16 @@ long /*int*/ gtk_changed (long /*int*/ widget) {
 	* is to post the modify event when the user is typing.
 	*/
 	boolean keyPress = false;
-	long /*int*/ eventPtr = GTK.gtk_get_current_event ();
+	long eventPtr = GTK.gtk_get_current_event ();
 	if (eventPtr != 0) {
-		GdkEventKey gdkEvent = new GdkEventKey ();
-		OS.memmove (gdkEvent, eventPtr, GdkEventKey.sizeof);
-		switch (gdkEvent.type) {
+		int eventType = GDK.gdk_event_get_event_type(eventPtr);
+		eventType = fixGdkEventTypeValues(eventType);
+		switch (eventType) {
 			case GDK.GDK_KEY_PRESS:
 				keyPress = true;
 				break;
 		}
-		GDK.gdk_event_free (eventPtr);
+		gdk_event_free (eventPtr);
 	}
 	if (keyPress) {
 		postEvent (SWT.Modify);
@@ -664,15 +634,15 @@ long /*int*/ gtk_changed (long /*int*/ widget) {
 }
 
 @Override
-long /*int*/ gtk_commit (long /*int*/ imContext, long /*int*/ text) {
+long gtk_commit (long imContext, long text) {
 	if (text == 0) return 0;
-	if (!GTK.gtk_editable_get_editable (handle)) return 0;
+	if (!GTK.gtk_editable_get_editable (GTK.GTK4? entryHandle : handle)) return 0;
 	int length = C.strlen (text);
 	if (length == 0) return 0;
 	byte [] buffer = new byte [length];
 	C.memmove (buffer, text, length);
 	char [] chars = Converter.mbcsToWcs (buffer);
-	char [] newChars = sendIMKeyEvent (SWT.KeyDown, null, chars);
+	char [] newChars = sendIMKeyEvent (SWT.KeyDown, 0, chars);
 	if (newChars == null) return 0;
 	/*
 	* Feature in GTK.  For a GtkEntry, during the insert-text signal,
@@ -695,78 +665,78 @@ long /*int*/ gtk_commit (long /*int*/ imContext, long /*int*/ text) {
 	OS.g_signal_handlers_unblock_matched (imContext, OS.G_SIGNAL_MATCH_DATA, 0, 0, 0, 0, COMMIT);
 	OS.g_signal_handlers_block_matched (imContext, mask, id, 0, 0, 0, handle);
 	if (fixStart != -1 && fixEnd != -1) {
-		GTK.gtk_editable_set_position (handle, fixStart);
-		GTK.gtk_editable_select_region (handle, fixStart, fixEnd);
+		GTK.gtk_editable_set_position (GTK.GTK4? entryHandle : handle, fixStart);
+		GTK.gtk_editable_select_region (GTK.GTK4? entryHandle : handle, fixStart, fixEnd);
 	}
 	fixStart = fixEnd = -1;
 	return 0;
 }
 
 @Override
-long /*int*/ gtk_delete_text (long /*int*/ widget, long /*int*/ start_pos, long /*int*/ end_pos) {
+long gtk_delete_text (long widget, long start_pos, long end_pos) {
 	if (!hooks (SWT.Verify) && !filters (SWT.Verify)) return 0;
-	long /*int*/ ptr = GTK.gtk_entry_get_text (handle);
+	long ptr = GTK.gtk_entry_get_text (GTK.GTK4 ? entryHandle : handle);
 	if (end_pos == -1) end_pos = OS.g_utf8_strlen (ptr, -1);
-	int start = (int)/*64*/OS.g_utf8_offset_to_utf16_offset (ptr, start_pos);
-	int end = (int)/*64*/OS.g_utf8_offset_to_utf16_offset (ptr, end_pos);
+	int start = (int)OS.g_utf8_offset_to_utf16_offset (ptr, start_pos);
+	int end = (int)OS.g_utf8_offset_to_utf16_offset (ptr, end_pos);
 	String newText = verifyText ("", start, end);
 	if (newText == null) {
 		OS.g_signal_stop_emission_by_name (handle, OS.delete_text);
 	} else {
 		if (newText.length () > 0) {
 			int [] pos = new int [1];
-			pos [0] = (int)/*64*/end_pos;
+			pos [0] = (int)end_pos;
 			byte [] buffer = Converter.wcsToMbcs (newText, false);
 			OS.g_signal_handlers_block_matched (handle, OS.G_SIGNAL_MATCH_DATA, 0, 0, 0, 0, CHANGED);
 			OS.g_signal_handlers_block_matched (handle, OS.G_SIGNAL_MATCH_DATA, 0, 0, 0, 0, INSERT_TEXT);
-			GTK.gtk_editable_insert_text (handle, buffer, buffer.length, pos);
+			GTK.gtk_editable_insert_text (GTK.GTK4? entryHandle : handle, buffer, buffer.length, pos);
 			OS.g_signal_handlers_unblock_matched (handle, OS.G_SIGNAL_MATCH_DATA, 0, 0, 0, 0, INSERT_TEXT);
 			OS.g_signal_handlers_unblock_matched (handle, OS.G_SIGNAL_MATCH_DATA, 0, 0, 0, 0, CHANGED);
-			GTK.gtk_editable_set_position (handle, pos [0]);
+			GTK.gtk_editable_set_position (GTK.GTK4? entryHandle : handle, pos [0]);
 		}
 	}
 	return 0;
 }
 
 @Override
-long /*int*/ gtk_event_after (long /*int*/ widget, long /*int*/ gdkEvent) {
+long gtk_event_after (long widget, long gdkEvent) {
 	if (cursor != null) setCursor (cursor.handle);
 	return super.gtk_event_after (widget, gdkEvent);
 }
 
 @Override
-long /*int*/ gtk_focus_out_event (long /*int*/ widget, long /*int*/ event) {
+long gtk_focus_out_event (long widget, long event) {
 	fixIM ();
 	return super.gtk_focus_out_event (widget, event);
 }
 
 @Override
-long /*int*/ gtk_insert_text (long /*int*/ widget, long /*int*/ new_text, long /*int*/ new_text_length, long /*int*/ position) {
+long gtk_insert_text (long widget, long new_text, long new_text_length, long position) {
 //	if (!hooks (SWT.Verify) && !filters (SWT.Verify)) return 0;
 	if (new_text == 0 || new_text_length == 0) return 0;
-	byte [] buffer = new byte [(int)/*64*/new_text_length];
+	byte [] buffer = new byte [(int)new_text_length];
 	C.memmove (buffer, new_text, buffer.length);
 	String oldText = new String (Converter.mbcsToWcs (buffer));
 	int [] pos = new int [1];
 	C.memmove (pos, position, 4);
-	long /*int*/ ptr = GTK.gtk_entry_get_text (handle);
-	if (pos [0] == -1) pos [0] = (int)/*64*/OS.g_utf8_strlen (ptr, -1);
-	int start = (int)/*64*/OS.g_utf16_pointer_to_offset (ptr, pos [0]);
+	long ptr = GTK.gtk_entry_get_text (GTK.GTK4 ? entryHandle : handle);
+	if (pos [0] == -1) pos [0] = (int)OS.g_utf8_strlen (ptr, -1);
+	int start = (int)OS.g_utf16_pointer_to_offset (ptr, pos [0]);
 	String newText = verifyText (oldText, start, start);
 	if (newText != oldText) {
 		int [] newStart = new int [1], newEnd = new int [1];
-		GTK.gtk_editable_get_selection_bounds (handle, newStart, newEnd);
+		GTK.gtk_editable_get_selection_bounds (GTK.GTK4? entryHandle : handle, newStart, newEnd);
 		if (newText != null) {
 			if (newStart [0] != newEnd [0]) {
 				OS.g_signal_handlers_block_matched (handle, OS.G_SIGNAL_MATCH_DATA, 0, 0, 0, 0, DELETE_TEXT);
 				OS.g_signal_handlers_block_matched (handle, OS.G_SIGNAL_MATCH_DATA, 0, 0, 0, 0, CHANGED);
-				GTK.gtk_editable_delete_selection (handle);
+				GTK.gtk_editable_delete_selection (GTK.GTK4? entryHandle : handle);
 				OS.g_signal_handlers_unblock_matched (handle, OS.G_SIGNAL_MATCH_DATA, 0, 0, 0, 0, DELETE_TEXT);
 				OS.g_signal_handlers_unblock_matched (handle, OS.G_SIGNAL_MATCH_DATA, 0, 0, 0, 0, CHANGED);
 			}
 			byte [] buffer3 = Converter.wcsToMbcs (newText, false);
 			OS.g_signal_handlers_block_matched (handle, OS.G_SIGNAL_MATCH_DATA, 0, 0, 0, 0, INSERT_TEXT);
-			GTK.gtk_editable_insert_text (handle, buffer3, buffer3.length, pos);
+			GTK.gtk_editable_insert_text (GTK.GTK4? entryHandle : handle, buffer3, buffer3.length, pos);
 			OS.g_signal_handlers_unblock_matched (handle, OS.G_SIGNAL_MATCH_DATA, 0, 0, 0, 0, INSERT_TEXT);
 			newStart [0] = newEnd [0] = pos [0];
 		}
@@ -782,8 +752,8 @@ long /*int*/ gtk_insert_text (long /*int*/ widget, long /*int*/ new_text, long /
 }
 
 @Override
-long /*int*/ gtk_key_press_event (long /*int*/ widget, long /*int*/ event) {
-	long /*int*/ result = super.gtk_key_press_event (widget, event);
+long gtk_key_press_event (long widget, long event) {
+	long result = super.gtk_key_press_event (widget, event);
 	if (result != 0) fixIM ();
 	if (gdkEventKey == -1) result = 1;
 	gdkEventKey = 0;
@@ -791,7 +761,7 @@ long /*int*/ gtk_key_press_event (long /*int*/ widget, long /*int*/ event) {
 }
 
 @Override
-long /*int*/ gtk_populate_popup (long /*int*/ widget, long /*int*/ menu) {
+long gtk_populate_popup (long widget, long menu) {
 	if ((style & SWT.RIGHT_TO_LEFT) != 0) {
 		GTK.gtk_widget_set_direction (menu, GTK.GTK_TEXT_DIR_RTL);
 		GTK.gtk_container_forall (menu, display.setDirectionProc, GTK.GTK_TEXT_DIR_RTL);
@@ -800,7 +770,7 @@ long /*int*/ gtk_populate_popup (long /*int*/ widget, long /*int*/ menu) {
 }
 
 @Override
-long /*int*/ gtk_value_changed (long /*int*/ widget) {
+long gtk_value_changed (long widget) {
 	sendSelectionEvent (SWT.Selection);
 	return 0;
 }
@@ -814,7 +784,7 @@ void hookEvents () {
 	OS.g_signal_connect_closure (handle, OS.value_changed, display.getClosure (VALUE_CHANGED), false);
 	OS.g_signal_connect_closure (handle, OS.activate, display.getClosure (ACTIVATE), false);
 	OS.g_signal_connect_closure (handle, OS.populate_popup, display.getClosure (POPULATE_POPUP), false);
-	long /*int*/ imContext = imContext ();
+	long imContext = imContext ();
 	if (imContext != 0) {
 		OS.g_signal_connect_closure (imContext, OS.commit, display.getClosure (COMMIT), false);
 		int id = OS.g_signal_lookup (OS.commit, GTK.gtk_im_context_get_type ());
@@ -823,20 +793,29 @@ void hookEvents () {
 	}
 }
 
-long /*int*/ imContext () {
+long imContext () {
 	if (imContext != 0) return imContext;
-	return GTK.GTK_ENTRY_IM_CONTEXT (handle);
+	return 0;
 }
 
 @Override
-long /*int*/ paintWindow () {
-	long /*int*/ window = super.paintWindow ();
-	long /*int*/ children = GDK.gdk_window_get_children (window);
+long paintWindow () {
+	long window = super.paintWindow ();
+	long children = GDK.gdk_window_get_children (window);
 	if (children != 0) window = OS.g_list_data (children);
 	OS.g_list_free (children);
 	return window;
 }
 
+@Override
+long paintSurface () {
+	long surface = super.paintSurface ();
+	long children = GDK.gdk_surface_get_children (surface);
+	if (children != 0) surface = OS.g_list_data (children);
+	OS.g_list_free (children);
+	return surface;
+}
+
 /**
  * Pastes text from clipboard.
  * <p>
@@ -851,13 +830,13 @@ long /*int*/ paintWindow () {
  */
 public void paste () {
 	checkWidget ();
-	GTK.gtk_editable_paste_clipboard (handle);
+	GTK.gtk_editable_paste_clipboard (GTK.GTK4? entryHandle : handle);
 }
 
 @Override
 void register () {
 	super.register ();
-	long /*int*/ imContext = imContext ();
+	long imContext = imContext ();
 	if (imContext != 0) display.addWidget (imContext, this);
 }
 
@@ -942,7 +921,6 @@ void removeVerifyListener (VerifyListener listener) {
 
 @Override
 GdkRGBA getContextBackgroundGdkRGBA () {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
 	if (background != null && (state & BACKGROUND) != 0) {
 		return background;
 	}
@@ -950,31 +928,40 @@ GdkRGBA getContextBackgroundGdkRGBA () {
 }
 
 @Override
-void setBackgroundGdkRGBA (long /*int*/ context, long /*int*/ handle, GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
-	background = rgba;
-	setBackgroundGradientGdkRGBA (context, handle, rgba);
+void setBackgroundGdkRGBA (long context, long handle, GdkRGBA rgba) {
+	if (rgba == null) {
+		background = defaultBackground();
+	} else {
+		background = rgba;
+	}
+	if (GTK.GTK4) {
+		super.setBackgroundGdkRGBA(context, handle, rgba);
+	} else {
+		String color = display.gtk_rgba_to_css_string (background);
+		String properties = " {background-image: -gtk-gradient (linear, 0 0, 0 1, color-stop(0, " + color + "), color-stop(1, " + color + "));}";
+		String name = GTK.GTK_VERSION >= OS.VERSION(3, 20, 0) ? "spinbutton" : "GtkSpinButton";
+		String css = name + properties;
+
+		cssBackground = css;
+
+		String finalCss = display.gtk_css_create_css_color_string (cssBackground, cssForeground, SWT.BACKGROUND);
+		gtk_css_provider_load_from_css(context, finalCss);
+	}
 }
 
 @Override
-void setBackgroundGdkColor (GdkColor color) {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	super.setBackgroundGdkColor (color);
-	GTK.gtk_widget_modify_base (handle, 0, color);
-}
-
-@Override
-void setCursor (long /*int*/ cursor) {
-	long /*int*/ defaultCursor = 0;
-	if (cursor == 0) defaultCursor = GDK.gdk_cursor_new_for_display (GDK.gdk_display_get_default(), GDK.GDK_XTERM);
+void setCursor (long cursor) {
+	long defaultCursor = 0;
+	if (cursor == 0)  {
+		if (GTK.GTK4) {
+			byte [] name = Converter.wcsToMbcs("text", true);
+			defaultCursor = GDK.gdk_cursor_new_from_name(name, 0);
+		} else {
+			defaultCursor = GDK.gdk_cursor_new_for_display (GDK.gdk_display_get_default(), GDK.GDK_XTERM);
+		}
+	}
 	super.setCursor (cursor != 0 ? cursor : defaultCursor);
-	if (cursor == 0) gdk_cursor_unref (defaultCursor);
-}
-
-@Override
-void setForegroundGdkColor (GdkColor color) {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	setForegroundColor (handle, color, false);
+	if (cursor == 0) OS.g_object_unref (defaultCursor);
 }
 
 /**
@@ -992,7 +979,7 @@ void setForegroundGdkColor (GdkColor color) {
 public void setIncrement (int value) {
 	checkWidget ();
 	if (value < 1) return;
-	long /*int*/ hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
+	long hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
 	double page_increment = GTK.gtk_adjustment_get_page_increment (hAdjustment);
 	double newValue = value;
 	int digits = GTK.gtk_spin_button_get_digits (handle);
@@ -1017,7 +1004,7 @@ public void setIncrement (int value) {
  */
 public void setMaximum (int value) {
 	checkWidget ();
-	long /*int*/ hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
+	long hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
 	double lower = GTK.gtk_adjustment_get_lower (hAdjustment);
 	double newValue = value;
 	int digits = GTK.gtk_spin_button_get_digits (handle);
@@ -1043,7 +1030,7 @@ public void setMaximum (int value) {
  */
 public void setMinimum (int value) {
 	checkWidget ();
-	long /*int*/ hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
+	long hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
 	double upper = GTK.gtk_adjustment_get_upper (hAdjustment);
 	double newValue = value;
 	int digits = GTK.gtk_spin_button_get_digits (handle);
@@ -1069,7 +1056,7 @@ public void setMinimum (int value) {
 public void setPageIncrement (int value) {
 	checkWidget ();
 	if (value < 1) return;
-	long /*int*/ hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
+	long hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
 	double step_increment = GTK.gtk_adjustment_get_step_increment(hAdjustment);
 	double newValue = value;
 	int digits = GTK.gtk_spin_button_get_digits (handle);
@@ -1127,7 +1114,7 @@ public void setSelection (int value) {
 public void setTextLimit (int limit) {
 	checkWidget ();
 	if (limit == 0) error (SWT.ERROR_CANNOT_BE_ZERO);
-	GTK.gtk_entry_set_max_length (handle, limit);
+	GTK.gtk_entry_set_max_length (GTK.GTK4 ? entryHandle : handle, limit);
 }
 
 /**
@@ -1155,7 +1142,7 @@ public void setDigits (int value) {
 	if (value < 0) error (SWT.ERROR_INVALID_ARGUMENT);
 	int digits = GTK.gtk_spin_button_get_digits (handle);
 	if (value == digits) return;
-	long /*int*/ hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
+	long hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
 	GtkAdjustment adjustment = new GtkAdjustment ();
 	gtk_adjustment_get (hAdjustment, adjustment);
 	int diff = Math.abs (value - digits);
@@ -1223,7 +1210,7 @@ public void setValues (int selection, int minimum, int maximum, int digits, int
 	*/
 	OS.g_signal_handlers_block_matched (handle, OS.G_SIGNAL_MATCH_DATA, 0, 0, 0, 0, VALUE_CHANGED);
 	climbRate = 1.0 / factor;
-	long /*int*/ adjustment = GTK.gtk_spin_button_get_adjustment(handle);
+	long adjustment = GTK.gtk_spin_button_get_adjustment(handle);
 	GTK.gtk_spin_button_configure (handle, adjustment, climbRate, digits);
 
 	GTK.gtk_spin_button_set_range (handle, minimum / factor, maximum / factor);
@@ -1238,14 +1225,15 @@ boolean checkSubwindow () {
 }
 
 @Override
-boolean translateTraversal (GdkEventKey keyEvent) {
-	int key = keyEvent.keyval;
-	switch (key) {
+boolean translateTraversal (long event) {
+	int [] key = new int[1];
+	GDK.gdk_event_get_keyval(event, key);
+	switch (key[0]) {
 		case GDK.GDK_KP_Enter:
 		case GDK.GDK_Return: {
-			long /*int*/ imContext =  imContext ();
+			long imContext =  imContext ();
 			if (imContext != 0) {
-				long /*int*/ [] preeditString = new long /*int*/ [1];
+				long [] preeditString = new long [1];
 				GTK.gtk_im_context_get_preedit_string (imContext, preeditString, null, null);
 				if (preeditString [0] != 0) {
 					int length = C.strlen (preeditString [0]);
@@ -1255,7 +1243,7 @@ boolean translateTraversal (GdkEventKey keyEvent) {
 			}
 		}
 	}
-	return super.translateTraversal (keyEvent);
+	return super.translateTraversal (event);
 }
 
 String verifyText (String string, int start, int end) {
@@ -1264,16 +1252,16 @@ String verifyText (String string, int start, int end) {
 	event.text = string;
 	event.start = start;
 	event.end = end;
-	long /*int*/ eventPtr = GTK.gtk_get_current_event ();
+	long eventPtr = GTK.gtk_get_current_event ();
 	if (eventPtr != 0) {
-		GdkEventKey gdkEvent = new GdkEventKey ();
-		OS.memmove (gdkEvent, eventPtr, GdkEventKey.sizeof);
-		switch (gdkEvent.type) {
+		int type = GDK.gdk_event_get_event_type(eventPtr);
+		type = fixGdkEventTypeValues(type);
+		switch (type) {
 			case GDK.GDK_KEY_PRESS:
-				setKeyState (event, gdkEvent);
+				setKeyState (event, eventPtr);
 				break;
 		}
-		GDK.gdk_event_free (eventPtr);
+		gdk_event_free (eventPtr);
 	}
 	int index = 0;
 	if (GTK.gtk_spin_button_get_digits (handle) > 0) {
@@ -1285,7 +1273,7 @@ String verifyText (String string, int start, int end) {
 		index = 0;
 	}
 	if (string.length () > 0) {
-		long /*int*/ hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
+		long hAdjustment = GTK.gtk_spin_button_get_adjustment (handle);
 		double lower = GTK.gtk_adjustment_get_lower (hAdjustment);
 		if (lower < 0 && string.charAt (0) == '-') index++;
 	}
