@@ -37,7 +37,7 @@ import org.eclipse.swt.internal.gtk.*;
  * @noextend This class is not intended to be subclassed by clients.
  */
 public class TabItem extends Item {
-	long /*int*/ labelHandle, imageHandle, pageHandle, provider;
+	long labelHandle, imageHandle, pageHandle, provider;
 	Control control;
 	TabFolder parent;
 	String toolTipText;
@@ -221,13 +221,13 @@ public String getToolTipText () {
 }
 
 @Override
-long /*int*/ gtk_enter_notify_event (long /*int*/ widget, long /*int*/ event) {
+long gtk_enter_notify_event (long widget, long event) {
 	parent.gtk_enter_notify_event (widget, event);
 	return 0;
 }
 
 @Override
-long /*int*/ gtk_mnemonic_activate (long /*int*/ widget, long /*int*/ arg1) {
+long gtk_mnemonic_activate (long widget, long arg1) {
 	return parent.gtk_mnemonic_activate (widget, arg1);
 }
 
@@ -235,7 +235,16 @@ long /*int*/ gtk_mnemonic_activate (long /*int*/ widget, long /*int*/ arg1) {
 void hookEvents () {
 	super.hookEvents ();
 	if (labelHandle != 0) OS.g_signal_connect_closure_by_id (labelHandle, display.signalIds [MNEMONIC_ACTIVATE], 0, display.getClosure (MNEMONIC_ACTIVATE), false);
-	OS.g_signal_connect_closure_by_id (handle, display.signalIds [ENTER_NOTIFY_EVENT], 0, display.getClosure (ENTER_NOTIFY_EVENT), false);
+	if (GTK.GTK4) {
+		long motionController = GTK.gtk_event_controller_motion_new();
+		GTK.gtk_widget_add_controller(handle, motionController);
+		GTK.gtk_event_controller_set_propagation_phase(motionController, GTK.GTK_PHASE_TARGET);
+
+		long enterMotionAddress = display.enterMotionScrollCallback.getAddress();
+		OS.g_signal_connect (motionController, OS.enter, enterMotionAddress, ENTER);
+	} else {
+		OS.g_signal_connect_closure_by_id (handle, display.signalIds [ENTER_NOTIFY_EVENT], 0, display.getClosure (ENTER_NOTIFY_EVENT), false);
+	}
 }
 
 @Override
@@ -250,7 +259,7 @@ void release (boolean destroy) {
 	//Since controls are now nested under the tabItem,
 	//tabItem is responsible for it's release.
 	if (control != null && !control.isDisposed ()) {
-		control.release (destroy);
+		Control.gtk_widget_reparent (control, parent.parentingHandle());
 	}
 	super.release (destroy);
 }
@@ -295,7 +304,19 @@ public void setControl (Control control) {
 
 	if (control != null) {
 		// To understand why we reparent, see implementation note about bug 454936 at the start of TabFolder.
-		Control.gtk_widget_reparent (control, pageHandle);
+		if (GTK.GTK4) {
+			long widget = control.topHandle();
+			long parentContainer = GTK.gtk_widget_get_parent (widget);
+			if (parentContainer != 0) {
+				OS.g_object_ref (widget); //so that it won't get destroyed due to lack of references.
+				GTK.gtk_container_remove (parentContainer, widget);
+				GTK.gtk_container_add (pageHandle, widget);
+				OS.g_object_unref (widget);
+				GTK.gtk_widget_show(widget);
+			}
+		} else {
+			Control.gtk_widget_reparent (control, pageHandle);
+		}
 	}
 
 	Control oldControl = this.control, newControl = control;
@@ -316,11 +337,15 @@ public void setControl (Control control) {
 		newControl.setVisible (true);
 	}
 
-	if (oldControl != null && newControl != null && oldControl != newControl)
-		oldControl.setVisible (false);
+	if ((oldControl != null) && (oldControl != newControl)) {
+		Control.gtk_widget_reparent (oldControl, parent.parentingHandle());
+		if (newControl != null) {
+			oldControl.setVisible (false);
+		}
+	}
 }
 
-void setFontDescription (long /*int*/ font) {
+void setFontDescription (long font) {
 	setFontDescription (labelHandle, font);
 	setFontDescription (imageHandle, font);
 }
@@ -330,14 +355,14 @@ void setForegroundRGBA (GdkRGBA rgba) {
 	setForegroundGdkRGBA (imageHandle, rgba);
 }
 
-void setForegroundGdkRGBA (long /*int*/ handle, GdkRGBA rgba) {
+void setForegroundGdkRGBA (long handle, GdkRGBA rgba) {
 	GdkRGBA toSet = new GdkRGBA();
 	if (rgba != null) {
 		toSet = rgba;
 	} else {
 		toSet = display.COLOR_WIDGET_FOREGROUND_RGBA;
 	}
-	long /*int*/ context = GTK.gtk_widget_get_style_context (handle);
+	long context = GTK.gtk_widget_get_style_context (handle);
 	// Form foreground string
 	String color = display.gtk_rgba_to_css_string(toSet);
 	String css = "* {color: " + color + ";}";
@@ -347,7 +372,7 @@ void setForegroundGdkRGBA (long /*int*/ handle, GdkRGBA rgba) {
 	gtk_css_provider_load_from_css(context, css);
 }
 
-void gtk_css_provider_load_from_css (long /*int*/ context, String css) {
+void gtk_css_provider_load_from_css (long context, String css) {
 	/* Utility function. */
 	//@param css : a 'css java' string like "{\nbackground: red;\n}".
 	if (provider == 0) {
@@ -355,7 +380,11 @@ void gtk_css_provider_load_from_css (long /*int*/ context, String css) {
 		GTK.gtk_style_context_add_provider (context, provider, GTK.GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 		OS.g_object_unref (provider);
 	}
-	GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (css, true), -1, null);
+	if (GTK.GTK4) {
+		GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (css, true), -1);
+	} else {
+		GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (css, true), -1, null);
+	}
 }
 
 @Override
@@ -371,7 +400,7 @@ public void setImage (Image image) {
 		} else {
 			imageList.put (imageIndex, image);
 		}
-		long /*int*/ pixbuf = imageList.getPixbuf (imageIndex);
+		long pixbuf = imageList.getPixbuf (imageIndex);
 		gtk_image_set_from_gicon (imageHandle, pixbuf);
 		GTK.gtk_widget_show (imageHandle);
 	} else {
@@ -394,7 +423,6 @@ void setOrientation (boolean create) {
 /**
  * Sets the receiver's text.  The string may include
  * the mnemonic character.
- * </p>
  * <p>
  * Mnemonics are indicated by an '&amp;' that causes the next
  * character to be the mnemonic.  When the user presses a
@@ -446,7 +474,7 @@ public void setText (String string) {
  * </p>
  * <p>
  * NOTE: This operation is a hint and behavior is platform specific, on Windows
- * for CJK-style mnemonics of the form " (&C)" at the end of the tooltip text
+ * for CJK-style mnemonics of the form " (&amp;C)" at the end of the tooltip text
  * are not shown in tooltip.
  * </p>
  *
