@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -41,7 +41,7 @@ public class TableItem extends Item {
 	Font font;
 	Font[] cellFont;
 	String [] strings;
-	boolean cached, grayed;
+	boolean cached, grayed, settingData;
 
 /**
  * Constructs a new instance of this class given its parent
@@ -131,40 +131,26 @@ static Table checkNull (Table control) {
 }
 
 Color _getBackground () {
-	long /*int*/ [] ptr = new long /*int*/ [1];
+	long [] ptr = new long [1];
 	GTK.gtk_tree_model_get (parent.modelHandle, handle, Table.BACKGROUND_COLUMN, ptr, -1);
 	if (ptr [0] == 0) return parent.getBackground ();
-	if (GTK.GTK3) {
-		GdkRGBA gdkRGBA = new GdkRGBA ();
-		OS.memmove(gdkRGBA, ptr [0], GdkRGBA.sizeof);
-		GDK.gdk_rgba_free (ptr [0]);
-		return Color.gtk_new(display, gdkRGBA);
-	} else {
-		GdkColor gdkColor = new GdkColor ();
-		OS.memmove (gdkColor, ptr [0], GdkColor.sizeof);
-		GDK.gdk_color_free (ptr [0]);
-		return Color.gtk_new (display, gdkColor);
-	}
+	GdkRGBA gdkRGBA = new GdkRGBA ();
+	OS.memmove(gdkRGBA, ptr [0], GdkRGBA.sizeof);
+	GDK.gdk_rgba_free (ptr [0]);
+	return Color.gtk_new(display, gdkRGBA);
 }
 
 Color _getBackground (int index) {
 	int count = Math.max (1, parent.columnCount);
 	if (0 > index || index > count - 1) return _getBackground ();
-	long /*int*/ [] ptr = new long /*int*/ [1];
+	long [] ptr = new long [1];
 	int modelIndex = parent.columnCount == 0 ? Table.FIRST_COLUMN : parent.columns [index].modelIndex;
 	GTK.gtk_tree_model_get (parent.modelHandle, handle, modelIndex + Table.CELL_BACKGROUND, ptr, -1);
 	if (ptr [0] == 0) return _getBackground ();
-	if (GTK.GTK3) {
-		GdkRGBA gdkRGBA = new GdkRGBA ();
-		OS.memmove(gdkRGBA, ptr [0], GdkRGBA.sizeof);
-		GDK.gdk_rgba_free (ptr [0]);
-		return Color.gtk_new(display, gdkRGBA);
-	} else {
-		GdkColor gdkColor = new GdkColor ();
-		OS.memmove (gdkColor, ptr [0], GdkColor.sizeof);
-		GDK.gdk_color_free (ptr [0]);
-		return Color.gtk_new (display, gdkColor);
-	}
+	GdkRGBA gdkRGBA = new GdkRGBA ();
+	OS.memmove(gdkRGBA, ptr [0], GdkRGBA.sizeof);
+	GDK.gdk_rgba_free (ptr [0]);
+	return Color.gtk_new(display, gdkRGBA);
 }
 
 boolean _getChecked () {
@@ -174,46 +160,32 @@ boolean _getChecked () {
 }
 
 Color _getForeground () {
-	long /*int*/ [] ptr = new long /*int*/ [1];
+	long [] ptr = new long [1];
 	GTK.gtk_tree_model_get (parent.modelHandle, handle, Table.FOREGROUND_COLUMN, ptr, -1);
 	if (ptr [0] == 0) return parent.getForeground ();
-	if (GTK.GTK3) {
-		GdkRGBA gdkRGBA = new GdkRGBA ();
-		OS.memmove(gdkRGBA, ptr [0], GdkRGBA.sizeof);
-		GDK.gdk_rgba_free (ptr [0]);
-		return Color.gtk_new(display, gdkRGBA);
-	} else {
-		GdkColor gdkColor = new GdkColor ();
-		OS.memmove (gdkColor, ptr [0], GdkColor.sizeof);
-		GDK.gdk_color_free (ptr [0]);
-		return Color.gtk_new (display, gdkColor);
-	}
+	GdkRGBA gdkRGBA = new GdkRGBA ();
+	OS.memmove(gdkRGBA, ptr [0], GdkRGBA.sizeof);
+	GDK.gdk_rgba_free (ptr [0]);
+	return Color.gtk_new(display, gdkRGBA);
 }
 
 Color _getForeground (int index) {
 	int count = Math.max (1, parent.columnCount);
 	if (0 > index || index > count - 1) return _getForeground ();
-	long /*int*/ [] ptr = new long /*int*/ [1];
+	long [] ptr = new long [1];
 	int modelIndex =  parent.columnCount == 0 ? Table.FIRST_COLUMN : parent.columns [index].modelIndex;
 	GTK.gtk_tree_model_get (parent.modelHandle, handle, modelIndex + Table.CELL_FOREGROUND, ptr, -1);
 	if (ptr [0] == 0) return _getForeground ();
-	if (GTK.GTK3) {
-		GdkRGBA gdkRGBA = new GdkRGBA ();
-		OS.memmove(gdkRGBA, ptr [0], GdkRGBA.sizeof);
-		GDK.gdk_rgba_free (ptr [0]);
-		return Color.gtk_new(display, gdkRGBA);
-	} else {
-		GdkColor gdkColor = new GdkColor ();
-		OS.memmove (gdkColor, ptr [0], GdkColor.sizeof);
-		GDK.gdk_color_free (ptr [0]);
-		return Color.gtk_new (display, gdkColor);
-	}
+	GdkRGBA gdkRGBA = new GdkRGBA ();
+	OS.memmove(gdkRGBA, ptr [0], GdkRGBA.sizeof);
+	GDK.gdk_rgba_free (ptr [0]);
+	return Color.gtk_new(display, gdkRGBA);
 }
 
 Image _getImage (int index) {
 	int count = Math.max (1, parent.getColumnCount ());
 	if (0 > index || index > count - 1) return null;
-	long /*int*/ [] ptr = new long /*int*/ [1];
+	long [] ptr = new long [1];
 	int modelIndex = parent.columnCount == 0 ? Table.FIRST_COLUMN : parent.columns [index].modelIndex;
 	GTK.gtk_tree_model_get (parent.modelHandle, handle, modelIndex + Table.CELL_PIXBUF, ptr, -1);
 	if (ptr [0] == 0) return null;
@@ -227,7 +199,7 @@ Image _getImage (int index) {
 String _getText (int index) {
 	int count = Math.max (1, parent.getColumnCount ());
 	if (0 > index || index > count - 1) return "";
-	long /*int*/ [] ptr = new long /*int*/ [1];
+	long [] ptr = new long [1];
 	int modelIndex = parent.columnCount == 0 ? Table.FIRST_COLUMN : parent.columns [index].modelIndex;
 	GTK.gtk_tree_model_get (parent.modelHandle, handle, modelIndex + Table.CELL_TEXT, ptr, -1);
 	if (ptr [0] == 0) return "";
@@ -252,7 +224,7 @@ void clear () {
 			GTK.gtk_list_store_set (parent.modelHandle, handle, i, 0, -1);
 		}
 		for (int i=Table.FOREGROUND_COLUMN; i<columnCount; i++) {
-			GTK.gtk_list_store_set (parent.modelHandle, handle, i, (long /*int*/)0, -1);
+			GTK.gtk_list_store_set (parent.modelHandle, handle, i, (long )0, -1);
 		}
 	}
 	cached = false;
@@ -267,6 +239,17 @@ void destroyWidget () {
 	releaseHandle ();
 }
 
+@Override
+public void dispose () {
+	// Workaround to Bug489751, avoid selecting next node when selected node is disposed.
+	Table tmpParent = null;
+	if (parent != null && parent.getItemCount() > 0 && parent.getSelectionCount() == 0) {
+		tmpParent = parent;
+	}
+	super.dispose();
+	if (tmpParent != null && !tmpParent.isDisposed()) tmpParent.deselectAll();
+}
+
 /**
  * Returns the receiver's background color.
  *
@@ -320,14 +303,14 @@ Rectangle getBoundsinPixels () {
 	// shifted a bit too far right on later versions of GTK - however, old Tree also had this problem
 	checkWidget ();
 	if (!parent.checkData (this)) error (SWT.ERROR_WIDGET_DISPOSED);
-	long /*int*/ parentHandle = parent.handle;
-	long /*int*/ column = GTK.gtk_tree_view_get_column (parentHandle, 0);
+	long parentHandle = parent.handle;
+	long column = GTK.gtk_tree_view_get_column (parentHandle, 0);
 	if (column == 0) return new Rectangle (0, 0, 0, 0);
-	long /*int*/ textRenderer = parent.getTextRenderer (column);
-	long /*int*/ pixbufRenderer = parent.getPixbufRenderer (column);
+	long textRenderer = parent.getTextRenderer (column);
+	long pixbufRenderer = parent.getPixbufRenderer (column);
 	if (textRenderer == 0 || pixbufRenderer == 0)  return new Rectangle (0, 0, 0, 0);
 
-	long /*int*/ path = GTK.gtk_tree_model_get_path (parent.modelHandle, handle);
+	long path = GTK.gtk_tree_model_get_path (parent.modelHandle, handle);
 	GTK.gtk_widget_realize (parentHandle);
 
 	boolean isExpander = GTK.gtk_tree_model_iter_n_children (parent.modelHandle, handle) > 0;
@@ -347,11 +330,26 @@ Rectangle getBoundsinPixels () {
 	rect.width = w [0];
 	int [] buffer = new int [1];
 	if (GTK.gtk_tree_view_get_expander_column (parentHandle) == column) {
-		GTK.gtk_widget_style_get (parentHandle, OS.expander_size, buffer, 0);
-		rect.x += buffer [0] + TreeItem.EXPANDER_EXTRA_PADDING;
+		if (GTK.GTK4) {
+			long image = GTK.gtk_image_new_from_icon_name(GTK.GTK_NAMED_ICON_PAN_DOWN, GTK.GTK_ICON_SIZE_MENU);
+			GtkAllocation allocation = new GtkAllocation ();
+			GTK.gtk_widget_get_allocation(image, allocation);
+			rect.x += allocation.width + TreeItem.EXPANDER_EXTRA_PADDING;
+		} else {
+			GTK.gtk_widget_style_get (parentHandle, OS.expander_size, buffer, 0);
+			rect.x += buffer [0] + TreeItem.EXPANDER_EXTRA_PADDING;
+		}
+	}
+	int horizontalSeparator;
+	if (GTK.GTK4) {
+		long separator = GTK.gtk_separator_new(GTK.GTK_ORIENTATION_HORIZONTAL);
+		GtkAllocation allocation = new GtkAllocation ();
+		GTK.gtk_widget_get_allocation(separator, allocation);
+		horizontalSeparator = allocation.height;
+	} else {
+		GTK.gtk_widget_style_get (parentHandle, OS.horizontal_separator, buffer, 0);
+		horizontalSeparator = buffer[0];
 	}
-	GTK.gtk_widget_style_get (parentHandle, OS.horizontal_separator, buffer, 0);
-	int horizontalSeparator = buffer[0];
 	rect.x += horizontalSeparator;
 
 	gtk_tree_view_column_cell_get_position (column, textRenderer, x, null);
@@ -406,15 +404,15 @@ public Rectangle getBounds (int index) {
 Rectangle getBoundsInPixels (int index) {
 	checkWidget();
 	if (!parent.checkData (this)) error (SWT.ERROR_WIDGET_DISPOSED);
-	long /*int*/ parentHandle = parent.handle;
-	long /*int*/ column = 0;
+	long parentHandle = parent.handle;
+	long column = 0;
 	if (index >= 0 && index < parent.columnCount) {
 		column = parent.columns [index].handle;
 	} else {
 		column = GTK.gtk_tree_view_get_column (parentHandle, index);
 	}
 	if (column == 0) return new Rectangle (0, 0, 0, 0);
-	long /*int*/ path = GTK.gtk_tree_model_get_path (parent.modelHandle, handle);
+	long path = GTK.gtk_tree_model_get_path (parent.modelHandle, handle);
 	GTK.gtk_widget_realize (parentHandle);
 	GTK.gtk_tree_view_column_cell_set_cell_data (column, parent.modelHandle, handle, false, false);
 	GdkRectangle rect = new GdkRectangle ();
@@ -433,6 +431,14 @@ Rectangle getBoundsInPixels (int index) {
 	}
 	int width = GTK.gtk_tree_view_column_get_visible (column) ? rect.width + 1 : 0;
 	Rectangle r = new Rectangle (rect.x, rect.y, width, rect.height + 1);
+	/*
+	 * On GTK4 the header is included in the entire widget's surface, so we must subtract
+	 * its size from the y-coordinate. This does not apply on GTK3 as the header and
+	 * "main-widget" have separate GdkWindows.
+	 */
+	if (parent != null && parent.getHeaderVisible() && GTK.GTK4) {
+		r.y += parent.getHeaderHeight();
+	}
 	return r;
 }
 
@@ -600,18 +606,18 @@ public Rectangle getImageBounds (int index) {
 Rectangle getImageBoundsInPixels (int index) {
 	checkWidget ();
 	if (!parent.checkData (this)) error (SWT.ERROR_WIDGET_DISPOSED);
-	long /*int*/ parentHandle = parent.handle;
-	long /*int*/ column = 0;
+	long parentHandle = parent.handle;
+	long column = 0;
 	if (index >= 0 && index < parent.columnCount) {
 		column = parent.columns [index].handle;
 	} else {
 		column = GTK.gtk_tree_view_get_column (parentHandle, index);
 	}
 	if (column == 0) return new Rectangle (0, 0, 0, 0);
-	long /*int*/ pixbufRenderer = parent.getPixbufRenderer (column);
+	long pixbufRenderer = parent.getPixbufRenderer (column);
 	if (pixbufRenderer == 0)  return new Rectangle (0, 0, 0, 0);
 	GdkRectangle rect = new GdkRectangle ();
-	long /*int*/ path = GTK.gtk_tree_model_get_path (parent.modelHandle, handle);
+	long path = GTK.gtk_tree_model_get_path (parent.modelHandle, handle);
 	GTK.gtk_widget_realize (parentHandle);
 	GTK.gtk_tree_view_get_cell_area (parentHandle, path, column, rect);
 	GTK.gtk_tree_path_free (path);
@@ -625,25 +631,21 @@ Rectangle getImageBoundsInPixels (int index) {
 	 * yet to be sized, as per Bug 469277 & 476419. NOTE: this change has been ported to Tables since Tables/Trees both
 	 * use the same underlying GTK structure.
 	 */
-	if (GTK.GTK3) {
-		if (parent.pixbufSizeSet) {
-			if (x [0] > 0) {
-				rect.x += x [0];
-			}
-		} else {
-			/*
-			 * If the size of the pixbufRenderer hasn't been set, we need to take into account the
-			 * position of the textRenderer, to ensure images/widgets/etc. aren't placed over the TableItem's
-			 * text.
-			 */
-			long /*int*/ textRenderer = parent.getTextRenderer (column);
-			if (textRenderer == 0)  return new Rectangle (0, 0, 0, 0);
-			int [] xText = new int [1], wText = new int [1];
-			gtk_tree_view_column_cell_get_position (column, textRenderer, xText, wText);
-			rect.x += xText [0];
+	if (parent.pixbufSizeSet) {
+		if (x [0] > 0) {
+			rect.x += x [0];
 		}
 	} else {
-		rect.x += x [0];
+		/*
+		 * If the size of the pixbufRenderer hasn't been set, we need to take into account the
+		 * position of the textRenderer, to ensure images/widgets/etc. aren't placed over the TableItem's
+		 * text.
+		 */
+		long textRenderer = parent.getTextRenderer (column);
+		if (textRenderer == 0)  return new Rectangle (0, 0, 0, 0);
+		int [] xText = new int [1], wText = new int [1];
+		gtk_tree_view_column_cell_get_position (column, textRenderer, xText, wText);
+		rect.x += xText [0];
 	}
 	rect.width = w [0];
 	int width = GTK.gtk_tree_view_column_get_visible (column) ? rect.width : 0;
@@ -749,19 +751,19 @@ Rectangle getTextBoundsInPixels (int index) {
 	if (0 > index || index > count - 1) return new Rectangle (0, 0, 0, 0);
 	// TODO fully test on early and later versions of GTK
 	// shifted a bit too far right on later versions of GTK - however, old Tree also had this problem
-	long /*int*/ parentHandle = parent.handle;
-	long /*int*/ column = 0;
+	long parentHandle = parent.handle;
+	long column = 0;
 	if (index >= 0 && index < parent.columnCount) {
 		column = parent.columns [index].handle;
 	} else {
 		column = GTK.gtk_tree_view_get_column (parentHandle, index);
 	}
 	if (column == 0) return new Rectangle (0, 0, 0, 0);
-	long /*int*/ textRenderer = parent.getTextRenderer (column);
-	long /*int*/ pixbufRenderer = parent.getPixbufRenderer (column);
+	long textRenderer = parent.getTextRenderer (column);
+	long pixbufRenderer = parent.getPixbufRenderer (column);
 	if (textRenderer == 0 || pixbufRenderer == 0)  return new Rectangle (0, 0, 0, 0);
 
-	long /*int*/ path = GTK.gtk_tree_model_get_path (parent.modelHandle, handle);
+	long path = GTK.gtk_tree_model_get_path (parent.modelHandle, handle);
 	GTK.gtk_widget_realize (parentHandle);
 
 	boolean isExpander = GTK.gtk_tree_model_iter_n_children (parent.modelHandle, handle) > 0;
@@ -780,11 +782,26 @@ Rectangle getTextBoundsInPixels (int index) {
 	parent.ignoreSize = false;
 	int [] buffer = new int [1];
 	if (GTK.gtk_tree_view_get_expander_column (parentHandle) == column) {
-		GTK.gtk_widget_style_get (parentHandle, OS.expander_size, buffer, 0);
-		rect.x += buffer [0] + TreeItem.EXPANDER_EXTRA_PADDING;
+		if (GTK.GTK4) {
+			long image = GTK.gtk_image_new_from_icon_name(GTK.GTK_NAMED_ICON_PAN_DOWN, GTK.GTK_ICON_SIZE_MENU);
+			GtkAllocation allocation = new GtkAllocation ();
+			GTK.gtk_widget_get_allocation(image, allocation);
+			rect.x += allocation.width + TreeItem.EXPANDER_EXTRA_PADDING;
+		} else {
+			GTK.gtk_widget_style_get (parentHandle, OS.expander_size, buffer, 0);
+			rect.x += buffer [0] + TreeItem.EXPANDER_EXTRA_PADDING;
+		}
+	}
+	int horizontalSeparator;
+	if (GTK.GTK4) {
+		long separator = GTK.gtk_separator_new(GTK.GTK_ORIENTATION_HORIZONTAL);
+		GtkAllocation allocation = new GtkAllocation ();
+		GTK.gtk_widget_get_allocation(separator, allocation);
+		horizontalSeparator = allocation.height;
+	} else {
+		GTK.gtk_widget_style_get (parentHandle, OS.horizontal_separator, buffer, 0);
+		horizontalSeparator = buffer[0];
 	}
-	GTK.gtk_widget_style_get (parentHandle, OS.horizontal_separator, buffer, 0);
-	int horizontalSeparator = buffer[0];
 	rect.x += horizontalSeparator;
 
 	gtk_tree_view_column_cell_get_position (column, textRenderer, x, null);
@@ -795,22 +812,18 @@ Rectangle getTextBoundsInPixels (int index) {
 	 * NOTE: this change has been ported to Tables since Tables/Trees both use the
 	 * same underlying GTK structure.
 	 */
-	if (GTK.GTK3) {
-		Image image = _getImage(index);
-		int imageWidth = 0;
-		if (image != null) {
-			if (DPIUtil.useCairoAutoScale()) {
-				imageWidth = image.getBounds ().width;
-			} else {
-				imageWidth = image.getBoundsInPixels ().width;
-			}
-
-		}
-		if (x [0] < imageWidth) {
-			rect.x += imageWidth;
+	Image image = _getImage(index);
+	int imageWidth = 0;
+	if (image != null) {
+		if (DPIUtil.useCairoAutoScale()) {
+			imageWidth = image.getBounds ().width;
 		} else {
-			rect.x += x [0];
+			imageWidth = image.getBoundsInPixels ().width;
 		}
+
+	}
+	if (x [0] < imageWidth) {
+		rect.x += imageWidth;
 	} else {
 		rect.x += x [0];
 	}
@@ -862,13 +875,8 @@ public void setBackground (Color color) {
 		error (SWT.ERROR_INVALID_ARGUMENT);
 	}
 	if (_getBackground ().equals (color)) return;
-	if (GTK.GTK3) {
-		GdkRGBA gdkRGBA = color != null ? color.handleRGBA : null;
-		GTK.gtk_list_store_set (parent.modelHandle, handle, Table.BACKGROUND_COLUMN, gdkRGBA, -1);
-	} else {
-		GdkColor gdkColor = color != null ? color.handle : null;
-		GTK.gtk_list_store_set (parent.modelHandle, handle, Table.BACKGROUND_COLUMN, gdkColor, -1);
-	}
+	GdkRGBA gdkRGBA = color != null ? color.handle : null;
+	GTK.gtk_list_store_set (parent.modelHandle, handle, Table.BACKGROUND_COLUMN, gdkRGBA, -1);
 	cached = true;
 }
 
@@ -899,29 +907,24 @@ public void setBackground (int index, Color color) {
 	int count = Math.max (1, parent.getColumnCount ());
 	if (0 > index || index > count - 1) return;
 	int modelIndex = parent.columnCount == 0 ? Table.FIRST_COLUMN : parent.columns [index].modelIndex;
-	if (GTK.GTK3) {
-		GdkRGBA gdkRGBA = color != null ? color.handleRGBA : null;
-		GTK.gtk_list_store_set (parent.modelHandle, handle, modelIndex + Table.CELL_BACKGROUND, gdkRGBA, -1);
-	} else {
-		GdkColor gdkColor = color != null ? color.handle : null;
-		GTK.gtk_list_store_set (parent.modelHandle, handle, modelIndex + Table.CELL_BACKGROUND, gdkColor, -1);
-	}
+	GdkRGBA gdkRGBA = color != null ? color.handle : null;
+	GTK.gtk_list_store_set (parent.modelHandle, handle, modelIndex + Table.CELL_BACKGROUND, gdkRGBA, -1);
 	cached = true;
 
 	if (color != null) {
 		boolean customDraw = (parent.columnCount == 0)  ? parent.firstCustomDraw : parent.columns [index].customDraw;
 		if (!customDraw) {
 			if ((parent.style & SWT.VIRTUAL) == 0) {
-				long /*int*/ parentHandle = parent.handle;
-				long /*int*/ column = 0;
+				long parentHandle = parent.handle;
+				long column = 0;
 				if (parent.columnCount > 0) {
 					column = parent.columns [index].handle;
 				} else {
 					column = GTK.gtk_tree_view_get_column (parentHandle, index);
 				}
 				if (column == 0) return;
-				long /*int*/ textRenderer = parent.getTextRenderer (column);
-				long /*int*/ imageRenderer = parent.getPixbufRenderer (column);
+				long textRenderer = parent.getTextRenderer (column);
+				long imageRenderer = parent.getPixbufRenderer (column);
 				GTK.gtk_tree_view_column_set_cell_data_func (column, textRenderer, display.cellDataProc, parentHandle, 0);
 				GTK.gtk_tree_view_column_set_cell_data_func (column, imageRenderer, display.cellDataProc, parentHandle, 0);
 			}
@@ -985,7 +988,7 @@ public void setFont (Font font){
 	if (oldFont == font) return;
 	this.font = font;
 	if (oldFont != null && oldFont.equals (font)) return;
-	long /*int*/ fontHandle = font != null ? font.handle : 0;
+	long fontHandle = font != null ? font.handle : 0;
 	GTK.gtk_list_store_set (parent.modelHandle, handle, Table.FONT_COLUMN, fontHandle, -1);
 	cached = true;
 }
@@ -1026,7 +1029,7 @@ public void setFont (int index, Font font) {
 	if (oldFont != null && oldFont.equals (font)) return;
 
 	int modelIndex = parent.columnCount == 0 ? Table.FIRST_COLUMN : parent.columns [index].modelIndex;
-	long /*int*/ fontHandle  = font != null ? font.handle : 0;
+	long fontHandle  = font != null ? font.handle : 0;
 	GTK.gtk_list_store_set (parent.modelHandle, handle, modelIndex + Table.CELL_FONT, fontHandle, -1);
 	cached = true;
 
@@ -1034,16 +1037,16 @@ public void setFont (int index, Font font) {
 		boolean customDraw = (parent.columnCount == 0)  ? parent.firstCustomDraw : parent.columns [index].customDraw;
 		if (!customDraw) {
 			if ((parent.style & SWT.VIRTUAL) == 0) {
-				long /*int*/ parentHandle = parent.handle;
-				long /*int*/ column = 0;
+				long parentHandle = parent.handle;
+				long column = 0;
 				if (parent.columnCount > 0) {
 					column = parent.columns [index].handle;
 				} else {
 					column = GTK.gtk_tree_view_get_column (parentHandle, index);
 				}
 				if (column == 0) return;
-				long /*int*/ textRenderer = parent.getTextRenderer (column);
-				long /*int*/ imageRenderer = parent.getPixbufRenderer (column);
+				long textRenderer = parent.getTextRenderer (column);
+				long imageRenderer = parent.getPixbufRenderer (column);
 				GTK.gtk_tree_view_column_set_cell_data_func (column, textRenderer, display.cellDataProc, parentHandle, 0);
 				GTK.gtk_tree_view_column_set_cell_data_func (column, imageRenderer, display.cellDataProc, parentHandle, 0);
 			}
@@ -1079,13 +1082,8 @@ public void setForeground (Color color){
 		error (SWT.ERROR_INVALID_ARGUMENT);
 	}
 	if (_getForeground ().equals (color)) return;
-	if (GTK.GTK3) {
-		GdkRGBA gdkRGBA = color != null ? color.handleRGBA : null;
-		GTK.gtk_list_store_set (parent.modelHandle, handle, Table.FOREGROUND_COLUMN, gdkRGBA, -1);
-	} else {
-		GdkColor gdkColor = color != null ? color.handle : null;
-		GTK.gtk_list_store_set (parent.modelHandle, handle, Table.FOREGROUND_COLUMN, gdkColor, -1);
-	}
+	GdkRGBA gdkRGBA = color != null ? color.handle : null;
+	GTK.gtk_list_store_set (parent.modelHandle, handle, Table.FOREGROUND_COLUMN, gdkRGBA, -1);
 	cached = true;
 }
 
@@ -1116,29 +1114,24 @@ public void setForeground (int index, Color color){
 	int count = Math.max (1, parent.getColumnCount ());
 	if (0 > index || index > count - 1) return;
 	int modelIndex = parent.columnCount == 0 ? Table.FIRST_COLUMN : parent.columns [index].modelIndex;
-	if (GTK.GTK3) {
-		GdkRGBA gdkRGBA = color != null ? color.handleRGBA : null;
-		GTK.gtk_list_store_set (parent.modelHandle, handle, modelIndex + Table.CELL_FOREGROUND, gdkRGBA, -1);
-	} else {
-		GdkColor gdkColor = color != null ? color.handle : null;
-		GTK.gtk_list_store_set (parent.modelHandle, handle, modelIndex + Table.CELL_FOREGROUND, gdkColor, -1);
-	}
+	GdkRGBA gdkRGBA = color != null ? color.handle : null;
+	GTK.gtk_list_store_set (parent.modelHandle, handle, modelIndex + Table.CELL_FOREGROUND, gdkRGBA, -1);
 	cached = true;
 
 	if (color != null) {
 		boolean customDraw = (parent.columnCount == 0)  ? parent.firstCustomDraw : parent.columns [index].customDraw;
 		if (!customDraw) {
 			if ((parent.style & SWT.VIRTUAL) == 0) {
-				long /*int*/ parentHandle = parent.handle;
-				long /*int*/ column = 0;
+				long parentHandle = parent.handle;
+				long column = 0;
 				if (parent.columnCount > 0) {
 					column = parent.columns [index].handle;
 				} else {
 					column = GTK.gtk_tree_view_get_column (parentHandle, index);
 				}
 				if (column == 0) return;
-				long /*int*/ textRenderer = parent.getTextRenderer (column);
-				long /*int*/ imageRenderer = parent.getPixbufRenderer (column);
+				long textRenderer = parent.getTextRenderer (column);
+				long imageRenderer = parent.getPixbufRenderer (column);
 				GTK.gtk_tree_view_column_set_cell_data_func (column, textRenderer, display.cellDataProc, parentHandle, 0);
 				GTK.gtk_tree_view_column_set_cell_data_func (column, imageRenderer, display.cellDataProc, parentHandle, 0);
 			}
@@ -1201,113 +1194,90 @@ public void setImage (int index, Image image) {
 	}
 	int count = Math.max (1, parent.getColumnCount ());
 	if (0 > index || index > count - 1) return;
-	long /*int*/ pixbuf = 0;
+	long pixbuf = 0;
 	if (image != null) {
 		ImageList imageList = parent.imageList;
 		if (imageList == null) imageList = parent.imageList = new ImageList ();
 		int imageIndex = imageList.indexOf (image);
-		if (imageIndex == -1) imageIndex = imageList.add (image);
-		pixbuf = imageList.getPixbuf (imageIndex);
-	}
-	/*
-	 * Reset size of pixbufRenderer if we have an image being set that is larger
-	 * than the current size of the pixbufRenderer. Fix for bug 457196.
-	 * We only do this if the size of the pixbufRenderer has not yet been set.
-	 * Otherwise, the pixbufRenderer retains the same size as the first image added.
-	 * See comment #4, Bug 478560. Note that all columns need to have their
-	 * pixbufRenderer set to this size after the initial image is set. NOTE: this
-	 * change has been ported to Tables since Tables/Trees both use the same
-	 * underlying GTK structure.
-	 */
-	if (GTK.GTK3) {
-		if (DPIUtil.useCairoAutoScale()) {
+		if (imageIndex == -1) {
+			imageIndex = imageList.add (image);
+			pixbuf = imageList.getPixbuf (imageIndex);
 			/*
-			 * Bug in GTK the default renderer does scale again on pixbuf.
-			 * Need to scaledown here and no need to scaledown id device scale is 1
+			 * Reset size of pixbufRenderer if we have an image being set that is larger
+			 * than the current size of the pixbufRenderer. Fix for bug 457196.
+			 * We only do this if the size of the pixbufRenderer has not yet been set.
+			 * Otherwise, the pixbufRenderer retains the same size as the first image added.
+			 * See comment #4, Bug 478560. Note that all columns need to have their
+			 * pixbufRenderer set to this size after the initial image is set. NOTE: this
+			 * change has been ported to Tables since Tables/Trees both use the same
+			 * underlying GTK structure.
 			 */
-			if ((!parent.ownerDraw) && (image != null) && (DPIUtil.getDeviceZoom() != 100)) {
-				Rectangle imgSize = image.getBounds();
-				long /*int*/ scaledPixbuf = GDK.gdk_pixbuf_scale_simple(pixbuf, imgSize.width, imgSize.height, GDK.GDK_INTERP_BILINEAR);
-				if (scaledPixbuf !=0) {
-					pixbuf = scaledPixbuf;
-				}
-			}
-		}
-		long /*int*/parentHandle = parent.handle;
-		long /*int*/ column = GTK.gtk_tree_view_get_column (parentHandle, index);
-		long /*int*/ pixbufRenderer = parent.getPixbufRenderer (column);
-		int [] currentWidth = new int [1];
-		int [] currentHeight= new int [1];
-		GTK.gtk_cell_renderer_get_fixed_size (pixbufRenderer, currentWidth, currentHeight);
-		if (!parent.pixbufSizeSet) {
-			if (image != null) {
-				int iWidth, iHeight;
-				if (DPIUtil.useCairoAutoScale()) {
-					iWidth = image.getBounds ().width;
-					iHeight = image.getBounds ().height;
-				} else {
-					iWidth = image.getBoundsInPixels ().width;
-					iHeight = image.getBoundsInPixels ().height;
-				}
-				if (iWidth > currentWidth [0] || iHeight > currentHeight [0]) {
-					GTK.gtk_cell_renderer_set_fixed_size (pixbufRenderer, iWidth, iHeight);
-					parent.pixbufHeight = iHeight;
-					parent.pixbufWidth = iWidth;
-					parent.pixbufSizeSet = true;
+			if (DPIUtil.useCairoAutoScale()) {
+				/*
+				 * Bug in GTK the default renderer does scale again on pixbuf.
+				 * Need to scaledown here and no need to scaledown id device scale is 1
+				 *
+				 * We should resize pixbuf and update pixbuf array in the imagelist only if
+				 * the image is added to the imagelist in this call. If the image is already
+				 * add imageList.getPixbuf returns resized pixbuf.
+				 */
+
+				if ((DPIUtil.getDeviceZoom() != 100)) {
+					Rectangle imgSize = image.getBounds();
+					long scaledPixbuf = GDK.gdk_pixbuf_scale_simple(pixbuf, imgSize.width, imgSize.height, GDK.GDK_INTERP_BILINEAR);
+					if (scaledPixbuf !=0) {
+						pixbuf = scaledPixbuf;
+					}
+					imageList.replacePixbuf(imageIndex, pixbuf);
 				}
 			}
 		} else {
-			/*
-			 * We check to see if the cached value is greater than the size of the pixbufRenderer.
-			 * If it is, then we change the size of the pixbufRenderer accordingly.
-			 * Bug 489025: There is a corner case where the below is triggered when current(Width|Height) is -1,
-			 * which results in icons being set to 0. Fix is to compare only positive sizes.
-			 */
-			if (parent.pixbufWidth > Math.max(currentWidth [0], 0) || parent.pixbufHeight > Math.max(currentHeight [0], 0)) {
-				GTK.gtk_cell_renderer_set_fixed_size (pixbufRenderer, parent.pixbufWidth, parent.pixbufHeight);
+			pixbuf = imageList.getPixbuf (imageIndex);
+		}
+	}
+
+	long parentHandle = parent.handle;
+	long column = GTK.gtk_tree_view_get_column (parentHandle, index);
+	long pixbufRenderer = parent.getPixbufRenderer (column);
+	int [] currentWidth = new int [1];
+	int [] currentHeight= new int [1];
+	GTK.gtk_cell_renderer_get_fixed_size (pixbufRenderer, currentWidth, currentHeight);
+	if (!parent.pixbufSizeSet) {
+		if (image != null) {
+			int iWidth, iHeight;
+			if (DPIUtil.useCairoAutoScale()) {
+				iWidth = image.getBounds ().width;
+				iHeight = image.getBounds ().height;
+			} else {
+				iWidth = image.getBoundsInPixels ().width;
+				iHeight = image.getBoundsInPixels ().height;
 			}
+			if (iWidth > currentWidth [0] || iHeight > currentHeight [0]) {
+				GTK.gtk_cell_renderer_set_fixed_size (pixbufRenderer, iWidth, iHeight);
+				parent.pixbufHeight = iHeight;
+				parent.pixbufWidth = iWidth;
+				parent.pixbufSizeSet = true;
+			}
+		}
+	} else {
+		/*
+		 * We check to see if the cached value is greater than the size of the pixbufRenderer.
+		 * If it is, then we change the size of the pixbufRenderer accordingly.
+		 * Bug 489025: There is a corner case where the below is triggered when current(Width|Height) is -1,
+		 * which results in icons being set to 0. Fix is to compare only positive sizes.
+		 */
+		if (parent.pixbufWidth > Math.max(currentWidth [0], 0) || parent.pixbufHeight > Math.max(currentHeight [0], 0)) {
+			GTK.gtk_cell_renderer_set_fixed_size (pixbufRenderer, parent.pixbufWidth, parent.pixbufHeight);
 		}
 	}
 	int modelIndex = parent.columnCount == 0 ? Table.FIRST_COLUMN : parent.columns [index].modelIndex;
 	GTK.gtk_list_store_set (parent.modelHandle, handle, modelIndex + Table.CELL_PIXBUF, pixbuf, -1);
-	/*
-	 * Bug in GTK.  When in fixed height mode, GTK does not recalculate the cell renderer width
-	 * when the image is changed in the model.  The fix is to force it to recalculate the width if
-	 * more space is required.
-	 */
-	if ((parent.style & SWT.VIRTUAL) != 0 && parent.currentItem == null) {
-		if (image != null) {
-			long /*int*/parentHandle = parent.handle;
-			long /*int*/ column = GTK.gtk_tree_view_get_column (parentHandle, index);
-			int [] w = new int [1];
-			long /*int*/ pixbufRenderer = parent.getPixbufRenderer(column);
-			gtk_tree_view_column_cell_get_position (column, pixbufRenderer, null, w);
-			int iWidth;
-			if (GTK.GTK3 && DPIUtil.useCairoAutoScale()) {
-				iWidth = image.getBounds ().width;
-			} else {
-				iWidth = image.getBoundsInPixels ().width;
-			}
-			if (w[0] < iWidth) {
-				/*
-				* There is no direct way to clear the cell renderer width so we
-				* are relying on the fact that it is done as part of modifying
-				* the style.
-				*/
-				if (!GTK.GTK3) {
-					long /*int*/ style = GTK.gtk_widget_get_modifier_style (parentHandle);
-					parent.modifyStyle (parentHandle, style);
-				}
-			}
-		}
-	}
 	cached = true;
 	/*
 	 * Bug 465056: single column Tables have a very small initial width.
 	 * Fix: when text or an image is set for a Table, compute its
 	 * width and see if it's larger than the maximum of the previous widths.
 	 */
-	long /*int*/ column;
 	if (parent.columnCount == 0) {
 		column = GTK.gtk_tree_view_get_column (parent.handle, index);
 		parent.maxWidth = Math.max(parent.maxWidth, parent.calculateWidth(column, this.handle));
@@ -1347,7 +1317,6 @@ public void setImage (Image [] images) {
  *
  * @param indent the new indent
  *
- * </ul>
  * @exception SWTException <ul>
  *    <li>ERROR_WIDGET_DISPOSED - if the receiver has been disposed</li>
  *    <li>ERROR_THREAD_INVALID_ACCESS - if not called from the thread that created the receiver</li>
@@ -1407,7 +1376,7 @@ public void setText (int index, String string) {
 	 * Fix: when text or an image is set for a Table, compute its
 	 * width and see if it's larger than the maximum of the previous widths.
 	 */
-	long /*int*/ column;
+	long column;
 	if (parent.columnCount == 0) {
 		column = GTK.gtk_tree_view_get_column (parent.handle, index);
 		parent.maxWidth = Math.max(parent.maxWidth, parent.calculateWidth(column, this.handle));
