@@ -41,13 +41,15 @@ import org.eclipse.swt.internal.gtk.*;
  * @noextend This class is not intended to be subclassed by clients.
  */
 public class ToolItem extends Item {
-	long /*int*/ arrowHandle, labelHandle, imageHandle;
-	long /*int*/ eventHandle, proxyMenuItem, provider;
+	long arrowHandle, labelHandle, imageHandle;
+	long eventHandle, proxyMenuItem, provider;
 	ToolBar parent;
 	Control control;
 	Image hotImage, disabledImage;
 	String toolTipText;
 	boolean drawHotImage;
+	/** True iff map has been hooked for this ToolItem. See bug 546914. */
+	boolean mapHooked;
 
 /**
  * Constructs a new instance of this class given its parent
@@ -207,14 +209,11 @@ void createHandle (int index) {
 			 * disabled when it does not contain menu. The fix is to
 			 * find the arrow button handle and enable it.
 			 */
-			long /*int*/ child = GTK.gtk_bin_get_child (handle);
-			long /*int*/ list = GTK.gtk_container_get_children (child);
+			long child = GTK.gtk_bin_get_child (handle);
+			long list = GTK.gtk_container_get_children (child);
 			arrowHandle = OS.g_list_nth_data (list, 1);
 			if (arrowHandle != 0) {
 				GTK.gtk_widget_set_sensitive (arrowHandle, true);
-				if (!GTK.GTK3) {
-					GTK.gtk_widget_set_size_request(GTK.gtk_bin_get_child(arrowHandle), 8, 6);
-				}
 			}
 			break;
 		case SWT.RADIO:
@@ -240,9 +239,6 @@ void createHandle (int index) {
 	if (imageHandle != 0) {
 		GTK.gtk_tool_button_set_icon_widget(handle, imageHandle);
 	}
-	if ((parent.state & FOREGROUND) != 0) {
-		setForegroundColor (parent.getForegroundGdkColor());
-	}
 	if ((parent.state & FONT) != 0) {
 		setFontDescription (parent.getFontDescription());
 	}
@@ -253,6 +249,11 @@ void createHandle (int index) {
 	 */
 	if ((parent.style & SWT.RIGHT) != 0) GTK.gtk_tool_item_set_is_important (handle, true);
 	if ((style & SWT.SEPARATOR) == 0) GTK.gtk_tool_button_set_use_underline (handle, true);
+	/*
+	 * Set the "homogeneous" property to false, otherwise all ToolItems will be as large as
+	 * the largest one in the ToolBar. See bug 548331, 395296 for more information.
+	 */
+	GTK.gtk_tool_item_set_homogeneous(handle, false);
 }
 
 @Override
@@ -309,7 +310,7 @@ public Rectangle getBounds () {
 Rectangle getBoundsInPixels () {
 	checkWidget();
 	parent.forceResize ();
-	long /*int*/ topHandle = topHandle ();
+	long topHandle = topHandle ();
 	GtkAllocation allocation = new GtkAllocation ();
 	GTK.gtk_widget_get_allocation (topHandle, allocation);
 	int x = allocation.x;
@@ -373,7 +374,7 @@ public Image getDisabledImage () {
  */
 public boolean getEnabled () {
 	checkWidget();
-	long /*int*/ topHandle = topHandle ();
+	long topHandle = topHandle ();
 	return GTK.gtk_widget_get_sensitive (topHandle);
 }
 
@@ -468,54 +469,47 @@ public int getWidth () {
 int getWidthInPixels () {
 	checkWidget();
 	parent.forceResize ();
-	long /*int*/ topHandle = topHandle ();
+	long topHandle = topHandle ();
 	GtkAllocation allocation = new GtkAllocation();
 	GTK.gtk_widget_get_allocation (topHandle, allocation);
 	return allocation.width;
 }
 
 @Override
-long /*int*/ gtk_button_press_event (long /*int*/ widget, long /*int*/ event) {
-	GdkEventButton gdkEvent = new GdkEventButton ();
-	OS.memmove (gdkEvent, event, GdkEventButton.sizeof);
-	GtkAllocation allocation = new GtkAllocation ();
-	GTK.gtk_widget_get_allocation (handle, allocation);
-	double x = gdkEvent.x + allocation.x;
-	double y = gdkEvent.y + allocation.y;
-	OS.memmove (event, gdkEvent, GdkEventButton.sizeof);
-	long /*int*/ result = parent.gtk_button_press_event (widget, event);
-	gdkEvent.x = x;
-	gdkEvent.y = y;
-	OS.memmove (event, gdkEvent, GdkEventButton.sizeof);
-	return result;
+long gtk_event (long widget, long event) {
+	if (!GTK.GTK4) return 0;
+	int eventType = GDK.gdk_event_get_event_type(event);
+	switch (eventType) {
+		case GDK.GDK4_BUTTON_PRESS: {
+			return gtk_button_press_event(widget, event);
+		}
+		case GDK.GDK4_BUTTON_RELEASE: {
+			return gtk_button_release_event(widget, event);
+		}
+	}
+	return 0;
 }
 
 @Override
-long /*int*/ gtk_button_release_event (long /*int*/ widget, long /*int*/ event) {
-	GdkEventButton gdkEvent = new GdkEventButton ();
-	OS.memmove (gdkEvent, event, GdkEventButton.sizeof);
-	GtkAllocation allocation = new GtkAllocation ();
-	GTK.gtk_widget_get_allocation (handle, allocation);
-	double x = gdkEvent.x + allocation.x;
-	double y = gdkEvent.y + allocation.y;
-	OS.memmove (event, gdkEvent, GdkEventButton.sizeof);
-	long /*int*/ result = parent.gtk_button_release_event (widget, event);
-	gdkEvent.x = x;
-	gdkEvent.y = y;
-	OS.memmove(event, gdkEvent, GdkEventButton.sizeof);
-	return result;
+long gtk_button_press_event (long widget, long event) {
+	return parent.gtk_button_press_event (widget, event);
 }
 
 @Override
-long /*int*/ gtk_clicked (long /*int*/ widget) {
+long gtk_button_release_event (long widget, long event) {
+	return parent.gtk_button_release_event (widget, event);
+}
+
+@Override
+long gtk_clicked (long widget) {
 	Event event = new Event ();
 	if ((style & SWT.DROP_DOWN) != 0) {
-		long /*int*/ eventPtr = GTK.gtk_get_current_event ();
+		long eventPtr = GTK.gtk_get_current_event ();
 		if (eventPtr != 0) {
-			GdkEvent gdkEvent = new GdkEvent ();
-			OS.memmove (gdkEvent, eventPtr, GdkEvent.sizeof);
-			long /*int*/ topHandle = topHandle();
-			switch (gdkEvent.type) {
+			int eventType = GDK.gdk_event_get_event_type(eventPtr);
+			eventType = Control.fixGdkEventTypeValues(eventType);
+			long topHandle = topHandle();
+			switch (eventType) {
 				case GDK.GDK_KEY_RELEASE: //Fall Through..
 				case GDK.GDK_BUTTON_PRESS:
 				case GDK.GDK_2BUTTON_PRESS:
@@ -543,7 +537,7 @@ long /*int*/ gtk_clicked (long /*int*/ widget) {
 					break;
 				}
 			}
-			GDK.gdk_event_free (eventPtr);
+			gdk_event_free (eventPtr);
 		}
 	}
 	if ((style & SWT.RADIO) != 0) {
@@ -556,7 +550,7 @@ long /*int*/ gtk_clicked (long /*int*/ widget) {
 }
 
 @Override
-long /*int*/ gtk_create_menu_proxy (long /*int*/ widget) {
+long gtk_create_menu_proxy (long widget) {
 	/*
 	 * Feature in GTK. If the item is a radio/check button
 	 * with only image, then that image does not appear in
@@ -580,17 +574,9 @@ long /*int*/ gtk_create_menu_proxy (long /*int*/ widget) {
 		if (imageList != null) {
 			int index = imageList.indexOf (image);
 			if (index != -1) {
-				long /*int*/ pixbuf = imageList.getPixbuf (index);
+				long pixbuf = imageList.getPixbuf (index);
 				byte[] label = null;
 				int [] showImages = new int []{1};
-				long /*int*/ settings = GTK.gtk_settings_get_default();
-				if (settings != 0) {
-					if (!GTK.GTK3) {
-						long /*int*/ property = OS.g_object_class_find_property(OS.G_OBJECT_GET_CLASS(settings), GTK.gtk_menu_images);
-						if (property != 0) OS.g_object_get (settings, GTK.gtk_menu_images, showImages, 0);
-					}
-				}
-
 				/*
 				 * GTK tool items with only image appear as blank items
 				 * in overflow menu when the system property "gtk-menu-images"
@@ -609,38 +595,27 @@ long /*int*/ gtk_create_menu_proxy (long /*int*/ widget) {
 				else {
 					label = Converter.wcsToMbcs(text, true);
 				}
-				long /*int*/ menuItem;
-				if (GTK.GTK3) {
+				long menuItem = GTK.gtk_menu_item_new ();
+				if (menuItem == 0) error (SWT.ERROR_NO_HANDLES);
 
-					menuItem = GTK.gtk_menu_item_new ();
-					if (menuItem == 0) error (SWT.ERROR_NO_HANDLES);
+				long boxHandle = gtk_box_new (GTK.GTK_ORIENTATION_HORIZONTAL, false, 6);
+				if (boxHandle == 0) error (SWT.ERROR_NO_HANDLES);
 
-					long /*int*/ boxHandle = gtk_box_new (GTK.GTK_ORIENTATION_HORIZONTAL, false, 6);
-					if (boxHandle == 0) error (SWT.ERROR_NO_HANDLES);
-
-					long /*int*/ menuLabel = GTK.gtk_accel_label_new (label);
-					if (menuLabel == 0) error (SWT.ERROR_NO_HANDLES);
-					if (GTK.GTK_VERSION >= OS.VERSION (3, 16, 0)) {
-						GTK.gtk_label_set_xalign (labelHandle, 0);
-						GTK.gtk_widget_set_halign (labelHandle, GTK.GTK_ALIGN_FILL);
-					} else {
-						GTK.gtk_misc_set_alignment(labelHandle, 0, 0);
-					}
-
-					long /*int*/ menuImage = GTK.gtk_image_new_from_pixbuf (pixbuf);
-					if (menuImage == 0) error (SWT.ERROR_NO_HANDLES);
-
-					GTK.gtk_container_add (boxHandle, menuImage);
-					GTK.gtk_box_pack_end (boxHandle, menuLabel, true, true, 0);
-					GTK.gtk_container_add (menuItem, boxHandle);
+				long menuLabel = GTK.gtk_accel_label_new (label);
+				if (menuLabel == 0) error (SWT.ERROR_NO_HANDLES);
+				if (GTK.GTK_VERSION >= OS.VERSION (3, 16, 0)) {
+					GTK.gtk_label_set_xalign (labelHandle, 0);
+					GTK.gtk_widget_set_halign (labelHandle, GTK.GTK_ALIGN_FILL);
 				} else {
-					menuItem = GTK.gtk_image_menu_item_new_with_label (label);
-					if (menuItem == 0) error (SWT.ERROR_NO_HANDLES);
-
-					long /*int*/ menuImage = GTK.gtk_image_new_from_pixbuf (pixbuf);
-					if (menuImage == 0) error (SWT.ERROR_NO_HANDLES);
-					GTK.gtk_image_menu_item_set_image (menuItem, menuImage);
+					GTK.gtk_misc_set_alignment(labelHandle, 0, 0);
 				}
+
+				long menuImage = GTK.gtk_image_new_from_pixbuf (pixbuf);
+				if (menuImage == 0) error (SWT.ERROR_NO_HANDLES);
+
+				GTK.gtk_container_add (boxHandle, menuImage);
+				gtk_box_pack_end (boxHandle, menuLabel, true, true, 0);
+				GTK.gtk_container_add (menuItem, boxHandle);
 				GTK.gtk_tool_item_set_proxy_menu_item (widget, buffer, menuItem);
 
 				/*
@@ -657,7 +632,7 @@ long /*int*/ gtk_create_menu_proxy (long /*int*/ widget) {
 	return 0;
 }
 
-void gtk_css_provider_load_from_css (long /*int*/ context, String css) {
+void gtk_css_provider_load_from_css (long context, String css) {
 	/* Utility function. */
 	//@param css : a 'css java' string like "{\nbackground: red;\n}".
 	if (provider == 0) {
@@ -665,11 +640,15 @@ void gtk_css_provider_load_from_css (long /*int*/ context, String css) {
 		GTK.gtk_style_context_add_provider (context, provider, GTK.GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 		OS.g_object_unref (provider);
 	}
-	GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (css, true), -1, null);
+	if (GTK.GTK4) {
+		GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (css, true), -1);
+	} else {
+		GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (css, true), -1, null);
+	}
 }
 
 @Override
-long /*int*/ gtk_enter_notify_event (long /*int*/ widget, long /*int*/ event) {
+long gtk_enter_notify_event (long widget, long event) {
 	parent.gtk_enter_notify_event (widget, event);
 	drawHotImage = (parent.style & SWT.FLAT) != 0 && hotImage != null;
 	if (drawHotImage) {
@@ -677,8 +656,8 @@ long /*int*/ gtk_enter_notify_event (long /*int*/ widget, long /*int*/ event) {
 		if (imageList != null) {
 			int index = imageList.indexOf (hotImage);
 			if (index != -1 && imageHandle != 0) {
-				long /*int*/ pixbuf = imageList.getPixbuf (index);
-				gtk_image_set_from_pixbuf(imageHandle, pixbuf);
+				long pixbuf = imageList.getPixbuf (index);
+				gtk_image_set_from_gicon(imageHandle, pixbuf);
 			}
 		}
 	}
@@ -686,15 +665,18 @@ long /*int*/ gtk_enter_notify_event (long /*int*/ widget, long /*int*/ event) {
 }
 
 @Override
-long /*int*/ gtk_event_after (long /*int*/ widget, long /*int*/ gdkEvent) {
-	GdkEvent event = new GdkEvent ();
-	OS.memmove (event, gdkEvent, GdkEvent.sizeof);
-	switch (event.type) {
+long gtk_event_after (long widget, long gdkEvent) {
+	int eventType = GDK.gdk_event_get_event_type(gdkEvent);
+	eventType = Control.fixGdkEventTypeValues(eventType);
+	switch (eventType) {
 		case GDK.GDK_BUTTON_PRESS: {
-			GdkEventButton gdkEventButton = new GdkEventButton ();
-			OS.memmove (gdkEventButton, gdkEvent, GdkEventButton.sizeof);
-			if (gdkEventButton.button == 3) {
-				parent.showMenu ((int) gdkEventButton.x_root, (int) gdkEventButton.y_root);
+			int [] eventButton = new int [1];
+			GDK.gdk_event_get_button(gdkEvent, eventButton);
+			if (eventButton[0] == 3) {
+				double [] eventRX = new double [1];
+				double [] eventRY = new double [1];
+				GDK.gdk_event_get_root_coords(gdkEvent, eventRX, eventRY);
+				parent.showMenu ((int) eventRX[0], (int) eventRY[0]);
 			}
 			break;
 		}
@@ -703,20 +685,20 @@ long /*int*/ gtk_event_after (long /*int*/ widget, long /*int*/ gdkEvent) {
 }
 
 @Override
-long /*int*/ gtk_focus_in_event (long /*int*/ widget, long /*int*/ event) {
+long gtk_focus_in_event (long widget, long event) {
 	parent.hasChildFocus = true;
 	parent.currentFocusItem = this;
 	return 0;
 }
 
 @Override
-long /*int*/ gtk_focus_out_event (long /*int*/ widget, long /*int*/ event) {
+long gtk_focus_out_event (long widget, long event) {
 	parent.hasChildFocus = false;
 	return 0;
 }
 
 @Override
-long /*int*/ gtk_leave_notify_event (long /*int*/ widget, long /*int*/ event) {
+long gtk_leave_notify_event (long widget, long event) {
 	parent.gtk_leave_notify_event (widget, event);
 	if (drawHotImage) {
 		drawHotImage = false;
@@ -725,8 +707,8 @@ long /*int*/ gtk_leave_notify_event (long /*int*/ widget, long /*int*/ event) {
 			if (imageList != null) {
 				int index = imageList.indexOf (image);
 				if (index != -1 && imageHandle != 0) {
-					long /*int*/ pixbuf = imageList.getPixbuf (index);
-					gtk_image_set_from_pixbuf(imageHandle, pixbuf);
+					long pixbuf = imageList.getPixbuf (index);
+					gtk_image_set_from_gicon(imageHandle, pixbuf);
 				}
 			}
 		}
@@ -735,13 +717,13 @@ long /*int*/ gtk_leave_notify_event (long /*int*/ widget, long /*int*/ event) {
 }
 
 @Override
-long /*int*/ gtk_map (long /*int*/ widget) {
+long gtk_map (long widget) {
 	parent.fixZOrder ();
 	return 0;
 }
 
 @Override
-long /*int*/ gtk_mnemonic_activate (long /*int*/ widget, long /*int*/ arg1) {
+long gtk_mnemonic_activate (long widget, long arg1) {
 	return parent.gtk_mnemonic_activate (widget, arg1);
 }
 
@@ -757,16 +739,35 @@ void hookEvents () {
 	 */
 	eventHandle = GTK.gtk_bin_get_child(handle);
 	if ((style & SWT.DROP_DOWN) != 0) {
-		long /*int*/ list = GTK.gtk_container_get_children(eventHandle);
+		long list = GTK.gtk_container_get_children(eventHandle);
 		eventHandle = OS.g_list_nth_data(list, 0);
 		if (arrowHandle != 0) OS.g_signal_connect_closure (arrowHandle, OS.clicked, display.getClosure (CLICKED), false);
 	}
 	OS.g_signal_connect_closure (handle, OS.create_menu_proxy, display.getClosure (CREATE_MENU_PROXY), false);
+	if (GTK.GTK4) {
+		long keyController = GTK.gtk_event_controller_key_new();
+		GTK.gtk_widget_add_controller(eventHandle, keyController);
+		GTK.gtk_event_controller_set_propagation_phase(keyController, GTK.GTK_PHASE_TARGET);
 
-	OS.g_signal_connect_closure_by_id (eventHandle, display.signalIds [ENTER_NOTIFY_EVENT], 0, display.getClosure (ENTER_NOTIFY_EVENT), false);
-	OS.g_signal_connect_closure_by_id (eventHandle, display.signalIds [LEAVE_NOTIFY_EVENT], 0, display.getClosure (LEAVE_NOTIFY_EVENT), false);
-	OS.g_signal_connect_closure_by_id (eventHandle, display.signalIds [FOCUS_IN_EVENT], 0, display.getClosure (FOCUS_IN_EVENT), false);
-	OS.g_signal_connect_closure_by_id (eventHandle, display.signalIds [FOCUS_OUT_EVENT], 0, display.getClosure (FOCUS_OUT_EVENT), false);
+		long focusAddress = display.focusCallback.getAddress();
+		OS.g_signal_connect (keyController, OS.focus_in, focusAddress, FOCUS_IN);
+		OS.g_signal_connect (keyController, OS.focus_out, focusAddress, FOCUS_OUT);
+
+		long motionController = GTK.gtk_event_controller_motion_new();
+		GTK.gtk_widget_add_controller(eventHandle, motionController);
+		GTK.gtk_event_controller_set_propagation_phase(motionController, GTK.GTK_PHASE_TARGET);
+
+		long enterAddress = display.enterMotionScrollCallback.getAddress();
+		long leaveAddress = display.leaveCallback.getAddress();
+		OS.g_signal_connect (motionController, OS.enter, enterAddress, ENTER);
+		OS.g_signal_connect (motionController, OS.leave, leaveAddress, LEAVE);
+	} else {
+		OS.g_signal_connect_closure_by_id (eventHandle, display.signalIds [FOCUS_IN_EVENT], 0, display.getClosure (FOCUS_IN_EVENT), false);
+		OS.g_signal_connect_closure_by_id (eventHandle, display.signalIds [FOCUS_OUT_EVENT], 0, display.getClosure (FOCUS_OUT_EVENT), false);
+
+		OS.g_signal_connect_closure_by_id (eventHandle, display.signalIds [ENTER_NOTIFY_EVENT], 0, display.getClosure (ENTER_NOTIFY_EVENT), false);
+		OS.g_signal_connect_closure_by_id (eventHandle, display.signalIds [LEAVE_NOTIFY_EVENT], 0, display.getClosure (LEAVE_NOTIFY_EVENT), false);
+	}
 	/*
 	* Feature in GTK.  Usually, GTK widgets propagate all events to their
 	* parent when they are done their own processing.  However, in contrast
@@ -782,12 +783,22 @@ void hookEvents () {
 		GDK.GDK_KEY_PRESS_MASK | GDK.GDK_KEY_RELEASE_MASK |
 		GDK.GDK_FOCUS_CHANGE_MASK;
 	GTK.gtk_widget_add_events (eventHandle, mask);
-	OS.g_signal_connect_closure_by_id (eventHandle, display.signalIds [BUTTON_PRESS_EVENT], 0, display.getClosure (BUTTON_PRESS_EVENT), false);
-	OS.g_signal_connect_closure_by_id (eventHandle, display.signalIds [BUTTON_RELEASE_EVENT], 0, display.getClosure (BUTTON_RELEASE_EVENT), false);
-	OS.g_signal_connect_closure_by_id (eventHandle, display.signalIds [EVENT_AFTER], 0, display.getClosure (EVENT_AFTER), false);
-
-	long /*int*/ topHandle = topHandle ();
-	OS.g_signal_connect_closure_by_id (topHandle, display.signalIds [MAP], 0, display.getClosure (MAP), true);
+	if (GTK.GTK4) {
+		OS.g_signal_connect_closure_by_id (eventHandle, display.signalIds [EVENT], 0, display.getClosure (EVENT), false);
+	} else {
+		OS.g_signal_connect_closure_by_id (eventHandle, display.signalIds [BUTTON_PRESS_EVENT], 0, display.getClosure (BUTTON_PRESS_EVENT), false);
+		OS.g_signal_connect_closure_by_id (eventHandle, display.signalIds [BUTTON_RELEASE_EVENT], 0, display.getClosure (BUTTON_RELEASE_EVENT), false);
+	}
+	if (GTK.GTK4) {
+		OS.g_signal_connect_closure_by_id (eventHandle, display.signalIds [EVENT], 0, display.getClosure (EVENT), false);
+	} else {
+		OS.g_signal_connect_closure_by_id (eventHandle, display.signalIds [EVENT_AFTER], 0, display.getClosure (EVENT_AFTER), false);
+	}
+	if (!mapHooked) {
+		long topHandle = topHandle ();
+		OS.g_signal_connect_closure_by_id (topHandle, display.signalIds [MAP], 0, display.getClosure (MAP), true);
+		mapHooked = true;
+	}
 }
 
 /**
@@ -900,7 +911,7 @@ void resizeHandle(int width, int height) {
 	* a call to gtk_widget_size_request().
 	*/
 	GtkRequisition requisition = new GtkRequisition ();
-	parent.gtk_widget_size_request (handle, requisition);
+	parent.gtk_widget_get_preferred_size (handle, requisition);
 	GtkAllocation allocation = new GtkAllocation ();
 	GTK.gtk_widget_get_allocation (handle, allocation);
 	allocation.width = width;
@@ -944,6 +955,14 @@ public void setControl (Control control) {
 	if (this.control == control) return;
 	this.control = control;
 	parent.relayout ();
+	// Fix the Z-order in order to ensure proper event traversal. See bug 546914.
+	if (control != null) {
+		parent.fixZOrder();
+		if (!mapHooked) {
+			OS.g_signal_connect_closure_by_id (topHandle(), display.signalIds [MAP], 0, display.getClosure (MAP), true);
+			mapHooked = true;
+		}
+	}
 }
 
 /**
@@ -987,67 +1006,33 @@ public void setDisabledImage (Image image) {
  */
 public void setEnabled (boolean enabled) {
 	checkWidget();
-	long /*int*/ topHandle = topHandle ();
+	long topHandle = topHandle ();
 	if (GTK.gtk_widget_get_sensitive (topHandle) == enabled) return;
 	GTK.gtk_widget_set_sensitive (topHandle, enabled);
-
-	if (!GTK.GTK3) {
-		if (enabled) {
-			/*
-			* Bug in GTK (see Eclipse bug 82169). GtkButton requires an enter notify before it
-			* allows the button to be pressed, but events are dropped when
-			* widgets are insensitive.  The fix is to hide and show the
-			* button if the pointer is within its bounds.
-			*/
-			int [] x = new int [1], y = new int [1];
-			gdk_window_get_device_position (parent.paintWindow (), x, y, null);
-			if (getBoundsInPixels ().contains (x [0], y [0])) {
-				GTK.gtk_widget_hide (handle);
-				GTK.gtk_widget_show (handle);
-			}
-		} else {
-			/*
-			* Bug in GTK. Starting with 2.14, if a button is disabled
-			* through on a button press, the field which keeps track
-			* whether the pointer is currently in the button is never updated.
-			* As a result, when it is re-enabled it automatically enters
-			* a PRELIGHT state. The fix is to set a NORMAL state.
-			*/
-			GTK.gtk_widget_set_state (topHandle, GTK.GTK_STATE_NORMAL);
-		}
-	}
 }
 
 boolean setFocus () {
 	return GTK.gtk_widget_child_focus (handle, GTK.GTK_DIR_TAB_FORWARD);
 }
 
-void setFontDescription (long /*int*/ font) {
+void setFontDescription (long font) {
 	if (labelHandle != 0) setFontDescription (labelHandle, font);
 }
 
 void setForegroundRGBA (GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
 	if (labelHandle != 0) setForegroundRGBA (labelHandle, rgba);
 }
 
 void setBackgroundRGBA (GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
 	if (handle != 0) setBackgroundRGBA (handle, rgba);
 }
 
-void setForegroundColor (GdkColor color) {
-	assert !GTK.GTK3 : "GTK2 code was run by GTK3";
-	if (labelHandle != 0) setForegroundColor (labelHandle, color);
-}
-
-void setBackgroundRGBA (long /*int*/ handle, GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
+void setBackgroundRGBA (long handle, GdkRGBA rgba) {
 	if (GTK.GTK_VERSION >= OS.VERSION(3, 14, 0)) {
 		// Form background string
-		long /*int*/ context = GTK.gtk_widget_get_style_context(handle);
+		long context = GTK.gtk_widget_get_style_context(handle);
 		String name = GTK.GTK_VERSION >= OS.VERSION(3,	 20, 0) ? display.gtk_widget_class_get_css_name(handle)
-        		: display.gtk_widget_get_name(handle);
+				: display.gtk_widget_get_name(handle);
 		String css = name + " {background-color: " + display.gtk_rgba_to_css_string(rgba) + "}";
 
 
@@ -1056,13 +1041,12 @@ void setBackgroundRGBA (long /*int*/ handle, GdkRGBA rgba) {
 	}
 }
 
-void setForegroundRGBA (long /*int*/ handle, GdkRGBA rgba) {
-	assert GTK.GTK3 : "GTK3 code was run by GTK2";
+void setForegroundRGBA (long handle, GdkRGBA rgba) {
 	if (GTK.GTK_VERSION < OS.VERSION(3, 14, 0)) {
 		GdkRGBA selectedForeground = display.COLOR_LIST_SELECTION_TEXT_RGBA;
 		GTK.gtk_widget_override_color (handle, GTK.GTK_STATE_FLAG_NORMAL, rgba);
 		GTK.gtk_widget_override_color (handle, GTK.GTK_STATE_FLAG_SELECTED, selectedForeground);
-		long /*int*/ context = GTK.gtk_widget_get_style_context (handle);
+		long context = GTK.gtk_widget_get_style_context (handle);
 		GTK.gtk_style_context_invalidate (context);
 		return;
 	}
@@ -1072,7 +1056,7 @@ void setForegroundRGBA (long /*int*/ handle, GdkRGBA rgba) {
 	} else {
 		toSet = display.COLOR_WIDGET_FOREGROUND_RGBA;
 	}
-	long /*int*/ context = GTK.gtk_widget_get_style_context (handle);
+	long context = GTK.gtk_widget_get_style_context (handle);
 	// Form foreground string
 	String color = display.gtk_rgba_to_css_string(toSet);
 	String css = "* {color: " + color + ";}";
@@ -1133,10 +1117,10 @@ public void setImage (Image image) {
 		} else {
 			imageList.put (imageIndex, image);
 		}
-		long /*int*/ pixbuf = imageList.getPixbuf (imageIndex);
-		gtk_image_set_from_pixbuf(imageHandle, pixbuf);
+		long pixbuf = imageList.getPixbuf (imageIndex);
+		gtk_image_set_from_gicon(imageHandle, pixbuf);
 	} else {
-		gtk_image_set_from_pixbuf(imageHandle, 0);
+		gtk_image_set_from_gicon(imageHandle, 0);
 	}
 	/*
 	* If Text/Image of a tool-item changes, then it is
@@ -1199,7 +1183,6 @@ boolean setTabItemFocus (boolean next) {
 /**
  * Sets the receiver's text. The string may include
  * the mnemonic character.
- * </p>
  * <p>
  * Mnemonics are indicated by an '&amp;' that causes the next
  * character to be the mnemonic.  When the user presses a
@@ -1262,7 +1245,7 @@ public void setText (String string) {
  * </p>
  * <p>
  * NOTE: This operation is a hint and behavior is platform specific, on Windows
- * for CJK-style mnemonics of the form " (&C)" at the end of the tooltip text
+ * for CJK-style mnemonics of the form " (&amp;C)" at the end of the tooltip text
  * are not shown in tooltip.
  * </p>
  *
@@ -1296,9 +1279,9 @@ public void setToolTipText (String string) {
 }
 
 void setToolTipText (Shell shell, String newString) {
-	long /*int*/ child = GTK.gtk_bin_get_child (handle);
+	long child = GTK.gtk_bin_get_child (handle);
 	if ((style & SWT.DROP_DOWN) != 0) {
-		long /*int*/ list = GTK.gtk_container_get_children (child);
+		long list = GTK.gtk_container_get_children (child);
 		child = OS.g_list_nth_data (list, 0);
 		if (arrowHandle != 0) shell.setToolTipText (arrowHandle, newString);
 	}
