@@ -24,14 +24,13 @@ import org.eclipse.swt.internal.gtk.*;
 /**
  * Instances of this class represent popup windows that are used
  * to inform or warn the user.
- * <p>
  * <dl>
  * <dt><b>Styles:</b></dt>
  * <dd>BALLOON, ICON_ERROR, ICON_INFORMATION, ICON_WARNING</dd>
  * <dt><b>Events:</b></dt>
  * <dd>Selection</dd>
  * </dl>
- * </p><p>
+ * <p>
  * Note: Only one of the styles ICON_ERROR, ICON_INFORMATION,
  * and ICON_WARNING may be specified.
  * </p><p>
@@ -50,8 +49,8 @@ public class ToolTip extends Widget {
 	String text, message;
 	TrayItem item;
 	int x, y, timerId;
-	long /*int*/ layoutText = 0, layoutMessage = 0;
-	long /*int*/ provider;
+	long layoutText = 0, layoutMessage = 0;
+	long provider;
 	int [] borderPolygon;
 	boolean spikeAbove, autohide;
 
@@ -150,12 +149,12 @@ void configure () {
 	int monitorNumber;
 	GdkRectangle dest = new GdkRectangle ();
 	if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0)) {
-		long /*int*/ display = GDK.gdk_display_get_default();
+		long display = GDK.gdk_display_get_default();
 		multipleMonitors = GDK.gdk_display_get_n_monitors(display) > 1;
-		long /*int*/ monitor = GDK.gdk_display_get_monitor_at_point(display, point.x, point.y);
+		long monitor = GDK.gdk_display_get_monitor_at_point(display, point.x, point.y);
 		GDK.gdk_monitor_get_geometry (monitor, dest);
 	} else {
-		long /*int*/ screen = GDK.gdk_screen_get_default ();
+		long screen = GDK.gdk_screen_get_default ();
 		multipleMonitors = GDK.gdk_screen_get_n_monitors(screen) > 1;
 		monitorNumber = GDK.gdk_screen_get_monitor_at_point(screen, point.x, point.y);
 		GDK.gdk_screen_get_monitor_geometry(screen, monitorNumber, dest);
@@ -169,7 +168,7 @@ void configure () {
 	GTK.gtk_window_resize (handle, w, h + TIP_HEIGHT);
 	int[] polyline;
 	Rectangle bounds = display.getBounds();
-	int width = bounds != null ? bounds.width : GDK.gdk_screen_width();
+	int width = bounds != null && GTK.GTK4 ? bounds.width : GDK.gdk_screen_width();
 	spikeAbove = dest.height >= y + h + TIP_HEIGHT;
 	if ((dest.width >= x + w) || (multipleMonitors && width >= x + w)) {
 		if (dest.height >= y + h + TIP_HEIGHT) {
@@ -284,7 +283,7 @@ void createHandle (int index) {
 		state |= HANDLE;
 		handle = GTK.gtk_window_new (GTK.GTK_WINDOW_POPUP);
 		Color background = display.getSystemColor (SWT.COLOR_INFO_BACKGROUND);
-		long /*int*/ context = GTK.gtk_widget_get_style_context (handle);
+		long context = GTK.gtk_widget_get_style_context (handle);
 		GdkRGBA bgRGBA = background.handle;
 		String name = GTK.GTK_VERSION >= OS.VERSION(3, 20, 0) ? "window" : "GtkWindow";
 		String css = name + " {background-color: " + display.gtk_rgba_to_css_string(bgRGBA) + ";}";
@@ -294,7 +293,7 @@ void createHandle (int index) {
 	}
 }
 
-void gtk_css_provider_load_from_css (long /*int*/ context, String css) {
+void gtk_css_provider_load_from_css (long context, String css) {
 	/* Utility function. */
 	//@param css : a 'css java' string like "{\nbackground: red;\n}".
 	if (provider == 0) {
@@ -302,7 +301,11 @@ void gtk_css_provider_load_from_css (long /*int*/ context, String css) {
 		GTK.gtk_style_context_add_provider (context, provider, GTK.GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 		OS.g_object_unref (provider);
 	}
-	GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (css, true), -1, null);
+	if (GTK.GTK4) {
+		GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (css, true), -1);
+	} else {
+		GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (css, true), -1, null);
+	}
 }
 
 @Override
@@ -316,7 +319,7 @@ void createWidget (int index) {
 
 @Override
 void destroyWidget () {
-	long /*int*/ topHandle = topHandle ();
+	long topHandle = topHandle ();
 	if (parent != null) parent.removeTooTip (this);
 	releaseHandle ();
 	if (topHandle != 0 && (state & HANDLE) != 0) {
@@ -349,7 +352,7 @@ Point getLocation () {
 	int x = this.x;
 	int y = this.y;
 	if (item != null) {
-		long /*int*/ itemHandle = item.handle;
+		long itemHandle = item.handle;
 		GdkRectangle area = new GdkRectangle ();
 		GTK.gtk_status_icon_get_geometry (itemHandle, 0, area, 0);
 		x = area.x + area.width / 2;
@@ -357,7 +360,15 @@ Point getLocation () {
 	}
 	if (x == -1 || y == -1) {
 		int [] px = new int [1], py = new int [1];
-		gdk_window_get_device_position (0, px, py, null);
+		if (GTK.GTK4) {
+			/*
+			 * TODO: calling gdk_window_get_device_position() with a 0
+			 * for the GdkWindow uses gdk_get_default_root_window(),
+			 * which doesn't exist on GTK4.
+			 */
+		} else {
+			display.gdk_window_get_device_position (0, px, py, null);
+		}
 		x = px [0];
 		y = py [0];
 	}
@@ -473,29 +484,30 @@ public boolean getVisible () {
 }
 
 @Override
-long /*int*/ gtk_button_press_event (long /*int*/ widget, long /*int*/ event) {
+long gtk_event (long widget, long event) {
+	if (!GTK.GTK4) return 0;
+	int eventType = GDK.gdk_event_get_event_type(event);
+	switch (eventType) {
+		case GDK.GDK4_BUTTON_PRESS: {
+			return gtk_button_press_event(widget, event);
+		}
+		case GDK.GDK4_BUTTON_RELEASE: {
+			return gtk_button_release_event(widget, event);
+		}
+	}
+	return 0;
+}
+
+@Override
+long gtk_button_press_event (long widget, long event) {
 	sendSelectionEvent (SWT.Selection, null, true);
 	setVisible (false);
 	return 0;
 }
 
-void drawTooltip (long /*int*/ cr) {
-	long /*int*/ gdkResource = GTK.GTK4 ? gtk_widget_get_surface(handle) : gtk_widget_get_window (handle);
+void drawTooltip (long cairo) {
 	int x = BORDER + PADDING;
 	int y = BORDER + PADDING;
-	long /*int*/ cairo = 0;
-	long /*int*/ context = 0;
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0)) {
-		if (cr == 0) {
-			long /*int*/ cairo_region = GDK.gdk_window_get_visible_region(gdkResource);
-			context = GDK.gdk_window_begin_draw_frame(gdkResource, cairo_region);
-			cairo = GDK.gdk_drawing_context_get_cairo_context(context);
-		} else {
-			cairo = cr;
-		}
-	} else {
-		cairo = cr != 0 ? cr : GDK.gdk_cairo_create(gdkResource);
-	}
 	if (cairo == 0) error (SWT.ERROR_NO_HANDLES);
 	int count = borderPolygon.length / 2;
 	if (count != 0) {
@@ -517,7 +529,7 @@ void drawTooltip (long /*int*/ cr) {
 			case SWT.ICON_WARNING: buffer = Converter.wcsToMbcs ("dialog-warning", true); break;
 		}
 		if (buffer != null) {
-			long /*int*/ pixbuf = GTK.gtk_icon_theme_load_icon(GTK.gtk_icon_theme_get_default(), buffer, GTK.GTK_ICON_SIZE_MENU, 0, 0);
+			long pixbuf = GTK.gtk_icon_theme_load_icon(GTK.gtk_icon_theme_get_default(), buffer, GTK.GTK_ICON_SIZE_MENU, 0, 0);
 			GDK.gdk_cairo_set_source_pixbuf(cairo, pixbuf, x, y);
 			Cairo.cairo_paint (cairo);
 			OS.g_object_unref (pixbuf);
@@ -539,33 +551,28 @@ void drawTooltip (long /*int*/ cr) {
 		Cairo.cairo_move_to(cairo, x, y);
 		OS.pango_cairo_show_layout(cairo, layoutMessage);
 	}
-	if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0)) {
-		if (cairo != cr && context != 0) GDK.gdk_window_end_draw_frame(gdkResource, context);
-	} else {
-		if (cairo != cr) Cairo.cairo_destroy(cairo);
-	}
 }
 
 @Override
-long /*int*/ gtk_draw (long /*int*/ widget, long /*int*/ cairo) {
+long gtk_draw (long widget, long cairo) {
 	if ((state & OBSCURED) != 0) return 0;
 	drawTooltip (cairo);
 	return 0;
 }
 
 @Override
-long /*int*/ gtk_size_allocate (long /*int*/ widget, long /*int*/ allocation) {
+long gtk_size_allocate (long widget, long allocation) {
 	Point point = getLocation ();
 	int x = point.x;
 	int y = point.y;
 	GTK.gtk_widget_realize (widget);
 	GdkRectangle dest = new GdkRectangle ();
 	if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0)) {
-		long /*int*/ display = GDK.gdk_display_get_default();
-		long /*int*/ monitor = GDK.gdk_display_get_monitor_at_point(display, x, y);
+		long display = GDK.gdk_display_get_default();
+		long monitor = GDK.gdk_display_get_monitor_at_point(display, x, y);
 		GDK.gdk_monitor_get_geometry(monitor, dest);
 	} else {
-		long /*int*/ screen = GDK.gdk_screen_get_default ();
+		long screen = GDK.gdk_screen_get_default ();
 		int monitorNumber = GDK.gdk_screen_get_monitor_at_point(screen, point.x, point.y);
 		GDK.gdk_screen_get_monitor_geometry (screen, monitorNumber, dest);
 	}
@@ -583,11 +590,13 @@ long /*int*/ gtk_size_allocate (long /*int*/ widget, long /*int*/ allocation) {
 void hookEvents () {
 	if ((style & SWT.BALLOON) != 0) {
 		OS.g_signal_connect_closure_by_id (handle, display.signalIds [EXPOSE_EVENT], 0, display.getClosure (EXPOSE_EVENT), true);
-		if (GTK.GTK_VERSION >= OS.VERSION (3, 9, 0)) {
-			OS.g_signal_connect_closure_by_id (handle, display.signalIds [EXPOSE_EVENT_INVERSE], 0, display.getClosure (EXPOSE_EVENT_INVERSE), true);
-		}
+		OS.g_signal_connect_closure_by_id (handle, display.signalIds [EXPOSE_EVENT_INVERSE], 0, display.getClosure (EXPOSE_EVENT_INVERSE), true);
 		GTK.gtk_widget_add_events (handle, GDK.GDK_BUTTON_PRESS_MASK);
-		OS.g_signal_connect_closure (handle, OS.button_press_event, display.getClosure (BUTTON_PRESS_EVENT), false);
+		if (GTK.GTK4) {
+			OS.g_signal_connect_closure_by_id (handle, display.signalIds [EVENT], 0, display.getClosure (EVENT), false);
+		} else {
+			OS.g_signal_connect_closure (handle, OS.button_press_event, display.getClosure (BUTTON_PRESS_EVENT), false);
+		}
 	}
 }
 
@@ -786,13 +795,13 @@ public void setText (String string) {
 		byte [] buffer = Converter.wcsToMbcs (text, true);
 		layoutText = GTK.gtk_widget_create_pango_layout (handle, buffer);
 		OS.pango_layout_set_auto_dir (layoutText, false);
-		long /*int*/ boldAttr = OS.pango_attr_weight_new (OS.PANGO_WEIGHT_BOLD);
+		long boldAttr = OS.pango_attr_weight_new (OS.PANGO_WEIGHT_BOLD);
 		PangoAttribute attribute = new PangoAttribute ();
 		OS.memmove (attribute, boldAttr, PangoAttribute.sizeof);
 		attribute.start_index = 0;
 		attribute.end_index = buffer.length;
 		OS.memmove (boldAttr, attribute, PangoAttribute.sizeof);
-		long /*int*/ attrList = OS.pango_attr_list_new ();
+		long attrList = OS.pango_attr_list_new ();
 		OS.pango_attr_list_insert (attrList, boldAttr);
 		OS.pango_layout_set_attributes (layoutText, attrList);
 		OS.pango_attr_list_unref (attrList);
@@ -826,7 +835,7 @@ public void setVisible (boolean visible) {
 			configure ();
 			GTK.gtk_widget_show (handle);
 		} else {
-			long /*int*/ vboxHandle = parent.vboxHandle;
+			long vboxHandle = parent.vboxHandle;
 			StringBuilder string = new StringBuilder (text);
 			if (text.length () > 0) string.append ("\n\n");
 			string.append (message);
@@ -838,7 +847,7 @@ public void setVisible (boolean visible) {
 		if ((style & SWT.BALLOON) != 0) {
 			GTK.gtk_widget_hide (handle);
 		} else {
-			long /*int*/ vboxHandle = parent.vboxHandle;
+			long vboxHandle = parent.vboxHandle;
 			byte[] buffer = Converter.wcsToMbcs("", true);
 			GTK.gtk_widget_set_tooltip_text(vboxHandle, buffer);
 		}
@@ -846,7 +855,7 @@ public void setVisible (boolean visible) {
 }
 
 @Override
-long /*int*/ timerProc (long /*int*/ widget) {
+long timerProc (long widget) {
 	if ((style & SWT.BALLOON) != 0) {
 		GTK.gtk_widget_hide (handle);
 	}
