@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -18,6 +18,7 @@ import org.eclipse.swt.*;
 import org.eclipse.swt.events.*;
 import org.eclipse.swt.graphics.*;
 import org.eclipse.swt.internal.*;
+import org.eclipse.swt.internal.cairo.*;
 import org.eclipse.swt.internal.gtk.*;
 
 /**
@@ -46,13 +47,14 @@ import org.eclipse.swt.internal.gtk.*;
 public class Tracker extends Widget {
 	Composite parent;
 	Cursor cursor;
-	long /*int*/ lastCursor, window, overlay;
+	long lastCursor, window, overlay;
+	long surface;
 	boolean tracking, cancelled, grabbed, stippled;
 	Rectangle [] rectangles = new Rectangle [0], proportions = rectangles;
 	Rectangle bounds;
 	int cursorOrientation = SWT.NONE;
 	int oldX, oldY;
-	long /*int*/ provider; // Gtk3.14
+	long provider; // Gtk3.14
 
 	// Re-use/cache some items for performance reasons as draw-events must be efficient to prevent jitter.
 	Rectangle cachedCombinedDisplayResolution = Display.getDefault().getBounds(); // Cached for performance reasons.
@@ -207,13 +209,12 @@ Point adjustMoveCursor () {
 	Point point = display.mapInPixels (parent, null, newX, newY);
 	display.setCursorLocation (point);
 
-	/*
-	 * The call to XWarpPointer does not always place the pointer on the
-	 * exact location that is specified, so do a query (below) to get the
-	 * actual location of the pointer after it has been moved.
-	 */
 	int [] actualX = new int [1], actualY = new int [1], state = new int [1];
-	gdk_window_get_device_position (window, actualX, actualY, state);
+	if (GTK.GTK4) {
+		display.gdk_surface_get_device_position (surface, actualX, actualY, state);
+	} else {
+		display.gdk_window_get_device_position (window, actualX, actualY, state);
+	}
 	return new Point (actualX [0], actualY [0]);
 }
 
@@ -246,7 +247,11 @@ Point adjustResizeCursor () {
 	 * actual location of the pointer after it has been moved.
 	 */
 	int [] actualX = new int [1], actualY = new int [1], state = new int [1];
-	gdk_window_get_device_position (window, actualX, actualY, state);
+	if (GTK.GTK4) {
+		display.gdk_surface_get_device_position (surface, actualX, actualY, state);
+	} else {
+		display.gdk_window_get_device_position (window, actualX, actualY, state);
+	}
 	return new Point (actualX [0], actualY [0]);
 }
 
@@ -324,100 +329,95 @@ Rectangle [] computeProportions (Rectangle [] rects) {
  * @param rects
  */
 void drawRectangles (Rectangle [] rects) {
-	long /*int*/ window = GDK.gdk_get_default_root_window();
-	if (parent != null) {
-		window = gtk_widget_get_window (parent.paintHandle());
+	long gdkResource = 0;
+	if (GTK.GTK4) {
+		if (parent != null) gdkResource = gtk_widget_get_surface(parent.handle);
+	} else {
+		gdkResource = GDK.gdk_get_default_root_window();
 	}
-	if (window == 0) return;
-	if (GTK.GTK3) {
-		if (overlay == 0) return;
-		GTK.gtk_widget_shape_combine_region (overlay, 0);
+	if (parent != null) {
+		long paintHandle = parent.paintHandle();
+		gdkResource = GTK.GTK4 ? gtk_widget_get_surface(paintHandle) : gtk_widget_get_window (paintHandle);
+	}
+	if (gdkResource == 0) return;
 
-		// Bug 498217.
-		// As of Gtk 3.9.1, Commit a60ccd3672467efb454b121993febc36f33cbc79, off-screen GDK windows are not processed.
-		// Because of this gtk doesn't send move events to SWT. Platform.UI uses an off-screen tracker to draw
-		// custom rectangles for it's part-drag-preview. Drawing/updates for these broke because tracker is off screen.
-		// Solution: If a tracker is to move off-screen, then instead draw it 1x1 and transparent.
-		boolean isOnScreen = true;
-		{ // Figure out if the combined rectangles are on or off screen.
+	if (overlay == 0) return;
+	GTK.gtk_widget_shape_combine_region (overlay, 0);
 
-			// Produce a single rectangle big enough to contain all rects.
-			// Note, this is different from loop below that creates a Region. (See region != rectangle note in javadoc).
-			cachedUnion.x = rects[0].x;
-			cachedUnion.y = rects[0].y;
-			cachedUnion.width = rects[0].width;
-			cachedUnion.height = rects[0].height;
-			if (rects.length > 1) {
-				for (int i = 1; i < rects.length; i++) {
-					cachedUnion.add(rects[i]);
-				}
-			}
+	// Bug 498217.
+	// As of Gtk 3.9.1, Commit a60ccd3672467efb454b121993febc36f33cbc79, off-screen GDK windows are not processed.
+	// Because of this gtk doesn't send move events to SWT. Platform.UI uses an off-screen tracker to draw
+	// custom rectangles for it's part-drag-preview. Drawing/updates for these broke because tracker is off screen.
+	// Solution: If a tracker is to move off-screen, then instead draw it 1x1 and transparent.
+	boolean isOnScreen = true;
+	{ // Figure out if the combined rectangles are on or off screen.
 
-			// Ensure we have absolute screen coordinates. (btw, there are no absolute coordinates on Wayland, so Tracker(Display) is probably broken).
-			if (parent != null) {  // if Tracker(Display) has absolute coords.  Tracker(Composite) has relative. For relative, we need to find absolute.
-				cachedUnion = display.mapInPixels(parent, null, cachedUnion) ;
-			}
-
-			if (!cachedCombinedDisplayResolution.intersects(cachedUnion)) {
-				isOnScreen = false;
+		// Produce a single rectangle big enough to contain all rects.
+		// Note, this is different from loop below that creates a Region. (See region != rectangle note in javadoc).
+		cachedUnion.x = rects[0].x;
+		cachedUnion.y = rects[0].y;
+		cachedUnion.width = rects[0].width;
+		cachedUnion.height = rects[0].height;
+		if (rects.length > 1) {
+			for (int i = 1; i < rects.length; i++) {
+				cachedUnion.add(rects[i]);
 			}
 		}
 
-		long /*int*/ region = GDK.gdk_region_new ();
-		GdkRectangle rect = new GdkRectangle();
-		if (isOnScreen) {
-			// Combine Rects into a region. (region is not necessarily a rectangle, E.g it can be 'L' shaped etc..).
-			for (int i = 0; i < rects.length; i++) {
-				// Turn filled rectangles into just the outer lines by drawing one line at a time.
-				Rectangle r = parent != null ? display.mapInPixels(parent, null, rects[i]) : rects[i];
-				rect.x = r.x;
-				rect.y = r.y;
-				rect.width = r.width + 1;
-				rect.height = 1;
-				GDK.gdk_region_union_with_rect(region, rect); // Top line
-				rect.width = 1;
-				rect.height = r.height + 1;
-				GDK.gdk_region_union_with_rect(region, rect); // Left line.
-				rect.x = r.x + r.width;
-				GDK.gdk_region_union_with_rect(region, rect); // Right line.
-				rect.x = r.x;
-				rect.y = r.y + r.height;
-				rect.width = r.width + 1;
-				rect.height = 1;
-				GDK.gdk_region_union_with_rect(region, rect); // Bottom line
-			}
-			setTrackerBackground(true);
-		} else { // Offscreen
-			// part of Bug 498217 fix. Tracker must be at least 1x1 for move events to work.
-			rect.x = 0;
-			rect.y = 0;
+		// Ensure we have absolute screen coordinates. (btw, there are no absolute coordinates on Wayland, so Tracker(Display) is probably broken).
+		if (parent != null) {  // if Tracker(Display) has absolute coords.  Tracker(Composite) has relative. For relative, we need to find absolute.
+			cachedUnion = display.mapInPixels(parent, null, cachedUnion) ;
+		}
+
+		if (!cachedCombinedDisplayResolution.intersects(cachedUnion)) {
+			isOnScreen = false;
+		}
+	}
+
+	long region = Cairo.cairo_region_create ();
+	cairo_rectangle_int_t rect = new cairo_rectangle_int_t();
+	if (isOnScreen) {
+		// Combine Rects into a region. (region is not necessarily a rectangle, E.g it can be 'L' shaped etc..).
+		for (int i = 0; i < rects.length; i++) {
+			// Turn filled rectangles into just the outer lines by drawing one line at a time.
+			Rectangle r = parent != null ? display.mapInPixels(parent, null, rects[i]) : rects[i];
+			rect.x = r.x;
+			rect.y = r.y;
+			rect.width = r.width + 1;
 			rect.height = 1;
+			Cairo.cairo_region_union_rectangle(region, rect); // Top line
 			rect.width = 1;
-			GDK.gdk_region_union_with_rect(region, rect);
-			setTrackerBackground(false);
+			rect.height = r.height + 1;
+			Cairo.cairo_region_union_rectangle(region, rect); // Left line.
+			rect.x = r.x + r.width;
+			Cairo.cairo_region_union_rectangle(region, rect); // Right line.
+			rect.x = r.x;
+			rect.y = r.y + r.height;
+			rect.width = r.width + 1;
+			rect.height = 1;
+			Cairo.cairo_region_union_rectangle(region, rect); // Bottom line
 		}
+		setTrackerBackground(true);
+	} else { // Offscreen
+		// part of Bug 498217 fix. Tracker must be at least 1x1 for move events to work.
+		rect.x = 0;
+		rect.y = 0;
+		rect.height = 1;
+		rect.width = 1;
+		Cairo.cairo_region_union_rectangle(region, rect);
+		setTrackerBackground(false);
+	}
 
-		GTK.gtk_widget_shape_combine_region (overlay, region);
-		GDK.gdk_region_destroy (region);
-		long /*int*/ overlayWindow = GTK.gtk_widget_get_window (overlay);
+	GTK.gtk_widget_shape_combine_region (overlay, region);
+	Cairo.cairo_region_destroy (region);
+	if (GTK.GTK4) {
+		long overlaySurface = GTK.gtk_widget_get_surface (overlay);
+		GDK.gdk_surface_hide (overlaySurface);
+		GDK.gdk_surface_show (overlaySurface);
+	} else {
+		long overlayWindow = GTK.gtk_widget_get_window (overlay);
 		GDK.gdk_window_hide (overlayWindow);
 		GDK.gdk_window_show (overlayWindow);
-	} else { // GTK2
-		long /*int*/ gc = GDK.gdk_gc_new (window);
-		if (gc == 0) return;
-		long /*int*/ colormap = GDK.gdk_colormap_get_system ();
-		GdkColor color = new GdkColor ();
-		GDK.gdk_color_white (colormap, color);
-		GDK.gdk_gc_set_foreground (gc, color);
-		GDK.gdk_gc_set_subwindow (gc, GDK.GDK_INCLUDE_INFERIORS);
-		GDK.gdk_gc_set_function (gc, GDK.GDK_XOR);
-		for (int i=0; i<rects.length; i++) {
-			Rectangle rect = rects [i];
-			int x = rect.x;
-			if (parent != null && (parent.style & SWT.MIRRORED) != 0) x = parent.getClientWidth () - rect.width - x;
-			GDK.gdk_draw_rectangle (window, gc, 0, x, rect.y, rect.width, rect.height);
-		}
-		OS.g_object_unref (gc);
 	}
 }
 
@@ -469,25 +469,29 @@ public boolean getStippled () {
 }
 
 boolean grab () {
-	long /*int*/ cursor = this.cursor != null ? this.cursor.handle : 0;
-	int result = gdk_pointer_grab (window, GDK.GDK_OWNERSHIP_NONE, false, GDK.GDK_POINTER_MOTION_MASK | GDK.GDK_BUTTON_RELEASE_MASK, 0, cursor, GDK.GDK_CURRENT_TIME);
+	long cursor = this.cursor != null ? this.cursor.handle : 0;
+	int result = gdk_pointer_grab (GTK.GTK4 ? surface : window, GDK.GDK_OWNERSHIP_NONE, false,
+			GDK.GDK_POINTER_MOTION_MASK | GDK.GDK_BUTTON_RELEASE_MASK, 0, cursor, GDK.GDK_CURRENT_TIME);
 	return result == GDK.GDK_GRAB_SUCCESS;
 }
 
 @Override
-long /*int*/ gtk_button_release_event (long /*int*/ widget, long /*int*/ event) {
-	return gtk_mouse (GDK.GDK_BUTTON_RELEASE, widget, event);
+long gtk_button_release_event (long widget, long event) {
+	Control.mouseDown = false;
+	return gtk_mouse (GTK.GTK4 ? GDK.GDK4_BUTTON_RELEASE : GDK.GDK_BUTTON_RELEASE, widget, event);
 }
 
 @Override
-long /*int*/ gtk_key_press_event (long /*int*/ widget, long /*int*/ eventPtr) {
-	long /*int*/ result = super.gtk_key_press_event (widget, eventPtr);
+long gtk_key_press_event (long widget, long eventPtr) {
+	long result = super.gtk_key_press_event (widget, eventPtr);
 	if (result != 0) return result;
-	GdkEventKey keyEvent = new GdkEventKey ();
-	OS.memmove (keyEvent, eventPtr, GdkEventKey.sizeof);
-	int stepSize = ((keyEvent.state & GDK.GDK_CONTROL_MASK) != 0) ? STEPSIZE_SMALL : STEPSIZE_LARGE;
+	int [] state = new int[1];
+	GDK.gdk_event_get_state(eventPtr, state);
+	int [] keyval = new int[1];
+	GDK.gdk_event_get_keyval(eventPtr, keyval);
+	int stepSize = ((state[0] & GDK.GDK_CONTROL_MASK) != 0) ? STEPSIZE_SMALL : STEPSIZE_LARGE;
 	int xChange = 0, yChange = 0;
-	switch (keyEvent.keyval) {
+	switch (keyval[0]) {
 		case GDK.GDK_Escape:
 			cancelled = true;
 			// fallthrough
@@ -556,10 +560,6 @@ long /*int*/ gtk_key_press_event (long /*int*/ widget, long /*int*/ eventPtr) {
 				draw = true;
 			}
 			if (draw) {
-				if (!GTK.GTK3) {
-					drawRectangles (rectsToErase);
-					update ();
-				}
 				drawRectangles (rectangles);
 			}
 			Point cursorPos = adjustResizeCursor ();
@@ -618,19 +618,23 @@ long /*int*/ gtk_key_press_event (long /*int*/ widget, long /*int*/ eventPtr) {
 }
 
 @Override
-long /*int*/ gtk_motion_notify_event (long /*int*/ widget, long /*int*/ eventPtr) {
-	long /*int*/ cursor = this.cursor != null ? this.cursor.handle : 0;
+long gtk_motion_notify_event (long widget, long eventPtr) {
+	long cursor = this.cursor != null ? this.cursor.handle : 0;
 	if (cursor != lastCursor) {
 		ungrab ();
 		grabbed = grab ();
 		lastCursor = cursor;
 	}
-	return gtk_mouse (GDK.GDK_MOTION_NOTIFY, widget, eventPtr);
+	return gtk_mouse (GTK.GTK4 ? GDK.GDK4_MOTION_NOTIFY : GDK.GDK_MOTION_NOTIFY, widget, eventPtr);
 }
 
-long /*int*/ gtk_mouse (int eventType, long /*int*/ widget, long /*int*/ eventPtr) {
+long gtk_mouse (int eventType, long widget, long eventPtr) {
 	int [] newX = new int [1], newY = new int [1];
-	gdk_window_get_device_position (window, newX, newY, null);
+	if (GTK.GTK4) {
+		display.gdk_surface_get_device_position (surface, newX, newY, null);
+	} else {
+		display.gdk_window_get_device_position (window, newX, newY, null);
+	}
 	if (oldX != newX [0] || oldY != newY [0]) {
 		Rectangle [] oldRectangles = rectangles;
 		Rectangle [] rectsToErase = new Rectangle [rectangles.length];
@@ -683,10 +687,6 @@ long /*int*/ gtk_mouse (int eventType, long /*int*/ widget, long /*int*/ eventPt
 				draw = true;
 			}
 			if (draw) {
-				if (!GTK.GTK3) {
-					drawRectangles (rectsToErase);
-					update ();
-				}
 				drawRectangles (rectangles);
 			}
 			Point cursorPos = adjustResizeCursor ();
@@ -730,16 +730,13 @@ long /*int*/ gtk_mouse (int eventType, long /*int*/ widget, long /*int*/ eventPt
 				draw = true;
 			}
 			if (draw) {
-				if (!GTK.GTK3) {
-					drawRectangles (rectsToErase);
-					update ();
-				}
 				drawRectangles (rectangles);
 			}
 		}
 		oldX = newX [0];
 		oldY = newY [0];
 	}
+	eventType = Control.fixGdkEventTypeValues(eventType);
 	tracking = eventType != GDK.GDK_BUTTON_RELEASE;
 	return 0;
 }
@@ -773,19 +770,19 @@ void moveRectangles (int xChange, int yChange) {
  */
 public boolean open () {
 	checkWidget();
-	window = GDK.gdk_get_default_root_window();
+	if (!GTK.GTK4) window = GDK.gdk_get_default_root_window();
 	if (parent != null) {
 		window = gtk_widget_get_window (parent.paintHandle());
 	}
 	if (window == 0) return false;
 	cancelled = false;
 	tracking = true;
-	if (!GTK.GTK3) {
-		update ();
-		drawRectangles (rectangles);
-	}
 	int [] oldX = new int [1], oldY = new int [1], state = new int [1];
-	gdk_window_get_device_position (window, oldX, oldY, state);
+	if (GTK.GTK4) {
+		display.gdk_surface_get_device_position (surface, oldX, oldY, state);
+	} else {
+		display.gdk_window_get_device_position (window, oldX, oldY, state);
+	}
 
 	/*
 	* if exactly one of UP/DOWN is specified as a style then set the cursor
@@ -820,20 +817,21 @@ public boolean open () {
 	grabbed = grab ();
 	lastCursor = this.cursor != null ? this.cursor.handle : 0;
 
-	if (GTK.GTK3) {
-		cachedCombinedDisplayResolution = Display.getDefault().getBounds(); // In case resolution was changed during run time.
-		overlay = GTK.gtk_window_new (GTK.GTK_WINDOW_POPUP);
-		GTK.gtk_window_set_skip_taskbar_hint (overlay, true);
-		GTK.gtk_window_set_title (overlay, new byte [1]);
-		GTK.gtk_widget_realize (overlay);
-		long /*int*/ overlayWindow = GTK.gtk_widget_get_window (overlay);
+	cachedCombinedDisplayResolution = Display.getDefault().getBounds(); // In case resolution was changed during run time.
+	overlay = GTK.gtk_window_new (GTK.GTK_WINDOW_POPUP);
+	GTK.gtk_window_set_skip_taskbar_hint (overlay, true);
+	GTK.gtk_window_set_title (overlay, new byte [1]);
+	if (parent != null) GTK.gtk_window_set_transient_for(overlay, parent.topHandle());
+	GTK.gtk_widget_realize (overlay);
+	if (!GTK.GTK4) {
+		long overlayWindow = GTK.gtk_widget_get_window (overlay);
 		GDK.gdk_window_set_override_redirect (overlayWindow, true);
-		setTrackerBackground(true);
-		Rectangle bounds = display.getBoundsInPixels();
-		GTK.gtk_window_move (overlay, bounds.x, bounds.y);
-		GTK.gtk_window_resize (overlay, bounds.width, bounds.height);
-		GTK.gtk_widget_show (overlay);
 	}
+	setTrackerBackground(true);
+	Rectangle bounds = display.getBoundsInPixels();
+	GTK.gtk_window_move (overlay, bounds.x, bounds.y);
+	GTK.gtk_window_resize (overlay, bounds.width, bounds.height);
+	GTK.gtk_widget_show (overlay);
 
 	/* Tracker behaves like a Dialog with its own OS event loop. */
 	Display display = this.display;
@@ -851,7 +849,7 @@ public boolean open () {
 			* code outside of SWT (i.e AWT, etc). It ensures that the current
 			* thread leaves the GTK lock before calling the function below.
 			*/
-			GDK.gdk_threads_leave();
+			if (!GTK.GTK4) GDK.gdk_threads_leave();
 			OS.g_main_context_iteration (0, true);
 			display.sendPostExternalEventDispatchEvent ();
 			display.runAsyncMessages (false);
@@ -859,12 +857,6 @@ public boolean open () {
 	} finally {
 		display.tracker = oldTracker;
 	}
-	if (!isDisposed ()) {
-		if (!GTK.GTK3) {
-			update ();
-			drawRectangles (rectangles);
-		}
-	}
 	ungrab ();
 	if (overlay != 0) {
 		GTK.gtk_widget_destroy (overlay);
@@ -896,26 +888,30 @@ private void setTrackerBackground(boolean opaque) {
 					+ "border-right-color: transparent;"
 					+ "border-bottom-color: transparent;}";
 		}
-		long /*int*/ context = GTK.gtk_widget_get_style_context (overlay);
+		long context = GTK.gtk_widget_get_style_context (overlay);
 		if (provider == 0) {
 			provider = GTK.gtk_css_provider_new ();
 			GTK.gtk_style_context_add_provider (context, provider, GTK.GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 			OS.g_object_unref (provider);
 		}
-		GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (css, true), -1, null);
+		if (GTK.GTK4) {
+			GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (css, true), -1);
+		} else {
+			GTK.gtk_css_provider_load_from_data (provider, Converter.wcsToMbcs (css, true), -1, null);
+		}
 		GTK.gtk_style_context_invalidate (context);
 	}
-	long /*int*/ region = GDK.gdk_region_new ();
+	long region = Cairo.cairo_region_create ();
 	GTK.gtk_widget_shape_combine_region (overlay, region);
 	GTK.gtk_widget_input_shape_combine_region (overlay, region);
-	GDK.gdk_region_destroy (region);
+	Cairo.cairo_region_destroy (region);
 }
 
-boolean processEvent (long /*int*/ eventPtr) {
-	GdkEvent gdkEvent = new GdkEvent();
-	OS.memmove (gdkEvent, eventPtr, GdkEvent.sizeof);
-	long /*int*/ widget = GTK.gtk_get_event_widget (eventPtr);
-	switch (gdkEvent.type) {
+boolean processEvent (long eventPtr) {
+	int eventType = GDK.gdk_event_get_event_type(eventPtr);
+	eventType = Control.fixGdkEventTypeValues(eventType);
+	long widget = GTK.gtk_get_event_widget (eventPtr);
+	switch (eventType) {
 		case GDK.GDK_MOTION_NOTIFY: gtk_motion_notify_event (widget, eventPtr); break;
 		case GDK.GDK_BUTTON_RELEASE: gtk_button_release_event (widget, eventPtr); break;
 		case GDK.GDK_KEY_PRESS: gtk_key_press_event (widget, eventPtr); break;
@@ -929,9 +925,7 @@ boolean processEvent (long /*int*/ eventPtr) {
 			break;
 		case GDK.GDK_EXPOSE:
 			update ();
-			if (!GTK.GTK3) drawRectangles (rectangles);
 			GTK.gtk_main_do_event (eventPtr);
-			if (!GTK.GTK3) drawRectangles (rectangles);
 			break;
 		default:
 			return true;
