@@ -22,14 +22,13 @@ import org.eclipse.swt.internal.gtk.*;
 /**
  * Instances of this class represent icons that can be placed on the
  * system tray or task bar status area.
- * <p>
  * <dl>
  * <dt><b>Styles:</b></dt>
  * <dd>(none)</dd>
  * <dt><b>Events:</b></dt>
  * <dd>DefaultSelection, MenuDetect, Selection</dd>
  * </dl>
- * </p><p>
+ * <p>
  * IMPORTANT: This class is <em>not</em> intended to be subclassed.
  * </p>
  *
@@ -43,8 +42,8 @@ public class TrayItem extends Item {
 	Tray parent;
 	ToolTip toolTip;
 	String toolTipText;
-	long /*int*/ imageHandle;
-	long /*int*/ tooltipsHandle;
+	long imageHandle;
+	long tooltipsHandle;
 	ImageList imageList;
 	Image highlightImage;
 
@@ -246,7 +245,7 @@ public String getToolTipText () {
 }
 
 @Override
-long /*int*/ gtk_activate (long /*int*/ widget) {
+long gtk_activate (long widget) {
 	sendSelectionEvent (SWT.Selection);
 	/*
 	* Feature in GTK. GTK will generate a single-click event before sending
@@ -254,16 +253,18 @@ long /*int*/ gtk_activate (long /*int*/ widget) {
 	* the single-click as the current event and for the double-click in the
 	* event queue.
 	*/
-	long /*int*/ nextEvent = GDK.gdk_event_peek ();
+	long nextEvent = gdk_event_peek ();
 	if (nextEvent != 0) {
 		int nextEventType = GDK.GDK_EVENT_TYPE (nextEvent);
-		long /*int*/ currEvent = GTK.gtk_get_current_event ();
+		long currEvent = GTK.gtk_get_current_event ();
 		int currEventType = 0;
 		if (currEvent != 0) {
 			currEventType = GDK.GDK_EVENT_TYPE (currEvent);
-			GDK.gdk_event_free (currEvent);
+			gdk_event_free(currEvent);
 		}
-		GDK.gdk_event_free (nextEvent);
+		gdk_event_free (nextEvent);
+		currEventType = Control.fixGdkEventTypeValues(currEventType);
+		nextEventType = Control.fixGdkEventTypeValues(nextEventType);
 		if (currEventType == GDK.GDK_BUTTON_PRESS && nextEventType == GDK.GDK_2BUTTON_PRESS) {
 			sendSelectionEvent (SWT.DefaultSelection);
 		}
@@ -272,15 +273,17 @@ long /*int*/ gtk_activate (long /*int*/ widget) {
 }
 
 @Override
-long /*int*/ gtk_button_press_event (long /*int*/ widget, long /*int*/ eventPtr) {
-	GdkEventButton gdkEvent = new GdkEventButton ();
-	OS.memmove (gdkEvent, eventPtr, GdkEventButton.sizeof);
-	if (gdkEvent.type == GDK.GDK_3BUTTON_PRESS) return 0;
-	if (gdkEvent.button == 3 && gdkEvent.type == GDK.GDK_BUTTON_PRESS) {
+long gtk_button_press_event (long widget, long event) {
+	int eventType = GDK.gdk_event_get_event_type(event);
+	eventType = Control.fixGdkEventTypeValues(eventType);
+	int [] eventButton = new int [1];
+	GDK.gdk_event_get_button(event, eventButton);
+	if (eventType == GDK.GDK_3BUTTON_PRESS) return 0;
+	if (eventButton[0] == 3 && eventType == GDK.GDK_BUTTON_PRESS) {
 		sendEvent (SWT.MenuDetect);
 		return 0;
 	}
-	if (gdkEvent.type == GDK.GDK_2BUTTON_PRESS) {
+	if (eventType == GDK.GDK_2BUTTON_PRESS) {
 		sendSelectionEvent (SWT.DefaultSelection);
 	} else {
 		sendSelectionEvent (SWT.Selection);
@@ -289,44 +292,25 @@ long /*int*/ gtk_button_press_event (long /*int*/ widget, long /*int*/ eventPtr)
 }
 
 @Override
-long /*int*/ gtk_size_allocate (long /*int*/ widget, long /*int*/ allocation) {
-	if (image != null && image.mask != 0) {
-		if (GDK.gdk_drawable_get_depth (image.mask) == 1) {
-			GtkAllocation widgetAllocation = new GtkAllocation ();
-			GTK.gtk_widget_get_allocation (widget, widgetAllocation);
-			int xoffset = (int) Math.floor (widgetAllocation.x + ((widgetAllocation.width -GTK.GTK_WIDGET_REQUISITION_WIDTH (widget)) * 0.5) + 0.5);
-			int yoffset = (int) Math.floor (widgetAllocation.y + ((widgetAllocation.height - GTK.GTK_WIDGET_REQUISITION_HEIGHT (widget)) * 0.5) + 0.5);
-			Rectangle b = image.getBoundsInPixels();
-			long /*int*/ gdkImagePtr = GDK.gdk_drawable_get_image (image.mask, 0, 0, b.width, b.height);
-			if (gdkImagePtr == 0) error(SWT.ERROR_NO_HANDLES);
-			GdkImage gdkImage = new GdkImage();
-			OS.memmove (gdkImage, gdkImagePtr);
-			byte[] maskData = new byte [gdkImage.bpl * gdkImage.height];
-			C.memmove (maskData, gdkImage.mem, maskData.length);
-			OS.g_object_unref (gdkImagePtr);
-			Region region = new Region (display);
-			for (int y = 0; y < b.height; y++) {
-				for (int x = 0; x < b.width; x++) {
-					int index = (y * gdkImage.bpl) + (x >> 3);
-					int theByte = maskData [index] & 0xFF;
-					int mask = 1 << (x & 0x7);
-					if ((theByte & mask) != 0) {
-						Rectangle rect = DPIUtil.autoScaleDown(new Rectangle(xoffset + x, yoffset + y, 1, 1));
-						region.add(rect.x, rect.y, rect.width, rect.height);
-					}
-				}
-			}
-			GTK.gtk_widget_realize (handle);
-			long /*int*/ window = gtk_widget_get_window (handle);
-			GDK.gdk_window_shape_combine_region (window, region.handle, 0, 0);
-			region.dispose ();
-		}
+long gtk_gesture_press_event (long gesture, int n_press, double x, double y, long event) {
+	if (n_press == 1) return 0;
+	long widget = GTK.gtk_event_controller_get_widget(gesture);
+	long result = gtk_button_press_event (widget, event);
+
+	if (n_press == 2) {
+		sendSelectionEvent (SWT.DefaultSelection);
 	}
+
+	return result;
+}
+
+@Override
+long gtk_size_allocate (long widget, long allocation) {
 	return 0;
 }
 
 @Override
-long /*int*/ gtk_status_icon_popup_menu (long /*int*/ widget, long /*int*/ button, long /*int*/ activate_time) {
+long gtk_status_icon_popup_menu (long widget, long button, long activate_time) {
 	/*
 	* GTK provides a MenuPositionFunc for GtkStatusIcon in order
 	* to set the popup-menu aligned to the tray.
@@ -487,7 +471,7 @@ public void setImage (Image image) {
 		} else {
 			imageList.put (imageIndex, image);
 		}
-		long /*int*/ pixbuf = imageList.getPixbuf (imageIndex);
+		long pixbuf = imageList.getPixbuf (imageIndex);
 		GTK.gtk_status_icon_set_from_pixbuf (handle, pixbuf);
 		GTK.gtk_status_icon_set_visible (handle, true);
 	} else {
@@ -532,7 +516,7 @@ public void setToolTip (ToolTip toolTip) {
  * </p>
  * <p>
  * NOTE: This operation is a hint and behavior is platform specific, on Windows
- * for CJK-style mnemonics of the form " (&C)" at the end of the tooltip text
+ * for CJK-style mnemonics of the form " (&amp;C)" at the end of the tooltip text
  * are not shown in tooltip.
  * </p>
  *
