@@ -47,7 +47,7 @@ public final class Font extends Resource {
 	 *
 	 * @noreference This field is not intended to be referenced by clients.
 	 */
-	public long /*int*/ handle;
+	public long handle;
 
 /**
  * Prevents uninitialized instances from being created outside the package.
@@ -210,7 +210,7 @@ public FontData[] getFontData() {
  */
 @Override
 public int hashCode () {
-	return (int)/*64*/handle;
+	return (int)handle;
 }
 
 void init (FontData fd) {
@@ -266,7 +266,7 @@ public String toString () {
  *
  * @noreference This method is not intended to be referenced by clients.
  */
-public static Font win32_new(Device device, long /*int*/ handle) {
+public static Font win32_new(Device device, long handle) {
 	Font font = new Font(device);
 	font.handle = handle;
 	return font;
