@@ -99,7 +99,7 @@ public final class Image extends Resource implements Drawable {
 	 *
 	 * @noreference This field is not intended to be referenced by clients.
 	 */
-	public long /*int*/ handle;
+	public long handle;
 
 	/**
 	 * specifies the transparent pixel
@@ -262,17 +262,17 @@ public Image(Device device, Image srcImage, int flag) {
 			switch (type) {
 				case SWT.BITMAP:
 					/* Get the HDC for the device */
-					long /*int*/ hDC = device.internal_new_GC(null);
+					long hDC = device.internal_new_GC(null);
 
 					/* Copy the bitmap */
-					long /*int*/ hdcSource = OS.CreateCompatibleDC(hDC);
-					long /*int*/ hdcDest = OS.CreateCompatibleDC(hDC);
-					long /*int*/ hOldSrc = OS.SelectObject(hdcSource, srcImage.handle);
+					long hdcSource = OS.CreateCompatibleDC(hDC);
+					long hdcDest = OS.CreateCompatibleDC(hDC);
+					long hOldSrc = OS.SelectObject(hdcSource, srcImage.handle);
 					BITMAP bm = new BITMAP();
 					OS.GetObject(srcImage.handle, BITMAP.sizeof, bm);
 					handle = OS.CreateCompatibleBitmap(hdcSource, rect.width, bm.bmBits != 0 ? -rect.height : rect.height);
 					if (handle == 0) SWT.error(SWT.ERROR_NO_HANDLES);
-					long /*int*/ hOldDest = OS.SelectObject(hdcDest, handle);
+					long hOldDest = OS.SelectObject(hdcDest, handle);
 					OS.BitBlt(hdcDest, 0, 0, rect.width, rect.height, hdcSource, 0, 0, OS.SRCCOPY);
 					OS.SelectObject(hdcSource, hOldSrc);
 					OS.SelectObject(hdcDest, hOldDest);
@@ -807,12 +807,8 @@ boolean refreshImageForZoom () {
 }
 
 void initNative(String filename) {
+	device.checkGDIP();
 	boolean gdip = true;
-	try {
-		device.checkGDIP();
-	} catch (SWTException e) {
-		gdip = false;
-	}
 	/*
 	* Bug in GDI+.  For some reason, Bitmap.LockBits() segment faults
 	* when loading GIF files in 64-bit Windows.  The fix is to not use
@@ -829,14 +825,14 @@ void initNative(String filename) {
 		int length = filename.length();
 		char[] chars = new char[length+1];
 		filename.getChars(0, length, chars, 0);
-		long /*int*/ bitmap = Gdip.Bitmap_new(chars, false);
+		long bitmap = Gdip.Bitmap_new(chars, false);
 		if (bitmap != 0) {
 			int error = SWT.ERROR_NO_HANDLES;
 			int status = Gdip.Image_GetLastStatus(bitmap);
 			if (status == 0) {
 				if (filename.toLowerCase().endsWith(".ico")) {
 					this.type = SWT.ICON;
-					long /*int*/[] hicon = new long /*int*/[1];
+					long[] hicon = new long[1];
 					status = Gdip.Bitmap_GetHICON(bitmap, hicon);
 					this.handle = hicon[0];
 				} else {
@@ -868,10 +864,10 @@ void initNative(String filename) {
 						* This performs better than getting the bits with Bitmap.LockBits(),
 						* but it cannot be used when there is transparency.
 						*/
-						long /*int*/ hDC = device.internal_new_GC(null);
-						long /*int*/ srcHDC = OS.CreateCompatibleDC(hDC);
-						long /*int*/ oldSrcBitmap = OS.SelectObject(srcHDC, this.handle);
-						long /*int*/ graphics = Gdip.Graphics_new(srcHDC);
+						long hDC = device.internal_new_GC(null);
+						long srcHDC = OS.CreateCompatibleDC(hDC);
+						long oldSrcBitmap = OS.SelectObject(srcHDC, this.handle);
+						long graphics = Gdip.Graphics_new(srcHDC);
 						if (graphics != 0) {
 							Rect rect = new Rect();
 							rect.Width = width;
@@ -888,14 +884,14 @@ void initNative(String filename) {
 						OS.DeleteDC(srcHDC);
 						device.internal_dispose_GC(hDC, null);
 					} else {
-						long /*int*/ lockedBitmapData = Gdip.BitmapData_new();
+						long lockedBitmapData = Gdip.BitmapData_new();
 						if (lockedBitmapData != 0) {
 							status = Gdip.Bitmap_LockBits(bitmap, 0, 0, pixelFormat, lockedBitmapData);
 							if (status == 0) {
 								BitmapData bitmapData = new BitmapData();
 								Gdip.MoveMemory(bitmapData, lockedBitmapData);
 								int stride = bitmapData.Stride;
-								long /*int*/ pixels = bitmapData.Scan0;
+								long pixels = bitmapData.Scan0;
 								int depth = 0, scanlinePad = 4, transparentPixel = -1;
 								switch (bitmapData.PixelFormat) {
 									case Gdip.PixelFormat1bppIndexed: depth = 1; break;
@@ -915,8 +911,8 @@ void initNative(String filename) {
 										case Gdip.PixelFormat4bppIndexed:
 										case Gdip.PixelFormat8bppIndexed:
 											int paletteSize = Gdip.Image_GetPaletteSize(bitmap);
-											long /*int*/ hHeap = OS.GetProcessHeap();
-											long /*int*/ palette = OS.HeapAlloc(hHeap, OS.HEAP_ZERO_MEMORY, paletteSize);
+											long hHeap = OS.GetProcessHeap();
+											long palette = OS.HeapAlloc(hHeap, OS.HEAP_ZERO_MEMORY, paletteSize);
 											if (palette == 0) SWT.error(SWT.ERROR_NO_HANDLES);
 											Gdip.Image_GetPalette(bitmap, palette, paletteSize);
 											ColorPalette colorPalette = new ColorPalette();
@@ -944,16 +940,16 @@ void initNative(String filename) {
 									OS.MoveMemory(data, pixels, data.length);
 									switch (bitmapData.PixelFormat) {
 										case Gdip.PixelFormat16bppARGB1555:
-							 		 		alphaData = new byte[width * height];
-							 		 		for (int i = 1, j = 0; i < data.length; i += 2, j++) {
-							 		 			alphaData[j] = (byte)((data[i] & 0x80) != 0 ? 255 : 0);
-							 		 		}
+											alphaData = new byte[width * height];
+											for (int i = 1, j = 0; i < data.length; i += 2, j++) {
+												alphaData[j] = (byte)((data[i] & 0x80) != 0 ? 255 : 0);
+											}
 											break;
 										case Gdip.PixelFormat32bppARGB:
-							 		 		alphaData = new byte[width * height];
-							 		 		for (int i = 3, j = 0; i < data.length; i += 4, j++) {
-							 		 			alphaData[j] = data[i];
-							 		 		}
+											alphaData = new byte[width * height];
+											for (int i = 3, j = 0; i < data.length; i += 4, j++) {
+												alphaData[j] = data[i];
+											}
 											break;
 									}
 									ImageData img = new ImageData(width, height, depth, paletteData, scanlinePad, data);
@@ -961,7 +957,7 @@ void initNative(String filename) {
 									img.alphaData = alphaData;
 									init(img);
 								}
-				 		 		Gdip.Bitmap_UnlockBits(bitmap, lockedBitmapData);
+								Gdip.Bitmap_UnlockBits(bitmap, lockedBitmapData);
 							} else {
 								error = SWT.ERROR_INVALID_IMAGE;
 							}
@@ -978,7 +974,7 @@ void initNative(String filename) {
 	}
 }
 
-long /*int*/ [] createGdipImage() {
+long [] createGdipImage() {
 	switch (type) {
 		case SWT.BITMAP: {
 			if (alpha != -1 || alphaData != null || transparentPixel != -1) {
@@ -986,19 +982,19 @@ long /*int*/ [] createGdipImage() {
 				OS.GetObject(handle, BITMAP.sizeof, bm);
 				int imgWidth = bm.bmWidth;
 				int imgHeight = bm.bmHeight;
-				long /*int*/ hDC = device.internal_new_GC(null);
-				long /*int*/ srcHdc = OS.CreateCompatibleDC(hDC);
-				long /*int*/ oldSrcBitmap = OS.SelectObject(srcHdc, handle);
-				long /*int*/ memHdc = OS.CreateCompatibleDC(hDC);
-				long /*int*/ memDib = createDIB(imgWidth, imgHeight, 32);
+				long hDC = device.internal_new_GC(null);
+				long srcHdc = OS.CreateCompatibleDC(hDC);
+				long oldSrcBitmap = OS.SelectObject(srcHdc, handle);
+				long memHdc = OS.CreateCompatibleDC(hDC);
+				long memDib = createDIB(imgWidth, imgHeight, 32);
 				if (memDib == 0) SWT.error(SWT.ERROR_NO_HANDLES);
-				long /*int*/ oldMemBitmap = OS.SelectObject(memHdc, memDib);
+				long oldMemBitmap = OS.SelectObject(memHdc, memDib);
 				BITMAP dibBM = new BITMAP();
 				OS.GetObject(memDib, BITMAP.sizeof, dibBM);
 				int sizeInBytes = dibBM.bmWidthBytes * dibBM.bmHeight;
-			 	OS.BitBlt(memHdc, 0, 0, imgWidth, imgHeight, srcHdc, 0, 0, OS.SRCCOPY);
-			 	byte red = 0, green = 0, blue = 0;
-			 	if (transparentPixel != -1) {
+				OS.BitBlt(memHdc, 0, 0, imgWidth, imgHeight, srcHdc, 0, 0, OS.SRCCOPY);
+				byte red = 0, green = 0, blue = 0;
+				if (transparentPixel != -1) {
 					if (bm.bmBitsPixel <= 8)  {
 						byte[] color = new byte[4];
 						OS.GetDIBColorTable(srcHdc, transparentPixel, 1, color);
@@ -1033,12 +1029,12 @@ long /*int*/ [] createGdipImage() {
 								break;
 						}
 					}
-			 	}
+				}
 				OS.SelectObject(srcHdc, oldSrcBitmap);
 				OS.SelectObject(memHdc, oldMemBitmap);
 				OS.DeleteObject(srcHdc);
 				OS.DeleteObject(memHdc);
-			 	byte[] srcData = new byte[sizeInBytes];
+				byte[] srcData = new byte[sizeInBytes];
 				OS.MoveMemory(srcData, dibBM.bmBits, sizeInBytes);
 				OS.DeleteObject(memDib);
 				device.internal_dispose_GC(hDC, null);
@@ -1068,13 +1064,13 @@ long /*int*/ [] createGdipImage() {
 						}
 					}
 				}
-				long /*int*/ hHeap = OS.GetProcessHeap();
-				long /*int*/ pixels = OS.HeapAlloc(hHeap, OS.HEAP_ZERO_MEMORY, srcData.length);
+				long hHeap = OS.GetProcessHeap();
+				long pixels = OS.HeapAlloc(hHeap, OS.HEAP_ZERO_MEMORY, srcData.length);
 				if (pixels == 0) SWT.error(SWT.ERROR_NO_HANDLES);
 				OS.MoveMemory(pixels, srcData, sizeInBytes);
-				return new long /*int*/ []{Gdip.Bitmap_new(imgWidth, imgHeight, dibBM.bmWidthBytes, Gdip.PixelFormat32bppARGB, pixels), pixels};
+				return new long []{Gdip.Bitmap_new(imgWidth, imgHeight, dibBM.bmWidthBytes, Gdip.PixelFormat32bppARGB, pixels), pixels};
 			}
-			return new long /*int*/ []{Gdip.Bitmap_new(handle, 0), 0};
+			return new long []{Gdip.Bitmap_new(handle, 0), 0};
 		}
 		case SWT.ICON: {
 			/*
@@ -1084,13 +1080,13 @@ long /*int*/ [] createGdipImage() {
 			*/
 			ICONINFO iconInfo = new ICONINFO();
 			OS.GetIconInfo(handle, iconInfo);
-			long /*int*/ hBitmap = iconInfo.hbmColor;
+			long hBitmap = iconInfo.hbmColor;
 			if (hBitmap == 0) hBitmap = iconInfo.hbmMask;
 			BITMAP bm = new BITMAP();
 			OS.GetObject(hBitmap, BITMAP.sizeof, bm);
 			int imgWidth = bm.bmWidth;
 			int imgHeight = hBitmap == iconInfo.hbmMask ? bm.bmHeight / 2 : bm.bmHeight;
-			long /*int*/ img = 0, pixels = 0;
+			long img = 0, pixels = 0;
 			/*
 			* Bug in GDI+.  Bitmap_new() segments fault if the image width
 			* is greater than the image height.
@@ -1099,19 +1095,19 @@ long /*int*/ [] createGdipImage() {
 			* channel when the icon depth is 32.
 			*/
 			if (imgWidth > imgHeight || bm.bmBitsPixel == 32) {
-				long /*int*/ hDC = device.internal_new_GC(null);
-				long /*int*/ srcHdc = OS.CreateCompatibleDC(hDC);
-				long /*int*/ oldSrcBitmap = OS.SelectObject(srcHdc, hBitmap);
-				long /*int*/ memHdc = OS.CreateCompatibleDC(hDC);
-				long /*int*/ memDib = createDIB(imgWidth, imgHeight, 32);
+				long hDC = device.internal_new_GC(null);
+				long srcHdc = OS.CreateCompatibleDC(hDC);
+				long oldSrcBitmap = OS.SelectObject(srcHdc, hBitmap);
+				long memHdc = OS.CreateCompatibleDC(hDC);
+				long memDib = createDIB(imgWidth, imgHeight, 32);
 				if (memDib == 0) SWT.error(SWT.ERROR_NO_HANDLES);
-				long /*int*/ oldMemBitmap = OS.SelectObject(memHdc, memDib);
+				long oldMemBitmap = OS.SelectObject(memHdc, memDib);
 				BITMAP dibBM = new BITMAP();
 				OS.GetObject(memDib, BITMAP.sizeof, dibBM);
-			 	OS.BitBlt(memHdc, 0, 0, imgWidth, imgHeight, srcHdc, 0, hBitmap == iconInfo.hbmMask ? imgHeight : 0, OS.SRCCOPY);
+				OS.BitBlt(memHdc, 0, 0, imgWidth, imgHeight, srcHdc, 0, hBitmap == iconInfo.hbmMask ? imgHeight : 0, OS.SRCCOPY);
 				OS.SelectObject(memHdc, oldMemBitmap);
 				OS.DeleteObject(memHdc);
-			 	byte[] srcData = new byte[dibBM.bmWidthBytes * dibBM.bmHeight];
+				byte[] srcData = new byte[dibBM.bmWidthBytes * dibBM.bmHeight];
 				OS.MoveMemory(srcData, dibBM.bmBits, srcData.length);
 				OS.DeleteObject(memDib);
 				OS.SelectObject(srcHdc, iconInfo.hbmMask);
@@ -1130,7 +1126,7 @@ long /*int*/ [] createGdipImage() {
 				OS.SelectObject(srcHdc, oldSrcBitmap);
 				OS.DeleteObject(srcHdc);
 				device.internal_dispose_GC(hDC, null);
-				long /*int*/ hHeap = OS.GetProcessHeap();
+				long hHeap = OS.GetProcessHeap();
 				pixels = OS.HeapAlloc(hHeap, OS.HEAP_ZERO_MEMORY, srcData.length);
 				if (pixels == 0) SWT.error(SWT.ERROR_NO_HANDLES);
 				OS.MoveMemory(pixels, srcData, srcData.length);
@@ -1140,7 +1136,7 @@ long /*int*/ [] createGdipImage() {
 			}
 			if (iconInfo.hbmColor != 0) OS.DeleteObject(iconInfo.hbmColor);
 			if (iconInfo.hbmMask != 0) OS.DeleteObject(iconInfo.hbmMask);
-			return new long /*int*/ []{img, pixels};
+			return new long []{img, pixels};
 		}
 		default: SWT.error(SWT.ERROR_INVALID_IMAGE);
 	}
@@ -1207,13 +1203,13 @@ public Color getBackground() {
 	if (transparentPixel == -1) return null;
 
 	/* Get the HDC for the device */
-	long /*int*/ hDC = device.internal_new_GC(null);
+	long hDC = device.internal_new_GC(null);
 
 	/* Compute the background color */
 	BITMAP bm = new BITMAP();
 	OS.GetObject(handle, BITMAP.sizeof, bm);
-	long /*int*/ hdcMem = OS.CreateCompatibleDC(hDC);
-	long /*int*/ hOldObject = OS.SelectObject(hdcMem, handle);
+	long hdcMem = OS.CreateCompatibleDC(hDC);
+	long hOldObject = OS.SelectObject(hdcMem, handle);
 	int red = 0, green = 0, blue = 0;
 	if (bm.bmBitsPixel <= 8)  {
 		byte[] color = new byte[4];
@@ -1304,7 +1300,7 @@ public Rectangle getBoundsInPixels() {
 		case SWT.ICON:
 			ICONINFO info = new ICONINFO();
 			OS.GetIconInfo(handle, info);
-			long /*int*/ hBitmap = info.hbmColor;
+			long hBitmap = info.hbmColor;
 			if (hBitmap == 0) hBitmap = info.hbmMask;
 			bm = new BITMAP();
 			OS.GetObject(hBitmap, BITMAP.sizeof, bm);
@@ -1355,7 +1351,7 @@ public ImageData getImageData() {
  *
  * @param zoom
  *            The zoom level in % of the standard resolution (which is 1
- *            physical monitor pixel == 1 SWT logical pixel). Typically 100,
+ *            physical monitor pixel == 1 SWT logical point). Typically 100,
  *            150, or 200.
  * @return an <code>ImageData</code> containing the image's data and
  *         attributes at the given zoom level
@@ -1380,7 +1376,7 @@ public ImageData getImageData (int zoom) {
 			return data;
 		}
 		// AutoScale the image at 100% zoom
-		return DPIUtil.autoScaleUp (device, data);
+		return DPIUtil.autoScaleImageData (device, data, zoom, 100);
 	} else if (imageFileNameProvider != null) {
 		boolean[] found = new boolean[1];
 		String fileName = DPIUtil.validateAndGetImagePathAtZoom (imageFileNameProvider, zoom, found);
@@ -1389,7 +1385,7 @@ public ImageData getImageData (int zoom) {
 			return new ImageData (fileName);
 		}
 		// AutoScale the image at 100% zoom
-		return DPIUtil.autoScaleUp (device, new ImageData (fileName));
+		return DPIUtil.autoScaleImageData (device, new ImageData (fileName), zoom, 100);
 	} else {
 		return DPIUtil.autoScaleImageData (device, getImageDataAtCurrentZoom (), zoom, currentDeviceZoom);
 	}
@@ -1424,7 +1420,7 @@ public ImageData getImageDataAtCurrentZoom() {
 			ICONINFO info = new ICONINFO();
 			OS.GetIconInfo(handle, info);
 			/* Get the basic BITMAP information */
-			long /*int*/ hBitmap = info.hbmColor;
+			long hBitmap = info.hbmColor;
 			if (hBitmap == 0) hBitmap = info.hbmMask;
 			bm = new BITMAP();
 			OS.GetObject(hBitmap, BITMAP.sizeof, bm);
@@ -1446,20 +1442,11 @@ public ImageData getImageDataAtCurrentZoom() {
 			OS.MoveMemory(bmi, bmiHeader, BITMAPINFOHEADER.sizeof);
 
 			/* Get the HDC for the device */
-			long /*int*/ hDC = device.internal_new_GC(null);
+			long hDC = device.internal_new_GC(null);
 
 			/* Create the DC and select the bitmap */
-			long /*int*/ hBitmapDC = OS.CreateCompatibleDC(hDC);
-			long /*int*/ hOldBitmap = OS.SelectObject(hBitmapDC, hBitmap);
-			/* Select the palette if necessary */
-			long /*int*/ oldPalette = 0;
-			if (depth <= 8) {
-				long /*int*/ hPalette = device.hPalette;
-				if (hPalette != 0) {
-					oldPalette = OS.SelectPalette(hBitmapDC, hPalette, false);
-					OS.RealizePalette(hBitmapDC);
-				}
-			}
+			long hBitmapDC = OS.CreateCompatibleDC(hDC);
+			long hOldBitmap = OS.SelectObject(hBitmapDC, hBitmap);
 			/* Find the size of the image and allocate data */
 			int imageSize;
 			/* Call with null lpBits to get the image size */
@@ -1534,10 +1521,6 @@ public ImageData getImageDataAtCurrentZoom() {
 			}
 			/* Clean up */
 			OS.SelectObject(hBitmapDC, hOldBitmap);
-			if (oldPalette != 0) {
-				OS.SelectPalette(hBitmapDC, oldPalette, false);
-				OS.RealizePalette(hBitmapDC);
-			}
 			OS.DeleteDC(hBitmapDC);
 
 			/* Release the HDC for the device */
@@ -1561,7 +1544,7 @@ public ImageData getImageDataAtCurrentZoom() {
 			/* Find out whether this is a DIB or a DDB. */
 			boolean isDib = (bm.bmBits != 0);
 			/* Get the HDC for the device */
-			long /*int*/ hDC = device.internal_new_GC(null);
+			long hDC = device.internal_new_GC(null);
 			DIBSECTION dib = null;
 			if (isDib) {
 				dib = new DIBSECTION();
@@ -1592,17 +1575,8 @@ public ImageData getImageDataAtCurrentZoom() {
 			}
 
 			/* Create the DC and select the bitmap */
-			long /*int*/ hBitmapDC = OS.CreateCompatibleDC(hDC);
-			long /*int*/ hOldBitmap = OS.SelectObject(hBitmapDC, handle);
-			/* Select the palette if necessary */
-			long /*int*/ oldPalette = 0;
-			if (!isDib && depth <= 8) {
-				long /*int*/ hPalette = device.hPalette;
-				if (hPalette != 0) {
-					oldPalette = OS.SelectPalette(hBitmapDC, hPalette, false);
-					OS.RealizePalette(hBitmapDC);
-				}
-			}
+			long hBitmapDC = OS.CreateCompatibleDC(hDC);
+			long hOldBitmap = OS.SelectObject(hBitmapDC, handle);
 			/* Find the size of the image and allocate data */
 			int imageSize;
 			if (isDib) {
@@ -1651,10 +1625,6 @@ public ImageData getImageDataAtCurrentZoom() {
 			}
 			/* Clean up */
 			OS.SelectObject(hBitmapDC, hOldBitmap);
-			if (oldPalette != 0) {
-				OS.SelectPalette(hBitmapDC, oldPalette, false);
-				OS.RealizePalette(hBitmapDC);
-			}
 			OS.DeleteDC(hBitmapDC);
 
 			/* Release the HDC for the device */
@@ -1693,7 +1663,7 @@ public int hashCode () {
 	} else if (imageFileNameProvider != null) {
 		return imageFileNameProvider.hashCode();
 	} else {
-		return (int)/*64*/handle;
+		return (int)handle;
 	}
 }
 
@@ -1702,7 +1672,7 @@ void init(int width, int height) {
 		SWT.error (SWT.ERROR_INVALID_ARGUMENT);
 	}
 	type = SWT.BITMAP;
-	long /*int*/ hDC = device.internal_new_GC(null);
+	long hDC = device.internal_new_GC(null);
 	handle = OS.CreateCompatibleBitmap(hDC, width, height);
 	/*
 	* Feature in Windows.  CreateCompatibleBitmap() may fail
@@ -1717,8 +1687,8 @@ void init(int width, int height) {
 		handle = createDIB(width, height, depth);
 	}
 	if (handle != 0) {
-		long /*int*/ memDC = OS.CreateCompatibleDC(hDC);
-		long /*int*/ hOldBitmap = OS.SelectObject(memDC, handle);
+		long memDC = OS.CreateCompatibleDC(hDC);
+		long hOldBitmap = OS.SelectObject(memDC, handle);
 		OS.PatBlt(memDC, 0, 0, width, height, OS.PATCOPY);
 		OS.SelectObject(memDC, hOldBitmap);
 		OS.DeleteDC(memDC);
@@ -1729,7 +1699,7 @@ void init(int width, int height) {
 	}
 }
 
-static long /*int*/ createDIB(int width, int height, int depth) {
+static long createDIB(int width, int height, int depth) {
 	BITMAPINFOHEADER bmiHeader = new BITMAPINFOHEADER();
 	bmiHeader.biSize = BITMAPINFOHEADER.sizeof;
 	bmiHeader.biWidth = width;
@@ -1739,11 +1709,11 @@ static long /*int*/ createDIB(int width, int height, int depth) {
 	bmiHeader.biCompression = OS.BI_RGB;
 	byte[] bmi = new byte[BITMAPINFOHEADER.sizeof];
 	OS.MoveMemory(bmi, bmiHeader, BITMAPINFOHEADER.sizeof);
-	long /*int*/[] pBits = new long /*int*/[1];
+	long[] pBits = new long[1];
 	return OS.CreateDIBSection(0, bmi, OS.DIB_RGB_COLORS, pBits, 0, 0);
 }
 
-static long /*int*/ [] init(Device device, Image image, ImageData i) {
+static long [] init(Device device, Image image, ImageData i) {
 	/* Windows does not support 2-bit images. Convert to 4-bit image. */
 	if (i.depth == 2) {
 		ImageData img = new ImageData(i.width, i.height, 4, i.palette);
@@ -1844,8 +1814,8 @@ static long /*int*/ [] init(Device device, Image image, ImageData i) {
 			offset += 4;
 		}
 	}
-	long /*int*/[] pBits = new long /*int*/[1];
-	long /*int*/ hDib = OS.CreateDIBSection(0, bmi, OS.DIB_RGB_COLORS, pBits, 0, 0);
+	long[] pBits = new long[1];
+	long hDib = OS.CreateDIBSection(0, bmi, OS.DIB_RGB_COLORS, pBits, 0, 0);
 	if (hDib == 0) SWT.error(SWT.ERROR_NO_HANDLES);
 	/* In case of a scanline pad other than 4, do the work to convert it */
 	byte[] data = i.data;
@@ -1854,17 +1824,17 @@ static long /*int*/ [] init(Device device, Image image, ImageData i) {
 	}
 	OS.MoveMemory(pBits[0], data, data.length);
 
-	long /*int*/ [] result = null;
+	long [] result = null;
 	if (i.getTransparencyType() == SWT.TRANSPARENCY_MASK) {
 		/* Get the HDC for the device */
-		long /*int*/ hDC = device.internal_new_GC(null);
+		long hDC = device.internal_new_GC(null);
 
 		/* Create the color bitmap */
-		long /*int*/ hdcSrc = OS.CreateCompatibleDC(hDC);
+		long hdcSrc = OS.CreateCompatibleDC(hDC);
 		OS.SelectObject(hdcSrc, hDib);
-		long /*int*/ hBitmap = OS.CreateCompatibleBitmap(hDC, i.width, i.height);
+		long hBitmap = OS.CreateCompatibleBitmap(hDC, i.width, i.height);
 		if (hBitmap == 0) SWT.error(SWT.ERROR_NO_HANDLES);
-		long /*int*/ hdcDest = OS.CreateCompatibleDC(hDC);
+		long hdcDest = OS.CreateCompatibleDC(hDC);
 		OS.SelectObject(hdcDest, hBitmap);
 		OS.BitBlt(hdcDest, 0, 0, i.width, i.height, hdcSrc, 0, 0, OS.SRCCOPY);
 
@@ -1873,7 +1843,7 @@ static long /*int*/ [] init(Device device, Image image, ImageData i) {
 
 		/* Create the mask. Windows requires icon masks to have a scanline pad of 2. */
 		byte[] maskData = ImageData.convertPad(i.maskData, i.width, i.height, 1, i.maskPad, 2);
-		long /*int*/ hMask = OS.CreateBitmap(i.width, i.height, 1, 1, maskData);
+		long hMask = OS.CreateBitmap(i.width, i.height, 1, 1, maskData);
 		if (hMask == 0) SWT.error(SWT.ERROR_NO_HANDLES);
 		OS.SelectObject(hdcSrc, hMask);
 		OS.PatBlt(hdcSrc, 0, 0, i.width, i.height, OS.DSTINVERT);
@@ -1882,14 +1852,14 @@ static long /*int*/ [] init(Device device, Image image, ImageData i) {
 		OS.DeleteObject(hDib);
 
 		if (image == null) {
-			result = new long /*int*/ []{hBitmap, hMask};
+			result = new long []{hBitmap, hMask};
 		} else {
 			/* Create the icon */
 			ICONINFO info = new ICONINFO();
 			info.fIcon = true;
 			info.hbmColor = hBitmap;
 			info.hbmMask = hMask;
-			long /*int*/ hIcon = OS.CreateIconIndirect(info);
+			long hIcon = OS.CreateIconIndirect(info);
 			if (hIcon == 0) SWT.error(SWT.ERROR_NO_HANDLES);
 			OS.DeleteObject(hBitmap);
 			OS.DeleteObject(hMask);
@@ -1898,7 +1868,7 @@ static long /*int*/ [] init(Device device, Image image, ImageData i) {
 		}
 	} else {
 		if (image == null) {
-			result = new long /*int*/ []{hDib};
+			result = new long []{hDib};
 		} else {
 			image.handle = hDib;
 			image.type = SWT.BITMAP;
@@ -1916,7 +1886,7 @@ static long /*int*/ [] init(Device device, Image image, ImageData i) {
 	return result;
 }
 
-static long /*int*/ [] init(Device device, Image image, ImageData source, ImageData mask) {
+static long [] init(Device device, Image image, ImageData source, ImageData mask) {
 	/* Create a temporary image and locate the black pixel */
 	ImageData imageData;
 	int blackIndex = 0;
@@ -2010,7 +1980,7 @@ void init(ImageData i) {
  * @noreference This method is not intended to be referenced by clients.
  */
 @Override
-public long /*int*/ internal_new_GC (GCData data) {
+public long internal_new_GC (GCData data) {
 	if (handle == 0) SWT.error(SWT.ERROR_GRAPHIC_DISPOSED);
 	/*
 	* Create a new GC that can draw into the image.
@@ -2021,8 +1991,8 @@ public long /*int*/ internal_new_GC (GCData data) {
 	}
 
 	/* Create a compatible HDC for the device */
-	long /*int*/ hDC = device.internal_new_GC(null);
-	long /*int*/ imageDC = OS.CreateCompatibleDC(hDC);
+	long hDC = device.internal_new_GC(null);
+	long imageDC = OS.CreateCompatibleDC(hDC);
 	device.internal_dispose_GC(hDC, null);
 	if (imageDC == 0) SWT.error(SWT.ERROR_NO_HANDLES);
 
@@ -2057,7 +2027,7 @@ public long /*int*/ internal_new_GC (GCData data) {
  * @noreference This method is not intended to be referenced by clients.
  */
 @Override
-public void internal_dispose_GC (long /*int*/ hDC, GCData data) {
+public void internal_dispose_GC (long hDC, GCData data) {
 	OS.DeleteDC(hDC);
 }
 
@@ -2084,13 +2054,13 @@ public boolean isDisposed() {
  * In these cases, it may be desired to simulate transparency by using
  * the background color of the widget to paint the transparent pixels
  * of the image. This method specifies the color that will be used in
- * these cases. For example:
+ * these cases. For example:</p>
  * <pre>
  *    Button b = new Button();
  *    image.setBackground(b.getBackground());
  *    b.setImage(image);
  * </pre>
- * </p><p>
+ * <p>
  * The image may be modified by this operation (in effect, the
  * transparent regions may be filled with the supplied color).  Hence
  * this operation is not reversible and it is not legal to call
@@ -2118,12 +2088,12 @@ public void setBackground(Color color) {
 	transparentColor = -1;
 
 	/* Get the HDC for the device */
-	long /*int*/ hDC = device.internal_new_GC(null);
+	long hDC = device.internal_new_GC(null);
 
 	/* Change the background color in the image */
 	BITMAP bm = new BITMAP();
 	OS.GetObject(handle, BITMAP.sizeof, bm);
-	long /*int*/ hdcMem = OS.CreateCompatibleDC(hDC);
+	long hdcMem = OS.CreateCompatibleDC(hDC);
 	OS.SelectObject(hdcMem, handle);
 	int maxColors = 1 << bm.bmBitsPixel;
 	byte[] colors = new byte[maxColors * 4];
@@ -2168,7 +2138,7 @@ public String toString () {
  *
  * @noreference This method is not intended to be referenced by clients.
  */
-public static Image win32_new(Device device, int type, long /*int*/ handle) {
+public static Image win32_new(Device device, int type, long handle) {
 	Image image = new Image(device);
 	image.type = type;
 	image.handle = handle;
