@@ -29,14 +29,14 @@ import org.eclipse.swt.internal.win32.*;
  * Note that although this class is a subclass of <code>Composite</code>,
  * it does not make sense to add <code>Control</code> children to it,
  * or set a layout on it.
- * </p><p>
+ * </p>
  * <dl>
  * <dt><b>Styles:</b></dt>
  * <dd>FLAT, HORIZONTAL, VERTICAL</dd>
  * <dt><b>Events:</b></dt>
  * <dd>(none)</dd>
  * </dl>
- * </p><p>
+ * <p>
  * Note: Only one of the styles HORIZONTAL and VERTICAL may be specified.
  * </p><p>
  * IMPORTANT: This class is <em>not</em> intended to be subclassed.
@@ -52,7 +52,7 @@ public class CoolBar extends Composite {
 	CoolItem [] originalItems;
 	boolean locked;
 	boolean ignoreResize;
-	static final long /*int*/ ReBarProc;
+	static final long ReBarProc;
 	static final TCHAR ReBarClass = new TCHAR (0, OS.REBARCLASSNAME, true);
 	static {
 		INITCOMMONCONTROLSEX icex = new INITCOMMONCONTROLSEX ();
@@ -122,7 +122,7 @@ public CoolBar (Composite parent, int style) {
 }
 
 @Override
-long /*int*/ callWindowProc (long /*int*/ hwnd, int msg, long /*int*/ wParam, long /*int*/ lParam) {
+long callWindowProc (long hwnd, int msg, long wParam, long lParam) {
 	if (handle == 0) return 0;
 	return OS.CallWindowProc (ReBarProc, hwnd, msg, wParam, lParam);
 }
@@ -149,7 +149,7 @@ protected void checkSubclass () {
 	int border = getBorderWidthInPixels ();
 	int newWidth = wHint == SWT.DEFAULT ? 0x3FFF : wHint + (border * 2);
 	int newHeight = hHint == SWT.DEFAULT ? 0x3FFF : hHint + (border * 2);
-	int count = (int)/*64*/OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
+	int count = (int)OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
 	if (count != 0) {
 		ignoreResize = true;
 		boolean redraw = false;
@@ -217,12 +217,12 @@ void createHandle () {
 	* The control will not destroy a font that it did not
 	* create.
 	*/
-	long /*int*/ hFont = OS.GetStockObject (OS.SYSTEM_FONT);
+	long hFont = OS.GetStockObject (OS.SYSTEM_FONT);
 	OS.SendMessage (handle, OS.WM_SETFONT, hFont, 0);
 }
 
 void createItem (CoolItem item, int index) {
-	int count = (int)/*64*/OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
+	int count = (int)OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
 	if (!(0 <= index && index <= count)) error (SWT.ERROR_INVALID_RANGE);
 	int id = 0;
 	while (id < items.length && items [id] != null) id++;
@@ -231,8 +231,8 @@ void createItem (CoolItem item, int index) {
 		System.arraycopy (items, 0, newItems, 0, items.length);
 		items = newItems;
 	}
-	long /*int*/ hHeap = OS.GetProcessHeap ();
-	long /*int*/ lpText = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, TCHAR.sizeof);
+	long hHeap = OS.GetProcessHeap ();
+	long lpText = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, TCHAR.sizeof);
 	REBARBANDINFO rbBand = new REBARBANDINFO ();
 	rbBand.cbSize = REBARBANDINFO.sizeof;
 	rbBand.fMask = OS.RBBIM_TEXT | OS.RBBIM_STYLE | OS.RBBIM_ID;
@@ -297,8 +297,8 @@ void createWidget () {
 }
 
 void destroyItem (CoolItem item) {
-	int index = (int)/*64*/OS.SendMessage (handle, OS.RB_IDTOINDEX, item.id, 0);
-	int count = (int)/*64*/OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
+	int index = (int)OS.SendMessage (handle, OS.RB_IDTOINDEX, item.id, 0);
+	int count = (int)OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
 	if (count != 0) {
 		int lastIndex = getLastIndexOfRow (index);
 		if (index == lastIndex) {
@@ -363,7 +363,7 @@ void destroyItem (CoolItem item) {
 }
 
 @Override
-void drawThemeBackground (long /*int*/ hDC, long /*int*/ hwnd, RECT rect) {
+void drawThemeBackground (long hDC, long hwnd, RECT rect) {
 	if (OS.IsAppThemed ()) {
 		if (background == -1 && (style & SWT.FLAT) != 0) {
 			Control control = findBackgroundControl ();
@@ -439,7 +439,7 @@ int getMargin (int index) {
  */
 public CoolItem getItem (int index) {
 	checkWidget ();
-	int count = (int)/*64*/OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
+	int count = (int)OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
 	if (!(0 <= index && index < count)) error (SWT.ERROR_INVALID_RANGE);
 	REBARBANDINFO rbBand = new REBARBANDINFO ();
 	rbBand.cbSize = REBARBANDINFO.sizeof;
@@ -460,7 +460,7 @@ public CoolItem getItem (int index) {
  */
 public int getItemCount () {
 	checkWidget ();
-	return (int)/*64*/OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
+	return (int)OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
 }
 
 /**
@@ -486,7 +486,7 @@ public int getItemCount () {
  */
 public int [] getItemOrder () {
 	checkWidget ();
-	int count = (int)/*64*/OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
+	int count = (int)OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
 	int [] indices = new int [count];
 	REBARBANDINFO rbBand = new REBARBANDINFO ();
 	rbBand.cbSize = REBARBANDINFO.sizeof;
@@ -523,7 +523,7 @@ public int [] getItemOrder () {
  */
 public CoolItem [] getItems () {
 	checkWidget ();
-	int count = (int)/*64*/OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
+	int count = (int)OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
 	CoolItem [] result = new CoolItem [count];
 	REBARBANDINFO rbBand = new REBARBANDINFO ();
 	rbBand.cbSize = REBARBANDINFO.sizeof;
@@ -559,7 +559,7 @@ public Point [] getItemSizes () {
 }
 
 Point [] getItemSizesInPixels () {
-	int count = (int)/*64*/OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
+	int count = (int)OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
 	Point [] sizes = new Point [count];
 	REBARBANDINFO rbBand = new REBARBANDINFO ();
 	rbBand.cbSize = REBARBANDINFO.sizeof;
@@ -584,7 +584,7 @@ Point [] getItemSizesInPixels () {
 }
 
 int getLastIndexOfRow (int index) {
-	int count = (int)/*64*/OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
+	int count = (int)OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
 	if (count == 0) return -1;
 	REBARBANDINFO rbBand = new REBARBANDINFO ();
 	rbBand.cbSize = REBARBANDINFO.sizeof;
@@ -599,7 +599,7 @@ int getLastIndexOfRow (int index) {
 }
 
 boolean isLastItemOfRow (int index) {
-	int count = (int)/*64*/OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
+	int count = (int)OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
 	if (index + 1 == count) return true;
 	REBARBANDINFO rbBand = new REBARBANDINFO ();
 	rbBand.cbSize = REBARBANDINFO.sizeof;
@@ -674,7 +674,7 @@ public int indexOf (CoolItem item) {
 	checkWidget ();
 	if (item == null) error (SWT.ERROR_NULL_ARGUMENT);
 	if (item.isDisposed()) error (SWT.ERROR_INVALID_ARGUMENT);
-	return (int)/*64*/OS.SendMessage (handle, OS.RB_IDTOINDEX, item.id, 0);
+	return (int)OS.SendMessage (handle, OS.RB_IDTOINDEX, item.id, 0);
 }
 
 void resizeToPreferredWidth (int index) {
@@ -683,7 +683,7 @@ void resizeToPreferredWidth (int index) {
 	* with an index out of range, Windows GP's.  The
 	* fix is to ensure the index is in range.
 	*/
-	int count = (int)/*64*/OS.SendMessage(handle, OS.RB_GETBANDCOUNT, 0, 0);
+	int count = (int)OS.SendMessage(handle, OS.RB_GETBANDCOUNT, 0, 0);
 	if (0 <= index && index < count) {
 		REBARBANDINFO rbBand = new REBARBANDINFO();
 		rbBand.cbSize = REBARBANDINFO.sizeof;
@@ -746,7 +746,7 @@ void reskinChildren (int flags) {
 void setBackgroundPixel (int pixel) {
 	if (pixel == -1) pixel = defaultBackground ();
 	OS.SendMessage (handle, OS.RB_SETBKCOLOR, 0, pixel);
-	setItemColors ((int)/*64*/OS.SendMessage (handle, OS.RB_GETTEXTCOLOR, 0, 0), pixel);
+	setItemColors ((int)OS.SendMessage (handle, OS.RB_GETTEXTCOLOR, 0, 0), pixel);
 	/*
 	* Feature in Windows.  For some reason, Windows
 	* does not fully erase the coolbar area and coolbar
@@ -762,11 +762,11 @@ void setBackgroundPixel (int pixel) {
 void setForegroundPixel (int pixel) {
 	if (pixel == -1) pixel = defaultForeground ();
 	OS.SendMessage (handle, OS.RB_SETTEXTCOLOR, 0, pixel);
-	setItemColors (pixel, (int)/*64*/OS.SendMessage (handle, OS.RB_GETBKCOLOR, 0, 0));
+	setItemColors (pixel, (int)OS.SendMessage (handle, OS.RB_GETBKCOLOR, 0, 0));
 }
 
 void setItemColors (int foreColor, int backColor) {
-	int count = (int)/*64*/OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
+	int count = (int)OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
 	REBARBANDINFO rbBand = new REBARBANDINFO ();
 	rbBand.cbSize = REBARBANDINFO.sizeof;
 	rbBand.fMask = OS.RBBIM_COLORS;
@@ -847,7 +847,7 @@ void setItemLayoutInPixels (int [] itemOrder, int [] wrapIndices, Point [] sizes
  */
 void setItemOrder (int [] itemOrder) {
 	if (itemOrder == null) error (SWT.ERROR_NULL_ARGUMENT);
-	int itemCount = (int)/*64*/OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
+	int itemCount = (int)OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
 	if (itemOrder.length != itemCount) error (SWT.ERROR_INVALID_ARGUMENT);
 
 	/* Ensure that itemOrder does not contain any duplicates. */
@@ -863,7 +863,7 @@ void setItemOrder (int [] itemOrder) {
 	rbBand.cbSize = REBARBANDINFO.sizeof;
 	for (int i=0; i<itemOrder.length; i++) {
 		int id = originalItems [itemOrder [i]].id;
-		int index = (int)/*64*/OS.SendMessage (handle, OS.RB_IDTOINDEX, id, 0);
+		int index = (int)OS.SendMessage (handle, OS.RB_IDTOINDEX, id, 0);
 		if (index != i) {
 			int lastItemSrcRow = getLastIndexOfRow (index);
 			int lastItemDstRow = getLastIndexOfRow (i);
@@ -906,7 +906,7 @@ void setItemOrder (int [] itemOrder) {
  */
 void setItemSizes (Point [] sizes) {
 	if (sizes == null) error (SWT.ERROR_NULL_ARGUMENT);
-	int count = (int)/*64*/OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
+	int count = (int)OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
 	if (sizes.length != count) error (SWT.ERROR_INVALID_ARGUMENT);
 	REBARBANDINFO rbBand = new REBARBANDINFO ();
 	rbBand.cbSize = REBARBANDINFO.sizeof;
@@ -933,7 +933,7 @@ void setItemSizes (Point [] sizes) {
 public void setLocked (boolean locked) {
 	checkWidget ();
 	this.locked = locked;
-	int count = (int)/*64*/OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
+	int count = (int)OS.SendMessage (handle, OS.RB_GETBANDCOUNT, 0, 0);
 	REBARBANDINFO rbBand = new REBARBANDINFO ();
 	rbBand.cbSize = REBARBANDINFO.sizeof;
 	rbBand.fMask = OS.RBBIM_STYLE;
@@ -1007,12 +1007,12 @@ TCHAR windowClass () {
 }
 
 @Override
-long /*int*/ windowProc () {
+long windowProc () {
 	return ReBarProc;
 }
 
 @Override
-LRESULT WM_COMMAND (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT WM_COMMAND (long wParam, long lParam) {
 	/*
 	* Feature in Windows.  When the coolbar window
 	* proc processes WM_COMMAND, it forwards this
@@ -1037,7 +1037,7 @@ LRESULT WM_COMMAND (long /*int*/ wParam, long /*int*/ lParam) {
 }
 
 @Override
-LRESULT WM_ERASEBKGND (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT WM_ERASEBKGND (long wParam, long lParam) {
 	LRESULT result = super.WM_ERASEBKGND (wParam, lParam);
 	/*
 	* Feature in Windows.  For some reason, Windows
@@ -1060,7 +1060,7 @@ LRESULT WM_ERASEBKGND (long /*int*/ wParam, long /*int*/ lParam) {
 }
 
 @Override
-LRESULT WM_NOTIFY (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT WM_NOTIFY (long wParam, long lParam) {
 	/*
 	* Feature in Windows.  When the cool bar window
 	* proc processes WM_NOTIFY, it forwards this
@@ -1085,7 +1085,7 @@ LRESULT WM_NOTIFY (long /*int*/ wParam, long /*int*/ lParam) {
 }
 
 @Override
-LRESULT WM_SETREDRAW (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT WM_SETREDRAW (long wParam, long lParam) {
 	LRESULT result = super.WM_SETREDRAW (wParam, lParam);
 	if (result != null) return result;
 	/*
@@ -1111,9 +1111,9 @@ LRESULT WM_SETREDRAW (long /*int*/ wParam, long /*int*/ lParam) {
 }
 
 @Override
-LRESULT WM_SIZE (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT WM_SIZE (long wParam, long lParam) {
 	if (ignoreResize) {
-		long /*int*/ code = callWindowProc (handle, OS.WM_SIZE, wParam, lParam);
+		long code = callWindowProc (handle, OS.WM_SIZE, wParam, lParam);
 		if (code == 0) return LRESULT.ZERO;
 		return new LRESULT (code);
 	}
@@ -1127,7 +1127,7 @@ LRESULT WM_SIZE (long /*int*/ wParam, long /*int*/ lParam) {
 }
 
 @Override
-LRESULT wmNotifyChild (NMHDR hdr, long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT wmNotifyChild (NMHDR hdr, long wParam, long lParam) {
 	switch (hdr.code) {
 		case OS.RBN_BEGINDRAG: {
 			int pos = OS.GetMessagePos ();
@@ -1165,7 +1165,7 @@ LRESULT wmNotifyChild (NMHDR hdr, long /*int*/ wParam, long /*int*/ lParam) {
 			if (!ignoreResize) {
 				Point size = getSizeInPixels ();
 				int border = getBorderWidthInPixels ();
-				int barHeight = (int)/*64*/OS.SendMessage (handle, OS.RB_GETBARHEIGHT, 0, 0);
+				int barHeight = (int)OS.SendMessage (handle, OS.RB_GETBARHEIGHT, 0, 0);
 				if ((style & SWT.VERTICAL) != 0) {
 					setSizeInPixels (barHeight + 2 * border, size.y);
 				} else {
