@@ -232,7 +232,7 @@ public Rectangle getBounds () {
 Rectangle getBoundsInPixels () {
 	int index = parent.indexOf (this);
 	if (index == -1) return new Rectangle (0, 0, 0, 0);
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	RECT rect = new RECT ();
 	OS.SendMessage (hwnd, OS.RB_GETRECT, index, rect);
 	MARGINS margins = new MARGINS ();
@@ -254,7 +254,7 @@ Rectangle getClientArea () {
 	checkWidget ();
 	int index = parent.indexOf (this);
 	if (index == -1) return new Rectangle (0, 0, 0, 0);
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	RECT insetRect = new RECT ();
 	OS.SendMessage (hwnd, OS.RB_GETBANDBORDERS, index, insetRect);
 	RECT rect = new RECT ();
@@ -343,8 +343,8 @@ public void setControl (Control control) {
 		this.control = null;
 	}
 	Control oldControl = this.control, newControl = control;
-	long /*int*/ hwnd = parent.handle;
-	long /*int*/ hwndChild = newControl != null ? control.topHandle () : 0;
+	long hwnd = parent.handle;
+	long hwndChild = newControl != null ? control.topHandle () : 0;
 	REBARBANDINFO rbBand = new REBARBANDINFO ();
 	rbBand.cbSize = REBARBANDINFO.sizeof;
 	rbBand.fMask = OS.RBBIM_CHILD;
@@ -357,7 +357,7 @@ public void setControl (Control control) {
 	* moves the new child to the top of the Z-order.  The fix is
 	* to save and restore the visibility and Z-order.
 	*/
-	long /*int*/ hwndAbove = 0;
+	long hwndAbove = 0;
 	if (newControl != null) {
 		hwndAbove = OS.GetWindow (hwndChild, OS.GW_HWNDPREV);
 	}
@@ -392,7 +392,7 @@ public Point getPreferredSize () {
 Point getPreferredSizeInPixels () {
 	int index = parent.indexOf (this);
 	if (index == -1) return new Point (0, 0);
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	REBARBANDINFO rbBand = new REBARBANDINFO ();
 	rbBand.cbSize = REBARBANDINFO.sizeof;
 	rbBand.fMask = OS.RBBIM_CHILDSIZE | OS.RBBIM_IDEALSIZE;
@@ -426,7 +426,7 @@ void setPreferredSizeInPixels (int width, int height) {
 	width = Math.max (0, width);
 	height = Math.max (0, height);
 	ideal = true;
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	int cxIdeal, cyMaxChild;
 	if ((parent.style & SWT.VERTICAL) != 0) {
 		cxIdeal = Math.max (0, height - parent.getMargin (index));
@@ -491,7 +491,7 @@ public Point getSize () {
 Point getSizeInPixels() {
 	int index = parent.indexOf (this);
 	if (index == -1) new Point (0, 0);
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	RECT rect = new RECT ();
 	OS.SendMessage (hwnd, OS.RB_GETRECT, index, rect);
 	MARGINS margins = new MARGINS ();
@@ -535,7 +535,7 @@ void setSizeInPixels (int width, int height) {
 	if (index == -1) return;
 	width = Math.max (0, width);
 	height = Math.max (0, height);
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	int cx, cyChild, cxIdeal;
 	if ((parent.style & SWT.VERTICAL) != 0) {
 		cx = height;
@@ -618,7 +618,7 @@ public Point getMinimumSize () {
 Point getMinimumSizeInPixels () {
 	int index = parent.indexOf (this);
 	if (index == -1) return new Point (0, 0);
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	REBARBANDINFO rbBand = new REBARBANDINFO ();
 	rbBand.cbSize = REBARBANDINFO.sizeof;
 	rbBand.fMask = OS.RBBIM_CHILDSIZE;
@@ -654,7 +654,7 @@ void setMinimumSizeInPixels (int width, int height) {
 	width = Math.max (0, width);
 	height = Math.max (0, height);
 	minimum = true;
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	int cxMinChild, cyMinChild;
 	if ((parent.style & SWT.VERTICAL) != 0) {
 		cxMinChild = height;
@@ -701,7 +701,7 @@ public void setMinimumSize (Point size) {
 
 boolean getWrap() {
 	int index = parent.indexOf (this);
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	REBARBANDINFO rbBand = new REBARBANDINFO ();
 	rbBand.cbSize = REBARBANDINFO.sizeof;
 	rbBand.fMask = OS.RBBIM_STYLE;
@@ -711,7 +711,7 @@ boolean getWrap() {
 
 void setWrap(boolean wrap) {
 	int index = parent.indexOf (this);
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	REBARBANDINFO rbBand = new REBARBANDINFO ();
 	rbBand.cbSize = REBARBANDINFO.sizeof;
 	rbBand.fMask = OS.RBBIM_STYLE;
