@@ -106,7 +106,7 @@ public class Decorations extends Canvas {
 	Control savedFocus;
 	Button defaultButton, saveDefault;
 	int swFlags, nAccel;
-	long /*int*/ hAccel;
+	long hAccel;
 	boolean moved, resized, opened;
 	int oldX = OS.CW_USEDEFAULT, oldY = OS.CW_USEDEFAULT;
 	int oldWidth = OS.CW_USEDEFAULT, oldHeight = OS.CW_USEDEFAULT;
@@ -274,7 +274,7 @@ protected void checkSubclass () {
 }
 
 @Override
-long /*int*/ callWindowProc (long /*int*/ hwnd, int msg, long /*int*/ wParam, long /*int*/ lParam) {
+long callWindowProc (long hwnd, int msg, long wParam, long lParam) {
 	if (handle == 0) return 0;
 	return OS.DefMDIChildProc (hwnd, msg, wParam, lParam);
 }
@@ -408,7 +408,7 @@ public void dispose () {
 	super.dispose ();
 }
 
-Menu findMenu (long /*int*/ hMenu) {
+Menu findMenu (long hMenu) {
 	if (menus == null) return null;
 	for (int i=0; i<menus.length; i++) {
 		Menu menu = menus [i];
@@ -903,7 +903,7 @@ void setImages (Image image, Image [] images) {
 	if (smallImage != null) smallImage.dispose ();
 	if (largeImage != null) largeImage.dispose ();
 	smallImage = largeImage = null;
-	long /*int*/ hSmallIcon = 0, hLargeIcon = 0;
+	long hSmallIcon = 0, hLargeIcon = 0;
 	Image smallIcon = null, largeIcon = null;
 	if (image != null) {
 		smallIcon = largeIcon = image;
@@ -1054,7 +1054,7 @@ public void setMenuBar (Menu menu) {
 	}
 	if (menu != null) display.removeBar (menu);
 	menuBar = menu;
-	long /*int*/ hMenu = menuBar != null ? menuBar.handle: 0;
+	long hMenu = menuBar != null ? menuBar.handle: 0;
 	OS.SetMenu (handle, hMenu);
 	destroyAccelerators ();
 }
@@ -1090,15 +1090,15 @@ public void setMinimized (boolean minimized) {
 
 @Override
 public void setOrientation (int orientation) {
-    super.setOrientation (orientation);
-    if (menus != null) {
-        for (int i=0; i<menus.length; i++) {
-            Menu menu = menus [i];
-            if (menu != null && !menu.isDisposed () && (menu.getStyle () & SWT.POP_UP) != 0) {
-                menu._setOrientation (menu.getOrientation ());
-            }
-        }
-    }
+	super.setOrientation (orientation);
+	if (menus != null) {
+		for (int i=0; i<menus.length; i++) {
+			Menu menu = menus [i];
+			if (menu != null && !menu.isDisposed () && (menu.getStyle () & SWT.POP_UP) != 0) {
+				menu._setOrientation (menu.getOrientation ());
+			}
+		}
+	}
 }
 
 void setParent () {
@@ -1110,7 +1110,7 @@ void setParent () {
 	* undocumented and possibly dangerous Windows
 	* feature.
 	*/
-	long /*int*/ hwndParent = parent.handle;
+	long hwndParent = parent.handle;
 	display.lockActiveWindow = true;
 	OS.SetParent (handle, hwndParent);
 	if (!OS.IsWindowVisible (hwndParent)) {
@@ -1181,7 +1181,7 @@ void setSavedFocus (Control control) {
 }
 
 void setSystemMenu () {
-	long /*int*/ hMenu = OS.GetSystemMenu (handle, false);
+	long hMenu = OS.GetSystemMenu (handle, false);
 	if (hMenu == 0) return;
 	int oldCount = OS.GetMenuItemCount (hMenu);
 	if ((style & SWT.RESIZE) == 0) {
@@ -1244,9 +1244,9 @@ public void setText (String string) {
 	TCHAR buffer = new TCHAR (0, string, true);
 	/* Ensure that the title appears in the task bar.*/
 	if ((state & FOREIGN_HANDLE) != 0) {
-		long /*int*/ hHeap = OS.GetProcessHeap ();
+		long hHeap = OS.GetProcessHeap ();
 		int byteCount = buffer.length () * TCHAR.sizeof;
-		long /*int*/ pszText = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, byteCount);
+		long pszText = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, byteCount);
 		OS.MoveMemory (pszText, buffer, byteCount);
 		OS.DefWindowProc (handle, OS.WM_SETTEXT, 0, pszText);
 		if (pszText != 0) OS.HeapFree (hHeap, 0, pszText);
@@ -1339,16 +1339,16 @@ void sort (Image [] images, ImageData [] datas, int width, int height, int depth
 	for (int gap=length/2; gap>0; gap/=2) {
 		for (int i=gap; i<length; i++) {
 			for (int j=i-gap; j>=0; j-=gap) {
-		   		if (compare (datas [j], datas [j + gap], width, height, depth) >= 0) {
+				if (compare (datas [j], datas [j + gap], width, height, depth) >= 0) {
 					Image swap = images [j];
 					images [j] = images [j + gap];
 					images [j + gap] = swap;
 					ImageData swapData = datas [j];
 					datas [j] = datas [j + gap];
 					datas [j + gap] = swapData;
-		   		}
-	    	}
-	    }
+				}
+			}
+		}
 	}
 }
 
@@ -1369,13 +1369,13 @@ boolean translateMenuAccelerator (MSG msg) {
 boolean translateMDIAccelerator (MSG msg) {
 	if (!(this instanceof Shell)) {
 		Shell shell = getShell ();
-		long /*int*/ hwndMDIClient = shell.hwndMDIClient;
+		long hwndMDIClient = shell.hwndMDIClient;
 		if (hwndMDIClient != 0 && OS.TranslateMDISysAccel (hwndMDIClient, msg)) {
 			return true;
 		}
 		if (msg.message == OS.WM_KEYDOWN) {
 			if (OS.GetKeyState (OS.VK_CONTROL) >= 0) return false;
-			switch ((int)/*64*/(msg.wParam)) {
+			switch ((int)(msg.wParam)) {
 				case OS.VK_F4:
 					OS.PostMessage (handle, OS.WM_CLOSE, 0, 0);
 					return true;
@@ -1385,7 +1385,7 @@ boolean translateMDIAccelerator (MSG msg) {
 			return false;
 		}
 		if (msg.message == OS.WM_SYSKEYDOWN) {
-			switch ((int)/*64*/(msg.wParam)) {
+			switch ((int)(msg.wParam)) {
 				case OS.VK_F4:
 					OS.PostMessage (shell.handle, OS.WM_CLOSE, 0, 0);
 					return true;
@@ -1449,7 +1449,7 @@ int widgetExtStyle () {
 }
 
 @Override
-long /*int*/ widgetParent () {
+long widgetParent () {
 	Shell shell = getShell ();
 	return shell.hwndMDIClient ();
 }
@@ -1491,7 +1491,7 @@ int widgetStyle () {
 }
 
 @Override
-long /*int*/ windowProc (long /*int*/ hwnd, int msg, long /*int*/ wParam, long /*int*/ lParam) {
+long windowProc (long hwnd, int msg, long wParam, long lParam) {
 	switch (msg) {
 		case Display.SWT_GETACCEL:
 		case Display.SWT_GETACCELCOUNT:
@@ -1502,7 +1502,7 @@ long /*int*/ windowProc (long /*int*/ hwnd, int msg, long /*int*/ wParam, long /
 }
 
 @Override
-LRESULT WM_ACTIVATE (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT WM_ACTIVATE (long wParam, long lParam) {
 	LRESULT result = super.WM_ACTIVATE (wParam, lParam);
 	if (result != null) return result;
 	/*
@@ -1567,7 +1567,7 @@ LRESULT WM_ACTIVATE (long /*int*/ wParam, long /*int*/ lParam) {
 }
 
 @Override
-LRESULT WM_CLOSE (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT WM_CLOSE (long wParam, long lParam) {
 	LRESULT result = super.WM_CLOSE (wParam, lParam);
 	if (result != null) return result;
 	if (isEnabled () && isActive ()) closeWidget ();
@@ -1575,14 +1575,14 @@ LRESULT WM_CLOSE (long /*int*/ wParam, long /*int*/ lParam) {
 }
 
 @Override
-LRESULT WM_KILLFOCUS (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT WM_KILLFOCUS (long wParam, long lParam) {
 	LRESULT result = super.WM_KILLFOCUS (wParam, lParam);
 	saveFocus ();
 	return result;
 }
 
 @Override
-LRESULT WM_MOVE (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT WM_MOVE (long wParam, long lParam) {
 	if (moved) {
 		Point location = getLocationInPixels ();
 		if (location.x == oldX && location.y == oldY) {
@@ -1595,7 +1595,7 @@ LRESULT WM_MOVE (long /*int*/ wParam, long /*int*/ lParam) {
 }
 
 @Override
-LRESULT WM_NCACTIVATE (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT WM_NCACTIVATE (long wParam, long lParam) {
 	LRESULT result = super.WM_NCACTIVATE (wParam, lParam);
 	if (result != null) return result;
 	if (wParam == 0) {
@@ -1615,14 +1615,14 @@ LRESULT WM_NCACTIVATE (long /*int*/ wParam, long /*int*/ lParam) {
 		}
 	}
 	if (!(this instanceof Shell)) {
-		long /*int*/ hwndShell = getShell().handle;
+		long hwndShell = getShell().handle;
 		OS.SendMessage (hwndShell, OS.WM_NCACTIVATE, wParam, lParam);
 	}
 	return result;
 }
 
 @Override
-LRESULT WM_QUERYOPEN (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT WM_QUERYOPEN (long wParam, long lParam) {
 	LRESULT result = super.WM_QUERYOPEN (wParam, lParam);
 	if (result != null) return result;
 	sendEvent (SWT.Deiconify);
@@ -1631,7 +1631,7 @@ LRESULT WM_QUERYOPEN (long /*int*/ wParam, long /*int*/ lParam) {
 }
 
 @Override
-LRESULT WM_SETFOCUS (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT WM_SETFOCUS (long wParam, long lParam) {
 	LRESULT result = super.WM_SETFOCUS (wParam, lParam);
 	if (isDisposed ()) return result;
 	if (savedFocus != this) restoreFocus ();
@@ -1639,12 +1639,12 @@ LRESULT WM_SETFOCUS (long /*int*/ wParam, long /*int*/ lParam) {
 }
 
 @Override
-LRESULT WM_SIZE (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT WM_SIZE (long wParam, long lParam) {
 	LRESULT result = null;
 	boolean changed = true;
 	if (resized) {
 		int newWidth = 0, newHeight = 0;
-		switch ((int)/*64*/wParam) {
+		switch ((int)wParam) {
 			case OS.SIZE_MAXIMIZED:
 				OS.GetWindowRect (handle, maxRect);
 			case OS.SIZE_RESTORED:
@@ -1675,11 +1675,11 @@ LRESULT WM_SIZE (long /*int*/ wParam, long /*int*/ lParam) {
 }
 
 @Override
-LRESULT WM_SYSCOMMAND (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT WM_SYSCOMMAND (long wParam, long lParam) {
 	LRESULT result = super.WM_SYSCOMMAND (wParam, lParam);
 	if (result != null) return result;
 	if (!(this instanceof Shell)) {
-		int cmd = (int)/*64*/wParam & 0xFFF0;
+		int cmd = (int)wParam & 0xFFF0;
 		switch (cmd) {
 			case OS.SC_CLOSE: {
 				OS.PostMessage (handle, OS.WM_CLOSE, 0, 0);
@@ -1695,7 +1695,7 @@ LRESULT WM_SYSCOMMAND (long /*int*/ wParam, long /*int*/ lParam) {
 }
 
 @Override
-LRESULT WM_WINDOWPOSCHANGING (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT WM_WINDOWPOSCHANGING (long wParam, long lParam) {
 	LRESULT result = super.WM_WINDOWPOSCHANGING (wParam, lParam);
 	if (result != null) return result;
 	if (display.lockActiveWindow) {
