@@ -197,20 +197,20 @@ public boolean getOverwrite () {
 	return overwrite;
 }
 
-long /*int*/ OFNHookProc (long /*int*/ hdlg, long /*int*/ uiMsg, long /*int*/ wParam, long /*int*/ lParam) {
-	switch ((int)/*64*/uiMsg) {
+long OFNHookProc (long hdlg, long uiMsg, long wParam, long lParam) {
+	switch ((int)uiMsg) {
 		case OS.WM_NOTIFY:
 			OFNOTIFY ofn = new OFNOTIFY ();
 			OS.MoveMemory (ofn, lParam, OFNOTIFY.sizeof);
 			if (ofn.code == OS.CDN_SELCHANGE) {
-				int lResult = (int)/*64*/OS.SendMessage (ofn.hwndFrom, OS.CDM_GETSPEC, 0, 0);
+				int lResult = (int)OS.SendMessage (ofn.hwndFrom, OS.CDM_GETSPEC, 0, 0);
 				if (lResult > 0) {
 					lResult += OS.MAX_PATH;
 					OPENFILENAME lpofn = new OPENFILENAME ();
 					OS.MoveMemory (lpofn, ofn.lpOFN, OPENFILENAME.sizeof);
 					if (lpofn.nMaxFile < lResult) {
-						long /*int*/ hHeap = OS.GetProcessHeap ();
-						long /*int*/ lpstrFile = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, lResult * TCHAR.sizeof);
+						long hHeap = OS.GetProcessHeap ();
+						long lpstrFile = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, lResult * TCHAR.sizeof);
 						if (lpstrFile != 0) {
 							if (lpofn.lpstrFile != 0) OS.HeapFree (hHeap, 0, lpofn.lpstrFile);
 							lpofn.lpstrFile = lpstrFile;
@@ -218,9 +218,9 @@ long /*int*/ OFNHookProc (long /*int*/ hdlg, long /*int*/ uiMsg, long /*int*/ wP
 							OS.MoveMemory (ofn.lpOFN, lpofn, OPENFILENAME.sizeof);
 						}
 					}
-			  }
-		  }
-		  break;
+				}
+			}
+		break;
 	}
 	return 0;
 }
@@ -238,11 +238,11 @@ long /*int*/ OFNHookProc (long /*int*/ hdlg, long /*int*/ uiMsg, long /*int*/ wP
  * </ul>
  */
 public String open () {
-	long /*int*/ hHeap = OS.GetProcessHeap ();
+	long hHeap = OS.GetProcessHeap ();
 
 	/* Get the owner HWND for the dialog */
-	long /*int*/ hwndOwner = parent.handle;
-	long /*int*/ hwndParent = parent.handle;
+	long hwndOwner = parent.handle;
+	long hwndParent = parent.handle;
 
 	/*
 	* Feature in Windows.  There is no API to set the orientation of a
@@ -275,7 +275,7 @@ public String open () {
 	/* Use the character encoding for the default locale */
 	TCHAR buffer3 = new TCHAR (0, title, true);
 	int byteCount3 = buffer3.length () * TCHAR.sizeof;
-	long /*int*/ lpstrTitle = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, byteCount3);
+	long lpstrTitle = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, byteCount3);
 	OS.MoveMemory (lpstrTitle, buffer3, byteCount3);
 
 	/* Compute filters and copy into lpstrFilter */
@@ -293,7 +293,7 @@ public String open () {
 	/* Use the character encoding for the default locale */
 	TCHAR buffer4 = new TCHAR (0, strFilter, true);
 	int byteCount4 = buffer4.length () * TCHAR.sizeof;
-	long /*int*/ lpstrFilter = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, byteCount4);
+	long lpstrFilter = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, byteCount4);
 	OS.MoveMemory (lpstrFilter, buffer4, byteCount4);
 
 	/* Convert the fileName and filterName to C strings */
@@ -308,7 +308,7 @@ public String open () {
 	int nMaxFile = OS.MAX_PATH;
 	if ((style & SWT.MULTI) != 0) nMaxFile = Math.max (nMaxFile, BUFFER_SIZE);
 	int byteCount = nMaxFile * TCHAR.sizeof;
-	long /*int*/ lpstrFile = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, byteCount);
+	long lpstrFile = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, byteCount);
 	int byteCountFile = Math.min (name.length () * TCHAR.sizeof, byteCount - TCHAR.sizeof);
 	OS.MoveMemory (lpstrFile, name, byteCountFile);
 
@@ -320,7 +320,7 @@ public String open () {
 	/* Use the character encoding for the default locale */
 	TCHAR path = new TCHAR (0, filterPath.replace ('/', '\\'), true);
 	int byteCount5 = OS.MAX_PATH * TCHAR.sizeof;
-	long /*int*/ lpstrInitialDir = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, byteCount5);
+	long lpstrInitialDir = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, byteCount5);
 	int byteCountDir = Math.min (path.length () * TCHAR.sizeof, byteCount5 - TCHAR.sizeof);
 	OS.MoveMemory (lpstrInitialDir, path, byteCountDir);
 
@@ -335,7 +335,7 @@ public String open () {
 		struct.Flags |= OS.OFN_ALLOWMULTISELECT | OS.OFN_EXPLORER | OS.OFN_ENABLESIZING;
 		if (USE_HOOK) {
 			callback = new Callback (this, "OFNHookProc", 4); //$NON-NLS-1$
-			long /*int*/ lpfnHook = callback.getAddress ();
+			long lpfnHook = callback.getAddress ();
 			if (lpfnHook == 0) error (SWT.ERROR_NO_MORE_CALLBACKS);
 			struct.lpfnHook = lpfnHook;
 			struct.Flags |= OS.OFN_ENABLEHOOK;
@@ -355,7 +355,7 @@ public String open () {
 	* empty, Windows uses the current value of the filter
 	* extension at the time that the dialog is closed.
 	*/
-	long /*int*/ lpstrDefExt = 0;
+	long lpstrDefExt = 0;
 	if (save) {
 		lpstrDefExt = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, TCHAR.sizeof);
 		struct.lpstrDefExt = lpstrDefExt;
