@@ -41,7 +41,7 @@ import org.eclipse.swt.internal.win32.*;
  */
 public class MenuItem extends Item {
 	Menu parent, menu;
-	long /*int*/ hBitmap;
+	long hBitmap;
 	int id, accelerator, userId, index;
 	ToolTip itemToolTip;
 	/* Image margin. */
@@ -267,7 +267,7 @@ boolean fillAccel (ACCEL accel) {
 				if (key == 0) return false;
 				vKey = OS.VkKeyScan ((short) key);
 				if (vKey == -1) {
-					if (key != (int)/*64*/OS.CharUpper ((short) key)) {
+					if (key != (int)OS.CharUpper ((short) key)) {
 						fVirt = 0;
 					}
 				} else {
@@ -298,7 +298,6 @@ void fixMenus (Decorations newParent) {
  *
  * @return the accelerator or 0
  *
- * </ul>
  * @exception SWTException <ul>
  *    <li>ERROR_WIDGET_DISPOSED - if the receiver has been disposed</li>
  *    <li>ERROR_THREAD_INVALID_ACCESS - if not called from the thread that created the receiver</li>
@@ -331,7 +330,7 @@ public int getAccelerator () {
 		if (shell.menuBar != parent) {
 			return new Rectangle (0, 0, 0, 0);
 		}
-		long /*int*/ hwndShell = shell.handle;
+		long hwndShell = shell.handle;
 		MENUBARINFO info1 = new MENUBARINFO ();
 		info1.cbSize = MENUBARINFO.sizeof;
 		if (!OS.GetMenuBarInfo (hwndShell, OS.OBJID_MENU, 1, info1)) {
@@ -348,7 +347,7 @@ public int getAccelerator () {
 		int height = info2.bottom - info2.top;
 		return new Rectangle (x, y, width, height);
 	} else {
-		long /*int*/ hMenu = parent.handle;
+		long hMenu = parent.handle;
 		RECT rect1 = new RECT ();
 		if (!OS.GetMenuItemRect (0, hMenu, 0, rect1)) {
 			return new Rectangle (0, 0, 0, 0);
@@ -391,7 +390,7 @@ public boolean getEnabled () {
 	if ((style & SWT.SEPARATOR) != 0) {
 		return (state & DISABLED) == 0;
 	}
-	long /*int*/ hMenu = parent.handle;
+	long hMenu = parent.handle;
 	MENUITEMINFO info = new MENUITEMINFO ();
 	info.cbSize = MENUITEMINFO.sizeof;
 	info.fMask = OS.MIIM_STATE;
@@ -475,7 +474,7 @@ public Menu getParent () {
 public boolean getSelection () {
 	checkWidget ();
 	if ((style & (SWT.CHECK | SWT.RADIO)) == 0) return false;
-	long /*int*/ hMenu = parent.handle;
+	long hMenu = parent.handle;
 	MENUITEMINFO info = new MENUITEMINFO ();
 	info.cbSize = MENUITEMINFO.sizeof;
 	info.fMask = OS.MIIM_STATE;
@@ -661,7 +660,6 @@ void selectRadio () {
  *
  * @param accelerator an integer that is the bit-wise OR of masks and a key
  *
- * </ul>
  * @exception SWTException <ul>
  *    <li>ERROR_WIDGET_DISPOSED - if the receiver has been disposed</li>
  *    <li>ERROR_THREAD_INVALID_ACCESS - if not called from the thread that created the receiver</li>
@@ -702,7 +700,7 @@ public void setEnabled (boolean enabled) {
 			state |= DISABLED;
 		}
 	}
-	long /*int*/ hMenu = parent.handle;
+	long hMenu = parent.handle;
 	MENUITEMINFO info = new MENUITEMINFO ();
 	info.cbSize = MENUITEMINFO.sizeof;
 	info.fMask = OS.MIIM_STATE;
@@ -795,7 +793,7 @@ public void setImage (Image image) {
 			info.hbmpItem = image != null ? OS.HBMMENU_CALLBACK : 0;
 		}
 	}
-	long /*int*/ hMenu = parent.handle;
+	long hMenu = parent.handle;
 	OS.SetMenuItemInfo (hMenu, id, false, info);
 	parent.redraw ();
 }
@@ -852,7 +850,7 @@ void setMenu (Menu menu, boolean dispose) {
 	if (oldMenu != null) oldMenu.cascade = null;
 	this.menu = menu;
 
-	long /*int*/ hMenu = parent.handle;
+	long hMenu = parent.handle;
 	MENUITEMINFO info = new MENUITEMINFO ();
 	info.cbSize = MENUITEMINFO.sizeof;
 	info.fMask = OS.MIIM_DATA;
@@ -863,9 +861,9 @@ void setMenu (Menu menu, boolean dispose) {
 	}
 	if (info.dwItemData != id) return;
 	int cch = 128;
-	long /*int*/ hHeap = OS.GetProcessHeap ();
+	long hHeap = OS.GetProcessHeap ();
 	int byteCount = cch * 2;
-	long /*int*/ pszText = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, byteCount);
+	long pszText = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, byteCount);
 	info.fMask = OS.MIIM_STATE | OS.MIIM_ID | OS.MIIM_DATA;
 	/*
 	* Bug in Windows.  When GetMenuItemInfo() is used to get the text,
@@ -915,13 +913,13 @@ boolean setRadioSelection (boolean value) {
 }
 
 void setOrientation (int orientation) {
-    long /*int*/ hMenu = parent.handle;
-    MENUITEMINFO info = new MENUITEMINFO ();
-    info.cbSize = MENUITEMINFO.sizeof;
-    info.fMask = OS.MIIM_FTYPE;
-    info.fType = widgetStyle ();
-    OS.SetMenuItemInfo (hMenu, id, false, info);
-    if (menu != null) menu._setOrientation (orientation);
+	long hMenu = parent.handle;
+	MENUITEMINFO info = new MENUITEMINFO ();
+	info.cbSize = MENUITEMINFO.sizeof;
+	info.fMask = OS.MIIM_FTYPE;
+	info.fType = widgetStyle ();
+	OS.SetMenuItemInfo (hMenu, id, false, info);
+	if (menu != null) menu._setOrientation (orientation);
 }
 
 /**
@@ -940,7 +938,7 @@ void setOrientation (int orientation) {
 public void setSelection (boolean selected) {
 	checkWidget ();
 	if ((style & (SWT.CHECK | SWT.RADIO)) == 0) return;
-	long /*int*/ hMenu = parent.handle;
+	long hMenu = parent.handle;
 	MENUITEMINFO info = new MENUITEMINFO ();
 	info.cbSize = MENUITEMINFO.sizeof;
 	info.fMask = OS.MIIM_STATE;
@@ -1010,11 +1008,11 @@ public void setText (String string) {
 	if ((style & SWT.SEPARATOR) != 0) return;
 	if (text.equals (string)) return;
 	super.setText (string);
-	long /*int*/ hHeap = OS.GetProcessHeap ();
-	long /*int*/ pszText = 0;
+	long hHeap = OS.GetProcessHeap ();
+	long pszText = 0;
 	MENUITEMINFO info = new MENUITEMINFO ();
 	info.cbSize = MENUITEMINFO.sizeof;
-	long /*int*/ hMenu = parent.handle;
+	long hMenu = parent.handle;
 
 	/* Use the character encoding for the default locale */
 	TCHAR buffer = new TCHAR (0, string, true);
@@ -1055,7 +1053,7 @@ public void setText (String string) {
  * </p>
  * <p>
  * NOTE: This operation is a hint and behavior is platform specific, on Windows
- * for CJK-style mnemonics of the form " (&C)" at the end of the tooltip text
+ * for CJK-style mnemonics of the form " (&amp;C)" at the end of the tooltip text
  * are not shown in tooltip.
  * </p>
  * @param toolTip the new tool tip text (or null)
@@ -1106,7 +1104,7 @@ int widgetStyle () {
 	return bits | OS.MFT_STRING;
 }
 
-LRESULT wmCommandChild (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT wmCommandChild (long wParam, long lParam) {
 	if ((style & SWT.CHECK) != 0) {
 		setSelection (!getSelection ());
 	} else {
@@ -1122,7 +1120,7 @@ LRESULT wmCommandChild (long /*int*/ wParam, long /*int*/ lParam) {
 	return null;
 }
 
-LRESULT wmDrawChild (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT wmDrawChild (long wParam, long lParam) {
 	DRAWITEMSTRUCT struct = new DRAWITEMSTRUCT ();
 	OS.MoveMemory (struct, lParam, DRAWITEMSTRUCT.sizeof);
 	if (image != null) {
@@ -1145,7 +1143,7 @@ LRESULT wmDrawChild (long /*int*/ wParam, long /*int*/ lParam) {
 	return null;
 }
 
-LRESULT wmMeasureChild (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT wmMeasureChild (long wParam, long lParam) {
 	MEASUREITEMSTRUCT struct = new MEASUREITEMSTRUCT ();
 	OS.MoveMemory (struct, lParam, MEASUREITEMSTRUCT.sizeof);
 	int width = 0, height = 0;
@@ -1167,7 +1165,7 @@ LRESULT wmMeasureChild (long /*int*/ wParam, long /*int*/ lParam) {
 		MENUINFO lpcmi = new MENUINFO ();
 		lpcmi.cbSize = MENUINFO.sizeof;
 		lpcmi.fMask = OS.MIM_STYLE;
-		long /*int*/ hMenu = parent.handle;
+		long hMenu = parent.handle;
 		OS.GetMenuInfo (hMenu, lpcmi);
 		if ((lpcmi.dwStyle & OS.MNS_CHECKORBMP) == 0) {
 			MenuItem [] items = parent.getItems ();
@@ -1195,7 +1193,7 @@ private static final class MenuItemToolTip extends ToolTip {
 	}
 
 	@Override
-	long /*int*/ hwndToolTip() {
+	long hwndToolTip() {
 		return parent.menuItemToolTipHandle();
 	}
 
