@@ -135,11 +135,11 @@ void _setText (int index, String string) {
 			if (j < i) string = new String (text, 0, j);
 		}
 	}
-	long /*int*/ hwnd = parent.handle;
-	long /*int*/ hHeap = OS.GetProcessHeap ();
+	long hwnd = parent.handle;
+	long hHeap = OS.GetProcessHeap ();
 	TCHAR buffer = new TCHAR (parent.getCodePage (), string, true);
 	int byteCount = buffer.length () * TCHAR.sizeof;
-	long /*int*/ pszText = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, byteCount);
+	long pszText = OS.HeapAlloc (hHeap, OS.HEAP_ZERO_MEMORY, byteCount);
 	OS.MoveMemory (pszText, buffer, byteCount);
 	TCITEM tcItem = new TCITEM ();
 	tcItem.mask = OS.TCIF_TEXT;
@@ -314,7 +314,7 @@ public void setImage (Image image) {
 	* whenever the image or text is changed.
 	*/
 	if (text.indexOf ('&') != -1) _setText (index, text);
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	TCITEM tcItem = new TCITEM ();
 	tcItem.mask = OS.TCIF_IMAGE;
 	tcItem.iImage = parent.imageIndex (image);
