@@ -50,7 +50,7 @@ public class TreeItem extends Item {
 	 *
 	 * @noreference This field is not intended to be referenced by clients.
 	 */
-	public long /*int*/ handle;
+	public long handle;
 	Tree parent;
 	String [] strings;
 	Image [] images;
@@ -61,22 +61,13 @@ public class TreeItem extends Item {
 	int [] cellBackground, cellForeground;
 
 /**
- * Constructs a new instance of this class given its parent
- * (which must be a <code>Tree</code> or a <code>TreeItem</code>)
- * and a style value describing its behavior and appearance.
- * The item is added to the end of the items maintained by its parent.
+ * Constructs <code>TreeItem</code> and <em>inserts</em> it into <code>Tree</code>.
+ * Item is inserted as last direct child of the tree.
  * <p>
- * The style value is either one of the style constants defined in
- * class <code>SWT</code> which is applicable to instances of this
- * class, or must be built by <em>bitwise OR</em>'ing together
- * (that is, using the <code>int</code> "|" operator) two or more
- * of those <code>SWT</code> style constants. The class description
- * lists the style constants that are applicable to the class.
- * Style bits are also inherited from superclasses.
- * </p>
+ * For bulk insert scenarios, see TreeItem#TreeItem(Tree,int,int)
  *
  * @param parent a tree control which will be the parent of the new instance (cannot be null)
- * @param style the style of control to construct
+ * @param style no styles are currently supported, pass SWT.NONE
  *
  * @exception IllegalArgumentException <ul>
  *    <li>ERROR_NULL_ARGUMENT - if the parent is null</li>
@@ -95,22 +86,17 @@ public TreeItem (Tree parent, int style) {
 }
 
 /**
- * Constructs a new instance of this class given its parent
- * (which must be a <code>Tree</code> or a <code>TreeItem</code>),
- * a style value describing its behavior and appearance, and the index
- * at which to place it in the items maintained by its parent.
+ * Constructs <code>TreeItem</code> and <em>inserts</em> it into <code>Tree</code>.
+ * Item is inserted as <code>index</code> direct child of the tree.
  * <p>
- * The style value is either one of the style constants defined in
- * class <code>SWT</code> which is applicable to instances of this
- * class, or must be built by <em>bitwise OR</em>'ing together
- * (that is, using the <code>int</code> "|" operator) two or more
- * of those <code>SWT</code> style constants. The class description
- * lists the style constants that are applicable to the class.
- * Style bits are also inherited from superclasses.
- * </p>
+ * The fastest way to insert many items is:
+ * <ol>
+ * <li>Use {@link Tree#setRedraw} to disable drawing during bulk insert</li>
+ * <li>Insert every item at index 0 (insert them in reverse to get the same result)</li>
+ * </ol>
  *
  * @param parent a tree control which will be the parent of the new instance (cannot be null)
- * @param style the style of control to construct
+ * @param style no styles are currently supported, pass SWT.NONE
  * @param index the zero-relative index to store the receiver in its parent
  *
  * @exception IllegalArgumentException <ul>
@@ -125,28 +111,20 @@ public TreeItem (Tree parent, int style) {
  * @see SWT
  * @see Widget#checkSubclass
  * @see Widget#getStyle
+ * @see Tree#setRedraw
  */
 public TreeItem (Tree parent, int style, int index) {
 	this (parent, style, OS.TVGN_ROOT, findPrevious (parent, index), 0);
 }
 
 /**
- * Constructs a new instance of this class given its parent
- * (which must be a <code>Tree</code> or a <code>TreeItem</code>)
- * and a style value describing its behavior and appearance.
- * The item is added to the end of the items maintained by its parent.
+ * Constructs <code>TreeItem</code> and <em>inserts</em> it into <code>Tree</code>.
+ * Item is inserted as last direct child of the specified <code>TreeItem</code>.
  * <p>
- * The style value is either one of the style constants defined in
- * class <code>SWT</code> which is applicable to instances of this
- * class, or must be built by <em>bitwise OR</em>'ing together
- * (that is, using the <code>int</code> "|" operator) two or more
- * of those <code>SWT</code> style constants. The class description
- * lists the style constants that are applicable to the class.
- * Style bits are also inherited from superclasses.
- * </p>
+ * For bulk insert scenarios, see TreeItem#TreeItem(TreeItem,int,int)
  *
  * @param parentItem a tree control which will be the parent of the new instance (cannot be null)
- * @param style the style of control to construct
+ * @param style no styles are currently supported, pass SWT.NONE
  *
  * @exception IllegalArgumentException <ul>
  *    <li>ERROR_NULL_ARGUMENT - if the parent is null</li>
@@ -165,22 +143,18 @@ public TreeItem (TreeItem parentItem, int style) {
 }
 
 /**
- * Constructs a new instance of this class given its parent
- * (which must be a <code>Tree</code> or a <code>TreeItem</code>),
- * a style value describing its behavior and appearance, and the index
- * at which to place it in the items maintained by its parent.
+ * Constructs <code>TreeItem</code> and <em>inserts</em> it into <code>Tree</code>.
+ * Item is inserted as <code>index</code> direct child of the specified <code>TreeItem</code>.
  * <p>
- * The style value is either one of the style constants defined in
- * class <code>SWT</code> which is applicable to instances of this
- * class, or must be built by <em>bitwise OR</em>'ing together
- * (that is, using the <code>int</code> "|" operator) two or more
- * of those <code>SWT</code> style constants. The class description
- * lists the style constants that are applicable to the class.
- * Style bits are also inherited from superclasses.
- * </p>
+ * The fastest way to insert many items is:
+ * <ol>
+ * <li>Use {@link Tree#setRedraw} to disable drawing during bulk insert</li>
+ * <li>Insert child items while parent item is collapsed</li>
+ * <li>Insert every item at index 0 (insert them in reverse to get the same result)</li>
+ * </ol>
  *
  * @param parentItem a tree control which will be the parent of the new instance (cannot be null)
- * @param style the style of control to construct
+ * @param style no styles are currently supported, pass SWT.NONE
  * @param index the zero-relative index to store the receiver in its parent
  *
  * @exception IllegalArgumentException <ul>
@@ -195,12 +169,13 @@ public TreeItem (TreeItem parentItem, int style) {
  * @see SWT
  * @see Widget#checkSubclass
  * @see Widget#getStyle
+ * @see Tree#setRedraw
  */
 public TreeItem (TreeItem parentItem, int style, int index) {
 	this (checkNull (parentItem).parent, style, parentItem.handle, findPrevious (parentItem, index), 0);
 }
 
-TreeItem (Tree parent, int style, long /*int*/ hParent, long /*int*/ hInsertAfter, long /*int*/ hItem) {
+TreeItem (Tree parent, int style, long hParent, long hInsertAfter, long hItem) {
 	super (parent, style);
 	this.parent = parent;
 	parent.createItem (this, hParent, hInsertAfter, hItem);
@@ -211,25 +186,25 @@ static TreeItem checkNull (TreeItem item) {
 	return item;
 }
 
-static long /*int*/ findPrevious (Tree parent, int index) {
+static long findPrevious (Tree parent, int index) {
 	if (parent == null) return 0;
 	if (index < 0) SWT.error (SWT.ERROR_INVALID_RANGE);
 	if (index == 0) return OS.TVI_FIRST;
-	long /*int*/ hwnd = parent.handle;
-	long /*int*/ hFirstItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_ROOT, 0);
-	long /*int*/ hItem = parent.findItem (hFirstItem, index - 1);
+	long hwnd = parent.handle;
+	long hFirstItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_ROOT, 0);
+	long hItem = parent.findItem (hFirstItem, index - 1);
 	if (hItem == 0) SWT.error (SWT.ERROR_INVALID_RANGE);
 	return hItem;
 }
 
-static long /*int*/ findPrevious (TreeItem parentItem, int index) {
+static long findPrevious (TreeItem parentItem, int index) {
 	if (parentItem == null) return 0;
 	if (index < 0) SWT.error (SWT.ERROR_INVALID_RANGE);
 	if (index == 0) return OS.TVI_FIRST;
 	Tree parent = parentItem.parent;
-	long /*int*/ hwnd = parent.handle, hParent = parentItem.handle;
-	long /*int*/ hFirstItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, hParent);
-	long /*int*/ hItem = parent.findItem (hFirstItem, index - 1);
+	long hwnd = parent.handle, hParent = parentItem.handle;
+	long hFirstItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, hParent);
+	long hItem = parent.findItem (hFirstItem, index - 1);
 	if (hItem == 0) SWT.error (SWT.ERROR_INVALID_RANGE);
 	return hItem;
 }
@@ -245,7 +220,7 @@ void clear () {
 	strings = null;
 	images = null;
 	if ((parent.style & SWT.CHECK) != 0) {
-		long /*int*/ hwnd = parent.handle;
+		long hwnd = parent.handle;
 		TVITEM tvItem = new TVITEM ();
 		tvItem.mask = OS.TVIF_HANDLE | OS.TVIF_STATE;
 		tvItem.stateMask = OS.TVIS_STATEIMAGEMASK;
@@ -285,8 +260,8 @@ void clear () {
  */
 public void clear (int index, boolean all) {
 	checkWidget ();
-	long /*int*/ hwnd = parent.handle;
-	long /*int*/ hItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, handle);
+	long hwnd = parent.handle;
+	long hItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, handle);
 	if (hItem == 0) error (SWT.ERROR_INVALID_RANGE);
 	hItem = parent.findItem (hItem, index);
 	if (hItem == 0) error (SWT.ERROR_INVALID_RANGE);
@@ -320,8 +295,8 @@ public void clear (int index, boolean all) {
  */
 public void clearAll (boolean all) {
 	checkWidget ();
-	long /*int*/ hwnd = parent.handle;
-	long /*int*/ hItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, handle);
+	long hwnd = parent.handle;
+	long hItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, handle);
 	if (hItem == 0) return;
 	TVITEM tvItem = new TVITEM ();
 	tvItem.mask = OS.TVIF_HANDLE | OS.TVIF_PARAM;
@@ -337,7 +312,7 @@ void destroyWidget () {
 	releaseHandle ();
 }
 
-long /*int*/ fontHandle (int index) {
+long fontHandle (int index) {
 	if (cellFont != null && cellFont [index] != null) return cellFont [index].handle;
 	if (font != null) return font.handle;
 	return -1;
@@ -439,9 +414,9 @@ RECT getBounds (int index, boolean getText, boolean getImage, boolean fullText)
 }
 
 //TODO - take into account grid (add boolean arg) to damage less during redraw
-RECT getBounds (int index, boolean getText, boolean getImage, boolean fullText, boolean fullImage, boolean clip, long /*int*/ hDC) {
+RECT getBounds (int index, boolean getText, boolean getImage, boolean fullText, boolean fullImage, boolean clip, long hDC) {
 	if (!getText && !getImage) return new RECT ();
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	if ((parent.style & SWT.VIRTUAL) == 0 && !cached && !parent.painted) {
 		TVITEM tvItem = new TVITEM ();
 		tvItem.mask = OS.TVIF_HANDLE | OS.TVIF_TEXT;
@@ -453,7 +428,7 @@ RECT getBounds (int index, boolean getText, boolean getImage, boolean fullText,
 	}
 	boolean firstColumn = index == 0;
 	int columnCount = 0;
-	long /*int*/ hwndHeader = parent.hwndHeader;
+	long hwndHeader = parent.hwndHeader;
 	if (hwndHeader != 0) {
 		columnCount = parent.columnCount;
 		firstColumn = index == OS.SendMessage (hwndHeader, OS.HDM_ORDERTOINDEX, 0, 0);
@@ -523,16 +498,16 @@ RECT getBounds (int index, boolean getText, boolean getImage, boolean fullText,
 					String string = index == 0 ? text : strings != null ? strings [index] : null;
 					if (string != null) {
 						RECT textRect = new RECT ();
-						TCHAR buffer = new TCHAR (parent.getCodePage (), string, false);
+						char [] buffer = string.toCharArray ();
 						int flags = OS.DT_NOPREFIX | OS.DT_SINGLELINE | OS.DT_CALCRECT;
-						long /*int*/ hNewDC = hDC, hFont = 0;
+						long hNewDC = hDC, hFont = 0;
 						if (hDC == 0) {
 							hNewDC = OS.GetDC (hwnd);
 							hFont = fontHandle (index);
 							if (hFont == -1) hFont = OS.SendMessage (hwnd, OS.WM_GETFONT, 0, 0);
 							hFont = OS.SelectObject (hNewDC, hFont);
 						}
-						OS.DrawText (hNewDC, buffer, buffer.length (), textRect, flags);
+						OS.DrawText (hNewDC, buffer, buffer.length, textRect, flags);
 						if (hDC == 0) {
 							OS.SelectObject (hNewDC, hFont);
 							OS.ReleaseDC (hwnd, hNewDC);
@@ -562,8 +537,7 @@ RECT getBounds (int index, boolean getText, boolean getImage, boolean fullText,
 /**
  * Returns <code>true</code> if the receiver is checked,
  * and false otherwise.  When the parent does not have
- * the <code>CHECK style, return false.
- * <p>
+ * the <code>CHECK</code> style, return false.
  *
  * @return the checked state
  *
@@ -576,12 +550,12 @@ public boolean getChecked () {
 	checkWidget ();
 	if (!parent.checkData (this, true)) error (SWT.ERROR_WIDGET_DISPOSED);
 	if ((parent.style & SWT.CHECK) == 0) return false;
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	TVITEM tvItem = new TVITEM ();
 	tvItem.mask = OS.TVIF_HANDLE | OS.TVIF_STATE;
 	tvItem.stateMask = OS.TVIS_STATEIMAGEMASK;
 	tvItem.hItem = handle;
-	long /*int*/ result = OS.SendMessage (hwnd, OS.TVM_GETITEM, 0, tvItem);
+	long result = OS.SendMessage (hwnd, OS.TVM_GETITEM, 0, tvItem);
 	return (result != 0) && (((tvItem.state >> 12) & 1) == 0);
 }
 
@@ -599,14 +573,14 @@ public boolean getChecked () {
  */
 public boolean getExpanded () {
 	checkWidget ();
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	/*
 	* Bug in Windows.  Despite the fact that TVM_GETITEMSTATE claims
 	* to return only the bits specified by the stateMask, when called
 	* with TVIS_EXPANDED, the entire state is returned.  The fix is
 	* to explicitly check for the TVIS_EXPANDED bit.
 	*/
-	int state = (int)/*64*/OS.SendMessage (hwnd, OS.TVM_GETITEMSTATE, handle, OS.TVIS_EXPANDED);
+	int state = (int)OS.SendMessage (hwnd, OS.TVM_GETITEMSTATE, handle, OS.TVIS_EXPANDED);
 	return (state & OS.TVIS_EXPANDED) != 0;
 }
 
@@ -697,8 +671,7 @@ public Color getForeground (int index) {
 /**
  * Returns <code>true</code> if the receiver is grayed,
  * and false otherwise. When the parent does not have
- * the <code>CHECK style, return false.
- * <p>
+ * the <code>CHECK</code> style, return false.
  *
  * @return the grayed state of the checkbox
  *
@@ -711,12 +684,12 @@ public boolean getGrayed () {
 	checkWidget ();
 	if (!parent.checkData (this, true)) error (SWT.ERROR_WIDGET_DISPOSED);
 	if ((parent.style & SWT.CHECK) == 0) return false;
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	TVITEM tvItem = new TVITEM ();
 	tvItem.mask = OS.TVIF_HANDLE | OS.TVIF_STATE;
 	tvItem.stateMask = OS.TVIS_STATEIMAGEMASK;
 	tvItem.hItem = handle;
-	long /*int*/ result = OS.SendMessage (hwnd, OS.TVM_GETITEM, 0, tvItem);
+	long result = OS.SendMessage (hwnd, OS.TVM_GETITEM, 0, tvItem);
 	return (result != 0) && ((tvItem.state >> 12) > 2);
 }
 
@@ -741,10 +714,10 @@ public TreeItem getItem (int index) {
 	checkWidget ();
 	if (index < 0) error (SWT.ERROR_INVALID_RANGE);
 	if (!parent.checkData (this, true)) error (SWT.ERROR_WIDGET_DISPOSED);
-	long /*int*/ hwnd = parent.handle;
-	long /*int*/ hFirstItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, handle);
+	long hwnd = parent.handle;
+	long hFirstItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, handle);
 	if (hFirstItem == 0) error (SWT.ERROR_INVALID_RANGE);
-	long /*int*/ hItem = parent.findItem (hFirstItem, index);
+	long hItem = parent.findItem (hFirstItem, index);
 	if (hItem == 0) error (SWT.ERROR_INVALID_RANGE);
 	return parent._getItem (hItem);
 }
@@ -763,8 +736,8 @@ public TreeItem getItem (int index) {
 public int getItemCount () {
 	checkWidget ();
 	if (!parent.checkData (this, true)) error (SWT.ERROR_WIDGET_DISPOSED);
-	long /*int*/ hwnd = parent.handle;
-	long /*int*/ hItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, handle);
+	long hwnd = parent.handle;
+	long hItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, handle);
 	if (hItem == 0) return 0;
 	return parent.getItemCount (hItem);
 }
@@ -788,8 +761,8 @@ public int getItemCount () {
 public TreeItem [] getItems () {
 	checkWidget ();
 	if (!parent.checkData (this, true)) error (SWT.ERROR_WIDGET_DISPOSED);
-	long /*int*/ hwnd = parent.handle;
-	long /*int*/ hItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, handle);
+	long hwnd = parent.handle;
+	long hItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, handle);
 	if (hItem == 0) return new TreeItem [0];
 	return parent.getItems (hItem);
 }
@@ -881,8 +854,8 @@ public Tree getParent () {
  */
 public TreeItem getParentItem () {
 	checkWidget ();
-	long /*int*/ hwnd = parent.handle;
-	long /*int*/ hItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_PARENT, handle);
+	long hwnd = parent.handle;
+	long hItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_PARENT, handle);
 	return hItem != 0 ? parent._getItem (hItem) : null;
 }
 
@@ -975,14 +948,14 @@ public int indexOf (TreeItem item) {
 	checkWidget ();
 	if (item == null) error (SWT.ERROR_NULL_ARGUMENT);
 	if (item.isDisposed()) error(SWT.ERROR_INVALID_ARGUMENT);
-	long /*int*/ hwnd = parent.handle;
-	long /*int*/ hItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, handle);
+	long hwnd = parent.handle;
+	long hItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, handle);
 	return hItem == 0 ? -1 : parent.findIndex (hItem, item.handle);
 }
 
 void redraw () {
 	if (parent.currentItem == this || !parent.getDrawing ()) return;
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	if (!OS.IsWindowVisible (hwnd)) return;
 	/*
 	* When there are no columns and the tree is not
@@ -1006,7 +979,7 @@ void redraw () {
 
 void redraw (int column, boolean drawText, boolean drawImage) {
 	if (parent.currentItem == this || !parent.getDrawing ()) return;
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	if (!OS.IsWindowVisible (hwnd)) return;
 	boolean fullImage = column == 0 && drawText && drawImage;
 	RECT rect = getBounds (column, drawText, drawImage, true, fullImage, true, 0);
@@ -1041,7 +1014,7 @@ void releaseWidget () {
 
 /**
  * Removes all of the items from the receiver.
- * <p>
+ *
  * @exception SWTException <ul>
  *    <li>ERROR_WIDGET_DISPOSED - if the receiver has been disposed</li>
  *    <li>ERROR_THREAD_INVALID_ACCESS - if not called from the thread that created the receiver</li>
@@ -1051,13 +1024,13 @@ void releaseWidget () {
  */
 public void removeAll () {
 	checkWidget ();
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	TVITEM tvItem = new TVITEM ();
 	tvItem.mask = OS.TVIF_HANDLE | OS.TVIF_PARAM;
 	tvItem.hItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, handle);
 	while (tvItem.hItem != 0) {
 		OS.SendMessage (hwnd, OS.TVM_GETITEM, 0, tvItem);
-		TreeItem item = tvItem.lParam != -1 ? parent.items [(int)/*64*/tvItem.lParam] : null;
+		TreeItem item = tvItem.lParam != -1 ? parent.items [(int)tvItem.lParam] : null;
 		if (item != null && !item.isDisposed ()) {
 			item.dispose ();
 		} else {
@@ -1159,7 +1132,7 @@ public void setBackground (int index, Color color) {
 public void setChecked (boolean checked) {
 	checkWidget ();
 	if ((parent.style & SWT.CHECK) == 0) return;
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	TVITEM tvItem = new TVITEM ();
 	tvItem.mask = OS.TVIF_HANDLE | OS.TVIF_STATE;
 	tvItem.stateMask = OS.TVIS_STATEIMAGEMASK;
@@ -1207,7 +1180,7 @@ public void setExpanded (boolean expanded) {
 	checkWidget ();
 
 	/* Do nothing when the item is a leaf or already expanded */
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	if (OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, handle) == 0) {
 		return;
 	}
@@ -1217,7 +1190,7 @@ public void setExpanded (boolean expanded) {
 	* with TVIS_EXPANDED, the entire state is returned.  The fix is
 	* to explicitly check for the TVIS_EXPANDED bit.
 	*/
-	int state = (int)/*64*/OS.SendMessage (hwnd, OS.TVM_GETITEMSTATE, handle, OS.TVIS_EXPANDED);
+	int state = (int)OS.SendMessage (hwnd, OS.TVM_GETITEMSTATE, handle, OS.TVIS_EXPANDED);
 	if (((state & OS.TVIS_EXPANDED) != 0) == expanded) return;
 
 	/*
@@ -1237,9 +1210,9 @@ public void setExpanded (boolean expanded) {
 	RECT [] rects = null;
 	SCROLLINFO oldInfo = null;
 	int count = 0;
- 	long /*int*/ hBottomItem = 0;
+	long hBottomItem = 0;
 	boolean redraw = false, noScroll = true;
-	long /*int*/ hTopItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_FIRSTVISIBLE, 0);
+	long hTopItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_FIRSTVISIBLE, 0);
 	if (noScroll && hTopItem != 0) {
 		oldInfo = new SCROLLINFO ();
 		oldInfo.cbSize = SCROLLINFO.sizeof;
@@ -1249,9 +1222,9 @@ public void setExpanded (boolean expanded) {
 		}
 		if (parent.getDrawing () && OS.IsWindowVisible (hwnd)) {
 			boolean noAnimate = true;
-			count = (int)/*64*/OS.SendMessage (hwnd, OS.TVM_GETVISIBLECOUNT, 0, 0);
+			count = (int)OS.SendMessage (hwnd, OS.TVM_GETVISIBLECOUNT, 0, 0);
 			rects = new RECT [count + 1];
-			long /*int*/ hItem = hTopItem;
+			long hItem = hTopItem;
 			int index = 0;
 			while (hItem != 0 && (noAnimate || hItem != handle) && index < count) {
 				RECT rect = new RECT ();
@@ -1266,7 +1239,7 @@ public void setExpanded (boolean expanded) {
 				hBottomItem = hItem;
 				oldRect = new RECT ();
 				OS.GetClientRect (hwnd, oldRect);
-				long /*int*/ topHandle = parent.topHandle ();
+				long topHandle = parent.topHandle ();
 				OS.UpdateWindow (topHandle);
 				OS.DefWindowProc (topHandle, OS.WM_SETREDRAW, 0, 0);
 				if (hwnd != topHandle) {
@@ -1293,7 +1266,7 @@ public void setExpanded (boolean expanded) {
 	* check whether the selection has changed and issue
 	* the event.
 	*/
-	long /*int*/ hOldItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CARET, 0);
+	long hOldItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CARET, 0);
 
 	/* Expand or collapse the item */
 	parent.ignoreExpand = true;
@@ -1321,7 +1294,7 @@ public void setExpanded (boolean expanded) {
 			newInfo.fMask = OS.SIF_ALL;
 			if (OS.GetScrollInfo (hwnd, OS.SB_HORZ, newInfo)) {
 				if (oldInfo.nPos != newInfo.nPos) {
-					long /*int*/ lParam = OS.MAKELPARAM (OS.SB_THUMBPOSITION, oldInfo.nPos);
+					long lParam = OS.MAKELPARAM (OS.SB_THUMBPOSITION, oldInfo.nPos);
 					OS.SendMessage (hwnd, OS.WM_HSCROLL, lParam, 0);
 				}
 			}
@@ -1332,7 +1305,7 @@ public void setExpanded (boolean expanded) {
 				RECT newRect = new RECT ();
 				OS.GetClientRect (hwnd, newRect);
 				if (OS.EqualRect (oldRect, newRect)) {
-					long /*int*/ hItem = hTopItem;
+					long hItem = hTopItem;
 					int index = 0;
 					while (hItem != 0 && index < count) {
 						RECT rect = new RECT ();
@@ -1347,7 +1320,7 @@ public void setExpanded (boolean expanded) {
 					fixScroll = index == count && hItem == hBottomItem;
 				}
 			}
-			long /*int*/ topHandle = parent.topHandle ();
+			long topHandle = parent.topHandle ();
 			OS.DefWindowProc (topHandle, OS.WM_SETREDRAW, 1, 0);
 			if (hwnd != topHandle) {
 				OS.DefWindowProc (hwnd, OS.WM_SETREDRAW, 1, 0);
@@ -1378,7 +1351,7 @@ public void setExpanded (boolean expanded) {
 	}
 
 	/* Check for a selection event */
-	long /*int*/ hNewItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CARET, 0);
+	long hNewItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CARET, 0);
 	if (hNewItem != hOldItem) {
 		Event event = new Event ();
 		if (hNewItem != 0) {
@@ -1426,7 +1399,7 @@ public void setFont (Font font){
 	if ((parent.style & SWT.VIRTUAL) == 0 && !cached && !parent.painted) {
 		return;
 	}
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	TVITEM tvItem = new TVITEM ();
 	tvItem.mask = OS.TVIF_HANDLE | OS.TVIF_TEXT;
 	tvItem.hItem = handle;
@@ -1481,7 +1454,7 @@ public void setFont (int index, Font font) {
 		if ((parent.style & SWT.VIRTUAL) == 0 && !cached && !parent.painted) {
 			return;
 		}
-		long /*int*/ hwnd = parent.handle;
+		long hwnd = parent.handle;
 		TVITEM tvItem = new TVITEM ();
 		tvItem.mask = OS.TVIF_HANDLE | OS.TVIF_TEXT;
 		tvItem.hItem = handle;
@@ -1583,7 +1556,7 @@ public void setForeground (int index, Color color){
 public void setGrayed (boolean grayed) {
 	checkWidget ();
 	if ((parent.style & SWT.CHECK) == 0) return;
-	long /*int*/ hwnd = parent.handle;
+	long hwnd = parent.handle;
 	TVITEM tvItem = new TVITEM ();
 	tvItem.mask = OS.TVIF_HANDLE | OS.TVIF_STATE;
 	tvItem.stateMask = OS.TVIS_STATEIMAGEMASK;
@@ -1692,7 +1665,7 @@ public void setImage (int index, Image image) {
 		if ((parent.style & SWT.VIRTUAL) == 0 &&!cached && !parent.painted) {
 			return;
 		}
-		long /*int*/ hwnd = parent.handle;
+		long hwnd = parent.handle;
 		TVITEM tvItem = new TVITEM ();
 		tvItem.mask = OS.TVIF_HANDLE | OS.TVIF_IMAGE | OS.TVIF_SELECTEDIMAGE;
 		tvItem.hItem = handle;
@@ -1733,8 +1706,8 @@ public void setImage (Image image) {
 public void setItemCount (int count) {
 	checkWidget ();
 	count = Math.max (0, count);
-	long /*int*/ hwnd = parent.handle;
-	long /*int*/ hItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, handle);
+	long hwnd = parent.handle;
+	long hItem = OS.SendMessage (hwnd, OS.TVM_GETNEXTITEM, OS.TVGN_CHILD, handle);
 	parent.setItemCount (count, handle, hItem);
 }
 
@@ -1806,7 +1779,7 @@ public void setText (int index, String string) {
 		if ((parent.style & SWT.VIRTUAL) == 0 && !cached && !parent.painted) {
 			return;
 		}
-		long /*int*/ hwnd = parent.handle;
+		long hwnd = parent.handle;
 		TVITEM tvItem = new TVITEM ();
 		tvItem.mask = OS.TVIF_HANDLE | OS.TVIF_TEXT;
 		tvItem.hItem = handle;
