@@ -38,9 +38,9 @@ class ColorTab extends Tab {
 	HashMap <Integer, String> hmap = new HashMap <> ();
 	static final int namedColorEnd = 8;
 	static String [] columnTitles	= {ControlExample.getResourceString("ColorTitle_0"),
-			   ControlExample.getResourceString("ColorTitle_1"),
-			   ControlExample.getResourceString("ColorTitle_2"),
-			   ControlExample.getResourceString("ColorTitle_3")};
+				ControlExample.getResourceString("ColorTitle_1"),
+				ControlExample.getResourceString("ColorTitle_2"),
+				ControlExample.getResourceString("ColorTitle_3")};
 
 	/* Size widgets added to the "Size" group */
 	Button packColumnsButton;
@@ -54,34 +54,36 @@ class ColorTab extends Tab {
 	}
 
 	void addTableElements () {
-	    hmap.put(SWT.COLOR_WHITE, "COLOR_WHITE");
-	    hmap.put(SWT.COLOR_BLACK, "COLOR_BLACK");
-	    hmap.put(SWT.COLOR_RED, "COLOR_RED");
-	    hmap.put(SWT.COLOR_DARK_RED, "COLOR_DARK_RED");
-	    hmap.put(SWT.COLOR_GREEN, "COLOR_GREEN");
-	    hmap.put(SWT.COLOR_DARK_GREEN, "COLOR_DARK_GREEN");
-	    hmap.put(SWT.COLOR_YELLOW, "COLOR_YELLOW");
-	    hmap.put(SWT.COLOR_DARK_YELLOW, "COLOR_DARK_YELLOW");
-	    hmap.put(SWT.COLOR_WIDGET_DARK_SHADOW, "COLOR_WIDGET_DARK_SHADOW");
-	    hmap.put(SWT.COLOR_WIDGET_NORMAL_SHADOW, "COLOR_WIDGET_NORMAL_SHADOW");
-	    hmap.put(SWT.COLOR_WIDGET_LIGHT_SHADOW, "COLOR_WIDGET_LIGHT_SHADOW");
-	    hmap.put(SWT.COLOR_WIDGET_HIGHLIGHT_SHADOW, "COLOR_WIDGET_HIGHLIGHT_SHADOW");
-	    hmap.put(SWT.COLOR_WIDGET_FOREGROUND, "COLOR_WIDGET_FOREGROUND");
-	    hmap.put(SWT.COLOR_WIDGET_BACKGROUND, "COLOR_WIDGET_BACKGROUND");
-	    hmap.put(SWT.COLOR_WIDGET_BORDER, "COLOR_WIDGET_BORDER");
-	    hmap.put(SWT.COLOR_LIST_FOREGROUND, "COLOR_LIST_FOREGROUND");
-	    hmap.put(SWT.COLOR_LIST_BACKGROUND, "COLOR_LIST_BACKGROUND");
-	    hmap.put(SWT.COLOR_LIST_SELECTION, "COLOR_LIST_SELECTION");
-	    hmap.put(SWT.COLOR_LIST_SELECTION_TEXT, "COLOR_LIST_SELECTION_TEXT");
-	    hmap.put(SWT.COLOR_INFO_FOREGROUND, "COLOR_INFO_FOREGROUND");
-	    hmap.put(SWT.COLOR_INFO_BACKGROUND, "COLOR_INFO_BACKGROUND");
-	    hmap.put(SWT.COLOR_TITLE_FOREGROUND, "COLOR_TITLE_FOREGROUND");
-	    hmap.put(SWT.COLOR_TITLE_BACKGROUND, "COLOR_TITLE_BACKGROUND");
-	    hmap.put(SWT.COLOR_TITLE_BACKGROUND_GRADIENT, "COLOR_TITLE_BACKGROUND_GRADIENT");
-	    hmap.put(SWT.COLOR_TITLE_INACTIVE_FOREGROUND, "COLOR_TITLE_INACTIVE_FOREGROUND");
-	    hmap.put(SWT.COLOR_TITLE_INACTIVE_BACKGROUND, "COLOR_TITLE_INACTIVE_BACKGROUND");
-	    hmap.put(SWT.COLOR_TITLE_INACTIVE_BACKGROUND_GRADIENT, "COLOR_TITLE_INACTIVE_BACKGROUND_GRADIENT");
-	    hmap.put(SWT.COLOR_LINK_FOREGROUND, "COLOR_LINK_FOREGROUND");
+		hmap.put(SWT.COLOR_WHITE, "COLOR_WHITE");
+		hmap.put(SWT.COLOR_BLACK, "COLOR_BLACK");
+		hmap.put(SWT.COLOR_RED, "COLOR_RED");
+		hmap.put(SWT.COLOR_DARK_RED, "COLOR_DARK_RED");
+		hmap.put(SWT.COLOR_GREEN, "COLOR_GREEN");
+		hmap.put(SWT.COLOR_DARK_GREEN, "COLOR_DARK_GREEN");
+		hmap.put(SWT.COLOR_YELLOW, "COLOR_YELLOW");
+		hmap.put(SWT.COLOR_DARK_YELLOW, "COLOR_DARK_YELLOW");
+		hmap.put(SWT.COLOR_WIDGET_DARK_SHADOW, "COLOR_WIDGET_DARK_SHADOW");
+		hmap.put(SWT.COLOR_WIDGET_NORMAL_SHADOW, "COLOR_WIDGET_NORMAL_SHADOW");
+		hmap.put(SWT.COLOR_WIDGET_LIGHT_SHADOW, "COLOR_WIDGET_LIGHT_SHADOW");
+		hmap.put(SWT.COLOR_WIDGET_HIGHLIGHT_SHADOW, "COLOR_WIDGET_HIGHLIGHT_SHADOW");
+		hmap.put(SWT.COLOR_WIDGET_FOREGROUND, "COLOR_WIDGET_FOREGROUND");
+		hmap.put(SWT.COLOR_WIDGET_BACKGROUND, "COLOR_WIDGET_BACKGROUND");
+		hmap.put(SWT.COLOR_WIDGET_BORDER, "COLOR_WIDGET_BORDER");
+		hmap.put(SWT.COLOR_LIST_FOREGROUND, "COLOR_LIST_FOREGROUND");
+		hmap.put(SWT.COLOR_LIST_BACKGROUND, "COLOR_LIST_BACKGROUND");
+		hmap.put(SWT.COLOR_LIST_SELECTION, "COLOR_LIST_SELECTION");
+		hmap.put(SWT.COLOR_LIST_SELECTION_TEXT, "COLOR_LIST_SELECTION_TEXT");
+		hmap.put(SWT.COLOR_INFO_FOREGROUND, "COLOR_INFO_FOREGROUND");
+		hmap.put(SWT.COLOR_INFO_BACKGROUND, "COLOR_INFO_BACKGROUND");
+		hmap.put(SWT.COLOR_TITLE_FOREGROUND, "COLOR_TITLE_FOREGROUND");
+		hmap.put(SWT.COLOR_TITLE_BACKGROUND, "COLOR_TITLE_BACKGROUND");
+		hmap.put(SWT.COLOR_TITLE_BACKGROUND_GRADIENT, "COLOR_TITLE_BACKGROUND_GRADIENT");
+		hmap.put(SWT.COLOR_TITLE_INACTIVE_FOREGROUND, "COLOR_TITLE_INACTIVE_FOREGROUND");
+		hmap.put(SWT.COLOR_TITLE_INACTIVE_BACKGROUND, "COLOR_TITLE_INACTIVE_BACKGROUND");
+		hmap.put(SWT.COLOR_TITLE_INACTIVE_BACKGROUND_GRADIENT, "COLOR_TITLE_INACTIVE_BACKGROUND_GRADIENT");
+		hmap.put(SWT.COLOR_LINK_FOREGROUND, "COLOR_LINK_FOREGROUND");
+		hmap.put(SWT.COLOR_WIDGET_DISABLED_FOREGROUND, "COLOR_WIDGET_DISABLED_FOREGROUND");
+		hmap.put(SWT.COLOR_TEXT_DISABLED_BACKGROUND, "COLOR_TEXT_DISABLED_BACKGROUND");
 	}
 
 	/**
