@@ -60,9 +60,6 @@ public class SwtTestUtil {
 	public static String[] invalidImageFilenames = new String[] {"corrupt", "corruptBadBitDepth.png"};
 	public static String[] transparentImageFilenames = new String[] {"transparent.png"};
 
-	// specify reparentable platforms
-	public static String[] reparentablePlatforms = new String[] {"win32", "gtk", "cocoa"};
-
 	public static final String testFontName;
 	// isWindows refers to windows platform, i.e. win32 windowing system; see also isWindowsOS
 	public final static boolean isWindows = SWT.getPlatform().startsWith("win32");
@@ -70,7 +67,6 @@ public class SwtTestUtil {
 	public final static boolean isGTK = SWT.getPlatform().equals("gtk");
 	public final static boolean isWindowsOS = System.getProperty("os.name").startsWith("Windows");
 	public final static boolean isLinux = System.getProperty("os.name").equals("Linux");
-	public final static boolean isAIX = System.getProperty("os.name").equals("AIX");
 
 
 	/** Useful if you want some tests not to run on Jenkins with user "genie.platform" */
@@ -104,28 +100,6 @@ public static void assertSWTProblem(String message, int expectedCode, Throwable
 	}
 }
 
-protected static boolean isReparentablePlatform() {
-	String platform = SWT.getPlatform();
-	for (int i=0; i<reparentablePlatforms.length; i++) {
-		if (reparentablePlatforms[i].equals(platform)) return true;
-	}
-	return false;
-}
-
-/*
- * Checks if the GTK version is 2 or 3.
- * Only works if OS.java has been initialized.
- */
-public static boolean isGTK3 () {
-	String gtkVersion = System.getProperty("org.eclipse.swt.internal.gtk.version");
-	if (gtkVersion != null) {
-		return Integer.parseInt(gtkVersion.substring(0,1)) == 3 ? true : false;
-	} else if (isGTK && gtkVersion == null) {
-		throw new IllegalStateException ("OS.java has not yet been initialized");
-	}
-	return false;
-}
-
 public static boolean isBidi() {
 	return true;
 }
