@@ -64,7 +64,7 @@ public void test_getMessage() {
 	assertTrue (
 		"did not include creation string in result",
 		new SWTError(SWT.ERROR_CANNOT_BE_ZERO, "An interesting message").getMessage()
-			.indexOf("An interesting message") >= 0);
+			.contains("An interesting message"));
 }
 
 @Test
@@ -86,7 +86,7 @@ public void test_printStackTrace() {
 	SWTError error = new SWTError();
 	error.printStackTrace();
 	assertTrue(out.size() > 0);
-	assertTrue(new String(out.toByteArray()).indexOf("test_printStackTrace") != -1);
+	assertTrue(new String(out.toByteArray()).contains("test_printStackTrace"));
 
 	// test SWTError with code
 
@@ -95,6 +95,6 @@ public void test_printStackTrace() {
 	error = new SWTError(SWT.ERROR_INVALID_ARGUMENT);
 	error.printStackTrace();
 	assertTrue(out.size() > 0);
-	assertTrue(new String(out.toByteArray()).indexOf("test_printStackTrace") != -1);
+	assertTrue(new String(out.toByteArray()).contains("test_printStackTrace"));
 }
 }
